# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/endpoint/endpoint_components.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import health_check_pb2 as envoy_dot_api_dot_v2_dot_core_dot_health__check__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/endpoint/endpoint_components.proto',
  package='envoy.api.v2.endpoint',
  syntax='proto3',
  serialized_options=b'\n#io.envoyproxy.envoy.api.v2.endpointB\027EndpointComponentsProtoP\001\362\230\376\217\005\032\022\030envoy.config.endpoint.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/envoy/api/v2/endpoint/endpoint_components.proto\x12\x15\x65nvoy.api.v2.endpoint\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a$envoy/api/v2/core/health_check.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xdf\x01\n\x08\x45ndpoint\x12+\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\x12N\n\x13health_check_config\x18\x02 \x01(\x0b\x32\x31.envoy.api.v2.endpoint.Endpoint.HealthCheckConfig\x12\x10\n\x08hostname\x18\x03 \x01(\t\x1a\x44\n\x11HealthCheckConfig\x12\x1d\n\nport_value\x18\x01 \x01(\rB\t\xfa\x42\x06*\x04\x18\xff\xff\x03\x12\x10\n\x08hostname\x18\x02 \x01(\t\"\x9a\x02\n\nLbEndpoint\x12\x33\n\x08\x65ndpoint\x18\x01 \x01(\x0b\x32\x1f.envoy.api.v2.endpoint.EndpointH\x00\x12\x17\n\rendpoint_name\x18\x05 \x01(\tH\x00\x12\x36\n\rhealth_status\x18\x02 \x01(\x0e\x32\x1f.envoy.api.v2.core.HealthStatus\x12-\n\x08metadata\x18\x03 \x01(\x0b\x32\x1b.envoy.api.v2.core.Metadata\x12\x44\n\x15load_balancing_weight\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x42\x11\n\x0fhost_identifier\"\x90\x02\n\x13LocalityLbEndpoints\x12-\n\x08locality\x18\x01 \x01(\x0b\x32\x1b.envoy.api.v2.core.Locality\x12\x37\n\x0clb_endpoints\x18\x02 \x03(\x0b\x32!.envoy.api.v2.endpoint.LbEndpoint\x12\x44\n\x15load_balancing_weight\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12\x1a\n\x08priority\x18\x05 \x01(\rB\x08\xfa\x42\x05*\x03\x18\x80\x01\x12/\n\tproximity\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueBh\n#io.envoyproxy.envoy.api.v2.endpointB\x17\x45ndpointComponentsProtoP\x01\xf2\x98\xfe\x8f\x05\x1a\x12\x18\x65nvoy.config.endpoint.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_address__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_health__check__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_ENDPOINT_HEALTHCHECKCONFIG = _descriptor.Descriptor(
  name='HealthCheckConfig',
  full_name='envoy.api.v2.endpoint.Endpoint.HealthCheckConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_value', full_name='envoy.api.v2.endpoint.Endpoint.HealthCheckConfig.port_value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006*\004\030\377\377\003', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='envoy.api.v2.endpoint.Endpoint.HealthCheckConfig.hostname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=451,
  serialized_end=519,
)

_ENDPOINT = _descriptor.Descriptor(
  name='Endpoint',
  full_name='envoy.api.v2.endpoint.Endpoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='envoy.api.v2.endpoint.Endpoint.address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health_check_config', full_name='envoy.api.v2.endpoint.Endpoint.health_check_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='envoy.api.v2.endpoint.Endpoint.hostname', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ENDPOINT_HEALTHCHECKCONFIG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=296,
  serialized_end=519,
)


_LBENDPOINT = _descriptor.Descriptor(
  name='LbEndpoint',
  full_name='envoy.api.v2.endpoint.LbEndpoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='envoy.api.v2.endpoint.LbEndpoint.endpoint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoint_name', full_name='envoy.api.v2.endpoint.LbEndpoint.endpoint_name', index=1,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health_status', full_name='envoy.api.v2.endpoint.LbEndpoint.health_status', index=2,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='envoy.api.v2.endpoint.LbEndpoint.metadata', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_balancing_weight', full_name='envoy.api.v2.endpoint.LbEndpoint.load_balancing_weight', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='host_identifier', full_name='envoy.api.v2.endpoint.LbEndpoint.host_identifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=522,
  serialized_end=804,
)


_LOCALITYLBENDPOINTS = _descriptor.Descriptor(
  name='LocalityLbEndpoints',
  full_name='envoy.api.v2.endpoint.LocalityLbEndpoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locality', full_name='envoy.api.v2.endpoint.LocalityLbEndpoints.locality', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lb_endpoints', full_name='envoy.api.v2.endpoint.LocalityLbEndpoints.lb_endpoints', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_balancing_weight', full_name='envoy.api.v2.endpoint.LocalityLbEndpoints.load_balancing_weight', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='envoy.api.v2.endpoint.LocalityLbEndpoints.priority', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005*\003\030\200\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proximity', full_name='envoy.api.v2.endpoint.LocalityLbEndpoints.proximity', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=807,
  serialized_end=1079,
)

_ENDPOINT_HEALTHCHECKCONFIG.containing_type = _ENDPOINT
_ENDPOINT.fields_by_name['address'].message_type = envoy_dot_api_dot_v2_dot_core_dot_address__pb2._ADDRESS
_ENDPOINT.fields_by_name['health_check_config'].message_type = _ENDPOINT_HEALTHCHECKCONFIG
_LBENDPOINT.fields_by_name['endpoint'].message_type = _ENDPOINT
_LBENDPOINT.fields_by_name['health_status'].enum_type = envoy_dot_api_dot_v2_dot_core_dot_health__check__pb2._HEALTHSTATUS
_LBENDPOINT.fields_by_name['metadata'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._METADATA
_LBENDPOINT.fields_by_name['load_balancing_weight'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_LBENDPOINT.oneofs_by_name['host_identifier'].fields.append(
  _LBENDPOINT.fields_by_name['endpoint'])
_LBENDPOINT.fields_by_name['endpoint'].containing_oneof = _LBENDPOINT.oneofs_by_name['host_identifier']
_LBENDPOINT.oneofs_by_name['host_identifier'].fields.append(
  _LBENDPOINT.fields_by_name['endpoint_name'])
_LBENDPOINT.fields_by_name['endpoint_name'].containing_oneof = _LBENDPOINT.oneofs_by_name['host_identifier']
_LOCALITYLBENDPOINTS.fields_by_name['locality'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._LOCALITY
_LOCALITYLBENDPOINTS.fields_by_name['lb_endpoints'].message_type = _LBENDPOINT
_LOCALITYLBENDPOINTS.fields_by_name['load_balancing_weight'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_LOCALITYLBENDPOINTS.fields_by_name['proximity'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
DESCRIPTOR.message_types_by_name['Endpoint'] = _ENDPOINT
DESCRIPTOR.message_types_by_name['LbEndpoint'] = _LBENDPOINT
DESCRIPTOR.message_types_by_name['LocalityLbEndpoints'] = _LOCALITYLBENDPOINTS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Endpoint = _reflection.GeneratedProtocolMessageType('Endpoint', (_message.Message,), {

  'HealthCheckConfig' : _reflection.GeneratedProtocolMessageType('HealthCheckConfig', (_message.Message,), {
    'DESCRIPTOR' : _ENDPOINT_HEALTHCHECKCONFIG,
    '__module__' : 'envoy.api.v2.endpoint.endpoint_components_pb2'
    # @@protoc_insertion_point(class_scope:envoy.api.v2.endpoint.Endpoint.HealthCheckConfig)
    })
  ,
  'DESCRIPTOR' : _ENDPOINT,
  '__module__' : 'envoy.api.v2.endpoint.endpoint_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.endpoint.Endpoint)
  })
_sym_db.RegisterMessage(Endpoint)
_sym_db.RegisterMessage(Endpoint.HealthCheckConfig)

LbEndpoint = _reflection.GeneratedProtocolMessageType('LbEndpoint', (_message.Message,), {
  'DESCRIPTOR' : _LBENDPOINT,
  '__module__' : 'envoy.api.v2.endpoint.endpoint_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.endpoint.LbEndpoint)
  })
_sym_db.RegisterMessage(LbEndpoint)

LocalityLbEndpoints = _reflection.GeneratedProtocolMessageType('LocalityLbEndpoints', (_message.Message,), {
  'DESCRIPTOR' : _LOCALITYLBENDPOINTS,
  '__module__' : 'envoy.api.v2.endpoint.endpoint_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.endpoint.LocalityLbEndpoints)
  })
_sym_db.RegisterMessage(LocalityLbEndpoints)


DESCRIPTOR._options = None
_ENDPOINT_HEALTHCHECKCONFIG.fields_by_name['port_value']._options = None
_LBENDPOINT.fields_by_name['load_balancing_weight']._options = None
_LOCALITYLBENDPOINTS.fields_by_name['load_balancing_weight']._options = None
_LOCALITYLBENDPOINTS.fields_by_name['priority']._options = None
# @@protoc_insertion_point(module_scope)
