# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/accesslog/v3/als.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.data.accesslog.v3 import accesslog_pb2 as envoy_dot_data_dot_accesslog_dot_v3_dot_accesslog__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/accesslog/v3/als.proto',
  package='envoy.service.accesslog.v3',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.service.accesslog.v3B\010AlsProtoP\001\210\001\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$envoy/service/accesslog/v3/als.proto\x12\x1a\x65nvoy.service.accesslog.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\'envoy/data/accesslog/v3/accesslog.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"V\n\x18StreamAccessLogsResponse::\x9a\xc5\x88\x1e\x35\n3envoy.service.accesslog.v2.StreamAccessLogsResponse\"\xff\x06\n\x17StreamAccessLogsMessage\x12R\n\nidentifier\x18\x01 \x01(\x0b\x32>.envoy.service.accesslog.v3.StreamAccessLogsMessage.Identifier\x12]\n\thttp_logs\x18\x02 \x01(\x0b\x32H.envoy.service.accesslog.v3.StreamAccessLogsMessage.HTTPAccessLogEntriesH\x00\x12[\n\x08tcp_logs\x18\x03 \x01(\x0b\x32G.envoy.service.accesslog.v3.StreamAccessLogsMessage.TCPAccessLogEntriesH\x00\x1a\xa1\x01\n\nIdentifier\x12\x32\n\x04node\x18\x01 \x01(\x0b\x32\x1a.envoy.config.core.v3.NodeB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x19\n\x08log_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01:D\x9a\xc5\x88\x1e?\n=envoy.service.accesslog.v2.StreamAccessLogsMessage.Identifier\x1a\xb0\x01\n\x14HTTPAccessLogEntries\x12H\n\tlog_entry\x18\x01 \x03(\x0b\x32+.envoy.data.accesslog.v3.HTTPAccessLogEntryB\x08\xfa\x42\x05\x92\x01\x02\x08\x01:N\x9a\xc5\x88\x1eI\nGenvoy.service.accesslog.v2.StreamAccessLogsMessage.HTTPAccessLogEntries\x1a\xad\x01\n\x13TCPAccessLogEntries\x12G\n\tlog_entry\x18\x01 \x03(\x0b\x32*.envoy.data.accesslog.v3.TCPAccessLogEntryB\x08\xfa\x42\x05\x92\x01\x02\x08\x01:M\x9a\xc5\x88\x1eH\nFenvoy.service.accesslog.v2.StreamAccessLogsMessage.TCPAccessLogEntries:9\x9a\xc5\x88\x1e\x34\n2envoy.service.accesslog.v2.StreamAccessLogsMessageB\x12\n\x0blog_entries\x12\x03\xf8\x42\x01\x32\x96\x01\n\x10\x41\x63\x63\x65ssLogService\x12\x81\x01\n\x10StreamAccessLogs\x12\x33.envoy.service.accesslog.v3.StreamAccessLogsMessage\x1a\x34.envoy.service.accesslog.v3.StreamAccessLogsResponse\"\x00(\x01\x42\x41\n(io.envoyproxy.envoy.service.accesslog.v3B\x08\x41lsProtoP\x01\x88\x01\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,envoy_dot_data_dot_accesslog_dot_v3_dot_accesslog__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_STREAMACCESSLOGSRESPONSE = _descriptor.Descriptor(
  name='StreamAccessLogsResponse',
  full_name='envoy.service.accesslog.v3.StreamAccessLogsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0365\n3envoy.service.accesslog.v2.StreamAccessLogsResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=319,
)


_STREAMACCESSLOGSMESSAGE_IDENTIFIER = _descriptor.Descriptor(
  name='Identifier',
  full_name='envoy.service.accesslog.v3.StreamAccessLogsMessage.Identifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='envoy.service.accesslog.v3.StreamAccessLogsMessage.Identifier.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_name', full_name='envoy.service.accesslog.v3.StreamAccessLogsMessage.Identifier.log_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036?\n=envoy.service.accesslog.v2.StreamAccessLogsMessage.Identifier',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=622,
  serialized_end=783,
)

_STREAMACCESSLOGSMESSAGE_HTTPACCESSLOGENTRIES = _descriptor.Descriptor(
  name='HTTPAccessLogEntries',
  full_name='envoy.service.accesslog.v3.StreamAccessLogsMessage.HTTPAccessLogEntries',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_entry', full_name='envoy.service.accesslog.v3.StreamAccessLogsMessage.HTTPAccessLogEntries.log_entry', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036I\nGenvoy.service.accesslog.v2.StreamAccessLogsMessage.HTTPAccessLogEntries',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=786,
  serialized_end=962,
)

_STREAMACCESSLOGSMESSAGE_TCPACCESSLOGENTRIES = _descriptor.Descriptor(
  name='TCPAccessLogEntries',
  full_name='envoy.service.accesslog.v3.StreamAccessLogsMessage.TCPAccessLogEntries',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_entry', full_name='envoy.service.accesslog.v3.StreamAccessLogsMessage.TCPAccessLogEntries.log_entry', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036H\nFenvoy.service.accesslog.v2.StreamAccessLogsMessage.TCPAccessLogEntries',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=965,
  serialized_end=1138,
)

_STREAMACCESSLOGSMESSAGE = _descriptor.Descriptor(
  name='StreamAccessLogsMessage',
  full_name='envoy.service.accesslog.v3.StreamAccessLogsMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='envoy.service.accesslog.v3.StreamAccessLogsMessage.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_logs', full_name='envoy.service.accesslog.v3.StreamAccessLogsMessage.http_logs', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tcp_logs', full_name='envoy.service.accesslog.v3.StreamAccessLogsMessage.tcp_logs', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STREAMACCESSLOGSMESSAGE_IDENTIFIER, _STREAMACCESSLOGSMESSAGE_HTTPACCESSLOGENTRIES, _STREAMACCESSLOGSMESSAGE_TCPACCESSLOGENTRIES, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0364\n2envoy.service.accesslog.v2.StreamAccessLogsMessage',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='log_entries', full_name='envoy.service.accesslog.v3.StreamAccessLogsMessage.log_entries',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=322,
  serialized_end=1217,
)

_STREAMACCESSLOGSMESSAGE_IDENTIFIER.fields_by_name['node'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._NODE
_STREAMACCESSLOGSMESSAGE_IDENTIFIER.containing_type = _STREAMACCESSLOGSMESSAGE
_STREAMACCESSLOGSMESSAGE_HTTPACCESSLOGENTRIES.fields_by_name['log_entry'].message_type = envoy_dot_data_dot_accesslog_dot_v3_dot_accesslog__pb2._HTTPACCESSLOGENTRY
_STREAMACCESSLOGSMESSAGE_HTTPACCESSLOGENTRIES.containing_type = _STREAMACCESSLOGSMESSAGE
_STREAMACCESSLOGSMESSAGE_TCPACCESSLOGENTRIES.fields_by_name['log_entry'].message_type = envoy_dot_data_dot_accesslog_dot_v3_dot_accesslog__pb2._TCPACCESSLOGENTRY
_STREAMACCESSLOGSMESSAGE_TCPACCESSLOGENTRIES.containing_type = _STREAMACCESSLOGSMESSAGE
_STREAMACCESSLOGSMESSAGE.fields_by_name['identifier'].message_type = _STREAMACCESSLOGSMESSAGE_IDENTIFIER
_STREAMACCESSLOGSMESSAGE.fields_by_name['http_logs'].message_type = _STREAMACCESSLOGSMESSAGE_HTTPACCESSLOGENTRIES
_STREAMACCESSLOGSMESSAGE.fields_by_name['tcp_logs'].message_type = _STREAMACCESSLOGSMESSAGE_TCPACCESSLOGENTRIES
_STREAMACCESSLOGSMESSAGE.oneofs_by_name['log_entries'].fields.append(
  _STREAMACCESSLOGSMESSAGE.fields_by_name['http_logs'])
_STREAMACCESSLOGSMESSAGE.fields_by_name['http_logs'].containing_oneof = _STREAMACCESSLOGSMESSAGE.oneofs_by_name['log_entries']
_STREAMACCESSLOGSMESSAGE.oneofs_by_name['log_entries'].fields.append(
  _STREAMACCESSLOGSMESSAGE.fields_by_name['tcp_logs'])
_STREAMACCESSLOGSMESSAGE.fields_by_name['tcp_logs'].containing_oneof = _STREAMACCESSLOGSMESSAGE.oneofs_by_name['log_entries']
DESCRIPTOR.message_types_by_name['StreamAccessLogsResponse'] = _STREAMACCESSLOGSRESPONSE
DESCRIPTOR.message_types_by_name['StreamAccessLogsMessage'] = _STREAMACCESSLOGSMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamAccessLogsResponse = _reflection.GeneratedProtocolMessageType('StreamAccessLogsResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMACCESSLOGSRESPONSE,
  '__module__' : 'envoy.service.accesslog.v3.als_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.accesslog.v3.StreamAccessLogsResponse)
  })
_sym_db.RegisterMessage(StreamAccessLogsResponse)

StreamAccessLogsMessage = _reflection.GeneratedProtocolMessageType('StreamAccessLogsMessage', (_message.Message,), {

  'Identifier' : _reflection.GeneratedProtocolMessageType('Identifier', (_message.Message,), {
    'DESCRIPTOR' : _STREAMACCESSLOGSMESSAGE_IDENTIFIER,
    '__module__' : 'envoy.service.accesslog.v3.als_pb2'
    # @@protoc_insertion_point(class_scope:envoy.service.accesslog.v3.StreamAccessLogsMessage.Identifier)
    })
  ,

  'HTTPAccessLogEntries' : _reflection.GeneratedProtocolMessageType('HTTPAccessLogEntries', (_message.Message,), {
    'DESCRIPTOR' : _STREAMACCESSLOGSMESSAGE_HTTPACCESSLOGENTRIES,
    '__module__' : 'envoy.service.accesslog.v3.als_pb2'
    # @@protoc_insertion_point(class_scope:envoy.service.accesslog.v3.StreamAccessLogsMessage.HTTPAccessLogEntries)
    })
  ,

  'TCPAccessLogEntries' : _reflection.GeneratedProtocolMessageType('TCPAccessLogEntries', (_message.Message,), {
    'DESCRIPTOR' : _STREAMACCESSLOGSMESSAGE_TCPACCESSLOGENTRIES,
    '__module__' : 'envoy.service.accesslog.v3.als_pb2'
    # @@protoc_insertion_point(class_scope:envoy.service.accesslog.v3.StreamAccessLogsMessage.TCPAccessLogEntries)
    })
  ,
  'DESCRIPTOR' : _STREAMACCESSLOGSMESSAGE,
  '__module__' : 'envoy.service.accesslog.v3.als_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.accesslog.v3.StreamAccessLogsMessage)
  })
_sym_db.RegisterMessage(StreamAccessLogsMessage)
_sym_db.RegisterMessage(StreamAccessLogsMessage.Identifier)
_sym_db.RegisterMessage(StreamAccessLogsMessage.HTTPAccessLogEntries)
_sym_db.RegisterMessage(StreamAccessLogsMessage.TCPAccessLogEntries)


DESCRIPTOR._options = None
_STREAMACCESSLOGSRESPONSE._options = None
_STREAMACCESSLOGSMESSAGE_IDENTIFIER.fields_by_name['node']._options = None
_STREAMACCESSLOGSMESSAGE_IDENTIFIER.fields_by_name['log_name']._options = None
_STREAMACCESSLOGSMESSAGE_IDENTIFIER._options = None
_STREAMACCESSLOGSMESSAGE_HTTPACCESSLOGENTRIES.fields_by_name['log_entry']._options = None
_STREAMACCESSLOGSMESSAGE_HTTPACCESSLOGENTRIES._options = None
_STREAMACCESSLOGSMESSAGE_TCPACCESSLOGENTRIES.fields_by_name['log_entry']._options = None
_STREAMACCESSLOGSMESSAGE_TCPACCESSLOGENTRIES._options = None
_STREAMACCESSLOGSMESSAGE.oneofs_by_name['log_entries']._options = None
_STREAMACCESSLOGSMESSAGE._options = None

_ACCESSLOGSERVICE = _descriptor.ServiceDescriptor(
  name='AccessLogService',
  full_name='envoy.service.accesslog.v3.AccessLogService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1220,
  serialized_end=1370,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamAccessLogs',
    full_name='envoy.service.accesslog.v3.AccessLogService.StreamAccessLogs',
    index=0,
    containing_service=None,
    input_type=_STREAMACCESSLOGSMESSAGE,
    output_type=_STREAMACCESSLOGSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ACCESSLOGSERVICE)

DESCRIPTOR.services_by_name['AccessLogService'] = _ACCESSLOGSERVICE

# @@protoc_insertion_point(module_scope)
