# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/watchdog/profile_action/v3alpha/profile_action.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/watchdog/profile_action/v3alpha/profile_action.proto',
  package='envoy.extensions.watchdog.profile_action.v3alpha',
  syntax='proto3',
  serialized_options=b'\n>io.envoyproxy.envoy.extensions.watchdog.profile_action.v3alphaB\022ProfileActionProtoP\001\272\200\310\321\006\002\010\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nEenvoy/extensions/watchdog/profile_action/v3alpha/profile_action.proto\x12\x30\x65nvoy.extensions.watchdog.profile_action.v3alpha\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x7f\n\x13ProfileActionConfig\x12\x33\n\x10profile_duration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1d\n\x0cprofile_path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x14\n\x0cmax_profiles\x18\x03 \x01(\x04\x42\x66\n>io.envoyproxy.envoy.extensions.watchdog.profile_action.v3alphaB\x12ProfileActionProtoP\x01\xba\x80\xc8\xd1\x06\x02\x08\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_PROFILEACTIONCONFIG = _descriptor.Descriptor(
  name='ProfileActionConfig',
  full_name='envoy.extensions.watchdog.profile_action.v3alpha.ProfileActionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='profile_duration', full_name='envoy.extensions.watchdog.profile_action.v3alpha.ProfileActionConfig.profile_duration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profile_path', full_name='envoy.extensions.watchdog.profile_action.v3alpha.ProfileActionConfig.profile_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_profiles', full_name='envoy.extensions.watchdog.profile_action.v3alpha.ProfileActionConfig.max_profiles', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=211,
  serialized_end=338,
)

_PROFILEACTIONCONFIG.fields_by_name['profile_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['ProfileActionConfig'] = _PROFILEACTIONCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProfileActionConfig = _reflection.GeneratedProtocolMessageType('ProfileActionConfig', (_message.Message,), {
  'DESCRIPTOR' : _PROFILEACTIONCONFIG,
  '__module__' : 'envoy.extensions.watchdog.profile_action.v3alpha.profile_action_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.watchdog.profile_action.v3alpha.ProfileActionConfig)
  })
_sym_db.RegisterMessage(ProfileActionConfig)


DESCRIPTOR._options = None
_PROFILEACTIONCONFIG.fields_by_name['profile_path']._options = None
# @@protoc_insertion_point(module_scope)
