# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/listener/v2/api_listener.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/listener/v2/api_listener.proto',
  package='envoy.config.listener.v2',
  syntax='proto3',
  serialized_options=b'\n&io.envoyproxy.envoy.config.listener.v2B\020ApiListenerProtoP\001\362\230\376\217\005\032\022\030envoy.config.listener.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+envoy/config/listener/v2/api_listener.proto\x12\x18\x65nvoy.config.listener.v2\x1a\x19google/protobuf/any.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"9\n\x0b\x41piListener\x12*\n\x0c\x61pi_listener\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyBd\n&io.envoyproxy.envoy.config.listener.v2B\x10\x41piListenerProtoP\x01\xf2\x98\xfe\x8f\x05\x1a\x12\x18\x65nvoy.config.listener.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_APILISTENER = _descriptor.Descriptor(
  name='ApiListener',
  full_name='envoy.config.listener.v2.ApiListener',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='api_listener', full_name='envoy.config.listener.v2.ApiListener.api_listener', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=163,
  serialized_end=220,
)

_APILISTENER.fields_by_name['api_listener'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['ApiListener'] = _APILISTENER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ApiListener = _reflection.GeneratedProtocolMessageType('ApiListener', (_message.Message,), {
  'DESCRIPTOR' : _APILISTENER,
  '__module__' : 'envoy.config.listener.v2.api_listener_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.listener.v2.ApiListener)
  })
_sym_db.RegisterMessage(ApiListener)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
