# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/grpc_stats/v2alpha/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import grpc_method_list_pb2 as envoy_dot_api_dot_v2_dot_core_dot_grpc__method__list__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/http/grpc_stats/v2alpha/config.proto',
  package='envoy.config.filter.http.grpc_stats.v2alpha',
  syntax='proto3',
  serialized_options=b'\n9io.envoyproxy.envoy.config.filter.http.grpc_stats.v2alphaB\013ConfigProtoP\001\362\230\376\217\005-\022+envoy.extensions.filters.http.grpc_stats.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n8envoy/config/filter/http/grpc_stats/v2alpha/config.proto\x12+envoy.config.filter.http.grpc_stats.v2alpha\x1a(envoy/api/v2/core/grpc_method_list.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\xd3\x01\n\x0c\x46ilterConfig\x12\x19\n\x11\x65mit_filter_state\x18\x01 \x01(\x08\x12N\n!individual_method_stats_allowlist\x18\x02 \x01(\x0b\x32!.envoy.api.v2.core.GrpcMethodListH\x00\x12;\n\x15stats_for_all_methods\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x00\x42\x1b\n\x19per_method_stat_specifier\"M\n\x0c\x46ilterObject\x12\x1d\n\x15request_message_count\x18\x01 \x01(\x04\x12\x1e\n\x16response_message_count\x18\x02 \x01(\x04\x42\x85\x01\n9io.envoyproxy.envoy.config.filter.http.grpc_stats.v2alphaB\x0b\x43onfigProtoP\x01\xf2\x98\xfe\x8f\x05-\x12+envoy.extensions.filters.http.grpc_stats.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_grpc__method__list__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_FILTERCONFIG = _descriptor.Descriptor(
  name='FilterConfig',
  full_name='envoy.config.filter.http.grpc_stats.v2alpha.FilterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='emit_filter_state', full_name='envoy.config.filter.http.grpc_stats.v2alpha.FilterConfig.emit_filter_state', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='individual_method_stats_allowlist', full_name='envoy.config.filter.http.grpc_stats.v2alpha.FilterConfig.individual_method_stats_allowlist', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats_for_all_methods', full_name='envoy.config.filter.http.grpc_stats.v2alpha.FilterConfig.stats_for_all_methods', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='per_method_stat_specifier', full_name='envoy.config.filter.http.grpc_stats.v2alpha.FilterConfig.per_method_stat_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=243,
  serialized_end=454,
)


_FILTEROBJECT = _descriptor.Descriptor(
  name='FilterObject',
  full_name='envoy.config.filter.http.grpc_stats.v2alpha.FilterObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_message_count', full_name='envoy.config.filter.http.grpc_stats.v2alpha.FilterObject.request_message_count', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_message_count', full_name='envoy.config.filter.http.grpc_stats.v2alpha.FilterObject.response_message_count', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=456,
  serialized_end=533,
)

_FILTERCONFIG.fields_by_name['individual_method_stats_allowlist'].message_type = envoy_dot_api_dot_v2_dot_core_dot_grpc__method__list__pb2._GRPCMETHODLIST
_FILTERCONFIG.fields_by_name['stats_for_all_methods'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_FILTERCONFIG.oneofs_by_name['per_method_stat_specifier'].fields.append(
  _FILTERCONFIG.fields_by_name['individual_method_stats_allowlist'])
_FILTERCONFIG.fields_by_name['individual_method_stats_allowlist'].containing_oneof = _FILTERCONFIG.oneofs_by_name['per_method_stat_specifier']
_FILTERCONFIG.oneofs_by_name['per_method_stat_specifier'].fields.append(
  _FILTERCONFIG.fields_by_name['stats_for_all_methods'])
_FILTERCONFIG.fields_by_name['stats_for_all_methods'].containing_oneof = _FILTERCONFIG.oneofs_by_name['per_method_stat_specifier']
DESCRIPTOR.message_types_by_name['FilterConfig'] = _FILTERCONFIG
DESCRIPTOR.message_types_by_name['FilterObject'] = _FILTEROBJECT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FilterConfig = _reflection.GeneratedProtocolMessageType('FilterConfig', (_message.Message,), {
  'DESCRIPTOR' : _FILTERCONFIG,
  '__module__' : 'envoy.config.filter.http.grpc_stats.v2alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.grpc_stats.v2alpha.FilterConfig)
  })
_sym_db.RegisterMessage(FilterConfig)

FilterObject = _reflection.GeneratedProtocolMessageType('FilterObject', (_message.Message,), {
  'DESCRIPTOR' : _FILTEROBJECT,
  '__module__' : 'envoy.config.filter.http.grpc_stats.v2alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.grpc_stats.v2alpha.FilterObject)
  })
_sym_db.RegisterMessage(FilterObject)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
