# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/common/matcher/v4alpha/matcher.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import extension_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2
from envoy.config.route.v4alpha import route_components_pb2 as envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2
from envoy.type.matcher.v4alpha import string_pb2 as envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/common/matcher/v4alpha/matcher.proto',
  package='envoy.config.common.matcher.v4alpha',
  syntax='proto3',
  serialized_options=b'\n1io.envoyproxy.envoy.config.common.matcher.v4alphaB\014MatcherProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1envoy/config/common/matcher/v4alpha/matcher.proto\x12#envoy.config.common.matcher.v4alpha\x1a)envoy/config/core/v4alpha/extension.proto\x1a\x31\x65nvoy/config/route/v4alpha/route_components.proto\x1a\'envoy/type/matcher/v4alpha/string.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xcc\x14\n\x07Matcher\x12P\n\x0cmatcher_list\x18\x01 \x01(\x0b\x32\x38.envoy.config.common.matcher.v4alpha.Matcher.MatcherListH\x00\x12P\n\x0cmatcher_tree\x18\x02 \x01(\x0b\x32\x38.envoy.config.common.matcher.v4alpha.Matcher.MatcherTreeH\x00\x12I\n\x0bon_no_match\x18\x03 \x01(\x0b\x32\x34.envoy.config.common.matcher.v4alpha.Matcher.OnMatch\x1a\xd5\x01\n\x07OnMatch\x12?\n\x07matcher\x18\x01 \x01(\x0b\x32,.envoy.config.common.matcher.v4alpha.MatcherH\x00\x12\x41\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32/.envoy.config.core.v4alpha.TypedExtensionConfigH\x00:5\x9a\xc5\x88\x1e\x30\n.envoy.config.common.matcher.v3.Matcher.OnMatchB\x0f\n\x08on_match\x12\x03\xf8\x42\x01\x1a\xf2\n\n\x0bMatcherList\x12\x61\n\x08matchers\x18\x01 \x03(\x0b\x32\x45.envoy.config.common.matcher.v4alpha.Matcher.MatcherList.FieldMatcherB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\xb8\x07\n\tPredicate\x12n\n\x10single_predicate\x18\x01 \x01(\x0b\x32R.envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.SinglePredicateH\x00\x12\x66\n\nor_matcher\x18\x02 \x01(\x0b\x32P.envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.PredicateListH\x00\x12g\n\x0b\x61nd_matcher\x18\x03 \x01(\x0b\x32P.envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.PredicateListH\x00\x1a\xcb\x02\n\x0fSinglePredicate\x12H\n\x05input\x18\x01 \x01(\x0b\x32/.envoy.config.core.v4alpha.TypedExtensionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12@\n\x0bvalue_match\x18\x02 \x01(\x0b\x32).envoy.type.matcher.v4alpha.StringMatcherH\x00\x12G\n\x0c\x63ustom_match\x18\x03 \x01(\x0b\x32/.envoy.config.core.v4alpha.TypedExtensionConfigH\x00:S\x9a\xc5\x88\x1eN\nLenvoy.config.common.matcher.v3.Matcher.MatcherList.Predicate.SinglePredicateB\x0e\n\x07matcher\x12\x03\xf8\x42\x01\x1a\xc3\x01\n\rPredicateList\x12_\n\tpredicate\x18\x01 \x03(\x0b\x32\x42.envoy.config.common.matcher.v4alpha.Matcher.MatcherList.PredicateB\x08\xfa\x42\x05\x92\x01\x02\x08\x02:Q\x9a\xc5\x88\x1eL\nJenvoy.config.common.matcher.v3.Matcher.MatcherList.Predicate.PredicateList:C\x9a\xc5\x88\x1e>\n<envoy.config.common.matcher.v3.Matcher.MatcherList.PredicateB\x11\n\nmatch_type\x12\x03\xf8\x42\x01\x1a\x89\x02\n\x0c\x46ieldMatcher\x12_\n\tpredicate\x18\x01 \x01(\x0b\x32\x42.envoy.config.common.matcher.v4alpha.Matcher.MatcherList.PredicateB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12P\n\x08on_match\x18\x02 \x01(\x0b\x32\x34.envoy.config.common.matcher.v4alpha.Matcher.OnMatchB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:F\x9a\xc5\x88\x1e\x41\n?envoy.config.common.matcher.v3.Matcher.MatcherList.FieldMatcher:9\x9a\xc5\x88\x1e\x34\n2envoy.config.common.matcher.v3.Matcher.MatcherList\x1a\xc0\x05\n\x0bMatcherTree\x12H\n\x05input\x18\x01 \x01(\x0b\x32/.envoy.config.core.v4alpha.TypedExtensionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\\\n\x0f\x65xact_match_map\x18\x02 \x01(\x0b\x32\x41.envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.MatchMapH\x00\x12]\n\x10prefix_match_map\x18\x03 \x01(\x0b\x32\x41.envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.MatchMapH\x00\x12G\n\x0c\x63ustom_match\x18\x04 \x01(\x0b\x32/.envoy.config.core.v4alpha.TypedExtensionConfigH\x00\x1a\x93\x02\n\x08MatchMap\x12\x61\n\x03map\x18\x01 \x03(\x0b\x32J.envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.MatchMap.MapEntryB\x08\xfa\x42\x05\x9a\x01\x02\x08\x01\x1a`\n\x08MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x43\n\x05value\x18\x02 \x01(\x0b\x32\x34.envoy.config.common.matcher.v4alpha.Matcher.OnMatch:\x02\x38\x01:B\x9a\xc5\x88\x1e=\n;envoy.config.common.matcher.v3.Matcher.MatcherTree.MatchMap:9\x9a\xc5\x88\x1e\x34\n2envoy.config.common.matcher.v3.Matcher.MatcherTreeB\x10\n\ttree_type\x12\x03\xf8\x42\x01:-\x9a\xc5\x88\x1e(\n&envoy.config.common.matcher.v3.MatcherB\x13\n\x0cmatcher_type\x12\x03\xf8\x42\x01\"\xbf\x08\n\x0eMatchPredicate\x12P\n\x08or_match\x18\x01 \x01(\x0b\x32<.envoy.config.common.matcher.v4alpha.MatchPredicate.MatchSetH\x00\x12Q\n\tand_match\x18\x02 \x01(\x0b\x32<.envoy.config.common.matcher.v4alpha.MatchPredicate.MatchSetH\x00\x12H\n\tnot_match\x18\x03 \x01(\x0b\x32\x33.envoy.config.common.matcher.v4alpha.MatchPredicateH\x00\x12\x1c\n\tany_match\x18\x04 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12[\n\x1ahttp_request_headers_match\x18\x05 \x01(\x0b\x32\x35.envoy.config.common.matcher.v4alpha.HttpHeadersMatchH\x00\x12\\\n\x1bhttp_request_trailers_match\x18\x06 \x01(\x0b\x32\x35.envoy.config.common.matcher.v4alpha.HttpHeadersMatchH\x00\x12\\\n\x1bhttp_response_headers_match\x18\x07 \x01(\x0b\x32\x35.envoy.config.common.matcher.v4alpha.HttpHeadersMatchH\x00\x12]\n\x1chttp_response_trailers_match\x18\x08 \x01(\x0b\x32\x35.envoy.config.common.matcher.v4alpha.HttpHeadersMatchH\x00\x12\x64\n\x1fhttp_request_generic_body_match\x18\t \x01(\x0b\x32\x39.envoy.config.common.matcher.v4alpha.HttpGenericBodyMatchH\x00\x12\x65\n http_response_generic_body_match\x18\n \x01(\x0b\x32\x39.envoy.config.common.matcher.v4alpha.HttpGenericBodyMatchH\x00\x1a\x97\x01\n\x08MatchSet\x12L\n\x05rules\x18\x01 \x03(\x0b\x32\x33.envoy.config.common.matcher.v4alpha.MatchPredicateB\x08\xfa\x42\x05\x92\x01\x02\x08\x02:=\x9a\xc5\x88\x1e\x38\n6envoy.config.common.matcher.v3.MatchPredicate.MatchSet:4\x9a\xc5\x88\x1e/\n-envoy.config.common.matcher.v3.MatchPredicateB\x0b\n\x04rule\x12\x03\xf8\x42\x01\"\x86\x01\n\x10HttpHeadersMatch\x12:\n\x07headers\x18\x01 \x03(\x0b\x32).envoy.config.route.v4alpha.HeaderMatcher:6\x9a\xc5\x88\x1e\x31\n/envoy.config.common.matcher.v3.HttpHeadersMatch\"\x80\x03\n\x14HttpGenericBodyMatch\x12\x13\n\x0b\x62ytes_limit\x18\x01 \x01(\r\x12\x66\n\x08patterns\x18\x02 \x03(\x0b\x32J.envoy.config.common.matcher.v4alpha.HttpGenericBodyMatch.GenericTextMatchB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\xae\x01\n\x10GenericTextMatch\x12\x1f\n\x0cstring_match\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x1f\n\x0c\x62inary_match\x18\x02 \x01(\x0c\x42\x07\xfa\x42\x04z\x02\x10\x01H\x00:K\x9a\xc5\x88\x1e\x46\nDenvoy.config.common.matcher.v3.HttpGenericBodyMatch.GenericTextMatchB\x0b\n\x04rule\x12\x03\xf8\x42\x01::\x9a\xc5\x88\x1e\x35\n3envoy.config.common.matcher.v3.HttpGenericBodyMatchBK\n1io.envoyproxy.envoy.config.common.matcher.v4alphaB\x0cMatcherProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2.DESCRIPTOR,envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_MATCHER_ONMATCH = _descriptor.Descriptor(
  name='OnMatch',
  full_name='envoy.config.common.matcher.v4alpha.Matcher.OnMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='matcher', full_name='envoy.config.common.matcher.v4alpha.Matcher.OnMatch.matcher', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='envoy.config.common.matcher.v4alpha.Matcher.OnMatch.action', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0360\n.envoy.config.common.matcher.v3.Matcher.OnMatch',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='on_match', full_name='envoy.config.common.matcher.v4alpha.Matcher.OnMatch.on_match',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=568,
  serialized_end=781,
)

_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE = _descriptor.Descriptor(
  name='SinglePredicate',
  full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.SinglePredicate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.SinglePredicate.input', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_match', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.SinglePredicate.value_match', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_match', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.SinglePredicate.custom_match', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036N\nLenvoy.config.common.matcher.v3.Matcher.MatcherList.Predicate.SinglePredicate',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='matcher', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.SinglePredicate.matcher',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1234,
  serialized_end=1565,
)

_MATCHER_MATCHERLIST_PREDICATE_PREDICATELIST = _descriptor.Descriptor(
  name='PredicateList',
  full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.PredicateList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='predicate', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.PredicateList.predicate', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036L\nJenvoy.config.common.matcher.v3.Matcher.MatcherList.Predicate.PredicateList',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1568,
  serialized_end=1763,
)

_MATCHER_MATCHERLIST_PREDICATE = _descriptor.Descriptor(
  name='Predicate',
  full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='single_predicate', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.single_predicate', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='or_matcher', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.or_matcher', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='and_matcher', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.and_matcher', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE, _MATCHER_MATCHERLIST_PREDICATE_PREDICATELIST, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036>\n<envoy.config.common.matcher.v3.Matcher.MatcherList.Predicate',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='match_type', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.match_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=899,
  serialized_end=1851,
)

_MATCHER_MATCHERLIST_FIELDMATCHER = _descriptor.Descriptor(
  name='FieldMatcher',
  full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.FieldMatcher',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='predicate', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.FieldMatcher.predicate', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_match', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.FieldMatcher.on_match', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036A\n?envoy.config.common.matcher.v3.Matcher.MatcherList.FieldMatcher',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1854,
  serialized_end=2119,
)

_MATCHER_MATCHERLIST = _descriptor.Descriptor(
  name='MatcherList',
  full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='matchers', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.matchers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MATCHER_MATCHERLIST_PREDICATE, _MATCHER_MATCHERLIST_FIELDMATCHER, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0364\n2envoy.config.common.matcher.v3.Matcher.MatcherList',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=784,
  serialized_end=2178,
)

_MATCHER_MATCHERTREE_MATCHMAP_MAPENTRY = _descriptor.Descriptor(
  name='MapEntry',
  full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.MatchMap.MapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.MatchMap.MapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.MatchMap.MapEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2644,
  serialized_end=2740,
)

_MATCHER_MATCHERTREE_MATCHMAP = _descriptor.Descriptor(
  name='MatchMap',
  full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.MatchMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='map', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.MatchMap.map', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\232\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MATCHER_MATCHERTREE_MATCHMAP_MAPENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036=\n;envoy.config.common.matcher.v3.Matcher.MatcherTree.MatchMap',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2533,
  serialized_end=2808,
)

_MATCHER_MATCHERTREE = _descriptor.Descriptor(
  name='MatcherTree',
  full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherTree',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.input', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exact_match_map', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.exact_match_map', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix_match_map', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.prefix_match_map', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_match', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.custom_match', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MATCHER_MATCHERTREE_MATCHMAP, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0364\n2envoy.config.common.matcher.v3.Matcher.MatcherTree',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='tree_type', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.tree_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=2181,
  serialized_end=2885,
)

_MATCHER = _descriptor.Descriptor(
  name='Matcher',
  full_name='envoy.config.common.matcher.v4alpha.Matcher',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='matcher_list', full_name='envoy.config.common.matcher.v4alpha.Matcher.matcher_list', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher_tree', full_name='envoy.config.common.matcher.v4alpha.Matcher.matcher_tree', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_no_match', full_name='envoy.config.common.matcher.v4alpha.Matcher.on_no_match', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MATCHER_ONMATCH, _MATCHER_MATCHERLIST, _MATCHER_MATCHERTREE, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036(\n&envoy.config.common.matcher.v3.Matcher',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='matcher_type', full_name='envoy.config.common.matcher.v4alpha.Matcher.matcher_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=317,
  serialized_end=2953,
)


_MATCHPREDICATE_MATCHSET = _descriptor.Descriptor(
  name='MatchSet',
  full_name='envoy.config.common.matcher.v4alpha.MatchPredicate.MatchSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rules', full_name='envoy.config.common.matcher.v4alpha.MatchPredicate.MatchSet.rules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0368\n6envoy.config.common.matcher.v3.MatchPredicate.MatchSet',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3825,
  serialized_end=3976,
)

_MATCHPREDICATE = _descriptor.Descriptor(
  name='MatchPredicate',
  full_name='envoy.config.common.matcher.v4alpha.MatchPredicate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='or_match', full_name='envoy.config.common.matcher.v4alpha.MatchPredicate.or_match', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='and_match', full_name='envoy.config.common.matcher.v4alpha.MatchPredicate.and_match', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='not_match', full_name='envoy.config.common.matcher.v4alpha.MatchPredicate.not_match', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='any_match', full_name='envoy.config.common.matcher.v4alpha.MatchPredicate.any_match', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004j\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_request_headers_match', full_name='envoy.config.common.matcher.v4alpha.MatchPredicate.http_request_headers_match', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_request_trailers_match', full_name='envoy.config.common.matcher.v4alpha.MatchPredicate.http_request_trailers_match', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_response_headers_match', full_name='envoy.config.common.matcher.v4alpha.MatchPredicate.http_response_headers_match', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_response_trailers_match', full_name='envoy.config.common.matcher.v4alpha.MatchPredicate.http_response_trailers_match', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_request_generic_body_match', full_name='envoy.config.common.matcher.v4alpha.MatchPredicate.http_request_generic_body_match', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_response_generic_body_match', full_name='envoy.config.common.matcher.v4alpha.MatchPredicate.http_response_generic_body_match', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MATCHPREDICATE_MATCHSET, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036/\n-envoy.config.common.matcher.v3.MatchPredicate',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='rule', full_name='envoy.config.common.matcher.v4alpha.MatchPredicate.rule',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=2956,
  serialized_end=4043,
)


_HTTPHEADERSMATCH = _descriptor.Descriptor(
  name='HttpHeadersMatch',
  full_name='envoy.config.common.matcher.v4alpha.HttpHeadersMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.config.common.matcher.v4alpha.HttpHeadersMatch.headers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0361\n/envoy.config.common.matcher.v3.HttpHeadersMatch',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4046,
  serialized_end=4180,
)


_HTTPGENERICBODYMATCH_GENERICTEXTMATCH = _descriptor.Descriptor(
  name='GenericTextMatch',
  full_name='envoy.config.common.matcher.v4alpha.HttpGenericBodyMatch.GenericTextMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='string_match', full_name='envoy.config.common.matcher.v4alpha.HttpGenericBodyMatch.GenericTextMatch.string_match', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='binary_match', full_name='envoy.config.common.matcher.v4alpha.HttpGenericBodyMatch.GenericTextMatch.binary_match', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004z\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036F\nDenvoy.config.common.matcher.v3.HttpGenericBodyMatch.GenericTextMatch',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='rule', full_name='envoy.config.common.matcher.v4alpha.HttpGenericBodyMatch.GenericTextMatch.rule',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=4333,
  serialized_end=4507,
)

_HTTPGENERICBODYMATCH = _descriptor.Descriptor(
  name='HttpGenericBodyMatch',
  full_name='envoy.config.common.matcher.v4alpha.HttpGenericBodyMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bytes_limit', full_name='envoy.config.common.matcher.v4alpha.HttpGenericBodyMatch.bytes_limit', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='patterns', full_name='envoy.config.common.matcher.v4alpha.HttpGenericBodyMatch.patterns', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HTTPGENERICBODYMATCH_GENERICTEXTMATCH, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0365\n3envoy.config.common.matcher.v3.HttpGenericBodyMatch',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4183,
  serialized_end=4567,
)

_MATCHER_ONMATCH.fields_by_name['matcher'].message_type = _MATCHER
_MATCHER_ONMATCH.fields_by_name['action'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2._TYPEDEXTENSIONCONFIG
_MATCHER_ONMATCH.containing_type = _MATCHER
_MATCHER_ONMATCH.oneofs_by_name['on_match'].fields.append(
  _MATCHER_ONMATCH.fields_by_name['matcher'])
_MATCHER_ONMATCH.fields_by_name['matcher'].containing_oneof = _MATCHER_ONMATCH.oneofs_by_name['on_match']
_MATCHER_ONMATCH.oneofs_by_name['on_match'].fields.append(
  _MATCHER_ONMATCH.fields_by_name['action'])
_MATCHER_ONMATCH.fields_by_name['action'].containing_oneof = _MATCHER_ONMATCH.oneofs_by_name['on_match']
_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.fields_by_name['input'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2._TYPEDEXTENSIONCONFIG
_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.fields_by_name['value_match'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2._STRINGMATCHER
_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.fields_by_name['custom_match'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2._TYPEDEXTENSIONCONFIG
_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.containing_type = _MATCHER_MATCHERLIST_PREDICATE
_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.oneofs_by_name['matcher'].fields.append(
  _MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.fields_by_name['value_match'])
_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.fields_by_name['value_match'].containing_oneof = _MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.oneofs_by_name['matcher']
_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.oneofs_by_name['matcher'].fields.append(
  _MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.fields_by_name['custom_match'])
_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.fields_by_name['custom_match'].containing_oneof = _MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.oneofs_by_name['matcher']
_MATCHER_MATCHERLIST_PREDICATE_PREDICATELIST.fields_by_name['predicate'].message_type = _MATCHER_MATCHERLIST_PREDICATE
_MATCHER_MATCHERLIST_PREDICATE_PREDICATELIST.containing_type = _MATCHER_MATCHERLIST_PREDICATE
_MATCHER_MATCHERLIST_PREDICATE.fields_by_name['single_predicate'].message_type = _MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE
_MATCHER_MATCHERLIST_PREDICATE.fields_by_name['or_matcher'].message_type = _MATCHER_MATCHERLIST_PREDICATE_PREDICATELIST
_MATCHER_MATCHERLIST_PREDICATE.fields_by_name['and_matcher'].message_type = _MATCHER_MATCHERLIST_PREDICATE_PREDICATELIST
_MATCHER_MATCHERLIST_PREDICATE.containing_type = _MATCHER_MATCHERLIST
_MATCHER_MATCHERLIST_PREDICATE.oneofs_by_name['match_type'].fields.append(
  _MATCHER_MATCHERLIST_PREDICATE.fields_by_name['single_predicate'])
_MATCHER_MATCHERLIST_PREDICATE.fields_by_name['single_predicate'].containing_oneof = _MATCHER_MATCHERLIST_PREDICATE.oneofs_by_name['match_type']
_MATCHER_MATCHERLIST_PREDICATE.oneofs_by_name['match_type'].fields.append(
  _MATCHER_MATCHERLIST_PREDICATE.fields_by_name['or_matcher'])
_MATCHER_MATCHERLIST_PREDICATE.fields_by_name['or_matcher'].containing_oneof = _MATCHER_MATCHERLIST_PREDICATE.oneofs_by_name['match_type']
_MATCHER_MATCHERLIST_PREDICATE.oneofs_by_name['match_type'].fields.append(
  _MATCHER_MATCHERLIST_PREDICATE.fields_by_name['and_matcher'])
_MATCHER_MATCHERLIST_PREDICATE.fields_by_name['and_matcher'].containing_oneof = _MATCHER_MATCHERLIST_PREDICATE.oneofs_by_name['match_type']
_MATCHER_MATCHERLIST_FIELDMATCHER.fields_by_name['predicate'].message_type = _MATCHER_MATCHERLIST_PREDICATE
_MATCHER_MATCHERLIST_FIELDMATCHER.fields_by_name['on_match'].message_type = _MATCHER_ONMATCH
_MATCHER_MATCHERLIST_FIELDMATCHER.containing_type = _MATCHER_MATCHERLIST
_MATCHER_MATCHERLIST.fields_by_name['matchers'].message_type = _MATCHER_MATCHERLIST_FIELDMATCHER
_MATCHER_MATCHERLIST.containing_type = _MATCHER
_MATCHER_MATCHERTREE_MATCHMAP_MAPENTRY.fields_by_name['value'].message_type = _MATCHER_ONMATCH
_MATCHER_MATCHERTREE_MATCHMAP_MAPENTRY.containing_type = _MATCHER_MATCHERTREE_MATCHMAP
_MATCHER_MATCHERTREE_MATCHMAP.fields_by_name['map'].message_type = _MATCHER_MATCHERTREE_MATCHMAP_MAPENTRY
_MATCHER_MATCHERTREE_MATCHMAP.containing_type = _MATCHER_MATCHERTREE
_MATCHER_MATCHERTREE.fields_by_name['input'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2._TYPEDEXTENSIONCONFIG
_MATCHER_MATCHERTREE.fields_by_name['exact_match_map'].message_type = _MATCHER_MATCHERTREE_MATCHMAP
_MATCHER_MATCHERTREE.fields_by_name['prefix_match_map'].message_type = _MATCHER_MATCHERTREE_MATCHMAP
_MATCHER_MATCHERTREE.fields_by_name['custom_match'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2._TYPEDEXTENSIONCONFIG
_MATCHER_MATCHERTREE.containing_type = _MATCHER
_MATCHER_MATCHERTREE.oneofs_by_name['tree_type'].fields.append(
  _MATCHER_MATCHERTREE.fields_by_name['exact_match_map'])
_MATCHER_MATCHERTREE.fields_by_name['exact_match_map'].containing_oneof = _MATCHER_MATCHERTREE.oneofs_by_name['tree_type']
_MATCHER_MATCHERTREE.oneofs_by_name['tree_type'].fields.append(
  _MATCHER_MATCHERTREE.fields_by_name['prefix_match_map'])
_MATCHER_MATCHERTREE.fields_by_name['prefix_match_map'].containing_oneof = _MATCHER_MATCHERTREE.oneofs_by_name['tree_type']
_MATCHER_MATCHERTREE.oneofs_by_name['tree_type'].fields.append(
  _MATCHER_MATCHERTREE.fields_by_name['custom_match'])
_MATCHER_MATCHERTREE.fields_by_name['custom_match'].containing_oneof = _MATCHER_MATCHERTREE.oneofs_by_name['tree_type']
_MATCHER.fields_by_name['matcher_list'].message_type = _MATCHER_MATCHERLIST
_MATCHER.fields_by_name['matcher_tree'].message_type = _MATCHER_MATCHERTREE
_MATCHER.fields_by_name['on_no_match'].message_type = _MATCHER_ONMATCH
_MATCHER.oneofs_by_name['matcher_type'].fields.append(
  _MATCHER.fields_by_name['matcher_list'])
_MATCHER.fields_by_name['matcher_list'].containing_oneof = _MATCHER.oneofs_by_name['matcher_type']
_MATCHER.oneofs_by_name['matcher_type'].fields.append(
  _MATCHER.fields_by_name['matcher_tree'])
_MATCHER.fields_by_name['matcher_tree'].containing_oneof = _MATCHER.oneofs_by_name['matcher_type']
_MATCHPREDICATE_MATCHSET.fields_by_name['rules'].message_type = _MATCHPREDICATE
_MATCHPREDICATE_MATCHSET.containing_type = _MATCHPREDICATE
_MATCHPREDICATE.fields_by_name['or_match'].message_type = _MATCHPREDICATE_MATCHSET
_MATCHPREDICATE.fields_by_name['and_match'].message_type = _MATCHPREDICATE_MATCHSET
_MATCHPREDICATE.fields_by_name['not_match'].message_type = _MATCHPREDICATE
_MATCHPREDICATE.fields_by_name['http_request_headers_match'].message_type = _HTTPHEADERSMATCH
_MATCHPREDICATE.fields_by_name['http_request_trailers_match'].message_type = _HTTPHEADERSMATCH
_MATCHPREDICATE.fields_by_name['http_response_headers_match'].message_type = _HTTPHEADERSMATCH
_MATCHPREDICATE.fields_by_name['http_response_trailers_match'].message_type = _HTTPHEADERSMATCH
_MATCHPREDICATE.fields_by_name['http_request_generic_body_match'].message_type = _HTTPGENERICBODYMATCH
_MATCHPREDICATE.fields_by_name['http_response_generic_body_match'].message_type = _HTTPGENERICBODYMATCH
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['or_match'])
_MATCHPREDICATE.fields_by_name['or_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['and_match'])
_MATCHPREDICATE.fields_by_name['and_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['not_match'])
_MATCHPREDICATE.fields_by_name['not_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['any_match'])
_MATCHPREDICATE.fields_by_name['any_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['http_request_headers_match'])
_MATCHPREDICATE.fields_by_name['http_request_headers_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['http_request_trailers_match'])
_MATCHPREDICATE.fields_by_name['http_request_trailers_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['http_response_headers_match'])
_MATCHPREDICATE.fields_by_name['http_response_headers_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['http_response_trailers_match'])
_MATCHPREDICATE.fields_by_name['http_response_trailers_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['http_request_generic_body_match'])
_MATCHPREDICATE.fields_by_name['http_request_generic_body_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['http_response_generic_body_match'])
_MATCHPREDICATE.fields_by_name['http_response_generic_body_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_HTTPHEADERSMATCH.fields_by_name['headers'].message_type = envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2._HEADERMATCHER
_HTTPGENERICBODYMATCH_GENERICTEXTMATCH.containing_type = _HTTPGENERICBODYMATCH
_HTTPGENERICBODYMATCH_GENERICTEXTMATCH.oneofs_by_name['rule'].fields.append(
  _HTTPGENERICBODYMATCH_GENERICTEXTMATCH.fields_by_name['string_match'])
_HTTPGENERICBODYMATCH_GENERICTEXTMATCH.fields_by_name['string_match'].containing_oneof = _HTTPGENERICBODYMATCH_GENERICTEXTMATCH.oneofs_by_name['rule']
_HTTPGENERICBODYMATCH_GENERICTEXTMATCH.oneofs_by_name['rule'].fields.append(
  _HTTPGENERICBODYMATCH_GENERICTEXTMATCH.fields_by_name['binary_match'])
_HTTPGENERICBODYMATCH_GENERICTEXTMATCH.fields_by_name['binary_match'].containing_oneof = _HTTPGENERICBODYMATCH_GENERICTEXTMATCH.oneofs_by_name['rule']
_HTTPGENERICBODYMATCH.fields_by_name['patterns'].message_type = _HTTPGENERICBODYMATCH_GENERICTEXTMATCH
DESCRIPTOR.message_types_by_name['Matcher'] = _MATCHER
DESCRIPTOR.message_types_by_name['MatchPredicate'] = _MATCHPREDICATE
DESCRIPTOR.message_types_by_name['HttpHeadersMatch'] = _HTTPHEADERSMATCH
DESCRIPTOR.message_types_by_name['HttpGenericBodyMatch'] = _HTTPGENERICBODYMATCH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Matcher = _reflection.GeneratedProtocolMessageType('Matcher', (_message.Message,), {

  'OnMatch' : _reflection.GeneratedProtocolMessageType('OnMatch', (_message.Message,), {
    'DESCRIPTOR' : _MATCHER_ONMATCH,
    '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.Matcher.OnMatch)
    })
  ,

  'MatcherList' : _reflection.GeneratedProtocolMessageType('MatcherList', (_message.Message,), {

    'Predicate' : _reflection.GeneratedProtocolMessageType('Predicate', (_message.Message,), {

      'SinglePredicate' : _reflection.GeneratedProtocolMessageType('SinglePredicate', (_message.Message,), {
        'DESCRIPTOR' : _MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE,
        '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
        # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.SinglePredicate)
        })
      ,

      'PredicateList' : _reflection.GeneratedProtocolMessageType('PredicateList', (_message.Message,), {
        'DESCRIPTOR' : _MATCHER_MATCHERLIST_PREDICATE_PREDICATELIST,
        '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
        # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.PredicateList)
        })
      ,
      'DESCRIPTOR' : _MATCHER_MATCHERLIST_PREDICATE,
      '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate)
      })
    ,

    'FieldMatcher' : _reflection.GeneratedProtocolMessageType('FieldMatcher', (_message.Message,), {
      'DESCRIPTOR' : _MATCHER_MATCHERLIST_FIELDMATCHER,
      '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.Matcher.MatcherList.FieldMatcher)
      })
    ,
    'DESCRIPTOR' : _MATCHER_MATCHERLIST,
    '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.Matcher.MatcherList)
    })
  ,

  'MatcherTree' : _reflection.GeneratedProtocolMessageType('MatcherTree', (_message.Message,), {

    'MatchMap' : _reflection.GeneratedProtocolMessageType('MatchMap', (_message.Message,), {

      'MapEntry' : _reflection.GeneratedProtocolMessageType('MapEntry', (_message.Message,), {
        'DESCRIPTOR' : _MATCHER_MATCHERTREE_MATCHMAP_MAPENTRY,
        '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
        # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.MatchMap.MapEntry)
        })
      ,
      'DESCRIPTOR' : _MATCHER_MATCHERTREE_MATCHMAP,
      '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.MatchMap)
      })
    ,
    'DESCRIPTOR' : _MATCHER_MATCHERTREE,
    '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.Matcher.MatcherTree)
    })
  ,
  'DESCRIPTOR' : _MATCHER,
  '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.Matcher)
  })
_sym_db.RegisterMessage(Matcher)
_sym_db.RegisterMessage(Matcher.OnMatch)
_sym_db.RegisterMessage(Matcher.MatcherList)
_sym_db.RegisterMessage(Matcher.MatcherList.Predicate)
_sym_db.RegisterMessage(Matcher.MatcherList.Predicate.SinglePredicate)
_sym_db.RegisterMessage(Matcher.MatcherList.Predicate.PredicateList)
_sym_db.RegisterMessage(Matcher.MatcherList.FieldMatcher)
_sym_db.RegisterMessage(Matcher.MatcherTree)
_sym_db.RegisterMessage(Matcher.MatcherTree.MatchMap)
_sym_db.RegisterMessage(Matcher.MatcherTree.MatchMap.MapEntry)

MatchPredicate = _reflection.GeneratedProtocolMessageType('MatchPredicate', (_message.Message,), {

  'MatchSet' : _reflection.GeneratedProtocolMessageType('MatchSet', (_message.Message,), {
    'DESCRIPTOR' : _MATCHPREDICATE_MATCHSET,
    '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.MatchPredicate.MatchSet)
    })
  ,
  'DESCRIPTOR' : _MATCHPREDICATE,
  '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.MatchPredicate)
  })
_sym_db.RegisterMessage(MatchPredicate)
_sym_db.RegisterMessage(MatchPredicate.MatchSet)

HttpHeadersMatch = _reflection.GeneratedProtocolMessageType('HttpHeadersMatch', (_message.Message,), {
  'DESCRIPTOR' : _HTTPHEADERSMATCH,
  '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.HttpHeadersMatch)
  })
_sym_db.RegisterMessage(HttpHeadersMatch)

HttpGenericBodyMatch = _reflection.GeneratedProtocolMessageType('HttpGenericBodyMatch', (_message.Message,), {

  'GenericTextMatch' : _reflection.GeneratedProtocolMessageType('GenericTextMatch', (_message.Message,), {
    'DESCRIPTOR' : _HTTPGENERICBODYMATCH_GENERICTEXTMATCH,
    '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.HttpGenericBodyMatch.GenericTextMatch)
    })
  ,
  'DESCRIPTOR' : _HTTPGENERICBODYMATCH,
  '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.HttpGenericBodyMatch)
  })
_sym_db.RegisterMessage(HttpGenericBodyMatch)
_sym_db.RegisterMessage(HttpGenericBodyMatch.GenericTextMatch)


DESCRIPTOR._options = None
_MATCHER_ONMATCH.oneofs_by_name['on_match']._options = None
_MATCHER_ONMATCH._options = None
_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.oneofs_by_name['matcher']._options = None
_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.fields_by_name['input']._options = None
_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE._options = None
_MATCHER_MATCHERLIST_PREDICATE_PREDICATELIST.fields_by_name['predicate']._options = None
_MATCHER_MATCHERLIST_PREDICATE_PREDICATELIST._options = None
_MATCHER_MATCHERLIST_PREDICATE.oneofs_by_name['match_type']._options = None
_MATCHER_MATCHERLIST_PREDICATE._options = None
_MATCHER_MATCHERLIST_FIELDMATCHER.fields_by_name['predicate']._options = None
_MATCHER_MATCHERLIST_FIELDMATCHER.fields_by_name['on_match']._options = None
_MATCHER_MATCHERLIST_FIELDMATCHER._options = None
_MATCHER_MATCHERLIST.fields_by_name['matchers']._options = None
_MATCHER_MATCHERLIST._options = None
_MATCHER_MATCHERTREE_MATCHMAP_MAPENTRY._options = None
_MATCHER_MATCHERTREE_MATCHMAP.fields_by_name['map']._options = None
_MATCHER_MATCHERTREE_MATCHMAP._options = None
_MATCHER_MATCHERTREE.oneofs_by_name['tree_type']._options = None
_MATCHER_MATCHERTREE.fields_by_name['input']._options = None
_MATCHER_MATCHERTREE._options = None
_MATCHER.oneofs_by_name['matcher_type']._options = None
_MATCHER._options = None
_MATCHPREDICATE_MATCHSET.fields_by_name['rules']._options = None
_MATCHPREDICATE_MATCHSET._options = None
_MATCHPREDICATE.oneofs_by_name['rule']._options = None
_MATCHPREDICATE.fields_by_name['any_match']._options = None
_MATCHPREDICATE._options = None
_HTTPHEADERSMATCH._options = None
_HTTPGENERICBODYMATCH_GENERICTEXTMATCH.oneofs_by_name['rule']._options = None
_HTTPGENERICBODYMATCH_GENERICTEXTMATCH.fields_by_name['string_match']._options = None
_HTTPGENERICBODYMATCH_GENERICTEXTMATCH.fields_by_name['binary_match']._options = None
_HTTPGENERICBODYMATCH_GENERICTEXTMATCH._options = None
_HTTPGENERICBODYMATCH.fields_by_name['patterns']._options = None
_HTTPGENERICBODYMATCH._options = None
# @@protoc_insertion_point(module_scope)
