# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/ext_authz/v2/ext_authz.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import grpc_service_pb2 as envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2
from envoy.api.v2.core import http_uri_pb2 as envoy_dot_api_dot_v2_dot_core_dot_http__uri__pb2
from envoy.type import http_status_pb2 as envoy_dot_type_dot_http__status__pb2
from envoy.type.matcher import string_pb2 as envoy_dot_type_dot_matcher_dot_string__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/http/ext_authz/v2/ext_authz.proto',
  package='envoy.config.filter.http.ext_authz.v2',
  syntax='proto3',
  serialized_options=b'\n3io.envoyproxy.envoy.config.filter.http.ext_authz.v2B\rExtAuthzProtoP\001\362\230\376\217\005,\022*envoy.extensions.filters.http.ext_authz.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5envoy/config/filter/http/ext_authz/v2/ext_authz.proto\x12%envoy.config.filter.http.ext_authz.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a$envoy/api/v2/core/grpc_service.proto\x1a envoy/api/v2/core/http_uri.proto\x1a\x1c\x65nvoy/type/http_status.proto\x1a\x1f\x65nvoy/type/matcher/string.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xbd\x04\n\x08\x45xtAuthz\x12\x36\n\x0cgrpc_service\x18\x01 \x01(\x0b\x32\x1e.envoy.api.v2.core.GrpcServiceH\x00\x12J\n\x0chttp_service\x18\x03 \x01(\x0b\x32\x32.envoy.config.filter.http.ext_authz.v2.HttpServiceH\x00\x12\x1a\n\x12\x66\x61ilure_mode_allow\x18\x02 \x01(\x08\x12\x1b\n\tuse_alpha\x18\x04 \x01(\x08\x42\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\x12P\n\x11with_request_body\x18\x05 \x01(\x0b\x32\x35.envoy.config.filter.http.ext_authz.v2.BufferSettings\x12\x19\n\x11\x63lear_route_cache\x18\x06 \x01(\x08\x12/\n\x0fstatus_on_error\x18\x07 \x01(\x0b\x32\x16.envoy.type.HttpStatus\x12#\n\x1bmetadata_context_namespaces\x18\x08 \x03(\t\x12\x43\n\x0e\x66ilter_enabled\x18\t \x01(\x0b\x32+.envoy.api.v2.core.RuntimeFractionalPercent\x12>\n\x0f\x64\x65ny_at_disable\x18\x0b \x01(\x0b\x32%.envoy.api.v2.core.RuntimeFeatureFlag\x12 \n\x18include_peer_certificate\x18\n \x01(\x08\x42\n\n\x08services\"S\n\x0e\x42ufferSettings\x12\"\n\x11max_request_bytes\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02 \x00\x12\x1d\n\x15\x61llow_partial_message\x18\x02 \x01(\x08\"\xa4\x02\n\x0bHttpService\x12.\n\nserver_uri\x18\x01 \x01(\x0b\x32\x1a.envoy.api.v2.core.HttpUri\x12\x13\n\x0bpath_prefix\x18\x02 \x01(\t\x12Z\n\x15\x61uthorization_request\x18\x07 \x01(\x0b\x32;.envoy.config.filter.http.ext_authz.v2.AuthorizationRequest\x12\\\n\x16\x61uthorization_response\x18\x08 \x01(\x0b\x32<.envoy.config.filter.http.ext_authz.v2.AuthorizationResponseJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07\"\x8e\x01\n\x14\x41uthorizationRequest\x12>\n\x0f\x61llowed_headers\x18\x01 \x01(\x0b\x32%.envoy.type.matcher.ListStringMatcher\x12\x36\n\x0eheaders_to_add\x18\x02 \x03(\x0b\x32\x1e.envoy.api.v2.core.HeaderValue\"\xa7\x01\n\x15\x41uthorizationResponse\x12G\n\x18\x61llowed_upstream_headers\x18\x01 \x01(\x0b\x32%.envoy.type.matcher.ListStringMatcher\x12\x45\n\x16\x61llowed_client_headers\x18\x02 \x01(\x0b\x32%.envoy.type.matcher.ListStringMatcher\"\x9a\x01\n\x10\x45xtAuthzPerRoute\x12\x1b\n\x08\x64isabled\x18\x01 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12X\n\x0e\x63heck_settings\x18\x02 \x01(\x0b\x32\x34.envoy.config.filter.http.ext_authz.v2.CheckSettingsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x42\x0f\n\x08override\x12\x03\xf8\x42\x01\"\xb2\x01\n\rCheckSettings\x12g\n\x12\x63ontext_extensions\x18\x01 \x03(\x0b\x32K.envoy.config.filter.http.ext_authz.v2.CheckSettings.ContextExtensionsEntry\x1a\x38\n\x16\x43ontextExtensionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x80\x01\n3io.envoyproxy.envoy.config.filter.http.ext_authz.v2B\rExtAuthzProtoP\x01\xf2\x98\xfe\x8f\x05,\x12*envoy.extensions.filters.http.ext_authz.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_http__uri__pb2.DESCRIPTOR,envoy_dot_type_dot_http__status__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_string__pb2.DESCRIPTOR,envoy_dot_annotations_dot_deprecation__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_EXTAUTHZ = _descriptor.Descriptor(
  name='ExtAuthz',
  full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='grpc_service', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthz.grpc_service', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_service', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthz.http_service', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure_mode_allow', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthz.failure_mode_allow', index=2,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_alpha', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthz.use_alpha', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001\270\356\362\322\005\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_request_body', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthz.with_request_body', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_route_cache', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthz.clear_route_cache', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_on_error', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthz.status_on_error', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_context_namespaces', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthz.metadata_context_namespaces', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_enabled', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthz.filter_enabled', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deny_at_disable', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthz.deny_at_disable', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_peer_certificate', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthz.include_peer_certificate', index=10,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='services', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthz.services',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=387,
  serialized_end=960,
)


_BUFFERSETTINGS = _descriptor.Descriptor(
  name='BufferSettings',
  full_name='envoy.config.filter.http.ext_authz.v2.BufferSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_request_bytes', full_name='envoy.config.filter.http.ext_authz.v2.BufferSettings.max_request_bytes', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002 \000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_partial_message', full_name='envoy.config.filter.http.ext_authz.v2.BufferSettings.allow_partial_message', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=962,
  serialized_end=1045,
)


_HTTPSERVICE = _descriptor.Descriptor(
  name='HttpService',
  full_name='envoy.config.filter.http.ext_authz.v2.HttpService',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_uri', full_name='envoy.config.filter.http.ext_authz.v2.HttpService.server_uri', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_prefix', full_name='envoy.config.filter.http.ext_authz.v2.HttpService.path_prefix', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authorization_request', full_name='envoy.config.filter.http.ext_authz.v2.HttpService.authorization_request', index=2,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authorization_response', full_name='envoy.config.filter.http.ext_authz.v2.HttpService.authorization_response', index=3,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1048,
  serialized_end=1340,
)


_AUTHORIZATIONREQUEST = _descriptor.Descriptor(
  name='AuthorizationRequest',
  full_name='envoy.config.filter.http.ext_authz.v2.AuthorizationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='allowed_headers', full_name='envoy.config.filter.http.ext_authz.v2.AuthorizationRequest.allowed_headers', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers_to_add', full_name='envoy.config.filter.http.ext_authz.v2.AuthorizationRequest.headers_to_add', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1343,
  serialized_end=1485,
)


_AUTHORIZATIONRESPONSE = _descriptor.Descriptor(
  name='AuthorizationResponse',
  full_name='envoy.config.filter.http.ext_authz.v2.AuthorizationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='allowed_upstream_headers', full_name='envoy.config.filter.http.ext_authz.v2.AuthorizationResponse.allowed_upstream_headers', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_client_headers', full_name='envoy.config.filter.http.ext_authz.v2.AuthorizationResponse.allowed_client_headers', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1488,
  serialized_end=1655,
)


_EXTAUTHZPERROUTE = _descriptor.Descriptor(
  name='ExtAuthzPerRoute',
  full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthzPerRoute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disabled', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthzPerRoute.disabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004j\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='check_settings', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthzPerRoute.check_settings', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='override', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthzPerRoute.override',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1658,
  serialized_end=1812,
)


_CHECKSETTINGS_CONTEXTEXTENSIONSENTRY = _descriptor.Descriptor(
  name='ContextExtensionsEntry',
  full_name='envoy.config.filter.http.ext_authz.v2.CheckSettings.ContextExtensionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.config.filter.http.ext_authz.v2.CheckSettings.ContextExtensionsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.config.filter.http.ext_authz.v2.CheckSettings.ContextExtensionsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1937,
  serialized_end=1993,
)

_CHECKSETTINGS = _descriptor.Descriptor(
  name='CheckSettings',
  full_name='envoy.config.filter.http.ext_authz.v2.CheckSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='context_extensions', full_name='envoy.config.filter.http.ext_authz.v2.CheckSettings.context_extensions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CHECKSETTINGS_CONTEXTEXTENSIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1815,
  serialized_end=1993,
)

_EXTAUTHZ.fields_by_name['grpc_service'].message_type = envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2._GRPCSERVICE
_EXTAUTHZ.fields_by_name['http_service'].message_type = _HTTPSERVICE
_EXTAUTHZ.fields_by_name['with_request_body'].message_type = _BUFFERSETTINGS
_EXTAUTHZ.fields_by_name['status_on_error'].message_type = envoy_dot_type_dot_http__status__pb2._HTTPSTATUS
_EXTAUTHZ.fields_by_name['filter_enabled'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._RUNTIMEFRACTIONALPERCENT
_EXTAUTHZ.fields_by_name['deny_at_disable'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._RUNTIMEFEATUREFLAG
_EXTAUTHZ.oneofs_by_name['services'].fields.append(
  _EXTAUTHZ.fields_by_name['grpc_service'])
_EXTAUTHZ.fields_by_name['grpc_service'].containing_oneof = _EXTAUTHZ.oneofs_by_name['services']
_EXTAUTHZ.oneofs_by_name['services'].fields.append(
  _EXTAUTHZ.fields_by_name['http_service'])
_EXTAUTHZ.fields_by_name['http_service'].containing_oneof = _EXTAUTHZ.oneofs_by_name['services']
_HTTPSERVICE.fields_by_name['server_uri'].message_type = envoy_dot_api_dot_v2_dot_core_dot_http__uri__pb2._HTTPURI
_HTTPSERVICE.fields_by_name['authorization_request'].message_type = _AUTHORIZATIONREQUEST
_HTTPSERVICE.fields_by_name['authorization_response'].message_type = _AUTHORIZATIONRESPONSE
_AUTHORIZATIONREQUEST.fields_by_name['allowed_headers'].message_type = envoy_dot_type_dot_matcher_dot_string__pb2._LISTSTRINGMATCHER
_AUTHORIZATIONREQUEST.fields_by_name['headers_to_add'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._HEADERVALUE
_AUTHORIZATIONRESPONSE.fields_by_name['allowed_upstream_headers'].message_type = envoy_dot_type_dot_matcher_dot_string__pb2._LISTSTRINGMATCHER
_AUTHORIZATIONRESPONSE.fields_by_name['allowed_client_headers'].message_type = envoy_dot_type_dot_matcher_dot_string__pb2._LISTSTRINGMATCHER
_EXTAUTHZPERROUTE.fields_by_name['check_settings'].message_type = _CHECKSETTINGS
_EXTAUTHZPERROUTE.oneofs_by_name['override'].fields.append(
  _EXTAUTHZPERROUTE.fields_by_name['disabled'])
_EXTAUTHZPERROUTE.fields_by_name['disabled'].containing_oneof = _EXTAUTHZPERROUTE.oneofs_by_name['override']
_EXTAUTHZPERROUTE.oneofs_by_name['override'].fields.append(
  _EXTAUTHZPERROUTE.fields_by_name['check_settings'])
_EXTAUTHZPERROUTE.fields_by_name['check_settings'].containing_oneof = _EXTAUTHZPERROUTE.oneofs_by_name['override']
_CHECKSETTINGS_CONTEXTEXTENSIONSENTRY.containing_type = _CHECKSETTINGS
_CHECKSETTINGS.fields_by_name['context_extensions'].message_type = _CHECKSETTINGS_CONTEXTEXTENSIONSENTRY
DESCRIPTOR.message_types_by_name['ExtAuthz'] = _EXTAUTHZ
DESCRIPTOR.message_types_by_name['BufferSettings'] = _BUFFERSETTINGS
DESCRIPTOR.message_types_by_name['HttpService'] = _HTTPSERVICE
DESCRIPTOR.message_types_by_name['AuthorizationRequest'] = _AUTHORIZATIONREQUEST
DESCRIPTOR.message_types_by_name['AuthorizationResponse'] = _AUTHORIZATIONRESPONSE
DESCRIPTOR.message_types_by_name['ExtAuthzPerRoute'] = _EXTAUTHZPERROUTE
DESCRIPTOR.message_types_by_name['CheckSettings'] = _CHECKSETTINGS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExtAuthz = _reflection.GeneratedProtocolMessageType('ExtAuthz', (_message.Message,), {
  'DESCRIPTOR' : _EXTAUTHZ,
  '__module__' : 'envoy.config.filter.http.ext_authz.v2.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.ext_authz.v2.ExtAuthz)
  })
_sym_db.RegisterMessage(ExtAuthz)

BufferSettings = _reflection.GeneratedProtocolMessageType('BufferSettings', (_message.Message,), {
  'DESCRIPTOR' : _BUFFERSETTINGS,
  '__module__' : 'envoy.config.filter.http.ext_authz.v2.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.ext_authz.v2.BufferSettings)
  })
_sym_db.RegisterMessage(BufferSettings)

HttpService = _reflection.GeneratedProtocolMessageType('HttpService', (_message.Message,), {
  'DESCRIPTOR' : _HTTPSERVICE,
  '__module__' : 'envoy.config.filter.http.ext_authz.v2.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.ext_authz.v2.HttpService)
  })
_sym_db.RegisterMessage(HttpService)

AuthorizationRequest = _reflection.GeneratedProtocolMessageType('AuthorizationRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORIZATIONREQUEST,
  '__module__' : 'envoy.config.filter.http.ext_authz.v2.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.ext_authz.v2.AuthorizationRequest)
  })
_sym_db.RegisterMessage(AuthorizationRequest)

AuthorizationResponse = _reflection.GeneratedProtocolMessageType('AuthorizationResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORIZATIONRESPONSE,
  '__module__' : 'envoy.config.filter.http.ext_authz.v2.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.ext_authz.v2.AuthorizationResponse)
  })
_sym_db.RegisterMessage(AuthorizationResponse)

ExtAuthzPerRoute = _reflection.GeneratedProtocolMessageType('ExtAuthzPerRoute', (_message.Message,), {
  'DESCRIPTOR' : _EXTAUTHZPERROUTE,
  '__module__' : 'envoy.config.filter.http.ext_authz.v2.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.ext_authz.v2.ExtAuthzPerRoute)
  })
_sym_db.RegisterMessage(ExtAuthzPerRoute)

CheckSettings = _reflection.GeneratedProtocolMessageType('CheckSettings', (_message.Message,), {

  'ContextExtensionsEntry' : _reflection.GeneratedProtocolMessageType('ContextExtensionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CHECKSETTINGS_CONTEXTEXTENSIONSENTRY,
    '__module__' : 'envoy.config.filter.http.ext_authz.v2.ext_authz_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.filter.http.ext_authz.v2.CheckSettings.ContextExtensionsEntry)
    })
  ,
  'DESCRIPTOR' : _CHECKSETTINGS,
  '__module__' : 'envoy.config.filter.http.ext_authz.v2.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.ext_authz.v2.CheckSettings)
  })
_sym_db.RegisterMessage(CheckSettings)
_sym_db.RegisterMessage(CheckSettings.ContextExtensionsEntry)


DESCRIPTOR._options = None
_EXTAUTHZ.fields_by_name['use_alpha']._options = None
_BUFFERSETTINGS.fields_by_name['max_request_bytes']._options = None
_EXTAUTHZPERROUTE.oneofs_by_name['override']._options = None
_EXTAUTHZPERROUTE.fields_by_name['disabled']._options = None
_EXTAUTHZPERROUTE.fields_by_name['check_settings']._options = None
_CHECKSETTINGS_CONTEXTEXTENSIONSENTRY._options = None
# @@protoc_insertion_point(module_scope)
