# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/extension/v3/config_discovery.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.service.discovery.v3 import discovery_pb2 as envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/extension/v3/config_discovery.proto',
  package='envoy.service.extension.v3',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.service.extension.v3B\024ConfigDiscoveryProtoP\001\210\001\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1envoy/service/extension/v3/config_discovery.proto\x12\x1a\x65nvoy.service.extension.v3\x1a*envoy/service/discovery/v3/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a envoy/annotations/resource.proto\x1a\x1dudpa/annotations/status.proto\"\x0b\n\tEcdsDummy2\x81\x04\n\x1f\x45xtensionConfigDiscoveryService\x12{\n\x16StreamExtensionConfigs\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"\x00(\x01\x30\x01\x12\x84\x01\n\x15\x44\x65ltaExtensionConfigs\x12\x31.envoy.service.discovery.v3.DeltaDiscoveryRequest\x1a\x32.envoy.service.discovery.v3.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12\xa6\x01\n\x15\x46\x65tchExtensionConfigs\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"0\x82\xd3\xe4\x93\x02!\"\x1f/v3/discovery:extension_configs\x82\xd3\xe4\x93\x02\x03:\x01*\x1a\x31\x8a\xa4\x96\xf3\x07+\n)envoy.config.core.v3.TypedExtensionConfigBM\n(io.envoyproxy.envoy.service.extension.v3B\x14\x43onfigDiscoveryProtoP\x01\x88\x01\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,envoy_dot_annotations_dot_resource__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_ECDSDUMMY = _descriptor.Descriptor(
  name='EcdsDummy',
  full_name='envoy.service.extension.v3.EcdsDummy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=220,
  serialized_end=231,
)

DESCRIPTOR.message_types_by_name['EcdsDummy'] = _ECDSDUMMY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EcdsDummy = _reflection.GeneratedProtocolMessageType('EcdsDummy', (_message.Message,), {
  'DESCRIPTOR' : _ECDSDUMMY,
  '__module__' : 'envoy.service.extension.v3.config_discovery_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.extension.v3.EcdsDummy)
  })
_sym_db.RegisterMessage(EcdsDummy)


DESCRIPTOR._options = None

_EXTENSIONCONFIGDISCOVERYSERVICE = _descriptor.ServiceDescriptor(
  name='ExtensionConfigDiscoveryService',
  full_name='envoy.service.extension.v3.ExtensionConfigDiscoveryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\212\244\226\363\007+\n)envoy.config.core.v3.TypedExtensionConfig',
  create_key=_descriptor._internal_create_key,
  serialized_start=234,
  serialized_end=747,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamExtensionConfigs',
    full_name='envoy.service.extension.v3.ExtensionConfigDiscoveryService.StreamExtensionConfigs',
    index=0,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeltaExtensionConfigs',
    full_name='envoy.service.extension.v3.ExtensionConfigDiscoveryService.DeltaExtensionConfigs',
    index=1,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DELTADISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DELTADISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchExtensionConfigs',
    full_name='envoy.service.extension.v3.ExtensionConfigDiscoveryService.FetchExtensionConfigs',
    index=2,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=b'\202\323\344\223\002!\"\037/v3/discovery:extension_configs\202\323\344\223\002\003:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXTENSIONCONFIGDISCOVERYSERVICE)

DESCRIPTOR.services_by_name['ExtensionConfigDiscoveryService'] = _EXTENSIONCONFIGDISCOVERYSERVICE

# @@protoc_insertion_point(module_scope)
