# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/decompressor/v3/decompressor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/decompressor/v3/decompressor.proto',
  package='envoy.extensions.filters.http.decompressor.v3',
  syntax='proto3',
  serialized_options=b'\n;io.envoyproxy.envoy.extensions.filters.http.decompressor.v3B\021DecompressorProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n@envoy/extensions/filters/http/decompressor/v3/decompressor.proto\x12-envoy.extensions.filters.http.decompressor.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a$envoy/config/core/v3/extension.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xee\x05\n\x0c\x44\x65\x63ompressor\x12R\n\x14\x64\x65\x63ompressor_library\x18\x01 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12t\n\x18request_direction_config\x18\x02 \x01(\x0b\x32R.envoy.extensions.filters.http.decompressor.v3.Decompressor.RequestDirectionConfig\x12v\n\x19response_direction_config\x18\x03 \x01(\x0b\x32S.envoy.extensions.filters.http.decompressor.v3.Decompressor.ResponseDirectionConfig\x1aR\n\x15\x43ommonDirectionConfig\x12\x39\n\x07\x65nabled\x18\x01 \x01(\x0b\x32(.envoy.config.core.v3.RuntimeFeatureFlag\x1a\xc1\x01\n\x16RequestDirectionConfig\x12h\n\rcommon_config\x18\x01 \x01(\x0b\x32Q.envoy.extensions.filters.http.decompressor.v3.Decompressor.CommonDirectionConfig\x12=\n\x19\x61\x64vertise_accept_encoding\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1a\x83\x01\n\x17ResponseDirectionConfig\x12h\n\rcommon_config\x18\x01 \x01(\x0b\x32Q.envoy.extensions.filters.http.decompressor.v3.Decompressor.CommonDirectionConfigBZ\n;io.envoyproxy.envoy.extensions.filters.http.decompressor.v3B\x11\x44\x65\x63ompressorProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v3_dot_extension__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_DECOMPRESSOR_COMMONDIRECTIONCONFIG = _descriptor.Descriptor(
  name='CommonDirectionConfig',
  full_name='envoy.extensions.filters.http.decompressor.v3.Decompressor.CommonDirectionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='envoy.extensions.filters.http.decompressor.v3.Decompressor.CommonDirectionConfig.enabled', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=613,
  serialized_end=695,
)

_DECOMPRESSOR_REQUESTDIRECTIONCONFIG = _descriptor.Descriptor(
  name='RequestDirectionConfig',
  full_name='envoy.extensions.filters.http.decompressor.v3.Decompressor.RequestDirectionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='common_config', full_name='envoy.extensions.filters.http.decompressor.v3.Decompressor.RequestDirectionConfig.common_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='advertise_accept_encoding', full_name='envoy.extensions.filters.http.decompressor.v3.Decompressor.RequestDirectionConfig.advertise_accept_encoding', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=698,
  serialized_end=891,
)

_DECOMPRESSOR_RESPONSEDIRECTIONCONFIG = _descriptor.Descriptor(
  name='ResponseDirectionConfig',
  full_name='envoy.extensions.filters.http.decompressor.v3.Decompressor.ResponseDirectionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='common_config', full_name='envoy.extensions.filters.http.decompressor.v3.Decompressor.ResponseDirectionConfig.common_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=894,
  serialized_end=1025,
)

_DECOMPRESSOR = _descriptor.Descriptor(
  name='Decompressor',
  full_name='envoy.extensions.filters.http.decompressor.v3.Decompressor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='decompressor_library', full_name='envoy.extensions.filters.http.decompressor.v3.Decompressor.decompressor_library', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_direction_config', full_name='envoy.extensions.filters.http.decompressor.v3.Decompressor.request_direction_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_direction_config', full_name='envoy.extensions.filters.http.decompressor.v3.Decompressor.response_direction_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DECOMPRESSOR_COMMONDIRECTIONCONFIG, _DECOMPRESSOR_REQUESTDIRECTIONCONFIG, _DECOMPRESSOR_RESPONSEDIRECTIONCONFIG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=1025,
)

_DECOMPRESSOR_COMMONDIRECTIONCONFIG.fields_by_name['enabled'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._RUNTIMEFEATUREFLAG
_DECOMPRESSOR_COMMONDIRECTIONCONFIG.containing_type = _DECOMPRESSOR
_DECOMPRESSOR_REQUESTDIRECTIONCONFIG.fields_by_name['common_config'].message_type = _DECOMPRESSOR_COMMONDIRECTIONCONFIG
_DECOMPRESSOR_REQUESTDIRECTIONCONFIG.fields_by_name['advertise_accept_encoding'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_DECOMPRESSOR_REQUESTDIRECTIONCONFIG.containing_type = _DECOMPRESSOR
_DECOMPRESSOR_RESPONSEDIRECTIONCONFIG.fields_by_name['common_config'].message_type = _DECOMPRESSOR_COMMONDIRECTIONCONFIG
_DECOMPRESSOR_RESPONSEDIRECTIONCONFIG.containing_type = _DECOMPRESSOR
_DECOMPRESSOR.fields_by_name['decompressor_library'].message_type = envoy_dot_config_dot_core_dot_v3_dot_extension__pb2._TYPEDEXTENSIONCONFIG
_DECOMPRESSOR.fields_by_name['request_direction_config'].message_type = _DECOMPRESSOR_REQUESTDIRECTIONCONFIG
_DECOMPRESSOR.fields_by_name['response_direction_config'].message_type = _DECOMPRESSOR_RESPONSEDIRECTIONCONFIG
DESCRIPTOR.message_types_by_name['Decompressor'] = _DECOMPRESSOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Decompressor = _reflection.GeneratedProtocolMessageType('Decompressor', (_message.Message,), {

  'CommonDirectionConfig' : _reflection.GeneratedProtocolMessageType('CommonDirectionConfig', (_message.Message,), {
    'DESCRIPTOR' : _DECOMPRESSOR_COMMONDIRECTIONCONFIG,
    '__module__' : 'envoy.extensions.filters.http.decompressor.v3.decompressor_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.decompressor.v3.Decompressor.CommonDirectionConfig)
    })
  ,

  'RequestDirectionConfig' : _reflection.GeneratedProtocolMessageType('RequestDirectionConfig', (_message.Message,), {
    'DESCRIPTOR' : _DECOMPRESSOR_REQUESTDIRECTIONCONFIG,
    '__module__' : 'envoy.extensions.filters.http.decompressor.v3.decompressor_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.decompressor.v3.Decompressor.RequestDirectionConfig)
    })
  ,

  'ResponseDirectionConfig' : _reflection.GeneratedProtocolMessageType('ResponseDirectionConfig', (_message.Message,), {
    'DESCRIPTOR' : _DECOMPRESSOR_RESPONSEDIRECTIONCONFIG,
    '__module__' : 'envoy.extensions.filters.http.decompressor.v3.decompressor_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.decompressor.v3.Decompressor.ResponseDirectionConfig)
    })
  ,
  'DESCRIPTOR' : _DECOMPRESSOR,
  '__module__' : 'envoy.extensions.filters.http.decompressor.v3.decompressor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.decompressor.v3.Decompressor)
  })
_sym_db.RegisterMessage(Decompressor)
_sym_db.RegisterMessage(Decompressor.CommonDirectionConfig)
_sym_db.RegisterMessage(Decompressor.RequestDirectionConfig)
_sym_db.RegisterMessage(Decompressor.ResponseDirectionConfig)


DESCRIPTOR._options = None
_DECOMPRESSOR.fields_by_name['decompressor_library']._options = None
# @@protoc_insertion_point(module_scope)
