# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/mysql_proxy/v3/mysql_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/network/mysql_proxy/v3/mysql_proxy.proto',
  package='envoy.extensions.filters.network.mysql_proxy.v3',
  syntax='proto3',
  serialized_options=b'\n=io.envoyproxy.envoy.extensions.filters.network.mysql_proxy.v3B\017MysqlProxyProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nAenvoy/extensions/filters/network/mysql_proxy/v3/mysql_proxy.proto\x12/envoy.extensions.filters.network.mysql_proxy.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x82\x01\n\nMySQLProxy\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\naccess_log\x18\x02 \x01(\t:B\x9a\xc5\x88\x1e=\n;envoy.config.filter.network.mysql_proxy.v1alpha1.MySQLProxyBZ\n=io.envoyproxy.envoy.extensions.filters.network.mysql_proxy.v3B\x0fMysqlProxyProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_MYSQLPROXY = _descriptor.Descriptor(
  name='MySQLProxy',
  full_name='envoy.extensions.filters.network.mysql_proxy.v3.MySQLProxy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.extensions.filters.network.mysql_proxy.v3.MySQLProxy.stat_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_log', full_name='envoy.extensions.filters.network.mysql_proxy.v3.MySQLProxy.access_log', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036=\n;envoy.config.filter.network.mysql_proxy.v1alpha1.MySQLProxy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=210,
  serialized_end=340,
)

DESCRIPTOR.message_types_by_name['MySQLProxy'] = _MYSQLPROXY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MySQLProxy = _reflection.GeneratedProtocolMessageType('MySQLProxy', (_message.Message,), {
  'DESCRIPTOR' : _MYSQLPROXY,
  '__module__' : 'envoy.extensions.filters.network.mysql_proxy.v3.mysql_proxy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.mysql_proxy.v3.MySQLProxy)
  })
_sym_db.RegisterMessage(MySQLProxy)


DESCRIPTOR._options = None
_MYSQLPROXY.fields_by_name['stat_prefix']._options = None
_MYSQLPROXY._options = None
# @@protoc_insertion_point(module_scope)
