# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/overload/v3/overload.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/overload/v3/overload.proto',
  package='envoy.config.overload.v3',
  syntax='proto3',
  serialized_options=b'\n&io.envoyproxy.envoy.config.overload.v3B\rOverloadProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'envoy/config/overload/v3/overload.proto\x12\x18\x65nvoy.config.overload.v3\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xa9\x01\n\x0fResourceMonitor\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00:4\x9a\xc5\x88\x1e/\n-envoy.config.overload.v2alpha.ResourceMonitorB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfig\"q\n\x10ThresholdTrigger\x12&\n\x05value\x18\x01 \x01(\x01\x42\x17\xfa\x42\x14\x12\x12\x19\x00\x00\x00\x00\x00\x00\xf0?)\x00\x00\x00\x00\x00\x00\x00\x00:5\x9a\xc5\x88\x1e\x30\n.envoy.config.overload.v2alpha.ThresholdTrigger\"z\n\rScaledTrigger\x12\x32\n\x11scaling_threshold\x18\x01 \x01(\x01\x42\x17\xfa\x42\x14\x12\x12\x19\x00\x00\x00\x00\x00\x00\xf0?)\x00\x00\x00\x00\x00\x00\x00\x00\x12\x35\n\x14saturation_threshold\x18\x02 \x01(\x01\x42\x17\xfa\x42\x14\x12\x12\x19\x00\x00\x00\x00\x00\x00\xf0?)\x00\x00\x00\x00\x00\x00\x00\x00\"\xe0\x01\n\x07Trigger\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12?\n\tthreshold\x18\x02 \x01(\x0b\x32*.envoy.config.overload.v3.ThresholdTriggerH\x00\x12\x39\n\x06scaled\x18\x03 \x01(\x0b\x32\'.envoy.config.overload.v3.ScaledTriggerH\x00:,\x9a\xc5\x88\x1e\'\n%envoy.config.overload.v2alpha.TriggerB\x14\n\rtrigger_oneof\x12\x03\xf8\x42\x01\"\xf7\x03\n\x1fScaleTimersOverloadActionConfig\x12k\n\x13timer_scale_factors\x18\x01 \x03(\x0b\x32\x44.envoy.config.overload.v3.ScaleTimersOverloadActionConfig.ScaleTimerB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\xe3\x01\n\nScaleTimer\x12^\n\x05timer\x18\x01 \x01(\x0e\x32\x43.envoy.config.overload.v3.ScaleTimersOverloadActionConfig.TimerTypeB\n\xfa\x42\x07\x82\x01\x04\x10\x01 \x00\x12\x30\n\x0bmin_timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00\x12+\n\tmin_scale\x18\x03 \x01(\x0b\x32\x16.envoy.type.v3.PercentH\x00\x42\x16\n\x0foverload_adjust\x12\x03\xf8\x42\x01\"\x80\x01\n\tTimerType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12#\n\x1fHTTP_DOWNSTREAM_CONNECTION_IDLE\x10\x01\x12\x1f\n\x1bHTTP_DOWNSTREAM_STREAM_IDLE\x10\x02\x12\x1c\n\x18TRANSPORT_SOCKET_CONNECT\x10\x03\"\xc7\x01\n\x0eOverloadAction\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12=\n\x08triggers\x18\x02 \x03(\x0b\x32!.envoy.config.overload.v3.TriggerB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12*\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any:3\x9a\xc5\x88\x1e.\n,envoy.config.overload.v2alpha.OverloadAction\"\x87\x02\n\x0fOverloadManager\x12\x33\n\x10refresh_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12N\n\x11resource_monitors\x18\x02 \x03(\x0b\x32).envoy.config.overload.v3.ResourceMonitorB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12\x39\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32(.envoy.config.overload.v3.OverloadAction:4\x9a\xc5\x88\x1e/\n-envoy.config.overload.v2alpha.OverloadManagerBA\n&io.envoyproxy.envoy.config.overload.v3B\rOverloadProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_type_dot_v3_dot_percent__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_SCALETIMERSOVERLOADACTIONCONFIG_TIMERTYPE = _descriptor.EnumDescriptor(
  name='TimerType',
  full_name='envoy.config.overload.v3.ScaleTimersOverloadActionConfig.TimerType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP_DOWNSTREAM_CONNECTION_IDLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP_DOWNSTREAM_STREAM_IDLE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRANSPORT_SOCKET_CONNECT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1262,
  serialized_end=1390,
)
_sym_db.RegisterEnumDescriptor(_SCALETIMERSOVERLOADACTIONCONFIG_TIMERTYPE)


_RESOURCEMONITOR = _descriptor.Descriptor(
  name='ResourceMonitor',
  full_name='envoy.config.overload.v3.ResourceMonitor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.overload.v3.ResourceMonitor.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.config.overload.v3.ResourceMonitor.typed_config', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036/\n-envoy.config.overload.v2alpha.ResourceMonitor',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.config.overload.v3.ResourceMonitor.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=249,
  serialized_end=418,
)


_THRESHOLDTRIGGER = _descriptor.Descriptor(
  name='ThresholdTrigger',
  full_name='envoy.config.overload.v3.ThresholdTrigger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.config.overload.v3.ThresholdTrigger.value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\024\022\022\031\000\000\000\000\000\000\360?)\000\000\000\000\000\000\000\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0360\n.envoy.config.overload.v2alpha.ThresholdTrigger',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=420,
  serialized_end=533,
)


_SCALEDTRIGGER = _descriptor.Descriptor(
  name='ScaledTrigger',
  full_name='envoy.config.overload.v3.ScaledTrigger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scaling_threshold', full_name='envoy.config.overload.v3.ScaledTrigger.scaling_threshold', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\024\022\022\031\000\000\000\000\000\000\360?)\000\000\000\000\000\000\000\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='saturation_threshold', full_name='envoy.config.overload.v3.ScaledTrigger.saturation_threshold', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\024\022\022\031\000\000\000\000\000\000\360?)\000\000\000\000\000\000\000\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=535,
  serialized_end=657,
)


_TRIGGER = _descriptor.Descriptor(
  name='Trigger',
  full_name='envoy.config.overload.v3.Trigger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.overload.v3.Trigger.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threshold', full_name='envoy.config.overload.v3.Trigger.threshold', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scaled', full_name='envoy.config.overload.v3.Trigger.scaled', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\'\n%envoy.config.overload.v2alpha.Trigger',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='trigger_oneof', full_name='envoy.config.overload.v3.Trigger.trigger_oneof',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=660,
  serialized_end=884,
)


_SCALETIMERSOVERLOADACTIONCONFIG_SCALETIMER = _descriptor.Descriptor(
  name='ScaleTimer',
  full_name='envoy.config.overload.v3.ScaleTimersOverloadActionConfig.ScaleTimer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timer', full_name='envoy.config.overload.v3.ScaleTimersOverloadActionConfig.ScaleTimer.timer', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007\202\001\004\020\001 \000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_timeout', full_name='envoy.config.overload.v3.ScaleTimersOverloadActionConfig.ScaleTimer.min_timeout', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_scale', full_name='envoy.config.overload.v3.ScaleTimersOverloadActionConfig.ScaleTimer.min_scale', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='overload_adjust', full_name='envoy.config.overload.v3.ScaleTimersOverloadActionConfig.ScaleTimer.overload_adjust',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1032,
  serialized_end=1259,
)

_SCALETIMERSOVERLOADACTIONCONFIG = _descriptor.Descriptor(
  name='ScaleTimersOverloadActionConfig',
  full_name='envoy.config.overload.v3.ScaleTimersOverloadActionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timer_scale_factors', full_name='envoy.config.overload.v3.ScaleTimersOverloadActionConfig.timer_scale_factors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCALETIMERSOVERLOADACTIONCONFIG_SCALETIMER, ],
  enum_types=[
    _SCALETIMERSOVERLOADACTIONCONFIG_TIMERTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=887,
  serialized_end=1390,
)


_OVERLOADACTION = _descriptor.Descriptor(
  name='OverloadAction',
  full_name='envoy.config.overload.v3.OverloadAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.overload.v3.OverloadAction.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='triggers', full_name='envoy.config.overload.v3.OverloadAction.triggers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.config.overload.v3.OverloadAction.typed_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036.\n,envoy.config.overload.v2alpha.OverloadAction',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1393,
  serialized_end=1592,
)


_OVERLOADMANAGER = _descriptor.Descriptor(
  name='OverloadManager',
  full_name='envoy.config.overload.v3.OverloadManager',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='refresh_interval', full_name='envoy.config.overload.v3.OverloadManager.refresh_interval', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_monitors', full_name='envoy.config.overload.v3.OverloadManager.resource_monitors', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actions', full_name='envoy.config.overload.v3.OverloadManager.actions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036/\n-envoy.config.overload.v2alpha.OverloadManager',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1595,
  serialized_end=1858,
)

_RESOURCEMONITOR.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_RESOURCEMONITOR.oneofs_by_name['config_type'].fields.append(
  _RESOURCEMONITOR.fields_by_name['typed_config'])
_RESOURCEMONITOR.fields_by_name['typed_config'].containing_oneof = _RESOURCEMONITOR.oneofs_by_name['config_type']
_TRIGGER.fields_by_name['threshold'].message_type = _THRESHOLDTRIGGER
_TRIGGER.fields_by_name['scaled'].message_type = _SCALEDTRIGGER
_TRIGGER.oneofs_by_name['trigger_oneof'].fields.append(
  _TRIGGER.fields_by_name['threshold'])
_TRIGGER.fields_by_name['threshold'].containing_oneof = _TRIGGER.oneofs_by_name['trigger_oneof']
_TRIGGER.oneofs_by_name['trigger_oneof'].fields.append(
  _TRIGGER.fields_by_name['scaled'])
_TRIGGER.fields_by_name['scaled'].containing_oneof = _TRIGGER.oneofs_by_name['trigger_oneof']
_SCALETIMERSOVERLOADACTIONCONFIG_SCALETIMER.fields_by_name['timer'].enum_type = _SCALETIMERSOVERLOADACTIONCONFIG_TIMERTYPE
_SCALETIMERSOVERLOADACTIONCONFIG_SCALETIMER.fields_by_name['min_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_SCALETIMERSOVERLOADACTIONCONFIG_SCALETIMER.fields_by_name['min_scale'].message_type = envoy_dot_type_dot_v3_dot_percent__pb2._PERCENT
_SCALETIMERSOVERLOADACTIONCONFIG_SCALETIMER.containing_type = _SCALETIMERSOVERLOADACTIONCONFIG
_SCALETIMERSOVERLOADACTIONCONFIG_SCALETIMER.oneofs_by_name['overload_adjust'].fields.append(
  _SCALETIMERSOVERLOADACTIONCONFIG_SCALETIMER.fields_by_name['min_timeout'])
_SCALETIMERSOVERLOADACTIONCONFIG_SCALETIMER.fields_by_name['min_timeout'].containing_oneof = _SCALETIMERSOVERLOADACTIONCONFIG_SCALETIMER.oneofs_by_name['overload_adjust']
_SCALETIMERSOVERLOADACTIONCONFIG_SCALETIMER.oneofs_by_name['overload_adjust'].fields.append(
  _SCALETIMERSOVERLOADACTIONCONFIG_SCALETIMER.fields_by_name['min_scale'])
_SCALETIMERSOVERLOADACTIONCONFIG_SCALETIMER.fields_by_name['min_scale'].containing_oneof = _SCALETIMERSOVERLOADACTIONCONFIG_SCALETIMER.oneofs_by_name['overload_adjust']
_SCALETIMERSOVERLOADACTIONCONFIG.fields_by_name['timer_scale_factors'].message_type = _SCALETIMERSOVERLOADACTIONCONFIG_SCALETIMER
_SCALETIMERSOVERLOADACTIONCONFIG_TIMERTYPE.containing_type = _SCALETIMERSOVERLOADACTIONCONFIG
_OVERLOADACTION.fields_by_name['triggers'].message_type = _TRIGGER
_OVERLOADACTION.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_OVERLOADMANAGER.fields_by_name['refresh_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_OVERLOADMANAGER.fields_by_name['resource_monitors'].message_type = _RESOURCEMONITOR
_OVERLOADMANAGER.fields_by_name['actions'].message_type = _OVERLOADACTION
DESCRIPTOR.message_types_by_name['ResourceMonitor'] = _RESOURCEMONITOR
DESCRIPTOR.message_types_by_name['ThresholdTrigger'] = _THRESHOLDTRIGGER
DESCRIPTOR.message_types_by_name['ScaledTrigger'] = _SCALEDTRIGGER
DESCRIPTOR.message_types_by_name['Trigger'] = _TRIGGER
DESCRIPTOR.message_types_by_name['ScaleTimersOverloadActionConfig'] = _SCALETIMERSOVERLOADACTIONCONFIG
DESCRIPTOR.message_types_by_name['OverloadAction'] = _OVERLOADACTION
DESCRIPTOR.message_types_by_name['OverloadManager'] = _OVERLOADMANAGER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ResourceMonitor = _reflection.GeneratedProtocolMessageType('ResourceMonitor', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEMONITOR,
  '__module__' : 'envoy.config.overload.v3.overload_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.overload.v3.ResourceMonitor)
  })
_sym_db.RegisterMessage(ResourceMonitor)

ThresholdTrigger = _reflection.GeneratedProtocolMessageType('ThresholdTrigger', (_message.Message,), {
  'DESCRIPTOR' : _THRESHOLDTRIGGER,
  '__module__' : 'envoy.config.overload.v3.overload_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.overload.v3.ThresholdTrigger)
  })
_sym_db.RegisterMessage(ThresholdTrigger)

ScaledTrigger = _reflection.GeneratedProtocolMessageType('ScaledTrigger', (_message.Message,), {
  'DESCRIPTOR' : _SCALEDTRIGGER,
  '__module__' : 'envoy.config.overload.v3.overload_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.overload.v3.ScaledTrigger)
  })
_sym_db.RegisterMessage(ScaledTrigger)

Trigger = _reflection.GeneratedProtocolMessageType('Trigger', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGER,
  '__module__' : 'envoy.config.overload.v3.overload_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.overload.v3.Trigger)
  })
_sym_db.RegisterMessage(Trigger)

ScaleTimersOverloadActionConfig = _reflection.GeneratedProtocolMessageType('ScaleTimersOverloadActionConfig', (_message.Message,), {

  'ScaleTimer' : _reflection.GeneratedProtocolMessageType('ScaleTimer', (_message.Message,), {
    'DESCRIPTOR' : _SCALETIMERSOVERLOADACTIONCONFIG_SCALETIMER,
    '__module__' : 'envoy.config.overload.v3.overload_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.overload.v3.ScaleTimersOverloadActionConfig.ScaleTimer)
    })
  ,
  'DESCRIPTOR' : _SCALETIMERSOVERLOADACTIONCONFIG,
  '__module__' : 'envoy.config.overload.v3.overload_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.overload.v3.ScaleTimersOverloadActionConfig)
  })
_sym_db.RegisterMessage(ScaleTimersOverloadActionConfig)
_sym_db.RegisterMessage(ScaleTimersOverloadActionConfig.ScaleTimer)

OverloadAction = _reflection.GeneratedProtocolMessageType('OverloadAction', (_message.Message,), {
  'DESCRIPTOR' : _OVERLOADACTION,
  '__module__' : 'envoy.config.overload.v3.overload_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.overload.v3.OverloadAction)
  })
_sym_db.RegisterMessage(OverloadAction)

OverloadManager = _reflection.GeneratedProtocolMessageType('OverloadManager', (_message.Message,), {
  'DESCRIPTOR' : _OVERLOADMANAGER,
  '__module__' : 'envoy.config.overload.v3.overload_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.overload.v3.OverloadManager)
  })
_sym_db.RegisterMessage(OverloadManager)


DESCRIPTOR._options = None
_RESOURCEMONITOR.fields_by_name['name']._options = None
_RESOURCEMONITOR._options = None
_THRESHOLDTRIGGER.fields_by_name['value']._options = None
_THRESHOLDTRIGGER._options = None
_SCALEDTRIGGER.fields_by_name['scaling_threshold']._options = None
_SCALEDTRIGGER.fields_by_name['saturation_threshold']._options = None
_TRIGGER.oneofs_by_name['trigger_oneof']._options = None
_TRIGGER.fields_by_name['name']._options = None
_TRIGGER._options = None
_SCALETIMERSOVERLOADACTIONCONFIG_SCALETIMER.oneofs_by_name['overload_adjust']._options = None
_SCALETIMERSOVERLOADACTIONCONFIG_SCALETIMER.fields_by_name['timer']._options = None
_SCALETIMERSOVERLOADACTIONCONFIG.fields_by_name['timer_scale_factors']._options = None
_OVERLOADACTION.fields_by_name['name']._options = None
_OVERLOADACTION.fields_by_name['triggers']._options = None
_OVERLOADACTION._options = None
_OVERLOADMANAGER.fields_by_name['resource_monitors']._options = None
_OVERLOADMANAGER._options = None
# @@protoc_insertion_point(module_scope)
