# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/runtime/v3/rtds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.service.discovery.v3 import discovery_pb2 as envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/runtime/v3/rtds.proto',
  package='envoy.service.runtime.v3',
  syntax='proto3',
  serialized_options=b'\n&io.envoyproxy.envoy.service.runtime.v3B\tRtdsProtoP\001\210\001\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#envoy/service/runtime/v3/rtds.proto\x12\x18\x65nvoy.service.runtime.v3\x1a*envoy/service/discovery/v3/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a envoy/annotations/resource.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"8\n\tRtdsDummy:+\x9a\xc5\x88\x1e&\n$envoy.service.discovery.v2.RtdsDummy\"s\n\x07Runtime\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12&\n\x05layer\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:)\x9a\xc5\x88\x1e$\n\"envoy.service.discovery.v2.Runtime2\xca\x03\n\x17RuntimeDiscoveryService\x12r\n\rStreamRuntime\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"\x00(\x01\x30\x01\x12{\n\x0c\x44\x65ltaRuntime\x12\x31.envoy.service.discovery.v3.DeltaDiscoveryRequest\x1a\x32.envoy.service.discovery.v3.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12\x93\x01\n\x0c\x46\x65tchRuntime\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"&\x82\xd3\xe4\x93\x02\x17\"\x15/v3/discovery:runtime\x82\xd3\xe4\x93\x02\x03:\x01*\x1a(\x8a\xa4\x96\xf3\x07\"\n envoy.service.runtime.v3.RuntimeB@\n&io.envoyproxy.envoy.service.runtime.v3B\tRtdsProtoP\x01\x88\x01\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,envoy_dot_annotations_dot_resource__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_RTDSDUMMY = _descriptor.Descriptor(
  name='RtdsDummy',
  full_name='envoy.service.runtime.v3.RtdsDummy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036&\n$envoy.service.discovery.v2.RtdsDummy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=294,
  serialized_end=350,
)


_RUNTIME = _descriptor.Descriptor(
  name='Runtime',
  full_name='envoy.service.runtime.v3.Runtime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.service.runtime.v3.Runtime.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='layer', full_name='envoy.service.runtime.v3.Runtime.layer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036$\n\"envoy.service.discovery.v2.Runtime',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=352,
  serialized_end=467,
)

_RUNTIME.fields_by_name['layer'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
DESCRIPTOR.message_types_by_name['RtdsDummy'] = _RTDSDUMMY
DESCRIPTOR.message_types_by_name['Runtime'] = _RUNTIME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RtdsDummy = _reflection.GeneratedProtocolMessageType('RtdsDummy', (_message.Message,), {
  'DESCRIPTOR' : _RTDSDUMMY,
  '__module__' : 'envoy.service.runtime.v3.rtds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.runtime.v3.RtdsDummy)
  })
_sym_db.RegisterMessage(RtdsDummy)

Runtime = _reflection.GeneratedProtocolMessageType('Runtime', (_message.Message,), {
  'DESCRIPTOR' : _RUNTIME,
  '__module__' : 'envoy.service.runtime.v3.rtds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.runtime.v3.Runtime)
  })
_sym_db.RegisterMessage(Runtime)


DESCRIPTOR._options = None
_RTDSDUMMY._options = None
_RUNTIME.fields_by_name['name']._options = None
_RUNTIME._options = None

_RUNTIMEDISCOVERYSERVICE = _descriptor.ServiceDescriptor(
  name='RuntimeDiscoveryService',
  full_name='envoy.service.runtime.v3.RuntimeDiscoveryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\212\244\226\363\007\"\n envoy.service.runtime.v3.Runtime',
  create_key=_descriptor._internal_create_key,
  serialized_start=470,
  serialized_end=928,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamRuntime',
    full_name='envoy.service.runtime.v3.RuntimeDiscoveryService.StreamRuntime',
    index=0,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeltaRuntime',
    full_name='envoy.service.runtime.v3.RuntimeDiscoveryService.DeltaRuntime',
    index=1,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DELTADISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DELTADISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchRuntime',
    full_name='envoy.service.runtime.v3.RuntimeDiscoveryService.FetchRuntime',
    index=2,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\"\025/v3/discovery:runtime\202\323\344\223\002\003:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RUNTIMEDISCOVERYSERVICE)

DESCRIPTOR.services_by_name['RuntimeDiscoveryService'] = _RUNTIMEDISCOVERYSERVICE

# @@protoc_insertion_point(module_scope)
