# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/transport_socket/raw_buffer/v2/raw_buffer.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/transport_socket/raw_buffer/v2/raw_buffer.proto',
  package='envoy.config.transport_socket.raw_buffer.v2',
  syntax='proto3',
  serialized_options=b'\n9io.envoyproxy.envoy.config.transport_socket.raw_buffer.v2B\016RawBufferProtoP\001\362\230\376\217\0052\0220envoy.extensions.transport_sockets.raw_buffer.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n<envoy/config/transport_socket/raw_buffer/v2/raw_buffer.proto\x12+envoy.config.transport_socket.raw_buffer.v2\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\x0b\n\tRawBufferB\x8d\x01\n9io.envoyproxy.envoy.config.transport_socket.raw_buffer.v2B\x0eRawBufferProtoP\x01\xf2\x98\xfe\x8f\x05\x32\x12\x30\x65nvoy.extensions.transport_sockets.raw_buffer.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_RAWBUFFER = _descriptor.Descriptor(
  name='RawBuffer',
  full_name='envoy.config.transport_socket.raw_buffer.v2.RawBuffer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=172,
  serialized_end=183,
)

DESCRIPTOR.message_types_by_name['RawBuffer'] = _RAWBUFFER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RawBuffer = _reflection.GeneratedProtocolMessageType('RawBuffer', (_message.Message,), {
  'DESCRIPTOR' : _RAWBUFFER,
  '__module__' : 'envoy.config.transport_socket.raw_buffer.v2.raw_buffer_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.transport_socket.raw_buffer.v2.RawBuffer)
  })
_sym_db.RegisterMessage(RawBuffer)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
