# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/udp/udp_proxy/v2alpha/udp_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/udp/udp_proxy/v2alpha/udp_proxy.proto',
  package='envoy.config.filter.udp.udp_proxy.v2alpha',
  syntax='proto3',
  serialized_options=b'\n7io.envoyproxy.envoy.config.filter.udp.udp_proxy.v2alphaB\rUdpProxyProtoP\001\362\230\376\217\005+\022)envoy.extensions.filters.udp.udp_proxy.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n9envoy/config/filter/udp/udp_proxy/v2alpha/udp_proxy.proto\x12)envoy.config.filter.udp.udp_proxy.v2alpha\x1a\x1egoogle/protobuf/duration.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x93\x01\n\x0eUdpProxyConfig\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x1a\n\x07\x63luster\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01H\x00\x12/\n\x0cidle_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x16\n\x0froute_specifier\x12\x03\xf8\x42\x01\x42\x83\x01\n7io.envoyproxy.envoy.config.filter.udp.udp_proxy.v2alphaB\rUdpProxyProtoP\x01\xf2\x98\xfe\x8f\x05+\x12)envoy.extensions.filters.udp.udp_proxy.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_UDPPROXYCONFIG = _descriptor.Descriptor(
  name='UdpProxyConfig',
  full_name='envoy.config.filter.udp.udp_proxy.v2alpha.UdpProxyConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.config.filter.udp.udp_proxy.v2alpha.UdpProxyConfig.stat_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='envoy.config.filter.udp.udp_proxy.v2alpha.UdpProxyConfig.cluster', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idle_timeout', full_name='envoy.config.filter.udp.udp_proxy.v2alpha.UdpProxyConfig.idle_timeout', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='route_specifier', full_name='envoy.config.filter.udp.udp_proxy.v2alpha.UdpProxyConfig.route_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=225,
  serialized_end=372,
)

_UDPPROXYCONFIG.fields_by_name['idle_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_UDPPROXYCONFIG.oneofs_by_name['route_specifier'].fields.append(
  _UDPPROXYCONFIG.fields_by_name['cluster'])
_UDPPROXYCONFIG.fields_by_name['cluster'].containing_oneof = _UDPPROXYCONFIG.oneofs_by_name['route_specifier']
DESCRIPTOR.message_types_by_name['UdpProxyConfig'] = _UDPPROXYCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UdpProxyConfig = _reflection.GeneratedProtocolMessageType('UdpProxyConfig', (_message.Message,), {
  'DESCRIPTOR' : _UDPPROXYCONFIG,
  '__module__' : 'envoy.config.filter.udp.udp_proxy.v2alpha.udp_proxy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.udp.udp_proxy.v2alpha.UdpProxyConfig)
  })
_sym_db.RegisterMessage(UdpProxyConfig)


DESCRIPTOR._options = None
_UDPPROXYCONFIG.oneofs_by_name['route_specifier']._options = None
_UDPPROXYCONFIG.fields_by_name['stat_prefix']._options = None
_UDPPROXYCONFIG.fields_by_name['cluster']._options = None
# @@protoc_insertion_point(module_scope)
