# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/cors/v3/cors.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/cors/v3/cors.proto',
  package='envoy.extensions.filters.http.cors.v3',
  syntax='proto3',
  serialized_options=b'\n3io.envoyproxy.envoy.extensions.filters.http.cors.v3B\tCorsProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0envoy/extensions/filters/http/cors/v3/cors.proto\x12%envoy.extensions.filters.http.cors.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"4\n\x04\x43ors:,\x9a\xc5\x88\x1e\'\n%envoy.config.filter.http.cors.v2.CorsBJ\n3io.envoyproxy.envoy.extensions.filters.http.cors.v3B\tCorsProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_CORS = _descriptor.Descriptor(
  name='Cors',
  full_name='envoy.extensions.filters.http.cors.v3.Cors',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\'\n%envoy.config.filter.http.cors.v2.Cors',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=209,
)

DESCRIPTOR.message_types_by_name['Cors'] = _CORS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Cors = _reflection.GeneratedProtocolMessageType('Cors', (_message.Message,), {
  'DESCRIPTOR' : _CORS,
  '__module__' : 'envoy.extensions.filters.http.cors.v3.cors_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.cors.v3.Cors)
  })
_sym_db.RegisterMessage(Cors)


DESCRIPTOR._options = None
_CORS._options = None
# @@protoc_insertion_point(module_scope)
