# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v3/base.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.config.core.v3 import backoff_pb2 as envoy_dot_config_dot_core_dot_v3_dot_backoff__pb2
from envoy.config.core.v3 import http_uri_pb2 as envoy_dot_config_dot_core_dot_v3_dot_http__uri__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from envoy.type.v3 import semantic_version_pb2 as envoy_dot_type_dot_v3_dot_semantic__version__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/core/v3/base.proto',
  package='envoy.config.core.v3',
  syntax='proto3',
  serialized_options=b'\n\"io.envoyproxy.envoy.config.core.v3B\tBaseProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1f\x65nvoy/config/core/v3/base.proto\x12\x14\x65nvoy.config.core.v3\x1a\"envoy/config/core/v3/address.proto\x1a\"envoy/config/core/v3/backoff.proto\x1a#envoy/config/core/v3/http_uri.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a$envoy/type/v3/semantic_version.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"]\n\x08Locality\x12\x0e\n\x06region\x18\x01 \x01(\t\x12\x0c\n\x04zone\x18\x02 \x01(\t\x12\x10\n\x08sub_zone\x18\x03 \x01(\t:!\x9a\xc5\x88\x1e\x1c\n\x1a\x65nvoy.api.v2.core.Locality\"\x91\x01\n\x0c\x42uildVersion\x12/\n\x07version\x18\x01 \x01(\x0b\x32\x1e.envoy.type.v3.SemanticVersion\x12)\n\x08metadata\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:%\x9a\xc5\x88\x1e \n\x1e\x65nvoy.api.v2.core.BuildVersion\"\xaf\x01\n\tExtension\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x17\n\x0ftype_descriptor\x18\x03 \x01(\t\x12\x33\n\x07version\x18\x04 \x01(\x0b\x32\".envoy.config.core.v3.BuildVersion\x12\x10\n\x08\x64isabled\x18\x05 \x01(\x08:\"\x9a\xc5\x88\x1e\x1d\n\x1b\x65nvoy.api.v2.core.Extension\"\xdc\x03\n\x04Node\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x63luster\x18\x02 \x01(\t\x12)\n\x08metadata\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x30\n\x08locality\x18\x04 \x01(\x0b\x32\x1e.envoy.config.core.v3.Locality\x12\x17\n\x0fuser_agent_name\x18\x06 \x01(\t\x12\x1c\n\x12user_agent_version\x18\x07 \x01(\tH\x00\x12\x46\n\x18user_agent_build_version\x18\x08 \x01(\x0b\x32\".envoy.config.core.v3.BuildVersionH\x00\x12\x33\n\nextensions\x18\t \x03(\x0b\x32\x1f.envoy.config.core.v3.Extension\x12\x17\n\x0f\x63lient_features\x18\n \x03(\t\x12>\n\x13listening_addresses\x18\x0b \x03(\x0b\x32\x1d.envoy.config.core.v3.AddressB\x02\x18\x01:\x1d\x9a\xc5\x88\x1e\x18\n\x16\x65nvoy.api.v2.core.NodeB\x19\n\x17user_agent_version_typeJ\x04\x08\x05\x10\x06R\rbuild_version\"\xca\x01\n\x08Metadata\x12K\n\x0f\x66ilter_metadata\x18\x01 \x03(\x0b\x32\x32.envoy.config.core.v3.Metadata.FilterMetadataEntry\x1aN\n\x13\x46ilterMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:\x02\x38\x01:!\x9a\xc5\x88\x1e\x1c\n\x1a\x65nvoy.api.v2.core.Metadata\"l\n\rRuntimeUInt32\x12\x15\n\rdefault_value\x18\x02 \x01(\r\x12\x1c\n\x0bruntime_key\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01:&\x9a\xc5\x88\x1e!\n\x1f\x65nvoy.api.v2.core.RuntimeUInt32\"]\n\x0eRuntimePercent\x12-\n\rdefault_value\x18\x01 \x01(\x0b\x32\x16.envoy.type.v3.Percent\x12\x1c\n\x0bruntime_key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"l\n\rRuntimeDouble\x12\x15\n\rdefault_value\x18\x01 \x01(\x01\x12\x1c\n\x0bruntime_key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01:&\x9a\xc5\x88\x1e!\n\x1f\x65nvoy.api.v2.core.RuntimeDouble\"\x9c\x01\n\x12RuntimeFeatureFlag\x12;\n\rdefault_value\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x1c\n\x0bruntime_key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01:+\x9a\xc5\x88\x1e&\n$envoy.api.v2.core.RuntimeFeatureFlag\"s\n\x0bHeaderValue\x12\x1e\n\x03key\x18\x01 \x01(\tB\x11\xfa\x42\x0er\x0c\x10\x01(\x80\x80\x01\xc0\x01\x01\xc8\x01\x00\x12\x1e\n\x05value\x18\x02 \x01(\tB\x0f\xfa\x42\x0cr\n(\x80\x80\x01\xc0\x01\x02\xc8\x01\x00:$\x9a\xc5\x88\x1e\x1f\n\x1d\x65nvoy.api.v2.core.HeaderValue\"\xa8\x01\n\x11HeaderValueOption\x12;\n\x06header\x18\x01 \x01(\x0b\x32!.envoy.config.core.v3.HeaderValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12*\n\x06\x61ppend\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue:*\x9a\xc5\x88\x1e%\n#envoy.api.v2.core.HeaderValueOption\"c\n\tHeaderMap\x12\x32\n\x07headers\x18\x01 \x03(\x0b\x32!.envoy.config.core.v3.HeaderValue:\"\x9a\xc5\x88\x1e\x1d\n\x1b\x65nvoy.api.v2.core.HeaderMap\")\n\x10WatchedDirectory\x12\x15\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\x91\x01\n\nDataSource\x12\x1b\n\x08\x66ilename\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x16\n\x0cinline_bytes\x18\x02 \x01(\x0cH\x00\x12\x17\n\rinline_string\x18\x03 \x01(\tH\x00:#\x9a\xc5\x88\x1e\x1e\n\x1c\x65nvoy.api.v2.core.DataSourceB\x10\n\tspecifier\x12\x03\xf8\x42\x01\"\xba\x01\n\x0bRetryPolicy\x12=\n\x0eretry_back_off\x18\x01 \x01(\x0b\x32%.envoy.config.core.v3.BackoffStrategy\x12\x46\n\x0bnum_retries\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x13\xf2\x98\xfe\x8f\x05\r\n\x0bmax_retries:$\x9a\xc5\x88\x1e\x1f\n\x1d\x65nvoy.api.v2.core.RetryPolicy\"\xca\x01\n\x10RemoteDataSource\x12\x39\n\x08http_uri\x18\x01 \x01(\x0b\x32\x1d.envoy.config.core.v3.HttpUriB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x17\n\x06sha256\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x37\n\x0cretry_policy\x18\x03 \x01(\x0b\x32!.envoy.config.core.v3.RetryPolicy:)\x9a\xc5\x88\x1e$\n\"envoy.api.v2.core.RemoteDataSource\"\xba\x01\n\x0f\x41syncDataSource\x12\x31\n\x05local\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceH\x00\x12\x38\n\x06remote\x18\x02 \x01(\x0b\x32&.envoy.config.core.v3.RemoteDataSourceH\x00:(\x9a\xc5\x88\x1e#\n!envoy.api.v2.core.AsyncDataSourceB\x10\n\tspecifier\x12\x03\xf8\x42\x01\"\x9d\x01\n\x0fTransportSocket\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00:(\x9a\xc5\x88\x1e#\n!envoy.api.v2.core.TransportSocketB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfig\"\xa5\x01\n\x18RuntimeFractionalPercent\x12\x41\n\rdefault_value\x18\x01 \x01(\x0b\x32 .envoy.type.v3.FractionalPercentB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x13\n\x0bruntime_key\x18\x02 \x01(\t:1\x9a\xc5\x88\x1e,\n*envoy.api.v2.core.RuntimeFractionalPercent\"I\n\x0c\x43ontrolPlane\x12\x12\n\nidentifier\x18\x01 \x01(\t:%\x9a\xc5\x88\x1e \n\x1e\x65nvoy.api.v2.core.ControlPlane*(\n\x0fRoutingPriority\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x08\n\x04HIGH\x10\x01*\x89\x01\n\rRequestMethod\x12\x16\n\x12METHOD_UNSPECIFIED\x10\x00\x12\x07\n\x03GET\x10\x01\x12\x08\n\x04HEAD\x10\x02\x12\x08\n\x04POST\x10\x03\x12\x07\n\x03PUT\x10\x04\x12\n\n\x06\x44\x45LETE\x10\x05\x12\x0b\n\x07\x43ONNECT\x10\x06\x12\x0b\n\x07OPTIONS\x10\x07\x12\t\n\x05TRACE\x10\x08\x12\t\n\x05PATCH\x10\t*>\n\x10TrafficDirection\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07INBOUND\x10\x01\x12\x0c\n\x08OUTBOUND\x10\x02\x42\x39\n\"io.envoyproxy.envoy.config.core.v3B\tBaseProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_address__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v3_dot_backoff__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v3_dot_http__uri__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_percent__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_semantic__version__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])

_ROUTINGPRIORITY = _descriptor.EnumDescriptor(
  name='RoutingPriority',
  full_name='envoy.config.core.v3.RoutingPriority',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGH', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3590,
  serialized_end=3630,
)
_sym_db.RegisterEnumDescriptor(_ROUTINGPRIORITY)

RoutingPriority = enum_type_wrapper.EnumTypeWrapper(_ROUTINGPRIORITY)
_REQUESTMETHOD = _descriptor.EnumDescriptor(
  name='RequestMethod',
  full_name='envoy.config.core.v3.RequestMethod',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='METHOD_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GET', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HEAD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POST', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PUT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONNECT', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPTIONS', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRACE', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PATCH', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3633,
  serialized_end=3770,
)
_sym_db.RegisterEnumDescriptor(_REQUESTMETHOD)

RequestMethod = enum_type_wrapper.EnumTypeWrapper(_REQUESTMETHOD)
_TRAFFICDIRECTION = _descriptor.EnumDescriptor(
  name='TrafficDirection',
  full_name='envoy.config.core.v3.TrafficDirection',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INBOUND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTBOUND', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3772,
  serialized_end=3834,
)
_sym_db.RegisterEnumDescriptor(_TRAFFICDIRECTION)

TrafficDirection = enum_type_wrapper.EnumTypeWrapper(_TRAFFICDIRECTION)
DEFAULT = 0
HIGH = 1
METHOD_UNSPECIFIED = 0
GET = 1
HEAD = 2
POST = 3
PUT = 4
DELETE = 5
CONNECT = 6
OPTIONS = 7
TRACE = 8
PATCH = 9
UNSPECIFIED = 0
INBOUND = 1
OUTBOUND = 2



_LOCALITY = _descriptor.Descriptor(
  name='Locality',
  full_name='envoy.config.core.v3.Locality',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='region', full_name='envoy.config.core.v3.Locality.region', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone', full_name='envoy.config.core.v3.Locality.zone', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sub_zone', full_name='envoy.config.core.v3.Locality.sub_zone', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\034\n\032envoy.api.v2.core.Locality',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=445,
  serialized_end=538,
)


_BUILDVERSION = _descriptor.Descriptor(
  name='BuildVersion',
  full_name='envoy.config.core.v3.BuildVersion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='envoy.config.core.v3.BuildVersion.version', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='envoy.config.core.v3.BuildVersion.metadata', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036 \n\036envoy.api.v2.core.BuildVersion',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=541,
  serialized_end=686,
)


_EXTENSION = _descriptor.Descriptor(
  name='Extension',
  full_name='envoy.config.core.v3.Extension',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.core.v3.Extension.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='category', full_name='envoy.config.core.v3.Extension.category', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_descriptor', full_name='envoy.config.core.v3.Extension.type_descriptor', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='envoy.config.core.v3.Extension.version', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disabled', full_name='envoy.config.core.v3.Extension.disabled', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\035\n\033envoy.api.v2.core.Extension',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=689,
  serialized_end=864,
)


_NODE = _descriptor.Descriptor(
  name='Node',
  full_name='envoy.config.core.v3.Node',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='envoy.config.core.v3.Node.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='envoy.config.core.v3.Node.cluster', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='envoy.config.core.v3.Node.metadata', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locality', full_name='envoy.config.core.v3.Node.locality', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_agent_name', full_name='envoy.config.core.v3.Node.user_agent_name', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_agent_version', full_name='envoy.config.core.v3.Node.user_agent_version', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_agent_build_version', full_name='envoy.config.core.v3.Node.user_agent_build_version', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extensions', full_name='envoy.config.core.v3.Node.extensions', index=7,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_features', full_name='envoy.config.core.v3.Node.client_features', index=8,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listening_addresses', full_name='envoy.config.core.v3.Node.listening_addresses', index=9,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\030\n\026envoy.api.v2.core.Node',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='user_agent_version_type', full_name='envoy.config.core.v3.Node.user_agent_version_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=867,
  serialized_end=1343,
)


_METADATA_FILTERMETADATAENTRY = _descriptor.Descriptor(
  name='FilterMetadataEntry',
  full_name='envoy.config.core.v3.Metadata.FilterMetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.config.core.v3.Metadata.FilterMetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.config.core.v3.Metadata.FilterMetadataEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1435,
  serialized_end=1513,
)

_METADATA = _descriptor.Descriptor(
  name='Metadata',
  full_name='envoy.config.core.v3.Metadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter_metadata', full_name='envoy.config.core.v3.Metadata.filter_metadata', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_METADATA_FILTERMETADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\034\n\032envoy.api.v2.core.Metadata',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1346,
  serialized_end=1548,
)


_RUNTIMEUINT32 = _descriptor.Descriptor(
  name='RuntimeUInt32',
  full_name='envoy.config.core.v3.RuntimeUInt32',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_value', full_name='envoy.config.core.v3.RuntimeUInt32.default_value', index=0,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime_key', full_name='envoy.config.core.v3.RuntimeUInt32.runtime_key', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036!\n\037envoy.api.v2.core.RuntimeUInt32',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1550,
  serialized_end=1658,
)


_RUNTIMEPERCENT = _descriptor.Descriptor(
  name='RuntimePercent',
  full_name='envoy.config.core.v3.RuntimePercent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_value', full_name='envoy.config.core.v3.RuntimePercent.default_value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime_key', full_name='envoy.config.core.v3.RuntimePercent.runtime_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1660,
  serialized_end=1753,
)


_RUNTIMEDOUBLE = _descriptor.Descriptor(
  name='RuntimeDouble',
  full_name='envoy.config.core.v3.RuntimeDouble',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_value', full_name='envoy.config.core.v3.RuntimeDouble.default_value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime_key', full_name='envoy.config.core.v3.RuntimeDouble.runtime_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036!\n\037envoy.api.v2.core.RuntimeDouble',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1755,
  serialized_end=1863,
)


_RUNTIMEFEATUREFLAG = _descriptor.Descriptor(
  name='RuntimeFeatureFlag',
  full_name='envoy.config.core.v3.RuntimeFeatureFlag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_value', full_name='envoy.config.core.v3.RuntimeFeatureFlag.default_value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime_key', full_name='envoy.config.core.v3.RuntimeFeatureFlag.runtime_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036&\n$envoy.api.v2.core.RuntimeFeatureFlag',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1866,
  serialized_end=2022,
)


_HEADERVALUE = _descriptor.Descriptor(
  name='HeaderValue',
  full_name='envoy.config.core.v3.HeaderValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.config.core.v3.HeaderValue.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\016r\014\020\001(\200\200\001\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.config.core.v3.HeaderValue.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\014r\n(\200\200\001\300\001\002\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\037\n\035envoy.api.v2.core.HeaderValue',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2024,
  serialized_end=2139,
)


_HEADERVALUEOPTION = _descriptor.Descriptor(
  name='HeaderValueOption',
  full_name='envoy.config.core.v3.HeaderValueOption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='envoy.config.core.v3.HeaderValueOption.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='append', full_name='envoy.config.core.v3.HeaderValueOption.append', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036%\n#envoy.api.v2.core.HeaderValueOption',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2142,
  serialized_end=2310,
)


_HEADERMAP = _descriptor.Descriptor(
  name='HeaderMap',
  full_name='envoy.config.core.v3.HeaderMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.config.core.v3.HeaderMap.headers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\035\n\033envoy.api.v2.core.HeaderMap',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2312,
  serialized_end=2411,
)


_WATCHEDDIRECTORY = _descriptor.Descriptor(
  name='WatchedDirectory',
  full_name='envoy.config.core.v3.WatchedDirectory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='envoy.config.core.v3.WatchedDirectory.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2413,
  serialized_end=2454,
)


_DATASOURCE = _descriptor.Descriptor(
  name='DataSource',
  full_name='envoy.config.core.v3.DataSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='envoy.config.core.v3.DataSource.filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inline_bytes', full_name='envoy.config.core.v3.DataSource.inline_bytes', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inline_string', full_name='envoy.config.core.v3.DataSource.inline_string', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\036\n\034envoy.api.v2.core.DataSource',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='specifier', full_name='envoy.config.core.v3.DataSource.specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=2457,
  serialized_end=2602,
)


_RETRYPOLICY = _descriptor.Descriptor(
  name='RetryPolicy',
  full_name='envoy.config.core.v3.RetryPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='retry_back_off', full_name='envoy.config.core.v3.RetryPolicy.retry_back_off', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_retries', full_name='envoy.config.core.v3.RetryPolicy.num_retries', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\230\376\217\005\r\n\013max_retries', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\037\n\035envoy.api.v2.core.RetryPolicy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2605,
  serialized_end=2791,
)


_REMOTEDATASOURCE = _descriptor.Descriptor(
  name='RemoteDataSource',
  full_name='envoy.config.core.v3.RemoteDataSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_uri', full_name='envoy.config.core.v3.RemoteDataSource.http_uri', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sha256', full_name='envoy.config.core.v3.RemoteDataSource.sha256', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retry_policy', full_name='envoy.config.core.v3.RemoteDataSource.retry_policy', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036$\n\"envoy.api.v2.core.RemoteDataSource',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2794,
  serialized_end=2996,
)


_ASYNCDATASOURCE = _descriptor.Descriptor(
  name='AsyncDataSource',
  full_name='envoy.config.core.v3.AsyncDataSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='local', full_name='envoy.config.core.v3.AsyncDataSource.local', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote', full_name='envoy.config.core.v3.AsyncDataSource.remote', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036#\n!envoy.api.v2.core.AsyncDataSource',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='specifier', full_name='envoy.config.core.v3.AsyncDataSource.specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=2999,
  serialized_end=3185,
)


_TRANSPORTSOCKET = _descriptor.Descriptor(
  name='TransportSocket',
  full_name='envoy.config.core.v3.TransportSocket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.core.v3.TransportSocket.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.config.core.v3.TransportSocket.typed_config', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036#\n!envoy.api.v2.core.TransportSocket',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.config.core.v3.TransportSocket.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3188,
  serialized_end=3345,
)


_RUNTIMEFRACTIONALPERCENT = _descriptor.Descriptor(
  name='RuntimeFractionalPercent',
  full_name='envoy.config.core.v3.RuntimeFractionalPercent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_value', full_name='envoy.config.core.v3.RuntimeFractionalPercent.default_value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime_key', full_name='envoy.config.core.v3.RuntimeFractionalPercent.runtime_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036,\n*envoy.api.v2.core.RuntimeFractionalPercent',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3348,
  serialized_end=3513,
)


_CONTROLPLANE = _descriptor.Descriptor(
  name='ControlPlane',
  full_name='envoy.config.core.v3.ControlPlane',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='envoy.config.core.v3.ControlPlane.identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036 \n\036envoy.api.v2.core.ControlPlane',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3515,
  serialized_end=3588,
)

_BUILDVERSION.fields_by_name['version'].message_type = envoy_dot_type_dot_v3_dot_semantic__version__pb2._SEMANTICVERSION
_BUILDVERSION.fields_by_name['metadata'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_EXTENSION.fields_by_name['version'].message_type = _BUILDVERSION
_NODE.fields_by_name['metadata'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_NODE.fields_by_name['locality'].message_type = _LOCALITY
_NODE.fields_by_name['user_agent_build_version'].message_type = _BUILDVERSION
_NODE.fields_by_name['extensions'].message_type = _EXTENSION
_NODE.fields_by_name['listening_addresses'].message_type = envoy_dot_config_dot_core_dot_v3_dot_address__pb2._ADDRESS
_NODE.oneofs_by_name['user_agent_version_type'].fields.append(
  _NODE.fields_by_name['user_agent_version'])
_NODE.fields_by_name['user_agent_version'].containing_oneof = _NODE.oneofs_by_name['user_agent_version_type']
_NODE.oneofs_by_name['user_agent_version_type'].fields.append(
  _NODE.fields_by_name['user_agent_build_version'])
_NODE.fields_by_name['user_agent_build_version'].containing_oneof = _NODE.oneofs_by_name['user_agent_version_type']
_METADATA_FILTERMETADATAENTRY.fields_by_name['value'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_METADATA_FILTERMETADATAENTRY.containing_type = _METADATA
_METADATA.fields_by_name['filter_metadata'].message_type = _METADATA_FILTERMETADATAENTRY
_RUNTIMEPERCENT.fields_by_name['default_value'].message_type = envoy_dot_type_dot_v3_dot_percent__pb2._PERCENT
_RUNTIMEFEATUREFLAG.fields_by_name['default_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_HEADERVALUEOPTION.fields_by_name['header'].message_type = _HEADERVALUE
_HEADERVALUEOPTION.fields_by_name['append'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_HEADERMAP.fields_by_name['headers'].message_type = _HEADERVALUE
_DATASOURCE.oneofs_by_name['specifier'].fields.append(
  _DATASOURCE.fields_by_name['filename'])
_DATASOURCE.fields_by_name['filename'].containing_oneof = _DATASOURCE.oneofs_by_name['specifier']
_DATASOURCE.oneofs_by_name['specifier'].fields.append(
  _DATASOURCE.fields_by_name['inline_bytes'])
_DATASOURCE.fields_by_name['inline_bytes'].containing_oneof = _DATASOURCE.oneofs_by_name['specifier']
_DATASOURCE.oneofs_by_name['specifier'].fields.append(
  _DATASOURCE.fields_by_name['inline_string'])
_DATASOURCE.fields_by_name['inline_string'].containing_oneof = _DATASOURCE.oneofs_by_name['specifier']
_RETRYPOLICY.fields_by_name['retry_back_off'].message_type = envoy_dot_config_dot_core_dot_v3_dot_backoff__pb2._BACKOFFSTRATEGY
_RETRYPOLICY.fields_by_name['num_retries'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_REMOTEDATASOURCE.fields_by_name['http_uri'].message_type = envoy_dot_config_dot_core_dot_v3_dot_http__uri__pb2._HTTPURI
_REMOTEDATASOURCE.fields_by_name['retry_policy'].message_type = _RETRYPOLICY
_ASYNCDATASOURCE.fields_by_name['local'].message_type = _DATASOURCE
_ASYNCDATASOURCE.fields_by_name['remote'].message_type = _REMOTEDATASOURCE
_ASYNCDATASOURCE.oneofs_by_name['specifier'].fields.append(
  _ASYNCDATASOURCE.fields_by_name['local'])
_ASYNCDATASOURCE.fields_by_name['local'].containing_oneof = _ASYNCDATASOURCE.oneofs_by_name['specifier']
_ASYNCDATASOURCE.oneofs_by_name['specifier'].fields.append(
  _ASYNCDATASOURCE.fields_by_name['remote'])
_ASYNCDATASOURCE.fields_by_name['remote'].containing_oneof = _ASYNCDATASOURCE.oneofs_by_name['specifier']
_TRANSPORTSOCKET.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_TRANSPORTSOCKET.oneofs_by_name['config_type'].fields.append(
  _TRANSPORTSOCKET.fields_by_name['typed_config'])
_TRANSPORTSOCKET.fields_by_name['typed_config'].containing_oneof = _TRANSPORTSOCKET.oneofs_by_name['config_type']
_RUNTIMEFRACTIONALPERCENT.fields_by_name['default_value'].message_type = envoy_dot_type_dot_v3_dot_percent__pb2._FRACTIONALPERCENT
DESCRIPTOR.message_types_by_name['Locality'] = _LOCALITY
DESCRIPTOR.message_types_by_name['BuildVersion'] = _BUILDVERSION
DESCRIPTOR.message_types_by_name['Extension'] = _EXTENSION
DESCRIPTOR.message_types_by_name['Node'] = _NODE
DESCRIPTOR.message_types_by_name['Metadata'] = _METADATA
DESCRIPTOR.message_types_by_name['RuntimeUInt32'] = _RUNTIMEUINT32
DESCRIPTOR.message_types_by_name['RuntimePercent'] = _RUNTIMEPERCENT
DESCRIPTOR.message_types_by_name['RuntimeDouble'] = _RUNTIMEDOUBLE
DESCRIPTOR.message_types_by_name['RuntimeFeatureFlag'] = _RUNTIMEFEATUREFLAG
DESCRIPTOR.message_types_by_name['HeaderValue'] = _HEADERVALUE
DESCRIPTOR.message_types_by_name['HeaderValueOption'] = _HEADERVALUEOPTION
DESCRIPTOR.message_types_by_name['HeaderMap'] = _HEADERMAP
DESCRIPTOR.message_types_by_name['WatchedDirectory'] = _WATCHEDDIRECTORY
DESCRIPTOR.message_types_by_name['DataSource'] = _DATASOURCE
DESCRIPTOR.message_types_by_name['RetryPolicy'] = _RETRYPOLICY
DESCRIPTOR.message_types_by_name['RemoteDataSource'] = _REMOTEDATASOURCE
DESCRIPTOR.message_types_by_name['AsyncDataSource'] = _ASYNCDATASOURCE
DESCRIPTOR.message_types_by_name['TransportSocket'] = _TRANSPORTSOCKET
DESCRIPTOR.message_types_by_name['RuntimeFractionalPercent'] = _RUNTIMEFRACTIONALPERCENT
DESCRIPTOR.message_types_by_name['ControlPlane'] = _CONTROLPLANE
DESCRIPTOR.enum_types_by_name['RoutingPriority'] = _ROUTINGPRIORITY
DESCRIPTOR.enum_types_by_name['RequestMethod'] = _REQUESTMETHOD
DESCRIPTOR.enum_types_by_name['TrafficDirection'] = _TRAFFICDIRECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Locality = _reflection.GeneratedProtocolMessageType('Locality', (_message.Message,), {
  'DESCRIPTOR' : _LOCALITY,
  '__module__' : 'envoy.config.core.v3.base_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.Locality)
  })
_sym_db.RegisterMessage(Locality)

BuildVersion = _reflection.GeneratedProtocolMessageType('BuildVersion', (_message.Message,), {
  'DESCRIPTOR' : _BUILDVERSION,
  '__module__' : 'envoy.config.core.v3.base_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.BuildVersion)
  })
_sym_db.RegisterMessage(BuildVersion)

Extension = _reflection.GeneratedProtocolMessageType('Extension', (_message.Message,), {
  'DESCRIPTOR' : _EXTENSION,
  '__module__' : 'envoy.config.core.v3.base_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.Extension)
  })
_sym_db.RegisterMessage(Extension)

Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), {
  'DESCRIPTOR' : _NODE,
  '__module__' : 'envoy.config.core.v3.base_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.Node)
  })
_sym_db.RegisterMessage(Node)

Metadata = _reflection.GeneratedProtocolMessageType('Metadata', (_message.Message,), {

  'FilterMetadataEntry' : _reflection.GeneratedProtocolMessageType('FilterMetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _METADATA_FILTERMETADATAENTRY,
    '__module__' : 'envoy.config.core.v3.base_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.core.v3.Metadata.FilterMetadataEntry)
    })
  ,
  'DESCRIPTOR' : _METADATA,
  '__module__' : 'envoy.config.core.v3.base_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.Metadata)
  })
_sym_db.RegisterMessage(Metadata)
_sym_db.RegisterMessage(Metadata.FilterMetadataEntry)

RuntimeUInt32 = _reflection.GeneratedProtocolMessageType('RuntimeUInt32', (_message.Message,), {
  'DESCRIPTOR' : _RUNTIMEUINT32,
  '__module__' : 'envoy.config.core.v3.base_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.RuntimeUInt32)
  })
_sym_db.RegisterMessage(RuntimeUInt32)

RuntimePercent = _reflection.GeneratedProtocolMessageType('RuntimePercent', (_message.Message,), {
  'DESCRIPTOR' : _RUNTIMEPERCENT,
  '__module__' : 'envoy.config.core.v3.base_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.RuntimePercent)
  })
_sym_db.RegisterMessage(RuntimePercent)

RuntimeDouble = _reflection.GeneratedProtocolMessageType('RuntimeDouble', (_message.Message,), {
  'DESCRIPTOR' : _RUNTIMEDOUBLE,
  '__module__' : 'envoy.config.core.v3.base_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.RuntimeDouble)
  })
_sym_db.RegisterMessage(RuntimeDouble)

RuntimeFeatureFlag = _reflection.GeneratedProtocolMessageType('RuntimeFeatureFlag', (_message.Message,), {
  'DESCRIPTOR' : _RUNTIMEFEATUREFLAG,
  '__module__' : 'envoy.config.core.v3.base_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.RuntimeFeatureFlag)
  })
_sym_db.RegisterMessage(RuntimeFeatureFlag)

HeaderValue = _reflection.GeneratedProtocolMessageType('HeaderValue', (_message.Message,), {
  'DESCRIPTOR' : _HEADERVALUE,
  '__module__' : 'envoy.config.core.v3.base_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.HeaderValue)
  })
_sym_db.RegisterMessage(HeaderValue)

HeaderValueOption = _reflection.GeneratedProtocolMessageType('HeaderValueOption', (_message.Message,), {
  'DESCRIPTOR' : _HEADERVALUEOPTION,
  '__module__' : 'envoy.config.core.v3.base_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.HeaderValueOption)
  })
_sym_db.RegisterMessage(HeaderValueOption)

HeaderMap = _reflection.GeneratedProtocolMessageType('HeaderMap', (_message.Message,), {
  'DESCRIPTOR' : _HEADERMAP,
  '__module__' : 'envoy.config.core.v3.base_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.HeaderMap)
  })
_sym_db.RegisterMessage(HeaderMap)

WatchedDirectory = _reflection.GeneratedProtocolMessageType('WatchedDirectory', (_message.Message,), {
  'DESCRIPTOR' : _WATCHEDDIRECTORY,
  '__module__' : 'envoy.config.core.v3.base_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.WatchedDirectory)
  })
_sym_db.RegisterMessage(WatchedDirectory)

DataSource = _reflection.GeneratedProtocolMessageType('DataSource', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCE,
  '__module__' : 'envoy.config.core.v3.base_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.DataSource)
  })
_sym_db.RegisterMessage(DataSource)

RetryPolicy = _reflection.GeneratedProtocolMessageType('RetryPolicy', (_message.Message,), {
  'DESCRIPTOR' : _RETRYPOLICY,
  '__module__' : 'envoy.config.core.v3.base_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.RetryPolicy)
  })
_sym_db.RegisterMessage(RetryPolicy)

RemoteDataSource = _reflection.GeneratedProtocolMessageType('RemoteDataSource', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEDATASOURCE,
  '__module__' : 'envoy.config.core.v3.base_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.RemoteDataSource)
  })
_sym_db.RegisterMessage(RemoteDataSource)

AsyncDataSource = _reflection.GeneratedProtocolMessageType('AsyncDataSource', (_message.Message,), {
  'DESCRIPTOR' : _ASYNCDATASOURCE,
  '__module__' : 'envoy.config.core.v3.base_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.AsyncDataSource)
  })
_sym_db.RegisterMessage(AsyncDataSource)

TransportSocket = _reflection.GeneratedProtocolMessageType('TransportSocket', (_message.Message,), {
  'DESCRIPTOR' : _TRANSPORTSOCKET,
  '__module__' : 'envoy.config.core.v3.base_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.TransportSocket)
  })
_sym_db.RegisterMessage(TransportSocket)

RuntimeFractionalPercent = _reflection.GeneratedProtocolMessageType('RuntimeFractionalPercent', (_message.Message,), {
  'DESCRIPTOR' : _RUNTIMEFRACTIONALPERCENT,
  '__module__' : 'envoy.config.core.v3.base_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.RuntimeFractionalPercent)
  })
_sym_db.RegisterMessage(RuntimeFractionalPercent)

ControlPlane = _reflection.GeneratedProtocolMessageType('ControlPlane', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLPLANE,
  '__module__' : 'envoy.config.core.v3.base_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.ControlPlane)
  })
_sym_db.RegisterMessage(ControlPlane)


DESCRIPTOR._options = None
_LOCALITY._options = None
_BUILDVERSION._options = None
_EXTENSION._options = None
_NODE.fields_by_name['listening_addresses']._options = None
_NODE._options = None
_METADATA_FILTERMETADATAENTRY._options = None
_METADATA._options = None
_RUNTIMEUINT32.fields_by_name['runtime_key']._options = None
_RUNTIMEUINT32._options = None
_RUNTIMEPERCENT.fields_by_name['runtime_key']._options = None
_RUNTIMEDOUBLE.fields_by_name['runtime_key']._options = None
_RUNTIMEDOUBLE._options = None
_RUNTIMEFEATUREFLAG.fields_by_name['default_value']._options = None
_RUNTIMEFEATUREFLAG.fields_by_name['runtime_key']._options = None
_RUNTIMEFEATUREFLAG._options = None
_HEADERVALUE.fields_by_name['key']._options = None
_HEADERVALUE.fields_by_name['value']._options = None
_HEADERVALUE._options = None
_HEADERVALUEOPTION.fields_by_name['header']._options = None
_HEADERVALUEOPTION._options = None
_HEADERMAP._options = None
_WATCHEDDIRECTORY.fields_by_name['path']._options = None
_DATASOURCE.oneofs_by_name['specifier']._options = None
_DATASOURCE.fields_by_name['filename']._options = None
_DATASOURCE._options = None
_RETRYPOLICY.fields_by_name['num_retries']._options = None
_RETRYPOLICY._options = None
_REMOTEDATASOURCE.fields_by_name['http_uri']._options = None
_REMOTEDATASOURCE.fields_by_name['sha256']._options = None
_REMOTEDATASOURCE._options = None
_ASYNCDATASOURCE.oneofs_by_name['specifier']._options = None
_ASYNCDATASOURCE._options = None
_TRANSPORTSOCKET.fields_by_name['name']._options = None
_TRANSPORTSOCKET._options = None
_RUNTIMEFRACTIONALPERCENT.fields_by_name['default_value']._options = None
_RUNTIMEFRACTIONALPERCENT._options = None
_CONTROLPLANE._options = None
# @@protoc_insertion_point(module_scope)
