# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/trace/v3/http_tracer.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/trace/v3/http_tracer.proto',
  package='envoy.config.trace.v3',
  syntax='proto3',
  serialized_options=b'\n#io.envoyproxy.envoy.config.trace.v3B\017HttpTracerProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'envoy/config/trace/v3/http_tracer.proto\x12\x15\x65nvoy.config.trace.v3\x1a\x19google/protobuf/any.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xf8\x01\n\x07Tracing\x12\x31\n\x04http\x18\x01 \x01(\x0b\x32#.envoy.config.trace.v3.Tracing.Http\x1a\x93\x01\n\x04Http\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00:)\x9a\xc5\x88\x1e$\n\"envoy.config.trace.v2.Tracing.HttpB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfig:$\x9a\xc5\x88\x1e\x1f\n\x1d\x65nvoy.config.trace.v2.TracingB@\n#io.envoyproxy.envoy.config.trace.v3B\x0fHttpTracerProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_TRACING_HTTP = _descriptor.Descriptor(
  name='Http',
  full_name='envoy.config.trace.v3.Tracing.Http',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.trace.v3.Tracing.Http.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.config.trace.v3.Tracing.Http.typed_config', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036$\n\"envoy.config.trace.v2.Tracing.Http',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.config.trace.v3.Tracing.Http.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=248,
  serialized_end=395,
)

_TRACING = _descriptor.Descriptor(
  name='Tracing',
  full_name='envoy.config.trace.v3.Tracing',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http', full_name='envoy.config.trace.v3.Tracing.http', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TRACING_HTTP, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\037\n\035envoy.config.trace.v2.Tracing',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=185,
  serialized_end=433,
)

_TRACING_HTTP.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_TRACING_HTTP.containing_type = _TRACING
_TRACING_HTTP.oneofs_by_name['config_type'].fields.append(
  _TRACING_HTTP.fields_by_name['typed_config'])
_TRACING_HTTP.fields_by_name['typed_config'].containing_oneof = _TRACING_HTTP.oneofs_by_name['config_type']
_TRACING.fields_by_name['http'].message_type = _TRACING_HTTP
DESCRIPTOR.message_types_by_name['Tracing'] = _TRACING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Tracing = _reflection.GeneratedProtocolMessageType('Tracing', (_message.Message,), {

  'Http' : _reflection.GeneratedProtocolMessageType('Http', (_message.Message,), {
    'DESCRIPTOR' : _TRACING_HTTP,
    '__module__' : 'envoy.config.trace.v3.http_tracer_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.trace.v3.Tracing.Http)
    })
  ,
  'DESCRIPTOR' : _TRACING,
  '__module__' : 'envoy.config.trace.v3.http_tracer_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.trace.v3.Tracing)
  })
_sym_db.RegisterMessage(Tracing)
_sym_db.RegisterMessage(Tracing.Http)


DESCRIPTOR._options = None
_TRACING_HTTP.fields_by_name['name']._options = None
_TRACING_HTTP._options = None
_TRACING._options = None
# @@protoc_insertion_point(module_scope)
