# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/health_check/v2/health_check.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.route import route_components_pb2 as envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2
from envoy.type import percent_pb2 as envoy_dot_type_dot_percent__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/http/health_check/v2/health_check.proto',
  package='envoy.config.filter.http.health_check.v2',
  syntax='proto3',
  serialized_options=b'\n6io.envoyproxy.envoy.config.filter.http.health_check.v2B\020HealthCheckProtoP\001\362\230\376\217\005/\022-envoy.extensions.filters.http.health_check.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n;envoy/config/filter/http/health_check/v2/health_check.proto\x12(envoy.config.filter.http.health_check.v2\x1a)envoy/api/v2/route/route_components.proto\x1a\x18\x65nvoy/type/percent.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x94\x03\n\x0bHealthCheck\x12?\n\x11pass_through_mode\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12-\n\ncache_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x80\x01\n\x1f\x63luster_min_healthy_percentages\x18\x04 \x03(\x0b\x32W.envoy.config.filter.http.health_check.v2.HealthCheck.ClusterMinHealthyPercentagesEntry\x12\x32\n\x07headers\x18\x05 \x03(\x0b\x32!.envoy.api.v2.route.HeaderMatcher\x1aX\n!ClusterMinHealthyPercentagesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.envoy.type.Percent:\x02\x38\x01J\x04\x08\x02\x10\x03\x42\x89\x01\n6io.envoyproxy.envoy.config.filter.http.health_check.v2B\x10HealthCheckProtoP\x01\xf2\x98\xfe\x8f\x05/\x12-envoy.extensions.filters.http.health_check.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2.DESCRIPTOR,envoy_dot_type_dot_percent__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY = _descriptor.Descriptor(
  name='ClusterMinHealthyPercentagesEntry',
  full_name='envoy.config.filter.http.health_check.v2.HealthCheck.ClusterMinHealthyPercentagesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.config.filter.http.health_check.v2.HealthCheck.ClusterMinHealthyPercentagesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.config.filter.http.health_check.v2.HealthCheck.ClusterMinHealthyPercentagesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=637,
  serialized_end=725,
)

_HEALTHCHECK = _descriptor.Descriptor(
  name='HealthCheck',
  full_name='envoy.config.filter.http.health_check.v2.HealthCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pass_through_mode', full_name='envoy.config.filter.http.health_check.v2.HealthCheck.pass_through_mode', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cache_time', full_name='envoy.config.filter.http.health_check.v2.HealthCheck.cache_time', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_min_healthy_percentages', full_name='envoy.config.filter.http.health_check.v2.HealthCheck.cluster_min_healthy_percentages', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.config.filter.http.health_check.v2.HealthCheck.headers', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=327,
  serialized_end=731,
)

_HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY.fields_by_name['value'].message_type = envoy_dot_type_dot_percent__pb2._PERCENT
_HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY.containing_type = _HEALTHCHECK
_HEALTHCHECK.fields_by_name['pass_through_mode'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_HEALTHCHECK.fields_by_name['cache_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECK.fields_by_name['cluster_min_healthy_percentages'].message_type = _HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY
_HEALTHCHECK.fields_by_name['headers'].message_type = envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2._HEADERMATCHER
DESCRIPTOR.message_types_by_name['HealthCheck'] = _HEALTHCHECK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HealthCheck = _reflection.GeneratedProtocolMessageType('HealthCheck', (_message.Message,), {

  'ClusterMinHealthyPercentagesEntry' : _reflection.GeneratedProtocolMessageType('ClusterMinHealthyPercentagesEntry', (_message.Message,), {
    'DESCRIPTOR' : _HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY,
    '__module__' : 'envoy.config.filter.http.health_check.v2.health_check_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.filter.http.health_check.v2.HealthCheck.ClusterMinHealthyPercentagesEntry)
    })
  ,
  'DESCRIPTOR' : _HEALTHCHECK,
  '__module__' : 'envoy.config.filter.http.health_check.v2.health_check_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.health_check.v2.HealthCheck)
  })
_sym_db.RegisterMessage(HealthCheck)
_sym_db.RegisterMessage(HealthCheck.ClusterMinHealthyPercentagesEntry)


DESCRIPTOR._options = None
_HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY._options = None
_HEALTHCHECK.fields_by_name['pass_through_mode']._options = None
# @@protoc_insertion_point(module_scope)
