# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/gzip/v2/gzip.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.filter.http.compressor.v2 import compressor_pb2 as envoy_dot_config_dot_filter_dot_http_dot_compressor_dot_v2_dot_compressor__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/http/gzip/v2/gzip.proto',
  package='envoy.config.filter.http.gzip.v2',
  syntax='proto3',
  serialized_options=b'\n.io.envoyproxy.envoy.config.filter.http.gzip.v2B\tGzipProtoP\001\362\230\376\217\005\'\022%envoy.extensions.filters.http.gzip.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+envoy/config/filter/http/gzip/v2/gzip.proto\x12 envoy.config.filter.http.gzip.v2\x1a\x37\x65nvoy/config/filter/http/compressor/v2/compressor.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xbb\x05\n\x04Gzip\x12=\n\x0cmemory_level\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18\t(\x01\x12\x38\n\x0e\x63ontent_length\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x02\x18\x01\x12\x61\n\x11\x63ompression_level\x18\x03 \x01(\x0e\x32<.envoy.config.filter.http.gzip.v2.Gzip.CompressionLevel.EnumB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x62\n\x14\x63ompression_strategy\x18\x04 \x01(\x0e\x32:.envoy.config.filter.http.gzip.v2.Gzip.CompressionStrategyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x18\n\x0c\x63ontent_type\x18\x06 \x03(\tB\x02\x18\x01\x12\"\n\x16\x64isable_on_etag_header\x18\x07 \x01(\x08\x42\x02\x18\x01\x12)\n\x1dremove_accept_encoding_header\x18\x08 \x01(\x08\x42\x02\x18\x01\x12<\n\x0bwindow_bits\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18\x0f(\t\x12\x46\n\ncompressor\x18\n \x01(\x0b\x32\x32.envoy.config.filter.http.compressor.v2.Compressor\x1a<\n\x10\x43ompressionLevel\"(\n\x04\x45num\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x08\n\x04\x42\x45ST\x10\x01\x12\t\n\x05SPEED\x10\x02\"F\n\x13\x43ompressionStrategy\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0c\n\x08\x46ILTERED\x10\x01\x12\x0b\n\x07HUFFMAN\x10\x02\x12\x07\n\x03RLE\x10\x03\x42r\n.io.envoyproxy.envoy.config.filter.http.gzip.v2B\tGzipProtoP\x01\xf2\x98\xfe\x8f\x05\'\x12%envoy.extensions.filters.http.gzip.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_filter_dot_http_dot_compressor_dot_v2_dot_compressor__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_GZIP_COMPRESSIONLEVEL_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='envoy.config.filter.http.gzip.v2.Gzip.CompressionLevel.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BEST', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPEED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=846,
  serialized_end=886,
)
_sym_db.RegisterEnumDescriptor(_GZIP_COMPRESSIONLEVEL_ENUM)

_GZIP_COMPRESSIONSTRATEGY = _descriptor.EnumDescriptor(
  name='CompressionStrategy',
  full_name='envoy.config.filter.http.gzip.v2.Gzip.CompressionStrategy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FILTERED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HUFFMAN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RLE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=888,
  serialized_end=958,
)
_sym_db.RegisterEnumDescriptor(_GZIP_COMPRESSIONSTRATEGY)


_GZIP_COMPRESSIONLEVEL = _descriptor.Descriptor(
  name='CompressionLevel',
  full_name='envoy.config.filter.http.gzip.v2.Gzip.CompressionLevel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GZIP_COMPRESSIONLEVEL_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=826,
  serialized_end=886,
)

_GZIP = _descriptor.Descriptor(
  name='Gzip',
  full_name='envoy.config.filter.http.gzip.v2.Gzip',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='memory_level', full_name='envoy.config.filter.http.gzip.v2.Gzip.memory_level', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006*\004\030\t(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_length', full_name='envoy.config.filter.http.gzip.v2.Gzip.content_length', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compression_level', full_name='envoy.config.filter.http.gzip.v2.Gzip.compression_level', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compression_strategy', full_name='envoy.config.filter.http.gzip.v2.Gzip.compression_strategy', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_type', full_name='envoy.config.filter.http.gzip.v2.Gzip.content_type', index=4,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_on_etag_header', full_name='envoy.config.filter.http.gzip.v2.Gzip.disable_on_etag_header', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remove_accept_encoding_header', full_name='envoy.config.filter.http.gzip.v2.Gzip.remove_accept_encoding_header', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='window_bits', full_name='envoy.config.filter.http.gzip.v2.Gzip.window_bits', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006*\004\030\017(\t', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compressor', full_name='envoy.config.filter.http.gzip.v2.Gzip.compressor', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GZIP_COMPRESSIONLEVEL, ],
  enum_types=[
    _GZIP_COMPRESSIONSTRATEGY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=259,
  serialized_end=958,
)

_GZIP_COMPRESSIONLEVEL.containing_type = _GZIP
_GZIP_COMPRESSIONLEVEL_ENUM.containing_type = _GZIP_COMPRESSIONLEVEL
_GZIP.fields_by_name['memory_level'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_GZIP.fields_by_name['content_length'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_GZIP.fields_by_name['compression_level'].enum_type = _GZIP_COMPRESSIONLEVEL_ENUM
_GZIP.fields_by_name['compression_strategy'].enum_type = _GZIP_COMPRESSIONSTRATEGY
_GZIP.fields_by_name['window_bits'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_GZIP.fields_by_name['compressor'].message_type = envoy_dot_config_dot_filter_dot_http_dot_compressor_dot_v2_dot_compressor__pb2._COMPRESSOR
_GZIP_COMPRESSIONSTRATEGY.containing_type = _GZIP
DESCRIPTOR.message_types_by_name['Gzip'] = _GZIP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Gzip = _reflection.GeneratedProtocolMessageType('Gzip', (_message.Message,), {

  'CompressionLevel' : _reflection.GeneratedProtocolMessageType('CompressionLevel', (_message.Message,), {
    'DESCRIPTOR' : _GZIP_COMPRESSIONLEVEL,
    '__module__' : 'envoy.config.filter.http.gzip.v2.gzip_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.filter.http.gzip.v2.Gzip.CompressionLevel)
    })
  ,
  'DESCRIPTOR' : _GZIP,
  '__module__' : 'envoy.config.filter.http.gzip.v2.gzip_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.gzip.v2.Gzip)
  })
_sym_db.RegisterMessage(Gzip)
_sym_db.RegisterMessage(Gzip.CompressionLevel)


DESCRIPTOR._options = None
_GZIP.fields_by_name['memory_level']._options = None
_GZIP.fields_by_name['content_length']._options = None
_GZIP.fields_by_name['compression_level']._options = None
_GZIP.fields_by_name['compression_strategy']._options = None
_GZIP.fields_by_name['content_type']._options = None
_GZIP.fields_by_name['disable_on_etag_header']._options = None
_GZIP.fields_by_name['remove_accept_encoding_header']._options = None
_GZIP.fields_by_name['window_bits']._options = None
# @@protoc_insertion_point(module_scope)
