# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/discovery/v2/sds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2 import discovery_pb2 as envoy_dot_api_dot_v2_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/discovery/v2/sds.proto',
  package='envoy.service.discovery.v2',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.service.discovery.v2B\010SdsProtoP\001\210\001\001\362\230\376\217\005\031\022\027envoy.service.secret.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$envoy/service/discovery/v2/sds.proto\x12\x1a\x65nvoy.service.discovery.v2\x1a\x1c\x65nvoy/api/v2/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a envoy/annotations/resource.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\n\n\x08SdsDummy2\xec\x02\n\x16SecretDiscoveryService\x12_\n\x0c\x44\x65ltaSecrets\x12#.envoy.api.v2.DeltaDiscoveryRequest\x1a$.envoy.api.v2.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12V\n\rStreamSecrets\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"\x00(\x01\x30\x01\x12w\n\x0c\x46\x65tchSecrets\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"&\x82\xd3\xe4\x93\x02\x17\"\x15/v2/discovery:secrets\x82\xd3\xe4\x93\x02\x03:\x01*\x1a \x8a\xa4\x96\xf3\x07\x1a\n\x18\x65nvoy.api.v2.auth.SecretB`\n(io.envoyproxy.envoy.service.discovery.v2B\x08SdsProtoP\x01\x88\x01\x01\xf2\x98\xfe\x8f\x05\x19\x12\x17\x65nvoy.service.secret.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_discovery__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,envoy_dot_annotations_dot_resource__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_SDSDUMMY = _descriptor.Descriptor(
  name='SdsDummy',
  full_name='envoy.service.discovery.v2.SdsDummy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=225,
  serialized_end=235,
)

DESCRIPTOR.message_types_by_name['SdsDummy'] = _SDSDUMMY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SdsDummy = _reflection.GeneratedProtocolMessageType('SdsDummy', (_message.Message,), {
  'DESCRIPTOR' : _SDSDUMMY,
  '__module__' : 'envoy.service.discovery.v2.sds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v2.SdsDummy)
  })
_sym_db.RegisterMessage(SdsDummy)


DESCRIPTOR._options = None

_SECRETDISCOVERYSERVICE = _descriptor.ServiceDescriptor(
  name='SecretDiscoveryService',
  full_name='envoy.service.discovery.v2.SecretDiscoveryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\212\244\226\363\007\032\n\030envoy.api.v2.auth.Secret',
  create_key=_descriptor._internal_create_key,
  serialized_start=238,
  serialized_end=602,
  methods=[
  _descriptor.MethodDescriptor(
    name='DeltaSecrets',
    full_name='envoy.service.discovery.v2.SecretDiscoveryService.DeltaSecrets',
    index=0,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DELTADISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DELTADISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamSecrets',
    full_name='envoy.service.discovery.v2.SecretDiscoveryService.StreamSecrets',
    index=1,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchSecrets',
    full_name='envoy.service.discovery.v2.SecretDiscoveryService.FetchSecrets',
    index=2,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\"\025/v2/discovery:secrets\202\323\344\223\002\003:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SECRETDISCOVERYSERVICE)

DESCRIPTOR.services_by_name['SecretDiscoveryService'] = _SECRETDISCOVERYSERVICE

# @@protoc_insertion_point(module_scope)
