# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/transport_sockets/tls/v3/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/transport_sockets/tls/v3/common.proto',
  package='envoy.extensions.transport_sockets.tls.v3',
  syntax='proto3',
  serialized_options=b'\n7io.envoyproxy.envoy.extensions.transport_sockets.tls.v3B\013CommonProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n6envoy/extensions/transport_sockets/tls/v3/common.proto\x12)envoy.extensions.transport_sockets.tls.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\"envoy/type/matcher/v3/string.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xa0\x03\n\rTlsParameters\x12t\n\x1ctls_minimum_protocol_version\x18\x01 \x01(\x0e\x32\x44.envoy.extensions.transport_sockets.tls.v3.TlsParameters.TlsProtocolB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12t\n\x1ctls_maximum_protocol_version\x18\x02 \x01(\x0e\x32\x44.envoy.extensions.transport_sockets.tls.v3.TlsParameters.TlsProtocolB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x15\n\rcipher_suites\x18\x03 \x03(\t\x12\x13\n\x0b\x65\x63\x64h_curves\x18\x04 \x03(\t\"O\n\x0bTlsProtocol\x12\x0c\n\x08TLS_AUTO\x10\x00\x12\x0b\n\x07TLSv1_0\x10\x01\x12\x0b\n\x07TLSv1_1\x10\x02\x12\x0b\n\x07TLSv1_2\x10\x03\x12\x0b\n\x07TLSv1_3\x10\x04:&\x9a\xc5\x88\x1e!\n\x1f\x65nvoy.api.v2.auth.TlsParameters\"\xb4\x01\n\x12PrivateKeyProvider\x12\x1e\n\rprovider_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x34\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB\x06\xb8\xb7\x8b\xa4\x02\x01H\x00:+\x9a\xc5\x88\x1e&\n$envoy.api.v2.auth.PrivateKeyProviderB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfig\"\x90\x04\n\x0eTlsCertificate\x12;\n\x11\x63\x65rtificate_chain\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSource\x12=\n\x0bprivate_key\x18\x02 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x41\n\x11watched_directory\x18\x07 \x01(\x0b\x32&.envoy.config.core.v3.WatchedDirectory\x12[\n\x14private_key_provider\x18\x06 \x01(\x0b\x32=.envoy.extensions.transport_sockets.tls.v3.PrivateKeyProvider\x12:\n\x08password\x18\x03 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x35\n\x0bocsp_staple\x18\x04 \x01(\x0b\x32 .envoy.config.core.v3.DataSource\x12\x46\n\x1csigned_certificate_timestamp\x18\x05 \x03(\x0b\x32 .envoy.config.core.v3.DataSource:\'\x9a\xc5\x88\x1e\"\n envoy.api.v2.auth.TlsCertificate\"\x85\x01\n\x14TlsSessionTicketKeys\x12>\n\x04keys\x18\x01 \x03(\x0b\x32 .envoy.config.core.v3.DataSourceB\x0e\xfa\x42\x05\x92\x01\x02\x08\x01\xb8\xb7\x8b\xa4\x02\x01:-\x9a\xc5\x88\x1e(\n&envoy.api.v2.auth.TlsSessionTicketKeys\"\x8d\x06\n\x1c\x43\x65rtificateValidationContext\x12\x34\n\ntrusted_ca\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSource\x12\x41\n\x11watched_directory\x18\x0b \x01(\x0b\x32&.envoy.config.core.v3.WatchedDirectory\x12/\n\x17verify_certificate_spki\x18\x03 \x03(\tB\x0e\xfa\x42\x0b\x92\x01\x08\"\x06r\x04\x10,(,\x12/\n\x17verify_certificate_hash\x18\x02 \x03(\tB\x0e\xfa\x42\x0b\x92\x01\x08\"\x06r\x04\x10@(_\x12\x45\n\x17match_subject_alt_names\x18\t \x03(\x0b\x32$.envoy.type.matcher.v3.StringMatcher\x12H\n$require_signed_certificate_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12-\n\x03\x63rl\x18\x07 \x01(\x0b\x32 .envoy.config.core.v3.DataSource\x12!\n\x19\x61llow_expired_certificate\x18\x08 \x01(\x08\x12\x8a\x01\n\x18trust_chain_verification\x18\n \x01(\x0e\x32^.envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext.TrustChainVerificationB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"F\n\x16TrustChainVerification\x12\x16\n\x12VERIFY_TRUST_CHAIN\x10\x00\x12\x14\n\x10\x41\x43\x43\x45PT_UNTRUSTED\x10\x01:5\x9a\xc5\x88\x1e\x30\n.envoy.api.v2.auth.CertificateValidationContextJ\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06R\x17verify_subject_alt_nameBP\n7io.envoyproxy.envoy.extensions.transport_sockets.tls.v3B\x0b\x43ommonProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_sensitive__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_TLSPARAMETERS_TLSPROTOCOL = _descriptor.EnumDescriptor(
  name='TlsProtocol',
  full_name='envoy.extensions.transport_sockets.tls.v3.TlsParameters.TlsProtocol',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TLS_AUTO', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TLSv1_0', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TLSv1_1', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TLSv1_2', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TLSv1_3', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=652,
  serialized_end=731,
)
_sym_db.RegisterEnumDescriptor(_TLSPARAMETERS_TLSPROTOCOL)

_CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION = _descriptor.EnumDescriptor(
  name='TrustChainVerification',
  full_name='envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext.TrustChainVerification',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VERIFY_TRUST_CHAIN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACCEPT_UNTRUSTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2243,
  serialized_end=2313,
)
_sym_db.RegisterEnumDescriptor(_CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION)


_TLSPARAMETERS = _descriptor.Descriptor(
  name='TlsParameters',
  full_name='envoy.extensions.transport_sockets.tls.v3.TlsParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tls_minimum_protocol_version', full_name='envoy.extensions.transport_sockets.tls.v3.TlsParameters.tls_minimum_protocol_version', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls_maximum_protocol_version', full_name='envoy.extensions.transport_sockets.tls.v3.TlsParameters.tls_maximum_protocol_version', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cipher_suites', full_name='envoy.extensions.transport_sockets.tls.v3.TlsParameters.cipher_suites', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ecdh_curves', full_name='envoy.extensions.transport_sockets.tls.v3.TlsParameters.ecdh_curves', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TLSPARAMETERS_TLSPROTOCOL,
  ],
  serialized_options=b'\232\305\210\036!\n\037envoy.api.v2.auth.TlsParameters',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=355,
  serialized_end=771,
)


_PRIVATEKEYPROVIDER = _descriptor.Descriptor(
  name='PrivateKeyProvider',
  full_name='envoy.extensions.transport_sockets.tls.v3.PrivateKeyProvider',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='provider_name', full_name='envoy.extensions.transport_sockets.tls.v3.PrivateKeyProvider.provider_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.extensions.transport_sockets.tls.v3.PrivateKeyProvider.typed_config', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036&\n$envoy.api.v2.auth.PrivateKeyProvider',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.extensions.transport_sockets.tls.v3.PrivateKeyProvider.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=774,
  serialized_end=954,
)


_TLSCERTIFICATE = _descriptor.Descriptor(
  name='TlsCertificate',
  full_name='envoy.extensions.transport_sockets.tls.v3.TlsCertificate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_chain', full_name='envoy.extensions.transport_sockets.tls.v3.TlsCertificate.certificate_chain', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private_key', full_name='envoy.extensions.transport_sockets.tls.v3.TlsCertificate.private_key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watched_directory', full_name='envoy.extensions.transport_sockets.tls.v3.TlsCertificate.watched_directory', index=2,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private_key_provider', full_name='envoy.extensions.transport_sockets.tls.v3.TlsCertificate.private_key_provider', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='envoy.extensions.transport_sockets.tls.v3.TlsCertificate.password', index=4,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ocsp_staple', full_name='envoy.extensions.transport_sockets.tls.v3.TlsCertificate.ocsp_staple', index=5,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signed_certificate_timestamp', full_name='envoy.extensions.transport_sockets.tls.v3.TlsCertificate.signed_certificate_timestamp', index=6,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\"\n envoy.api.v2.auth.TlsCertificate',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=957,
  serialized_end=1485,
)


_TLSSESSIONTICKETKEYS = _descriptor.Descriptor(
  name='TlsSessionTicketKeys',
  full_name='envoy.extensions.transport_sockets.tls.v3.TlsSessionTicketKeys',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='keys', full_name='envoy.extensions.transport_sockets.tls.v3.TlsSessionTicketKeys.keys', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036(\n&envoy.api.v2.auth.TlsSessionTicketKeys',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1488,
  serialized_end=1621,
)


_CERTIFICATEVALIDATIONCONTEXT = _descriptor.Descriptor(
  name='CertificateValidationContext',
  full_name='envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trusted_ca', full_name='envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext.trusted_ca', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watched_directory', full_name='envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext.watched_directory', index=1,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verify_certificate_spki', full_name='envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext.verify_certificate_spki', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\013\222\001\010\"\006r\004\020,(,', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verify_certificate_hash', full_name='envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext.verify_certificate_hash', index=3,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\013\222\001\010\"\006r\004\020@(_', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='match_subject_alt_names', full_name='envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext.match_subject_alt_names', index=4,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='require_signed_certificate_timestamp', full_name='envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext.require_signed_certificate_timestamp', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crl', full_name='envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext.crl', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_expired_certificate', full_name='envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext.allow_expired_certificate', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trust_chain_verification', full_name='envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext.trust_chain_verification', index=8,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION,
  ],
  serialized_options=b'\232\305\210\0360\n.envoy.api.v2.auth.CertificateValidationContext',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1624,
  serialized_end=2405,
)

_TLSPARAMETERS.fields_by_name['tls_minimum_protocol_version'].enum_type = _TLSPARAMETERS_TLSPROTOCOL
_TLSPARAMETERS.fields_by_name['tls_maximum_protocol_version'].enum_type = _TLSPARAMETERS_TLSPROTOCOL
_TLSPARAMETERS_TLSPROTOCOL.containing_type = _TLSPARAMETERS
_PRIVATEKEYPROVIDER.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_PRIVATEKEYPROVIDER.oneofs_by_name['config_type'].fields.append(
  _PRIVATEKEYPROVIDER.fields_by_name['typed_config'])
_PRIVATEKEYPROVIDER.fields_by_name['typed_config'].containing_oneof = _PRIVATEKEYPROVIDER.oneofs_by_name['config_type']
_TLSCERTIFICATE.fields_by_name['certificate_chain'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._DATASOURCE
_TLSCERTIFICATE.fields_by_name['private_key'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._DATASOURCE
_TLSCERTIFICATE.fields_by_name['watched_directory'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._WATCHEDDIRECTORY
_TLSCERTIFICATE.fields_by_name['private_key_provider'].message_type = _PRIVATEKEYPROVIDER
_TLSCERTIFICATE.fields_by_name['password'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._DATASOURCE
_TLSCERTIFICATE.fields_by_name['ocsp_staple'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._DATASOURCE
_TLSCERTIFICATE.fields_by_name['signed_certificate_timestamp'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._DATASOURCE
_TLSSESSIONTICKETKEYS.fields_by_name['keys'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._DATASOURCE
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['trusted_ca'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._DATASOURCE
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['watched_directory'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._WATCHEDDIRECTORY
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['match_subject_alt_names'].message_type = envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2._STRINGMATCHER
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['require_signed_certificate_timestamp'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['crl'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._DATASOURCE
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['trust_chain_verification'].enum_type = _CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION
_CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION.containing_type = _CERTIFICATEVALIDATIONCONTEXT
DESCRIPTOR.message_types_by_name['TlsParameters'] = _TLSPARAMETERS
DESCRIPTOR.message_types_by_name['PrivateKeyProvider'] = _PRIVATEKEYPROVIDER
DESCRIPTOR.message_types_by_name['TlsCertificate'] = _TLSCERTIFICATE
DESCRIPTOR.message_types_by_name['TlsSessionTicketKeys'] = _TLSSESSIONTICKETKEYS
DESCRIPTOR.message_types_by_name['CertificateValidationContext'] = _CERTIFICATEVALIDATIONCONTEXT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TlsParameters = _reflection.GeneratedProtocolMessageType('TlsParameters', (_message.Message,), {
  'DESCRIPTOR' : _TLSPARAMETERS,
  '__module__' : 'envoy.extensions.transport_sockets.tls.v3.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.transport_sockets.tls.v3.TlsParameters)
  })
_sym_db.RegisterMessage(TlsParameters)

PrivateKeyProvider = _reflection.GeneratedProtocolMessageType('PrivateKeyProvider', (_message.Message,), {
  'DESCRIPTOR' : _PRIVATEKEYPROVIDER,
  '__module__' : 'envoy.extensions.transport_sockets.tls.v3.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.transport_sockets.tls.v3.PrivateKeyProvider)
  })
_sym_db.RegisterMessage(PrivateKeyProvider)

TlsCertificate = _reflection.GeneratedProtocolMessageType('TlsCertificate', (_message.Message,), {
  'DESCRIPTOR' : _TLSCERTIFICATE,
  '__module__' : 'envoy.extensions.transport_sockets.tls.v3.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.transport_sockets.tls.v3.TlsCertificate)
  })
_sym_db.RegisterMessage(TlsCertificate)

TlsSessionTicketKeys = _reflection.GeneratedProtocolMessageType('TlsSessionTicketKeys', (_message.Message,), {
  'DESCRIPTOR' : _TLSSESSIONTICKETKEYS,
  '__module__' : 'envoy.extensions.transport_sockets.tls.v3.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.transport_sockets.tls.v3.TlsSessionTicketKeys)
  })
_sym_db.RegisterMessage(TlsSessionTicketKeys)

CertificateValidationContext = _reflection.GeneratedProtocolMessageType('CertificateValidationContext', (_message.Message,), {
  'DESCRIPTOR' : _CERTIFICATEVALIDATIONCONTEXT,
  '__module__' : 'envoy.extensions.transport_sockets.tls.v3.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext)
  })
_sym_db.RegisterMessage(CertificateValidationContext)


DESCRIPTOR._options = None
_TLSPARAMETERS.fields_by_name['tls_minimum_protocol_version']._options = None
_TLSPARAMETERS.fields_by_name['tls_maximum_protocol_version']._options = None
_TLSPARAMETERS._options = None
_PRIVATEKEYPROVIDER.fields_by_name['provider_name']._options = None
_PRIVATEKEYPROVIDER.fields_by_name['typed_config']._options = None
_PRIVATEKEYPROVIDER._options = None
_TLSCERTIFICATE.fields_by_name['private_key']._options = None
_TLSCERTIFICATE.fields_by_name['password']._options = None
_TLSCERTIFICATE._options = None
_TLSSESSIONTICKETKEYS.fields_by_name['keys']._options = None
_TLSSESSIONTICKETKEYS._options = None
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['verify_certificate_spki']._options = None
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['verify_certificate_hash']._options = None
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['trust_chain_verification']._options = None
_CERTIFICATEVALIDATIONCONTEXT._options = None
# @@protoc_insertion_point(module_scope)
