# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/transport_sockets/starttls/v4alpha/starttls.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.transport_sockets.raw_buffer.v3 import raw_buffer_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_raw__buffer_dot_v3_dot_raw__buffer__pb2
from envoy.extensions.transport_sockets.tls.v4alpha import tls_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v4alpha_dot_tls__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/transport_sockets/starttls/v4alpha/starttls.proto',
  package='envoy.extensions.transport_sockets.starttls.v4alpha',
  syntax='proto3',
  serialized_options=b'\nAio.envoyproxy.envoy.extensions.transport_sockets.starttls.v4alphaB\rStarttlsProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nBenvoy/extensions/transport_sockets/starttls/v4alpha/starttls.proto\x12\x33\x65nvoy.extensions.transport_sockets.starttls.v4alpha\x1a\x41\x65nvoy/extensions/transport_sockets/raw_buffer/v3/raw_buffer.proto\x1a\x38\x65nvoy/extensions/transport_sockets/tls/v4alpha/tls.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x9f\x02\n\x0eStartTlsConfig\x12\\\n\x17\x63leartext_socket_config\x18\x01 \x01(\x0b\x32;.envoy.extensions.transport_sockets.raw_buffer.v3.RawBuffer\x12i\n\x11tls_socket_config\x18\x02 \x01(\x0b\x32\x44.envoy.extensions.transport_sockets.tls.v4alpha.DownstreamTlsContextB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:D\x9a\xc5\x88\x1e?\n=envoy.extensions.transport_sockets.starttls.v3.StartTlsConfigB\\\nAio.envoyproxy.envoy.extensions.transport_sockets.starttls.v4alphaB\rStarttlsProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_extensions_dot_transport__sockets_dot_raw__buffer_dot_v3_dot_raw__buffer__pb2.DESCRIPTOR,envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v4alpha_dot_tls__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_STARTTLSCONFIG = _descriptor.Descriptor(
  name='StartTlsConfig',
  full_name='envoy.extensions.transport_sockets.starttls.v4alpha.StartTlsConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cleartext_socket_config', full_name='envoy.extensions.transport_sockets.starttls.v4alpha.StartTlsConfig.cleartext_socket_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls_socket_config', full_name='envoy.extensions.transport_sockets.starttls.v4alpha.StartTlsConfig.tls_socket_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036?\n=envoy.extensions.transport_sockets.starttls.v3.StartTlsConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=340,
  serialized_end=627,
)

_STARTTLSCONFIG.fields_by_name['cleartext_socket_config'].message_type = envoy_dot_extensions_dot_transport__sockets_dot_raw__buffer_dot_v3_dot_raw__buffer__pb2._RAWBUFFER
_STARTTLSCONFIG.fields_by_name['tls_socket_config'].message_type = envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v4alpha_dot_tls__pb2._DOWNSTREAMTLSCONTEXT
DESCRIPTOR.message_types_by_name['StartTlsConfig'] = _STARTTLSCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StartTlsConfig = _reflection.GeneratedProtocolMessageType('StartTlsConfig', (_message.Message,), {
  'DESCRIPTOR' : _STARTTLSCONFIG,
  '__module__' : 'envoy.extensions.transport_sockets.starttls.v4alpha.starttls_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.transport_sockets.starttls.v4alpha.StartTlsConfig)
  })
_sym_db.RegisterMessage(StartTlsConfig)


DESCRIPTOR._options = None
_STARTTLSCONFIG.fields_by_name['tls_socket_config']._options = None
_STARTTLSCONFIG._options = None
# @@protoc_insertion_point(module_scope)
