# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/internal_redirect/allow_listed_routes/v3/allow_listed_routes_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/internal_redirect/allow_listed_routes/v3/allow_listed_routes_config.proto',
  package='envoy.extensions.internal_redirect.allow_listed_routes.v3',
  syntax='proto3',
  serialized_options=b'\nGio.envoyproxy.envoy.extensions.internal_redirect.allow_listed_routes.v3B\034AllowListedRoutesConfigProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nZenvoy/extensions/internal_redirect/allow_listed_routes/v3/allow_listed_routes_config.proto\x12\x39\x65nvoy.extensions.internal_redirect.allow_listed_routes.v3\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"D\n\x17\x41llowListedRoutesConfig\x12)\n\x13\x61llowed_route_names\x18\x01 \x03(\tB\x0c\xfa\x42\t\x92\x01\x06\"\x04r\x02\x10\x01\x42q\nGio.envoyproxy.envoy.extensions.internal_redirect.allow_listed_routes.v3B\x1c\x41llowListedRoutesConfigProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_ALLOWLISTEDROUTESCONFIG = _descriptor.Descriptor(
  name='AllowListedRoutesConfig',
  full_name='envoy.extensions.internal_redirect.allow_listed_routes.v3.AllowListedRoutesConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='allowed_route_names', full_name='envoy.extensions.internal_redirect.allow_listed_routes.v3.AllowListedRoutesConfig.allowed_route_names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\t\222\001\006\"\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=277,
)

DESCRIPTOR.message_types_by_name['AllowListedRoutesConfig'] = _ALLOWLISTEDROUTESCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AllowListedRoutesConfig = _reflection.GeneratedProtocolMessageType('AllowListedRoutesConfig', (_message.Message,), {
  'DESCRIPTOR' : _ALLOWLISTEDROUTESCONFIG,
  '__module__' : 'envoy.extensions.internal_redirect.allow_listed_routes.v3.allow_listed_routes_config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.internal_redirect.allow_listed_routes.v3.AllowListedRoutesConfig)
  })
_sym_db.RegisterMessage(AllowListedRoutesConfig)


DESCRIPTOR._options = None
_ALLOWLISTEDROUTESCONFIG.fields_by_name['allowed_route_names']._options = None
# @@protoc_insertion_point(module_scope)
