# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v3/health_check.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import event_service_config_pb2 as envoy_dot_config_dot_core_dot_v3_dot_event__service__config__pb2
from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from envoy.type.v3 import http_pb2 as envoy_dot_type_dot_v3_dot_http__pb2
from envoy.type.v3 import range_pb2 as envoy_dot_type_dot_v3_dot_range__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/core/v3/health_check.proto',
  package='envoy.config.core.v3',
  syntax='proto3',
  serialized_options=b'\n\"io.envoyproxy.envoy.config.core.v3B\020HealthCheckProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'envoy/config/core/v3/health_check.proto\x12\x14\x65nvoy.config.core.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a/envoy/config/core/v3/event_service_config.proto\x1a\"envoy/type/matcher/v3/string.proto\x1a\x18\x65nvoy/type/v3/http.proto\x1a\x19\x65nvoy/type/v3/range.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xcb\x16\n\x0bHealthCheck\x12\x36\n\x07timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\x12\x37\n\x08interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\x12\x31\n\x0einitial_jitter\x18\x14 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x32\n\x0finterval_jitter\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1f\n\x17interval_jitter_percent\x18\x12 \x01(\r\x12\x43\n\x13unhealthy_threshold\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x41\n\x11healthy_threshold\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12.\n\x08\x61lt_port\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x34\n\x10reuse_connection\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12N\n\x11http_health_check\x18\x08 \x01(\x0b\x32\x31.envoy.config.core.v3.HealthCheck.HttpHealthCheckH\x00\x12L\n\x10tcp_health_check\x18\t \x01(\x0b\x32\x30.envoy.config.core.v3.HealthCheck.TcpHealthCheckH\x00\x12N\n\x11grpc_health_check\x18\x0b \x01(\x0b\x32\x31.envoy.config.core.v3.HealthCheck.GrpcHealthCheckH\x00\x12R\n\x13\x63ustom_health_check\x18\r \x01(\x0b\x32\x33.envoy.config.core.v3.HealthCheck.CustomHealthCheckH\x00\x12@\n\x13no_traffic_interval\x18\x0c \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12H\n\x1bno_traffic_healthy_interval\x18\x18 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12?\n\x12unhealthy_interval\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x44\n\x17unhealthy_edge_interval\x18\x0f \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x42\n\x15healthy_edge_interval\x18\x10 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x16\n\x0e\x65vent_log_path\x18\x11 \x01(\t\x12?\n\revent_service\x18\x16 \x01(\x0b\x32(.envoy.config.core.v3.EventServiceConfig\x12(\n always_log_health_check_failures\x18\x13 \x01(\x08\x12\x41\n\x0btls_options\x18\x15 \x01(\x0b\x32,.envoy.config.core.v3.HealthCheck.TlsOptions\x12@\n\x1ftransport_socket_match_criteria\x18\x17 \x01(\x0b\x32\x17.google.protobuf.Struct\x1ar\n\x07Payload\x12\x17\n\x04text\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x10\n\x06\x62inary\x18\x02 \x01(\x0cH\x00:,\x9a\xc5\x88\x1e\'\n%envoy.api.v2.core.HealthCheck.PayloadB\x0e\n\x07payload\x12\x03\xf8\x42\x01\x1a\xe1\x04\n\x0fHttpHealthCheck\x12\x19\n\x04host\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00\x12\x1b\n\x04path\x18\x02 \x01(\tB\r\xfa\x42\nr\x08\x10\x01\xc0\x01\x02\xc8\x01\x00\x12\x37\n\x04send\x18\x03 \x01(\x0b\x32).envoy.config.core.v3.HealthCheck.Payload\x12:\n\x07receive\x18\x04 \x01(\x0b\x32).envoy.config.core.v3.HealthCheck.Payload\x12R\n\x16request_headers_to_add\x18\x06 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12\x33\n\x19request_headers_to_remove\x18\x08 \x03(\tB\x10\xfa\x42\r\x92\x01\n\"\x08r\x06\xc0\x01\x01\xc8\x01\x00\x12\x34\n\x11\x65xpected_statuses\x18\t \x03(\x0b\x32\x19.envoy.type.v3.Int64Range\x12\x43\n\x11\x63odec_client_type\x18\n \x01(\x0e\x32\x1e.envoy.type.v3.CodecClientTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x42\n\x14service_name_matcher\x18\x0b \x01(\x0b\x32$.envoy.type.matcher.v3.StringMatcher:4\x9a\xc5\x88\x1e/\n-envoy.api.v2.core.HealthCheck.HttpHealthCheckJ\x04\x08\x05\x10\x06J\x04\x08\x07\x10\x08R\x0cservice_nameR\tuse_http2\x1a\xba\x01\n\x0eTcpHealthCheck\x12\x37\n\x04send\x18\x01 \x01(\x0b\x32).envoy.config.core.v3.HealthCheck.Payload\x12:\n\x07receive\x18\x02 \x03(\x0b\x32).envoy.config.core.v3.HealthCheck.Payload:3\x9a\xc5\x88\x1e.\n,envoy.api.v2.core.HealthCheck.TcpHealthCheck\x1aV\n\x10RedisHealthCheck\x12\x0b\n\x03key\x18\x01 \x01(\t:5\x9a\xc5\x88\x1e\x30\n.envoy.api.v2.core.HealthCheck.RedisHealthCheck\x1a}\n\x0fGrpcHealthCheck\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x1e\n\tauthority\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00:4\x9a\xc5\x88\x1e/\n-envoy.api.v2.core.HealthCheck.GrpcHealthCheck\x1a\xad\x01\n\x11\x43ustomHealthCheck\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00:6\x9a\xc5\x88\x1e\x31\n/envoy.api.v2.core.HealthCheck.CustomHealthCheckB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfig\x1aU\n\nTlsOptions\x12\x16\n\x0e\x61lpn_protocols\x18\x01 \x03(\t:/\x9a\xc5\x88\x1e*\n(envoy.api.v2.core.HealthCheck.TlsOptions:$\x9a\xc5\x88\x1e\x1f\n\x1d\x65nvoy.api.v2.core.HealthCheckB\x15\n\x0ehealth_checker\x12\x03\xf8\x42\x01J\x04\x08\n\x10\x0b*`\n\x0cHealthStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07HEALTHY\x10\x01\x12\r\n\tUNHEALTHY\x10\x02\x12\x0c\n\x08\x44RAINING\x10\x03\x12\x0b\n\x07TIMEOUT\x10\x04\x12\x0c\n\x08\x44\x45GRADED\x10\x05\x42@\n\"io.envoyproxy.envoy.config.core.v3B\x10HealthCheckProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v3_dot_event__service__config__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_http__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_range__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])

_HEALTHSTATUS = _descriptor.EnumDescriptor(
  name='HealthStatus',
  full_name='envoy.config.core.v3.HealthStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HEALTHY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNHEALTHY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DRAINING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TIMEOUT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEGRADED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3342,
  serialized_end=3438,
)
_sym_db.RegisterEnumDescriptor(_HEALTHSTATUS)

HealthStatus = enum_type_wrapper.EnumTypeWrapper(_HEALTHSTATUS)
UNKNOWN = 0
HEALTHY = 1
UNHEALTHY = 2
DRAINING = 3
TIMEOUT = 4
DEGRADED = 5



_HEALTHCHECK_PAYLOAD = _descriptor.Descriptor(
  name='Payload',
  full_name='envoy.config.core.v3.HealthCheck.Payload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='envoy.config.core.v3.HealthCheck.Payload.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='binary', full_name='envoy.config.core.v3.HealthCheck.Payload.binary', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\'\n%envoy.api.v2.core.HealthCheck.Payload',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='envoy.config.core.v3.HealthCheck.Payload.payload',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1880,
  serialized_end=1994,
)

_HEALTHCHECK_HTTPHEALTHCHECK = _descriptor.Descriptor(
  name='HttpHealthCheck',
  full_name='envoy.config.core.v3.HealthCheck.HttpHealthCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host', full_name='envoy.config.core.v3.HealthCheck.HttpHealthCheck.host', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010r\006\300\001\002\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='envoy.config.core.v3.HealthCheck.HttpHealthCheck.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\nr\010\020\001\300\001\002\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send', full_name='envoy.config.core.v3.HealthCheck.HttpHealthCheck.send', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receive', full_name='envoy.config.core.v3.HealthCheck.HttpHealthCheck.receive', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_headers_to_add', full_name='envoy.config.core.v3.HealthCheck.HttpHealthCheck.request_headers_to_add', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006\222\001\003\020\350\007', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_headers_to_remove', full_name='envoy.config.core.v3.HealthCheck.HttpHealthCheck.request_headers_to_remove', index=5,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\r\222\001\n\"\010r\006\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expected_statuses', full_name='envoy.config.core.v3.HealthCheck.HttpHealthCheck.expected_statuses', index=6,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='codec_client_type', full_name='envoy.config.core.v3.HealthCheck.HttpHealthCheck.codec_client_type', index=7,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_name_matcher', full_name='envoy.config.core.v3.HealthCheck.HttpHealthCheck.service_name_matcher', index=8,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036/\n-envoy.api.v2.core.HealthCheck.HttpHealthCheck',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1997,
  serialized_end=2606,
)

_HEALTHCHECK_TCPHEALTHCHECK = _descriptor.Descriptor(
  name='TcpHealthCheck',
  full_name='envoy.config.core.v3.HealthCheck.TcpHealthCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='send', full_name='envoy.config.core.v3.HealthCheck.TcpHealthCheck.send', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receive', full_name='envoy.config.core.v3.HealthCheck.TcpHealthCheck.receive', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036.\n,envoy.api.v2.core.HealthCheck.TcpHealthCheck',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2609,
  serialized_end=2795,
)

_HEALTHCHECK_REDISHEALTHCHECK = _descriptor.Descriptor(
  name='RedisHealthCheck',
  full_name='envoy.config.core.v3.HealthCheck.RedisHealthCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.config.core.v3.HealthCheck.RedisHealthCheck.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0360\n.envoy.api.v2.core.HealthCheck.RedisHealthCheck',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2797,
  serialized_end=2883,
)

_HEALTHCHECK_GRPCHEALTHCHECK = _descriptor.Descriptor(
  name='GrpcHealthCheck',
  full_name='envoy.config.core.v3.HealthCheck.GrpcHealthCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_name', full_name='envoy.config.core.v3.HealthCheck.GrpcHealthCheck.service_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authority', full_name='envoy.config.core.v3.HealthCheck.GrpcHealthCheck.authority', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010r\006\300\001\002\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036/\n-envoy.api.v2.core.HealthCheck.GrpcHealthCheck',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2885,
  serialized_end=3010,
)

_HEALTHCHECK_CUSTOMHEALTHCHECK = _descriptor.Descriptor(
  name='CustomHealthCheck',
  full_name='envoy.config.core.v3.HealthCheck.CustomHealthCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.core.v3.HealthCheck.CustomHealthCheck.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.config.core.v3.HealthCheck.CustomHealthCheck.typed_config', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0361\n/envoy.api.v2.core.HealthCheck.CustomHealthCheck',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.config.core.v3.HealthCheck.CustomHealthCheck.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3013,
  serialized_end=3186,
)

_HEALTHCHECK_TLSOPTIONS = _descriptor.Descriptor(
  name='TlsOptions',
  full_name='envoy.config.core.v3.HealthCheck.TlsOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='alpn_protocols', full_name='envoy.config.core.v3.HealthCheck.TlsOptions.alpn_protocols', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036*\n(envoy.api.v2.core.HealthCheck.TlsOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3188,
  serialized_end=3273,
)

_HEALTHCHECK = _descriptor.Descriptor(
  name='HealthCheck',
  full_name='envoy.config.core.v3.HealthCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeout', full_name='envoy.config.core.v3.HealthCheck.timeout', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007\252\001\004\010\001*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='envoy.config.core.v3.HealthCheck.interval', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007\252\001\004\010\001*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_jitter', full_name='envoy.config.core.v3.HealthCheck.initial_jitter', index=2,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval_jitter', full_name='envoy.config.core.v3.HealthCheck.interval_jitter', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval_jitter_percent', full_name='envoy.config.core.v3.HealthCheck.interval_jitter_percent', index=4,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unhealthy_threshold', full_name='envoy.config.core.v3.HealthCheck.unhealthy_threshold', index=5,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='healthy_threshold', full_name='envoy.config.core.v3.HealthCheck.healthy_threshold', index=6,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alt_port', full_name='envoy.config.core.v3.HealthCheck.alt_port', index=7,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reuse_connection', full_name='envoy.config.core.v3.HealthCheck.reuse_connection', index=8,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_health_check', full_name='envoy.config.core.v3.HealthCheck.http_health_check', index=9,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tcp_health_check', full_name='envoy.config.core.v3.HealthCheck.tcp_health_check', index=10,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc_health_check', full_name='envoy.config.core.v3.HealthCheck.grpc_health_check', index=11,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_health_check', full_name='envoy.config.core.v3.HealthCheck.custom_health_check', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_traffic_interval', full_name='envoy.config.core.v3.HealthCheck.no_traffic_interval', index=13,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_traffic_healthy_interval', full_name='envoy.config.core.v3.HealthCheck.no_traffic_healthy_interval', index=14,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unhealthy_interval', full_name='envoy.config.core.v3.HealthCheck.unhealthy_interval', index=15,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unhealthy_edge_interval', full_name='envoy.config.core.v3.HealthCheck.unhealthy_edge_interval', index=16,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='healthy_edge_interval', full_name='envoy.config.core.v3.HealthCheck.healthy_edge_interval', index=17,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_log_path', full_name='envoy.config.core.v3.HealthCheck.event_log_path', index=18,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_service', full_name='envoy.config.core.v3.HealthCheck.event_service', index=19,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='always_log_health_check_failures', full_name='envoy.config.core.v3.HealthCheck.always_log_health_check_failures', index=20,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls_options', full_name='envoy.config.core.v3.HealthCheck.tls_options', index=21,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transport_socket_match_criteria', full_name='envoy.config.core.v3.HealthCheck.transport_socket_match_criteria', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HEALTHCHECK_PAYLOAD, _HEALTHCHECK_HTTPHEALTHCHECK, _HEALTHCHECK_TCPHEALTHCHECK, _HEALTHCHECK_REDISHEALTHCHECK, _HEALTHCHECK_GRPCHEALTHCHECK, _HEALTHCHECK_CUSTOMHEALTHCHECK, _HEALTHCHECK_TLSOPTIONS, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\037\n\035envoy.api.v2.core.HealthCheck',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='health_checker', full_name='envoy.config.core.v3.HealthCheck.health_checker',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=449,
  serialized_end=3340,
)

_HEALTHCHECK_PAYLOAD.containing_type = _HEALTHCHECK
_HEALTHCHECK_PAYLOAD.oneofs_by_name['payload'].fields.append(
  _HEALTHCHECK_PAYLOAD.fields_by_name['text'])
_HEALTHCHECK_PAYLOAD.fields_by_name['text'].containing_oneof = _HEALTHCHECK_PAYLOAD.oneofs_by_name['payload']
_HEALTHCHECK_PAYLOAD.oneofs_by_name['payload'].fields.append(
  _HEALTHCHECK_PAYLOAD.fields_by_name['binary'])
_HEALTHCHECK_PAYLOAD.fields_by_name['binary'].containing_oneof = _HEALTHCHECK_PAYLOAD.oneofs_by_name['payload']
_HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['send'].message_type = _HEALTHCHECK_PAYLOAD
_HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['receive'].message_type = _HEALTHCHECK_PAYLOAD
_HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['request_headers_to_add'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._HEADERVALUEOPTION
_HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['expected_statuses'].message_type = envoy_dot_type_dot_v3_dot_range__pb2._INT64RANGE
_HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['codec_client_type'].enum_type = envoy_dot_type_dot_v3_dot_http__pb2._CODECCLIENTTYPE
_HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['service_name_matcher'].message_type = envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2._STRINGMATCHER
_HEALTHCHECK_HTTPHEALTHCHECK.containing_type = _HEALTHCHECK
_HEALTHCHECK_TCPHEALTHCHECK.fields_by_name['send'].message_type = _HEALTHCHECK_PAYLOAD
_HEALTHCHECK_TCPHEALTHCHECK.fields_by_name['receive'].message_type = _HEALTHCHECK_PAYLOAD
_HEALTHCHECK_TCPHEALTHCHECK.containing_type = _HEALTHCHECK
_HEALTHCHECK_REDISHEALTHCHECK.containing_type = _HEALTHCHECK
_HEALTHCHECK_GRPCHEALTHCHECK.containing_type = _HEALTHCHECK
_HEALTHCHECK_CUSTOMHEALTHCHECK.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_HEALTHCHECK_CUSTOMHEALTHCHECK.containing_type = _HEALTHCHECK
_HEALTHCHECK_CUSTOMHEALTHCHECK.oneofs_by_name['config_type'].fields.append(
  _HEALTHCHECK_CUSTOMHEALTHCHECK.fields_by_name['typed_config'])
_HEALTHCHECK_CUSTOMHEALTHCHECK.fields_by_name['typed_config'].containing_oneof = _HEALTHCHECK_CUSTOMHEALTHCHECK.oneofs_by_name['config_type']
_HEALTHCHECK_TLSOPTIONS.containing_type = _HEALTHCHECK
_HEALTHCHECK.fields_by_name['timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECK.fields_by_name['interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECK.fields_by_name['initial_jitter'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECK.fields_by_name['interval_jitter'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECK.fields_by_name['unhealthy_threshold'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HEALTHCHECK.fields_by_name['healthy_threshold'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HEALTHCHECK.fields_by_name['alt_port'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HEALTHCHECK.fields_by_name['reuse_connection'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_HEALTHCHECK.fields_by_name['http_health_check'].message_type = _HEALTHCHECK_HTTPHEALTHCHECK
_HEALTHCHECK.fields_by_name['tcp_health_check'].message_type = _HEALTHCHECK_TCPHEALTHCHECK
_HEALTHCHECK.fields_by_name['grpc_health_check'].message_type = _HEALTHCHECK_GRPCHEALTHCHECK
_HEALTHCHECK.fields_by_name['custom_health_check'].message_type = _HEALTHCHECK_CUSTOMHEALTHCHECK
_HEALTHCHECK.fields_by_name['no_traffic_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECK.fields_by_name['no_traffic_healthy_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECK.fields_by_name['unhealthy_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECK.fields_by_name['unhealthy_edge_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECK.fields_by_name['healthy_edge_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECK.fields_by_name['event_service'].message_type = envoy_dot_config_dot_core_dot_v3_dot_event__service__config__pb2._EVENTSERVICECONFIG
_HEALTHCHECK.fields_by_name['tls_options'].message_type = _HEALTHCHECK_TLSOPTIONS
_HEALTHCHECK.fields_by_name['transport_socket_match_criteria'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_HEALTHCHECK.oneofs_by_name['health_checker'].fields.append(
  _HEALTHCHECK.fields_by_name['http_health_check'])
_HEALTHCHECK.fields_by_name['http_health_check'].containing_oneof = _HEALTHCHECK.oneofs_by_name['health_checker']
_HEALTHCHECK.oneofs_by_name['health_checker'].fields.append(
  _HEALTHCHECK.fields_by_name['tcp_health_check'])
_HEALTHCHECK.fields_by_name['tcp_health_check'].containing_oneof = _HEALTHCHECK.oneofs_by_name['health_checker']
_HEALTHCHECK.oneofs_by_name['health_checker'].fields.append(
  _HEALTHCHECK.fields_by_name['grpc_health_check'])
_HEALTHCHECK.fields_by_name['grpc_health_check'].containing_oneof = _HEALTHCHECK.oneofs_by_name['health_checker']
_HEALTHCHECK.oneofs_by_name['health_checker'].fields.append(
  _HEALTHCHECK.fields_by_name['custom_health_check'])
_HEALTHCHECK.fields_by_name['custom_health_check'].containing_oneof = _HEALTHCHECK.oneofs_by_name['health_checker']
DESCRIPTOR.message_types_by_name['HealthCheck'] = _HEALTHCHECK
DESCRIPTOR.enum_types_by_name['HealthStatus'] = _HEALTHSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HealthCheck = _reflection.GeneratedProtocolMessageType('HealthCheck', (_message.Message,), {

  'Payload' : _reflection.GeneratedProtocolMessageType('Payload', (_message.Message,), {
    'DESCRIPTOR' : _HEALTHCHECK_PAYLOAD,
    '__module__' : 'envoy.config.core.v3.health_check_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.core.v3.HealthCheck.Payload)
    })
  ,

  'HttpHealthCheck' : _reflection.GeneratedProtocolMessageType('HttpHealthCheck', (_message.Message,), {
    'DESCRIPTOR' : _HEALTHCHECK_HTTPHEALTHCHECK,
    '__module__' : 'envoy.config.core.v3.health_check_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.core.v3.HealthCheck.HttpHealthCheck)
    })
  ,

  'TcpHealthCheck' : _reflection.GeneratedProtocolMessageType('TcpHealthCheck', (_message.Message,), {
    'DESCRIPTOR' : _HEALTHCHECK_TCPHEALTHCHECK,
    '__module__' : 'envoy.config.core.v3.health_check_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.core.v3.HealthCheck.TcpHealthCheck)
    })
  ,

  'RedisHealthCheck' : _reflection.GeneratedProtocolMessageType('RedisHealthCheck', (_message.Message,), {
    'DESCRIPTOR' : _HEALTHCHECK_REDISHEALTHCHECK,
    '__module__' : 'envoy.config.core.v3.health_check_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.core.v3.HealthCheck.RedisHealthCheck)
    })
  ,

  'GrpcHealthCheck' : _reflection.GeneratedProtocolMessageType('GrpcHealthCheck', (_message.Message,), {
    'DESCRIPTOR' : _HEALTHCHECK_GRPCHEALTHCHECK,
    '__module__' : 'envoy.config.core.v3.health_check_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.core.v3.HealthCheck.GrpcHealthCheck)
    })
  ,

  'CustomHealthCheck' : _reflection.GeneratedProtocolMessageType('CustomHealthCheck', (_message.Message,), {
    'DESCRIPTOR' : _HEALTHCHECK_CUSTOMHEALTHCHECK,
    '__module__' : 'envoy.config.core.v3.health_check_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.core.v3.HealthCheck.CustomHealthCheck)
    })
  ,

  'TlsOptions' : _reflection.GeneratedProtocolMessageType('TlsOptions', (_message.Message,), {
    'DESCRIPTOR' : _HEALTHCHECK_TLSOPTIONS,
    '__module__' : 'envoy.config.core.v3.health_check_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.core.v3.HealthCheck.TlsOptions)
    })
  ,
  'DESCRIPTOR' : _HEALTHCHECK,
  '__module__' : 'envoy.config.core.v3.health_check_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.HealthCheck)
  })
_sym_db.RegisterMessage(HealthCheck)
_sym_db.RegisterMessage(HealthCheck.Payload)
_sym_db.RegisterMessage(HealthCheck.HttpHealthCheck)
_sym_db.RegisterMessage(HealthCheck.TcpHealthCheck)
_sym_db.RegisterMessage(HealthCheck.RedisHealthCheck)
_sym_db.RegisterMessage(HealthCheck.GrpcHealthCheck)
_sym_db.RegisterMessage(HealthCheck.CustomHealthCheck)
_sym_db.RegisterMessage(HealthCheck.TlsOptions)


DESCRIPTOR._options = None
_HEALTHCHECK_PAYLOAD.oneofs_by_name['payload']._options = None
_HEALTHCHECK_PAYLOAD.fields_by_name['text']._options = None
_HEALTHCHECK_PAYLOAD._options = None
_HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['host']._options = None
_HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['path']._options = None
_HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['request_headers_to_add']._options = None
_HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['request_headers_to_remove']._options = None
_HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['codec_client_type']._options = None
_HEALTHCHECK_HTTPHEALTHCHECK._options = None
_HEALTHCHECK_TCPHEALTHCHECK._options = None
_HEALTHCHECK_REDISHEALTHCHECK._options = None
_HEALTHCHECK_GRPCHEALTHCHECK.fields_by_name['authority']._options = None
_HEALTHCHECK_GRPCHEALTHCHECK._options = None
_HEALTHCHECK_CUSTOMHEALTHCHECK.fields_by_name['name']._options = None
_HEALTHCHECK_CUSTOMHEALTHCHECK._options = None
_HEALTHCHECK_TLSOPTIONS._options = None
_HEALTHCHECK.oneofs_by_name['health_checker']._options = None
_HEALTHCHECK.fields_by_name['timeout']._options = None
_HEALTHCHECK.fields_by_name['interval']._options = None
_HEALTHCHECK.fields_by_name['unhealthy_threshold']._options = None
_HEALTHCHECK.fields_by_name['healthy_threshold']._options = None
_HEALTHCHECK.fields_by_name['no_traffic_interval']._options = None
_HEALTHCHECK.fields_by_name['no_traffic_healthy_interval']._options = None
_HEALTHCHECK.fields_by_name['unhealthy_interval']._options = None
_HEALTHCHECK.fields_by_name['unhealthy_edge_interval']._options = None
_HEALTHCHECK.fields_by_name['healthy_edge_interval']._options = None
_HEALTHCHECK._options = None
# @@protoc_insertion_point(module_scope)
