# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/cluster/v3/cds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.service.discovery.v3 import discovery_pb2 as envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/cluster/v3/cds.proto',
  package='envoy.service.cluster.v3',
  syntax='proto3',
  serialized_options=b'\n&io.envoyproxy.envoy.service.cluster.v3B\010CdsProtoP\001\210\001\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"envoy/service/cluster/v3/cds.proto\x12\x18\x65nvoy.service.cluster.v3\x1a*envoy/service/discovery/v3/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a envoy/annotations/resource.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"(\n\x08\x43\x64sDummy:\x1c\x9a\xc5\x88\x1e\x17\n\x15\x65nvoy.api.v2.CdsDummy2\xcd\x03\n\x17\x43lusterDiscoveryService\x12s\n\x0eStreamClusters\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"\x00(\x01\x30\x01\x12|\n\rDeltaClusters\x12\x31.envoy.service.discovery.v3.DeltaDiscoveryRequest\x1a\x32.envoy.service.discovery.v3.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12\x95\x01\n\rFetchClusters\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"\'\x82\xd3\xe4\x93\x02\x18\"\x16/v3/discovery:clusters\x82\xd3\xe4\x93\x02\x03:\x01*\x1a\'\x8a\xa4\x96\xf3\x07!\n\x1f\x65nvoy.config.cluster.v3.ClusterB?\n&io.envoyproxy.envoy.service.cluster.v3B\x08\x43\x64sProtoP\x01\x88\x01\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,envoy_dot_annotations_dot_resource__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_CDSDUMMY = _descriptor.Descriptor(
  name='CdsDummy',
  full_name='envoy.service.cluster.v3.CdsDummy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\027\n\025envoy.api.v2.CdsDummy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=238,
  serialized_end=278,
)

DESCRIPTOR.message_types_by_name['CdsDummy'] = _CDSDUMMY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CdsDummy = _reflection.GeneratedProtocolMessageType('CdsDummy', (_message.Message,), {
  'DESCRIPTOR' : _CDSDUMMY,
  '__module__' : 'envoy.service.cluster.v3.cds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.cluster.v3.CdsDummy)
  })
_sym_db.RegisterMessage(CdsDummy)


DESCRIPTOR._options = None
_CDSDUMMY._options = None

_CLUSTERDISCOVERYSERVICE = _descriptor.ServiceDescriptor(
  name='ClusterDiscoveryService',
  full_name='envoy.service.cluster.v3.ClusterDiscoveryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\212\244\226\363\007!\n\037envoy.config.cluster.v3.Cluster',
  create_key=_descriptor._internal_create_key,
  serialized_start=281,
  serialized_end=742,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamClusters',
    full_name='envoy.service.cluster.v3.ClusterDiscoveryService.StreamClusters',
    index=0,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeltaClusters',
    full_name='envoy.service.cluster.v3.ClusterDiscoveryService.DeltaClusters',
    index=1,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DELTADISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DELTADISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchClusters',
    full_name='envoy.service.cluster.v3.ClusterDiscoveryService.FetchClusters',
    index=2,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\"\026/v3/discovery:clusters\202\323\344\223\002\003:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CLUSTERDISCOVERYSERVICE)

DESCRIPTOR.services_by_name['ClusterDiscoveryService'] = _CLUSTERDISCOVERYSERVICE

# @@protoc_insertion_point(module_scope)
