# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/kill_request/v3/kill_request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/kill_request/v3/kill_request.proto',
  package='envoy.extensions.filters.http.kill_request.v3',
  syntax='proto3',
  serialized_options=b'\n;io.envoyproxy.envoy.extensions.filters.http.kill_request.v3B\020KillRequestProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n@envoy/extensions/filters/http/kill_request/v3/kill_request.proto\x12-envoy.extensions.filters.http.kill_request.v3\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"n\n\x0bKillRequest\x12\x35\n\x0bprobability\x18\x01 \x01(\x0b\x32 .envoy.type.v3.FractionalPercent\x12(\n\x13kill_request_header\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00\x42Y\n;io.envoyproxy.envoy.extensions.filters.http.kill_request.v3B\x10KillRequestProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_type_dot_v3_dot_percent__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_KILLREQUEST = _descriptor.Descriptor(
  name='KillRequest',
  full_name='envoy.extensions.filters.http.kill_request.v3.KillRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='probability', full_name='envoy.extensions.filters.http.kill_request.v3.KillRequest.probability', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kill_request_header', full_name='envoy.extensions.filters.http.kill_request.v3.KillRequest.kill_request_header', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010r\006\300\001\002\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=235,
  serialized_end=345,
)

_KILLREQUEST.fields_by_name['probability'].message_type = envoy_dot_type_dot_v3_dot_percent__pb2._FRACTIONALPERCENT
DESCRIPTOR.message_types_by_name['KillRequest'] = _KILLREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KillRequest = _reflection.GeneratedProtocolMessageType('KillRequest', (_message.Message,), {
  'DESCRIPTOR' : _KILLREQUEST,
  '__module__' : 'envoy.extensions.filters.http.kill_request.v3.kill_request_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.kill_request.v3.KillRequest)
  })
_sym_db.RegisterMessage(KillRequest)


DESCRIPTOR._options = None
_KILLREQUEST.fields_by_name['kill_request_header']._options = None
# @@protoc_insertion_point(module_scope)
