# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/ip_tagging/v2/ip_tagging.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/http/ip_tagging/v2/ip_tagging.proto',
  package='envoy.config.filter.http.ip_tagging.v2',
  syntax='proto3',
  serialized_options=b'\n4io.envoyproxy.envoy.config.filter.http.ip_tagging.v2B\016IpTaggingProtoP\001\362\230\376\217\005-\022+envoy.extensions.filters.http.ip_tagging.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7envoy/config/filter/http/ip_tagging/v2/ip_tagging.proto\x12&envoy.config.filter.http.ip_tagging.v2\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xc0\x02\n\tIPTagging\x12]\n\x0crequest_type\x18\x01 \x01(\x0e\x32=.envoy.config.filter.http.ip_tagging.v2.IPTagging.RequestTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12R\n\x07ip_tags\x18\x04 \x03(\x0b\x32\x37.envoy.config.filter.http.ip_tagging.v2.IPTagging.IPTagB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1aK\n\x05IPTag\x12\x13\n\x0bip_tag_name\x18\x01 \x01(\t\x12-\n\x07ip_list\x18\x02 \x03(\x0b\x32\x1c.envoy.api.v2.core.CidrRange\"3\n\x0bRequestType\x12\x08\n\x04\x42OTH\x10\x00\x12\x0c\n\x08INTERNAL\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\x42\x83\x01\n4io.envoyproxy.envoy.config.filter.http.ip_tagging.v2B\x0eIpTaggingProtoP\x01\xf2\x98\xfe\x8f\x05-\x12+envoy.extensions.filters.http.ip_tagging.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_address__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_IPTAGGING_REQUESTTYPE = _descriptor.EnumDescriptor(
  name='RequestType',
  full_name='envoy.config.filter.http.ip_tagging.v2.IPTagging.RequestType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BOTH', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXTERNAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=490,
  serialized_end=541,
)
_sym_db.RegisterEnumDescriptor(_IPTAGGING_REQUESTTYPE)


_IPTAGGING_IPTAG = _descriptor.Descriptor(
  name='IPTag',
  full_name='envoy.config.filter.http.ip_tagging.v2.IPTagging.IPTag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip_tag_name', full_name='envoy.config.filter.http.ip_tagging.v2.IPTagging.IPTag.ip_tag_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_list', full_name='envoy.config.filter.http.ip_tagging.v2.IPTagging.IPTag.ip_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=413,
  serialized_end=488,
)

_IPTAGGING = _descriptor.Descriptor(
  name='IPTagging',
  full_name='envoy.config.filter.http.ip_tagging.v2.IPTagging',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_type', full_name='envoy.config.filter.http.ip_tagging.v2.IPTagging.request_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_tags', full_name='envoy.config.filter.http.ip_tagging.v2.IPTagging.ip_tags', index=1,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_IPTAGGING_IPTAG, ],
  enum_types=[
    _IPTAGGING_REQUESTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=541,
)

_IPTAGGING_IPTAG.fields_by_name['ip_list'].message_type = envoy_dot_api_dot_v2_dot_core_dot_address__pb2._CIDRRANGE
_IPTAGGING_IPTAG.containing_type = _IPTAGGING
_IPTAGGING.fields_by_name['request_type'].enum_type = _IPTAGGING_REQUESTTYPE
_IPTAGGING.fields_by_name['ip_tags'].message_type = _IPTAGGING_IPTAG
_IPTAGGING_REQUESTTYPE.containing_type = _IPTAGGING
DESCRIPTOR.message_types_by_name['IPTagging'] = _IPTAGGING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IPTagging = _reflection.GeneratedProtocolMessageType('IPTagging', (_message.Message,), {

  'IPTag' : _reflection.GeneratedProtocolMessageType('IPTag', (_message.Message,), {
    'DESCRIPTOR' : _IPTAGGING_IPTAG,
    '__module__' : 'envoy.config.filter.http.ip_tagging.v2.ip_tagging_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.filter.http.ip_tagging.v2.IPTagging.IPTag)
    })
  ,
  'DESCRIPTOR' : _IPTAGGING,
  '__module__' : 'envoy.config.filter.http.ip_tagging.v2.ip_tagging_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.ip_tagging.v2.IPTagging)
  })
_sym_db.RegisterMessage(IPTagging)
_sym_db.RegisterMessage(IPTagging.IPTag)


DESCRIPTOR._options = None
_IPTAGGING.fields_by_name['request_type']._options = None
_IPTAGGING.fields_by_name['ip_tags']._options = None
# @@protoc_insertion_point(module_scope)
