# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/auth/v2alpha/external_auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.service.auth.v2 import external_auth_pb2 as envoy_dot_service_dot_auth_dot_v2_dot_external__auth__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/auth/v2alpha/external_auth.proto',
  package='envoy.service.auth.v2alpha',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.service.auth.v2alphaB\nCertsProtoP\001\210\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.envoy/service/auth/v2alpha/external_auth.proto\x12\x1a\x65nvoy.service.auth.v2alpha\x1a)envoy/service/auth/v2/external_auth.proto2c\n\rAuthorization\x12R\n\x05\x43heck\x12#.envoy.service.auth.v2.CheckRequest\x1a$.envoy.service.auth.v2.CheckResponseB;\n(io.envoyproxy.envoy.service.auth.v2alphaB\nCertsProtoP\x01\x88\x01\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_service_dot_auth_dot_v2_dot_external__auth__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_AUTHORIZATION = _descriptor.ServiceDescriptor(
  name='Authorization',
  full_name='envoy.service.auth.v2alpha.Authorization',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=121,
  serialized_end=220,
  methods=[
  _descriptor.MethodDescriptor(
    name='Check',
    full_name='envoy.service.auth.v2alpha.Authorization.Check',
    index=0,
    containing_service=None,
    input_type=envoy_dot_service_dot_auth_dot_v2_dot_external__auth__pb2._CHECKREQUEST,
    output_type=envoy_dot_service_dot_auth_dot_v2_dot_external__auth__pb2._CHECKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUTHORIZATION)

DESCRIPTOR.services_by_name['Authorization'] = _AUTHORIZATION

# @@protoc_insertion_point(module_scope)
