# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/router/v3/router.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.accesslog.v3 import accesslog_pb2 as envoy_dot_config_dot_accesslog_dot_v3_dot_accesslog__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/router/v3/router.proto',
  package='envoy.extensions.filters.http.router.v3',
  syntax='proto3',
  serialized_options=b'\n5io.envoyproxy.envoy.extensions.filters.http.router.v3B\013RouterProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4envoy/extensions/filters/http/router/v3/router.proto\x12\'envoy.extensions.filters.http.router.v3\x1a)envoy/config/accesslog/v3/accesslog.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xbe\x03\n\x06Router\x12\x31\n\rdynamic_stats\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x18\n\x10start_child_span\x18\x02 \x01(\x08\x12:\n\x0cupstream_log\x18\x03 \x03(\x0b\x32$.envoy.config.accesslog.v3.AccessLog\x12\x1e\n\x16suppress_envoy_headers\x18\x04 \x01(\x08\x12\xb3\x01\n\x14strict_check_headers\x18\x05 \x03(\tB\x94\x01\xfa\x42\x90\x01\x92\x01\x8c\x01\"\x89\x01r\x86\x01R\x1ex-envoy-upstream-rq-timeout-msR&x-envoy-upstream-rq-per-try-timeout-msR\x13x-envoy-max-retriesR\x15x-envoy-retry-grpc-onR\x10x-envoy-retry-on\x12#\n\x1brespect_expected_rq_timeout\x18\x06 \x01(\x08:0\x9a\xc5\x88\x1e+\n)envoy.config.filter.http.router.v2.RouterBN\n5io.envoyproxy.envoy.extensions.filters.http.router.v3B\x0bRouterProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_accesslog_dot_v3_dot_accesslog__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_ROUTER = _descriptor.Descriptor(
  name='Router',
  full_name='envoy.extensions.filters.http.router.v3.Router',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dynamic_stats', full_name='envoy.extensions.filters.http.router.v3.Router.dynamic_stats', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_child_span', full_name='envoy.extensions.filters.http.router.v3.Router.start_child_span', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_log', full_name='envoy.extensions.filters.http.router.v3.Router.upstream_log', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='suppress_envoy_headers', full_name='envoy.extensions.filters.http.router.v3.Router.suppress_envoy_headers', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strict_check_headers', full_name='envoy.extensions.filters.http.router.v3.Router.strict_check_headers', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\220\001\222\001\214\001\"\211\001r\206\001R\036x-envoy-upstream-rq-timeout-msR&x-envoy-upstream-rq-per-try-timeout-msR\023x-envoy-max-retriesR\025x-envoy-retry-grpc-onR\020x-envoy-retry-on', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='respect_expected_rq_timeout', full_name='envoy.extensions.filters.http.router.v3.Router.respect_expected_rq_timeout', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036+\n)envoy.config.filter.http.router.v2.Router',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=264,
  serialized_end=710,
)

_ROUTER.fields_by_name['dynamic_stats'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_ROUTER.fields_by_name['upstream_log'].message_type = envoy_dot_config_dot_accesslog_dot_v3_dot_accesslog__pb2._ACCESSLOG
DESCRIPTOR.message_types_by_name['Router'] = _ROUTER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Router = _reflection.GeneratedProtocolMessageType('Router', (_message.Message,), {
  'DESCRIPTOR' : _ROUTER,
  '__module__' : 'envoy.extensions.filters.http.router.v3.router_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.router.v3.Router)
  })
_sym_db.RegisterMessage(Router)


DESCRIPTOR._options = None
_ROUTER.fields_by_name['strict_check_headers']._options = None
_ROUTER._options = None
# @@protoc_insertion_point(module_scope)
