# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/retry/omit_host_metadata/v2/omit_host_metadata_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/retry/omit_host_metadata/v2/omit_host_metadata_config.proto',
  package='envoy.config.retry.omit_host_metadata.v2',
  syntax='proto3',
  serialized_options=b'\n6io.envoyproxy.envoy.config.retry.omit_host_metadata.v2B\033OmitHostMetadataConfigProtoP\001\362\230\376\217\0053\0221envoy.extensions.retry.host.omit_host_metadata.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nHenvoy/config/retry/omit_host_metadata/v2/omit_host_metadata_config.proto\x12(envoy.config.retry.omit_host_metadata.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"M\n\x16OmitHostMetadataConfig\x12\x33\n\x0emetadata_match\x18\x01 \x01(\x0b\x32\x1b.envoy.api.v2.core.MetadataB\x98\x01\n6io.envoyproxy.envoy.config.retry.omit_host_metadata.v2B\x1bOmitHostMetadataConfigProtoP\x01\xf2\x98\xfe\x8f\x05\x33\x12\x31\x65nvoy.extensions.retry.host.omit_host_metadata.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_OMITHOSTMETADATACONFIG = _descriptor.Descriptor(
  name='OmitHostMetadataConfig',
  full_name='envoy.config.retry.omit_host_metadata.v2.OmitHostMetadataConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata_match', full_name='envoy.config.retry.omit_host_metadata.v2.OmitHostMetadataConfig.metadata_match', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=211,
  serialized_end=288,
)

_OMITHOSTMETADATACONFIG.fields_by_name['metadata_match'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._METADATA
DESCRIPTOR.message_types_by_name['OmitHostMetadataConfig'] = _OMITHOSTMETADATACONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OmitHostMetadataConfig = _reflection.GeneratedProtocolMessageType('OmitHostMetadataConfig', (_message.Message,), {
  'DESCRIPTOR' : _OMITHOSTMETADATACONFIG,
  '__module__' : 'envoy.config.retry.omit_host_metadata.v2.omit_host_metadata_config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.retry.omit_host_metadata.v2.OmitHostMetadataConfig)
  })
_sym_db.RegisterMessage(OmitHostMetadataConfig)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
