# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/compressor/v2/compressor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/http/compressor/v2/compressor.proto',
  package='envoy.config.filter.http.compressor.v2',
  syntax='proto3',
  serialized_options=b'\n4io.envoyproxy.envoy.config.filter.http.compressor.v2B\017CompressorProtoP\001\362\230\376\217\005-\022+envoy.extensions.filters.http.compressor.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7envoy/config/filter/http/compressor/v2/compressor.proto\x12&envoy.config.filter.http.compressor.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\xdf\x01\n\nCompressor\x12\x34\n\x0e\x63ontent_length\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x14\n\x0c\x63ontent_type\x18\x02 \x03(\t\x12\x1e\n\x16\x64isable_on_etag_header\x18\x03 \x01(\x08\x12%\n\x1dremove_accept_encoding_header\x18\x04 \x01(\x08\x12>\n\x0fruntime_enabled\x18\x05 \x01(\x0b\x32%.envoy.api.v2.core.RuntimeFeatureFlagB\x84\x01\n4io.envoyproxy.envoy.config.filter.http.compressor.v2B\x0f\x43ompressorProtoP\x01\xf2\x98\xfe\x8f\x05-\x12+envoy.extensions.filters.http.compressor.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_COMPRESSOR = _descriptor.Descriptor(
  name='Compressor',
  full_name='envoy.config.filter.http.compressor.v2.Compressor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content_length', full_name='envoy.config.filter.http.compressor.v2.Compressor.content_length', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_type', full_name='envoy.config.filter.http.compressor.v2.Compressor.content_type', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_on_etag_header', full_name='envoy.config.filter.http.compressor.v2.Compressor.disable_on_etag_header', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remove_accept_encoding_header', full_name='envoy.config.filter.http.compressor.v2.Compressor.remove_accept_encoding_header', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime_enabled', full_name='envoy.config.filter.http.compressor.v2.Compressor.runtime_enabled', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=225,
  serialized_end=448,
)

_COMPRESSOR.fields_by_name['content_length'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_COMPRESSOR.fields_by_name['runtime_enabled'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._RUNTIMEFEATUREFLAG
DESCRIPTOR.message_types_by_name['Compressor'] = _COMPRESSOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Compressor = _reflection.GeneratedProtocolMessageType('Compressor', (_message.Message,), {
  'DESCRIPTOR' : _COMPRESSOR,
  '__module__' : 'envoy.config.filter.http.compressor.v2.compressor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.compressor.v2.Compressor)
  })
_sym_db.RegisterMessage(Compressor)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
