# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/discovery/v2/hds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import health_check_pb2 as envoy_dot_api_dot_v2_dot_core_dot_health__check__pb2
from envoy.api.v2.endpoint import endpoint_components_pb2 as envoy_dot_api_dot_v2_dot_endpoint_dot_endpoint__components__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/discovery/v2/hds.proto',
  package='envoy.service.discovery.v2',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.service.discovery.v2B\010HdsProtoP\001\210\001\001\362\230\376\217\005\031\022\027envoy.service.health.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$envoy/service/discovery/v2/hds.proto\x12\x1a\x65nvoy.service.discovery.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a$envoy/api/v2/core/health_check.proto\x1a/envoy/api/v2/endpoint/endpoint_components.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\x87\x01\n\nCapability\x12O\n\x16health_check_protocols\x18\x01 \x03(\x0e\x32/.envoy.service.discovery.v2.Capability.Protocol\"(\n\x08Protocol\x12\x08\n\x04HTTP\x10\x00\x12\x07\n\x03TCP\x10\x01\x12\t\n\x05REDIS\x10\x02\"w\n\x12HealthCheckRequest\x12%\n\x04node\x18\x01 \x01(\x0b\x32\x17.envoy.api.v2.core.Node\x12:\n\ncapability\x18\x02 \x01(\x0b\x32&.envoy.service.discovery.v2.Capability\"{\n\x0e\x45ndpointHealth\x12\x31\n\x08\x65ndpoint\x18\x01 \x01(\x0b\x32\x1f.envoy.api.v2.endpoint.Endpoint\x12\x36\n\rhealth_status\x18\x02 \x01(\x0e\x32\x1f.envoy.api.v2.core.HealthStatus\"^\n\x16\x45ndpointHealthResponse\x12\x44\n\x10\x65ndpoints_health\x18\x01 \x03(\x0b\x32*.envoy.service.discovery.v2.EndpointHealth\"\xe4\x01\n*HealthCheckRequestOrEndpointHealthResponse\x12N\n\x14health_check_request\x18\x01 \x01(\x0b\x32..envoy.service.discovery.v2.HealthCheckRequestH\x00\x12V\n\x18\x65ndpoint_health_response\x18\x02 \x01(\x0b\x32\x32.envoy.service.discovery.v2.EndpointHealthResponseH\x00\x42\x0e\n\x0crequest_type\"v\n\x11LocalityEndpoints\x12-\n\x08locality\x18\x01 \x01(\x0b\x32\x1b.envoy.api.v2.core.Locality\x12\x32\n\tendpoints\x18\x02 \x03(\x0b\x32\x1f.envoy.api.v2.endpoint.Endpoint\"\xac\x01\n\x12\x43lusterHealthCheck\x12\x14\n\x0c\x63luster_name\x18\x01 \x01(\t\x12\x35\n\rhealth_checks\x18\x02 \x03(\x0b\x32\x1e.envoy.api.v2.core.HealthCheck\x12I\n\x12locality_endpoints\x18\x03 \x03(\x0b\x32-.envoy.service.discovery.v2.LocalityEndpoints\"\x92\x01\n\x14HealthCheckSpecifier\x12M\n\x15\x63luster_health_checks\x18\x01 \x03(\x0b\x32..envoy.service.discovery.v2.ClusterHealthCheck\x12+\n\x08interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration2\xea\x02\n\x16HealthDiscoveryService\x12\x93\x01\n\x11StreamHealthCheck\x12\x46.envoy.service.discovery.v2.HealthCheckRequestOrEndpointHealthResponse\x1a\x30.envoy.service.discovery.v2.HealthCheckSpecifier\"\x00(\x01\x30\x01\x12\xb9\x01\n\x10\x46\x65tchHealthCheck\x12\x46.envoy.service.discovery.v2.HealthCheckRequestOrEndpointHealthResponse\x1a\x30.envoy.service.discovery.v2.HealthCheckSpecifier\"+\x82\xd3\xe4\x93\x02\x1c\"\x1a/v2/discovery:health_check\x82\xd3\xe4\x93\x02\x03:\x01*B`\n(io.envoyproxy.envoy.service.discovery.v2B\x08HdsProtoP\x01\x88\x01\x01\xf2\x98\xfe\x8f\x05\x19\x12\x17\x65nvoy.service.health.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_health__check__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_endpoint_dot_endpoint__components__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])



_CAPABILITY_PROTOCOL = _descriptor.EnumDescriptor(
  name='Protocol',
  full_name='envoy.service.discovery.v2.Capability.Protocol',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HTTP', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TCP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REDIS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=406,
  serialized_end=446,
)
_sym_db.RegisterEnumDescriptor(_CAPABILITY_PROTOCOL)


_CAPABILITY = _descriptor.Descriptor(
  name='Capability',
  full_name='envoy.service.discovery.v2.Capability',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='health_check_protocols', full_name='envoy.service.discovery.v2.Capability.health_check_protocols', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CAPABILITY_PROTOCOL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=311,
  serialized_end=446,
)


_HEALTHCHECKREQUEST = _descriptor.Descriptor(
  name='HealthCheckRequest',
  full_name='envoy.service.discovery.v2.HealthCheckRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='envoy.service.discovery.v2.HealthCheckRequest.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='capability', full_name='envoy.service.discovery.v2.HealthCheckRequest.capability', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=448,
  serialized_end=567,
)


_ENDPOINTHEALTH = _descriptor.Descriptor(
  name='EndpointHealth',
  full_name='envoy.service.discovery.v2.EndpointHealth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='envoy.service.discovery.v2.EndpointHealth.endpoint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health_status', full_name='envoy.service.discovery.v2.EndpointHealth.health_status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=569,
  serialized_end=692,
)


_ENDPOINTHEALTHRESPONSE = _descriptor.Descriptor(
  name='EndpointHealthResponse',
  full_name='envoy.service.discovery.v2.EndpointHealthResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoints_health', full_name='envoy.service.discovery.v2.EndpointHealthResponse.endpoints_health', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=694,
  serialized_end=788,
)


_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE = _descriptor.Descriptor(
  name='HealthCheckRequestOrEndpointHealthResponse',
  full_name='envoy.service.discovery.v2.HealthCheckRequestOrEndpointHealthResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='health_check_request', full_name='envoy.service.discovery.v2.HealthCheckRequestOrEndpointHealthResponse.health_check_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoint_health_response', full_name='envoy.service.discovery.v2.HealthCheckRequestOrEndpointHealthResponse.endpoint_health_response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='request_type', full_name='envoy.service.discovery.v2.HealthCheckRequestOrEndpointHealthResponse.request_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=791,
  serialized_end=1019,
)


_LOCALITYENDPOINTS = _descriptor.Descriptor(
  name='LocalityEndpoints',
  full_name='envoy.service.discovery.v2.LocalityEndpoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locality', full_name='envoy.service.discovery.v2.LocalityEndpoints.locality', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoints', full_name='envoy.service.discovery.v2.LocalityEndpoints.endpoints', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1021,
  serialized_end=1139,
)


_CLUSTERHEALTHCHECK = _descriptor.Descriptor(
  name='ClusterHealthCheck',
  full_name='envoy.service.discovery.v2.ClusterHealthCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_name', full_name='envoy.service.discovery.v2.ClusterHealthCheck.cluster_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health_checks', full_name='envoy.service.discovery.v2.ClusterHealthCheck.health_checks', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locality_endpoints', full_name='envoy.service.discovery.v2.ClusterHealthCheck.locality_endpoints', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1142,
  serialized_end=1314,
)


_HEALTHCHECKSPECIFIER = _descriptor.Descriptor(
  name='HealthCheckSpecifier',
  full_name='envoy.service.discovery.v2.HealthCheckSpecifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_health_checks', full_name='envoy.service.discovery.v2.HealthCheckSpecifier.cluster_health_checks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='envoy.service.discovery.v2.HealthCheckSpecifier.interval', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1317,
  serialized_end=1463,
)

_CAPABILITY.fields_by_name['health_check_protocols'].enum_type = _CAPABILITY_PROTOCOL
_CAPABILITY_PROTOCOL.containing_type = _CAPABILITY
_HEALTHCHECKREQUEST.fields_by_name['node'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._NODE
_HEALTHCHECKREQUEST.fields_by_name['capability'].message_type = _CAPABILITY
_ENDPOINTHEALTH.fields_by_name['endpoint'].message_type = envoy_dot_api_dot_v2_dot_endpoint_dot_endpoint__components__pb2._ENDPOINT
_ENDPOINTHEALTH.fields_by_name['health_status'].enum_type = envoy_dot_api_dot_v2_dot_core_dot_health__check__pb2._HEALTHSTATUS
_ENDPOINTHEALTHRESPONSE.fields_by_name['endpoints_health'].message_type = _ENDPOINTHEALTH
_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.fields_by_name['health_check_request'].message_type = _HEALTHCHECKREQUEST
_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.fields_by_name['endpoint_health_response'].message_type = _ENDPOINTHEALTHRESPONSE
_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.oneofs_by_name['request_type'].fields.append(
  _HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.fields_by_name['health_check_request'])
_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.fields_by_name['health_check_request'].containing_oneof = _HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.oneofs_by_name['request_type']
_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.oneofs_by_name['request_type'].fields.append(
  _HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.fields_by_name['endpoint_health_response'])
_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.fields_by_name['endpoint_health_response'].containing_oneof = _HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.oneofs_by_name['request_type']
_LOCALITYENDPOINTS.fields_by_name['locality'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._LOCALITY
_LOCALITYENDPOINTS.fields_by_name['endpoints'].message_type = envoy_dot_api_dot_v2_dot_endpoint_dot_endpoint__components__pb2._ENDPOINT
_CLUSTERHEALTHCHECK.fields_by_name['health_checks'].message_type = envoy_dot_api_dot_v2_dot_core_dot_health__check__pb2._HEALTHCHECK
_CLUSTERHEALTHCHECK.fields_by_name['locality_endpoints'].message_type = _LOCALITYENDPOINTS
_HEALTHCHECKSPECIFIER.fields_by_name['cluster_health_checks'].message_type = _CLUSTERHEALTHCHECK
_HEALTHCHECKSPECIFIER.fields_by_name['interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['Capability'] = _CAPABILITY
DESCRIPTOR.message_types_by_name['HealthCheckRequest'] = _HEALTHCHECKREQUEST
DESCRIPTOR.message_types_by_name['EndpointHealth'] = _ENDPOINTHEALTH
DESCRIPTOR.message_types_by_name['EndpointHealthResponse'] = _ENDPOINTHEALTHRESPONSE
DESCRIPTOR.message_types_by_name['HealthCheckRequestOrEndpointHealthResponse'] = _HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE
DESCRIPTOR.message_types_by_name['LocalityEndpoints'] = _LOCALITYENDPOINTS
DESCRIPTOR.message_types_by_name['ClusterHealthCheck'] = _CLUSTERHEALTHCHECK
DESCRIPTOR.message_types_by_name['HealthCheckSpecifier'] = _HEALTHCHECKSPECIFIER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Capability = _reflection.GeneratedProtocolMessageType('Capability', (_message.Message,), {
  'DESCRIPTOR' : _CAPABILITY,
  '__module__' : 'envoy.service.discovery.v2.hds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v2.Capability)
  })
_sym_db.RegisterMessage(Capability)

HealthCheckRequest = _reflection.GeneratedProtocolMessageType('HealthCheckRequest', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECKREQUEST,
  '__module__' : 'envoy.service.discovery.v2.hds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v2.HealthCheckRequest)
  })
_sym_db.RegisterMessage(HealthCheckRequest)

EndpointHealth = _reflection.GeneratedProtocolMessageType('EndpointHealth', (_message.Message,), {
  'DESCRIPTOR' : _ENDPOINTHEALTH,
  '__module__' : 'envoy.service.discovery.v2.hds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v2.EndpointHealth)
  })
_sym_db.RegisterMessage(EndpointHealth)

EndpointHealthResponse = _reflection.GeneratedProtocolMessageType('EndpointHealthResponse', (_message.Message,), {
  'DESCRIPTOR' : _ENDPOINTHEALTHRESPONSE,
  '__module__' : 'envoy.service.discovery.v2.hds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v2.EndpointHealthResponse)
  })
_sym_db.RegisterMessage(EndpointHealthResponse)

HealthCheckRequestOrEndpointHealthResponse = _reflection.GeneratedProtocolMessageType('HealthCheckRequestOrEndpointHealthResponse', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE,
  '__module__' : 'envoy.service.discovery.v2.hds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v2.HealthCheckRequestOrEndpointHealthResponse)
  })
_sym_db.RegisterMessage(HealthCheckRequestOrEndpointHealthResponse)

LocalityEndpoints = _reflection.GeneratedProtocolMessageType('LocalityEndpoints', (_message.Message,), {
  'DESCRIPTOR' : _LOCALITYENDPOINTS,
  '__module__' : 'envoy.service.discovery.v2.hds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v2.LocalityEndpoints)
  })
_sym_db.RegisterMessage(LocalityEndpoints)

ClusterHealthCheck = _reflection.GeneratedProtocolMessageType('ClusterHealthCheck', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERHEALTHCHECK,
  '__module__' : 'envoy.service.discovery.v2.hds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v2.ClusterHealthCheck)
  })
_sym_db.RegisterMessage(ClusterHealthCheck)

HealthCheckSpecifier = _reflection.GeneratedProtocolMessageType('HealthCheckSpecifier', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECKSPECIFIER,
  '__module__' : 'envoy.service.discovery.v2.hds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v2.HealthCheckSpecifier)
  })
_sym_db.RegisterMessage(HealthCheckSpecifier)


DESCRIPTOR._options = None

_HEALTHDISCOVERYSERVICE = _descriptor.ServiceDescriptor(
  name='HealthDiscoveryService',
  full_name='envoy.service.discovery.v2.HealthDiscoveryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1466,
  serialized_end=1828,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamHealthCheck',
    full_name='envoy.service.discovery.v2.HealthDiscoveryService.StreamHealthCheck',
    index=0,
    containing_service=None,
    input_type=_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE,
    output_type=_HEALTHCHECKSPECIFIER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchHealthCheck',
    full_name='envoy.service.discovery.v2.HealthDiscoveryService.FetchHealthCheck',
    index=1,
    containing_service=None,
    input_type=_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE,
    output_type=_HEALTHCHECKSPECIFIER,
    serialized_options=b'\202\323\344\223\002\034\"\032/v2/discovery:health_check\202\323\344\223\002\003:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_HEALTHDISCOVERYSERVICE)

DESCRIPTOR.services_by_name['HealthDiscoveryService'] = _HEALTHDISCOVERYSERVICE

# @@protoc_insertion_point(module_scope)
