# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/route/v3/srds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.service.discovery.v3 import discovery_pb2 as envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/route/v3/srds.proto',
  package='envoy.service.route.v3',
  syntax='proto3',
  serialized_options=b'\n$io.envoyproxy.envoy.service.route.v3B\tSrdsProtoP\001\210\001\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!envoy/service/route/v3/srds.proto\x12\x16\x65nvoy.service.route.v3\x1a*envoy/service/discovery/v3/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a envoy/annotations/resource.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"*\n\tSrdsDummy:\x1d\x9a\xc5\x88\x1e\x18\n\x16\x65nvoy.api.v2.SrdsDummy2\xf3\x03\n\x1cScopedRoutesDiscoveryService\x12w\n\x12StreamScopedRoutes\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"\x00(\x01\x30\x01\x12\x80\x01\n\x11\x44\x65ltaScopedRoutes\x12\x31.envoy.service.discovery.v3.DeltaDiscoveryRequest\x1a\x32.envoy.service.discovery.v3.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12\x9e\x01\n\x11\x46\x65tchScopedRoutes\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\",\x82\xd3\xe4\x93\x02\x1d\"\x1b/v3/discovery:scoped-routes\x82\xd3\xe4\x93\x02\x03:\x01*\x1a\x36\x8a\xa4\x96\xf3\x07\x30\n.envoy.config.route.v3.ScopedRouteConfigurationB>\n$io.envoyproxy.envoy.service.route.v3B\tSrdsProtoP\x01\x88\x01\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,envoy_dot_annotations_dot_resource__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_SRDSDUMMY = _descriptor.Descriptor(
  name='SrdsDummy',
  full_name='envoy.service.route.v3.SrdsDummy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\030\n\026envoy.api.v2.SrdsDummy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=235,
  serialized_end=277,
)

DESCRIPTOR.message_types_by_name['SrdsDummy'] = _SRDSDUMMY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SrdsDummy = _reflection.GeneratedProtocolMessageType('SrdsDummy', (_message.Message,), {
  'DESCRIPTOR' : _SRDSDUMMY,
  '__module__' : 'envoy.service.route.v3.srds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.route.v3.SrdsDummy)
  })
_sym_db.RegisterMessage(SrdsDummy)


DESCRIPTOR._options = None
_SRDSDUMMY._options = None

_SCOPEDROUTESDISCOVERYSERVICE = _descriptor.ServiceDescriptor(
  name='ScopedRoutesDiscoveryService',
  full_name='envoy.service.route.v3.ScopedRoutesDiscoveryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\212\244\226\363\0070\n.envoy.config.route.v3.ScopedRouteConfiguration',
  create_key=_descriptor._internal_create_key,
  serialized_start=280,
  serialized_end=779,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamScopedRoutes',
    full_name='envoy.service.route.v3.ScopedRoutesDiscoveryService.StreamScopedRoutes',
    index=0,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeltaScopedRoutes',
    full_name='envoy.service.route.v3.ScopedRoutesDiscoveryService.DeltaScopedRoutes',
    index=1,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DELTADISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DELTADISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchScopedRoutes',
    full_name='envoy.service.route.v3.ScopedRoutesDiscoveryService.FetchScopedRoutes',
    index=2,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=b'\202\323\344\223\002\035\"\033/v3/discovery:scoped-routes\202\323\344\223\002\003:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SCOPEDROUTESDISCOVERYSERVICE)

DESCRIPTOR.services_by_name['ScopedRoutesDiscoveryService'] = _SCOPEDROUTESDISCOVERYSERVICE

# @@protoc_insertion_point(module_scope)
