# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/fault/v3/fault.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from envoy.extensions.filters.common.fault.v3 import fault_pb2 as envoy_dot_extensions_dot_filters_dot_common_dot_fault_dot_v3_dot_fault__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/fault/v3/fault.proto',
  package='envoy.extensions.filters.http.fault.v3',
  syntax='proto3',
  serialized_options=b'\n4io.envoyproxy.envoy.extensions.filters.http.fault.v3B\nFaultProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2envoy/extensions/filters/http/fault/v3/fault.proto\x12&envoy.extensions.filters.http.fault.v3\x1a,envoy/config/route/v3/route_components.proto\x1a\x34\x65nvoy/extensions/filters/common/fault/v3/fault.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xf3\x02\n\nFaultAbort\x12\"\n\x0bhttp_status\x18\x02 \x01(\rB\x0b\xfa\x42\x08*\x06\x10\xd8\x04(\xc8\x01H\x00\x12\x15\n\x0bgrpc_status\x18\x05 \x01(\rH\x00\x12V\n\x0cheader_abort\x18\x04 \x01(\x0b\x32>.envoy.extensions.filters.http.fault.v3.FaultAbort.HeaderAbortH\x00\x12\x34\n\npercentage\x18\x03 \x01(\x0b\x32 .envoy.type.v3.FractionalPercent\x1aN\n\x0bHeaderAbort:?\x9a\xc5\x88\x1e:\n8envoy.config.filter.http.fault.v2.FaultAbort.HeaderAbort:3\x9a\xc5\x88\x1e.\n,envoy.config.filter.http.fault.v2.FaultAbortB\x11\n\nerror_type\x12\x03\xf8\x42\x01J\x04\x08\x01\x10\x02\"\xb6\x05\n\tHTTPFault\x12\x43\n\x05\x64\x65lay\x18\x01 \x01(\x0b\x32\x34.envoy.extensions.filters.common.fault.v3.FaultDelay\x12\x41\n\x05\x61\x62ort\x18\x02 \x01(\x0b\x32\x32.envoy.extensions.filters.http.fault.v3.FaultAbort\x12\x18\n\x10upstream_cluster\x18\x03 \x01(\t\x12\x35\n\x07headers\x18\x04 \x03(\x0b\x32$.envoy.config.route.v3.HeaderMatcher\x12\x18\n\x10\x64ownstream_nodes\x18\x05 \x03(\t\x12\x37\n\x11max_active_faults\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12U\n\x13response_rate_limit\x18\x07 \x01(\x0b\x32\x38.envoy.extensions.filters.common.fault.v3.FaultRateLimit\x12\x1d\n\x15\x64\x65lay_percent_runtime\x18\x08 \x01(\t\x12\x1d\n\x15\x61\x62ort_percent_runtime\x18\t \x01(\t\x12\x1e\n\x16\x64\x65lay_duration_runtime\x18\n \x01(\t\x12!\n\x19\x61\x62ort_http_status_runtime\x18\x0b \x01(\t\x12!\n\x19max_active_faults_runtime\x18\x0c \x01(\t\x12+\n#response_rate_limit_percent_runtime\x18\r \x01(\t\x12!\n\x19\x61\x62ort_grpc_status_runtime\x18\x0e \x01(\t:2\x9a\xc5\x88\x1e-\n+envoy.config.filter.http.fault.v2.HTTPFaultBL\n4io.envoyproxy.envoy.extensions.filters.http.fault.v3B\nFaultProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2.DESCRIPTOR,envoy_dot_extensions_dot_filters_dot_common_dot_fault_dot_v3_dot_fault__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_percent__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_FAULTABORT_HEADERABORT = _descriptor.Descriptor(
  name='HeaderAbort',
  full_name='envoy.extensions.filters.http.fault.v3.FaultAbort.HeaderAbort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036:\n8envoy.config.filter.http.fault.v2.FaultAbort.HeaderAbort',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=562,
  serialized_end=640,
)

_FAULTABORT = _descriptor.Descriptor(
  name='FaultAbort',
  full_name='envoy.extensions.filters.http.fault.v3.FaultAbort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_status', full_name='envoy.extensions.filters.http.fault.v3.FaultAbort.http_status', index=0,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010*\006\020\330\004(\310\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc_status', full_name='envoy.extensions.filters.http.fault.v3.FaultAbort.grpc_status', index=1,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header_abort', full_name='envoy.extensions.filters.http.fault.v3.FaultAbort.header_abort', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percentage', full_name='envoy.extensions.filters.http.fault.v3.FaultAbort.percentage', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FAULTABORT_HEADERABORT, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036.\n,envoy.config.filter.http.fault.v2.FaultAbort',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='error_type', full_name='envoy.extensions.filters.http.fault.v3.FaultAbort.error_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=347,
  serialized_end=718,
)


_HTTPFAULT = _descriptor.Descriptor(
  name='HTTPFault',
  full_name='envoy.extensions.filters.http.fault.v3.HTTPFault',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='delay', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.delay', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='abort', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.abort', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_cluster', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.upstream_cluster', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.headers', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='downstream_nodes', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.downstream_nodes', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_active_faults', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.max_active_faults', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_rate_limit', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.response_rate_limit', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delay_percent_runtime', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.delay_percent_runtime', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='abort_percent_runtime', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.abort_percent_runtime', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delay_duration_runtime', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.delay_duration_runtime', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='abort_http_status_runtime', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.abort_http_status_runtime', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_active_faults_runtime', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.max_active_faults_runtime', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_rate_limit_percent_runtime', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.response_rate_limit_percent_runtime', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='abort_grpc_status_runtime', full_name='envoy.extensions.filters.http.fault.v3.HTTPFault.abort_grpc_status_runtime', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036-\n+envoy.config.filter.http.fault.v2.HTTPFault',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=721,
  serialized_end=1415,
)

_FAULTABORT_HEADERABORT.containing_type = _FAULTABORT
_FAULTABORT.fields_by_name['header_abort'].message_type = _FAULTABORT_HEADERABORT
_FAULTABORT.fields_by_name['percentage'].message_type = envoy_dot_type_dot_v3_dot_percent__pb2._FRACTIONALPERCENT
_FAULTABORT.oneofs_by_name['error_type'].fields.append(
  _FAULTABORT.fields_by_name['http_status'])
_FAULTABORT.fields_by_name['http_status'].containing_oneof = _FAULTABORT.oneofs_by_name['error_type']
_FAULTABORT.oneofs_by_name['error_type'].fields.append(
  _FAULTABORT.fields_by_name['grpc_status'])
_FAULTABORT.fields_by_name['grpc_status'].containing_oneof = _FAULTABORT.oneofs_by_name['error_type']
_FAULTABORT.oneofs_by_name['error_type'].fields.append(
  _FAULTABORT.fields_by_name['header_abort'])
_FAULTABORT.fields_by_name['header_abort'].containing_oneof = _FAULTABORT.oneofs_by_name['error_type']
_HTTPFAULT.fields_by_name['delay'].message_type = envoy_dot_extensions_dot_filters_dot_common_dot_fault_dot_v3_dot_fault__pb2._FAULTDELAY
_HTTPFAULT.fields_by_name['abort'].message_type = _FAULTABORT
_HTTPFAULT.fields_by_name['headers'].message_type = envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2._HEADERMATCHER
_HTTPFAULT.fields_by_name['max_active_faults'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTPFAULT.fields_by_name['response_rate_limit'].message_type = envoy_dot_extensions_dot_filters_dot_common_dot_fault_dot_v3_dot_fault__pb2._FAULTRATELIMIT
DESCRIPTOR.message_types_by_name['FaultAbort'] = _FAULTABORT
DESCRIPTOR.message_types_by_name['HTTPFault'] = _HTTPFAULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FaultAbort = _reflection.GeneratedProtocolMessageType('FaultAbort', (_message.Message,), {

  'HeaderAbort' : _reflection.GeneratedProtocolMessageType('HeaderAbort', (_message.Message,), {
    'DESCRIPTOR' : _FAULTABORT_HEADERABORT,
    '__module__' : 'envoy.extensions.filters.http.fault.v3.fault_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.fault.v3.FaultAbort.HeaderAbort)
    })
  ,
  'DESCRIPTOR' : _FAULTABORT,
  '__module__' : 'envoy.extensions.filters.http.fault.v3.fault_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.fault.v3.FaultAbort)
  })
_sym_db.RegisterMessage(FaultAbort)
_sym_db.RegisterMessage(FaultAbort.HeaderAbort)

HTTPFault = _reflection.GeneratedProtocolMessageType('HTTPFault', (_message.Message,), {
  'DESCRIPTOR' : _HTTPFAULT,
  '__module__' : 'envoy.extensions.filters.http.fault.v3.fault_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.fault.v3.HTTPFault)
  })
_sym_db.RegisterMessage(HTTPFault)


DESCRIPTOR._options = None
_FAULTABORT_HEADERABORT._options = None
_FAULTABORT.oneofs_by_name['error_type']._options = None
_FAULTABORT.fields_by_name['http_status']._options = None
_FAULTABORT._options = None
_HTTPFAULT._options = None
# @@protoc_insertion_point(module_scope)
