# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v2alpha/listeners.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/admin/v2alpha/listeners.proto',
  package='envoy.admin.v2alpha',
  syntax='proto3',
  serialized_options=b'\n!io.envoyproxy.envoy.admin.v2alphaB\016ListenersProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#envoy/admin/v2alpha/listeners.proto\x12\x13\x65nvoy.admin.v2alpha\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1dudpa/annotations/status.proto\"K\n\tListeners\x12>\n\x11listener_statuses\x18\x01 \x03(\x0b\x32#.envoy.admin.v2alpha.ListenerStatus\"Q\n\x0eListenerStatus\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x31\n\rlocal_address\x18\x02 \x01(\x0b\x32\x1a.envoy.api.v2.core.AddressB=\n!io.envoyproxy.envoy.admin.v2alphaB\x0eListenersProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_address__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_LISTENERS = _descriptor.Descriptor(
  name='Listeners',
  full_name='envoy.admin.v2alpha.Listeners',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='listener_statuses', full_name='envoy.admin.v2alpha.Listeners.listener_statuses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=199,
)


_LISTENERSTATUS = _descriptor.Descriptor(
  name='ListenerStatus',
  full_name='envoy.admin.v2alpha.ListenerStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.admin.v2alpha.ListenerStatus.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_address', full_name='envoy.admin.v2alpha.ListenerStatus.local_address', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=201,
  serialized_end=282,
)

_LISTENERS.fields_by_name['listener_statuses'].message_type = _LISTENERSTATUS
_LISTENERSTATUS.fields_by_name['local_address'].message_type = envoy_dot_api_dot_v2_dot_core_dot_address__pb2._ADDRESS
DESCRIPTOR.message_types_by_name['Listeners'] = _LISTENERS
DESCRIPTOR.message_types_by_name['ListenerStatus'] = _LISTENERSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Listeners = _reflection.GeneratedProtocolMessageType('Listeners', (_message.Message,), {
  'DESCRIPTOR' : _LISTENERS,
  '__module__' : 'envoy.admin.v2alpha.listeners_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.Listeners)
  })
_sym_db.RegisterMessage(Listeners)

ListenerStatus = _reflection.GeneratedProtocolMessageType('ListenerStatus', (_message.Message,), {
  'DESCRIPTOR' : _LISTENERSTATUS,
  '__module__' : 'envoy.admin.v2alpha.listeners_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.ListenerStatus)
  })
_sym_db.RegisterMessage(ListenerStatus)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
