# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/csrf/v2/csrf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.type.matcher import string_pb2 as envoy_dot_type_dot_matcher_dot_string__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/http/csrf/v2/csrf.proto',
  package='envoy.config.filter.http.csrf.v2',
  syntax='proto3',
  serialized_options=b'\n.io.envoyproxy.envoy.config.filter.http.csrf.v2B\tCsrfProtoP\001\362\230\376\217\005\'\022%envoy.extensions.filters.http.csrf.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+envoy/config/filter/http/csrf/v2/csrf.proto\x12 envoy.config.filter.http.csrf.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x1f\x65nvoy/type/matcher/string.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xdf\x01\n\nCsrfPolicy\x12M\n\x0e\x66ilter_enabled\x18\x01 \x01(\x0b\x32+.envoy.api.v2.core.RuntimeFractionalPercentB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x43\n\x0eshadow_enabled\x18\x02 \x01(\x0b\x32+.envoy.api.v2.core.RuntimeFractionalPercent\x12=\n\x12\x61\x64\x64itional_origins\x18\x03 \x03(\x0b\x32!.envoy.type.matcher.StringMatcherBr\n.io.envoyproxy.envoy.config.filter.http.csrf.v2B\tCsrfProtoP\x01\xf2\x98\xfe\x8f\x05\'\x12%envoy.extensions.filters.http.csrf.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_string__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_CSRFPOLICY = _descriptor.Descriptor(
  name='CsrfPolicy',
  full_name='envoy.config.filter.http.csrf.v2.CsrfPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter_enabled', full_name='envoy.config.filter.http.csrf.v2.CsrfPolicy.filter_enabled', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shadow_enabled', full_name='envoy.config.filter.http.csrf.v2.CsrfPolicy.shadow_enabled', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='additional_origins', full_name='envoy.config.filter.http.csrf.v2.CsrfPolicy.additional_origins', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=456,
)

_CSRFPOLICY.fields_by_name['filter_enabled'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._RUNTIMEFRACTIONALPERCENT
_CSRFPOLICY.fields_by_name['shadow_enabled'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._RUNTIMEFRACTIONALPERCENT
_CSRFPOLICY.fields_by_name['additional_origins'].message_type = envoy_dot_type_dot_matcher_dot_string__pb2._STRINGMATCHER
DESCRIPTOR.message_types_by_name['CsrfPolicy'] = _CSRFPOLICY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CsrfPolicy = _reflection.GeneratedProtocolMessageType('CsrfPolicy', (_message.Message,), {
  'DESCRIPTOR' : _CSRFPOLICY,
  '__module__' : 'envoy.config.filter.http.csrf.v2.csrf_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.csrf.v2.CsrfPolicy)
  })
_sym_db.RegisterMessage(CsrfPolicy)


DESCRIPTOR._options = None
_CSRFPOLICY.fields_by_name['filter_enabled']._options = None
# @@protoc_insertion_point(module_scope)
