# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/aws_lambda/v2alpha/aws_lambda.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/http/aws_lambda/v2alpha/aws_lambda.proto',
  package='envoy.config.filter.http.aws_lambda.v2alpha',
  syntax='proto3',
  serialized_options=b'\n9io.envoyproxy.envoy.config.filter.http.aws_lambda.v2alphaB\016AwsLambdaProtoP\001\362\230\376\217\005-\022+envoy.extensions.filters.http.aws_lambda.v3\272\200\310\321\006\002\010\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n<envoy/config/filter/http/aws_lambda/v2alpha/aws_lambda.proto\x12+envoy.config.filter.http.aws_lambda.v2alpha\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xd7\x01\n\x06\x43onfig\x12\x14\n\x03\x61rn\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1b\n\x13payload_passthrough\x18\x02 \x01(\x08\x12\x65\n\x0finvocation_mode\x18\x03 \x01(\x0e\x32\x42.envoy.config.filter.http.aws_lambda.v2alpha.Config.InvocationModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"3\n\x0eInvocationMode\x12\x0f\n\x0bSYNCHRONOUS\x10\x00\x12\x10\n\x0c\x41SYNCHRONOUS\x10\x01\"\\\n\x0ePerRouteConfig\x12J\n\rinvoke_config\x18\x01 \x01(\x0b\x32\x33.envoy.config.filter.http.aws_lambda.v2alpha.ConfigB\x90\x01\n9io.envoyproxy.envoy.config.filter.http.aws_lambda.v2alphaB\x0e\x41wsLambdaProtoP\x01\xf2\x98\xfe\x8f\x05-\x12+envoy.extensions.filters.http.aws_lambda.v3\xba\x80\xc8\xd1\x06\x02\x08\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_CONFIG_INVOCATIONMODE = _descriptor.EnumDescriptor(
  name='InvocationMode',
  full_name='envoy.config.filter.http.aws_lambda.v2alpha.Config.InvocationMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SYNCHRONOUS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ASYNCHRONOUS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=362,
  serialized_end=413,
)
_sym_db.RegisterEnumDescriptor(_CONFIG_INVOCATIONMODE)


_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='envoy.config.filter.http.aws_lambda.v2alpha.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='arn', full_name='envoy.config.filter.http.aws_lambda.v2alpha.Config.arn', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload_passthrough', full_name='envoy.config.filter.http.aws_lambda.v2alpha.Config.payload_passthrough', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invocation_mode', full_name='envoy.config.filter.http.aws_lambda.v2alpha.Config.invocation_mode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONFIG_INVOCATIONMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=198,
  serialized_end=413,
)


_PERROUTECONFIG = _descriptor.Descriptor(
  name='PerRouteConfig',
  full_name='envoy.config.filter.http.aws_lambda.v2alpha.PerRouteConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='invoke_config', full_name='envoy.config.filter.http.aws_lambda.v2alpha.PerRouteConfig.invoke_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=415,
  serialized_end=507,
)

_CONFIG.fields_by_name['invocation_mode'].enum_type = _CONFIG_INVOCATIONMODE
_CONFIG_INVOCATIONMODE.containing_type = _CONFIG
_PERROUTECONFIG.fields_by_name['invoke_config'].message_type = _CONFIG
DESCRIPTOR.message_types_by_name['Config'] = _CONFIG
DESCRIPTOR.message_types_by_name['PerRouteConfig'] = _PERROUTECONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Config = _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
  'DESCRIPTOR' : _CONFIG,
  '__module__' : 'envoy.config.filter.http.aws_lambda.v2alpha.aws_lambda_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.aws_lambda.v2alpha.Config)
  })
_sym_db.RegisterMessage(Config)

PerRouteConfig = _reflection.GeneratedProtocolMessageType('PerRouteConfig', (_message.Message,), {
  'DESCRIPTOR' : _PERROUTECONFIG,
  '__module__' : 'envoy.config.filter.http.aws_lambda.v2alpha.aws_lambda_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.aws_lambda.v2alpha.PerRouteConfig)
  })
_sym_db.RegisterMessage(PerRouteConfig)


DESCRIPTOR._options = None
_CONFIG.fields_by_name['arn']._options = None
_CONFIG.fields_by_name['invocation_mode']._options = None
# @@protoc_insertion_point(module_scope)
