# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/trace/v2/trace_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from opencensus.proto.trace.v1 import trace_pb2 as opencensus_dot_proto_dot_trace_dot_v1_dot_trace__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/trace/v2/trace_service.proto',
  package='envoy.service.trace.v2',
  syntax='proto3',
  serialized_options=b'\n$io.envoyproxy.envoy.service.trace.v2B\021TraceServiceProtoP\001\210\001\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*envoy/service/trace/v2/trace_service.proto\x12\x16\x65nvoy.service.trace.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a%opencensus/proto/trace/v1/trace.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x16\n\x14StreamTracesResponse\"\xd0\x01\n\x13StreamTracesMessage\x12J\n\nidentifier\x18\x01 \x01(\x0b\x32\x36.envoy.service.trace.v2.StreamTracesMessage.Identifier\x12.\n\x05spans\x18\x02 \x03(\x0b\x32\x1f.opencensus.proto.trace.v1.Span\x1a=\n\nIdentifier\x12/\n\x04node\x18\x01 \x01(\x0b\x32\x17.envoy.api.v2.core.NodeB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x32}\n\x0cTraceService\x12m\n\x0cStreamTraces\x12+.envoy.service.trace.v2.StreamTracesMessage\x1a,.envoy.service.trace.v2.StreamTracesResponse\"\x00(\x01\x42\x46\n$io.envoyproxy.envoy.service.trace.v2B\x11TraceServiceProtoP\x01\x88\x01\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,opencensus_dot_proto_dot_trace_dot_v1_dot_trace__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_STREAMTRACESRESPONSE = _descriptor.Descriptor(
  name='StreamTracesResponse',
  full_name='envoy.service.trace.v2.StreamTracesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=195,
  serialized_end=217,
)


_STREAMTRACESMESSAGE_IDENTIFIER = _descriptor.Descriptor(
  name='Identifier',
  full_name='envoy.service.trace.v2.StreamTracesMessage.Identifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='envoy.service.trace.v2.StreamTracesMessage.Identifier.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=367,
  serialized_end=428,
)

_STREAMTRACESMESSAGE = _descriptor.Descriptor(
  name='StreamTracesMessage',
  full_name='envoy.service.trace.v2.StreamTracesMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='envoy.service.trace.v2.StreamTracesMessage.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spans', full_name='envoy.service.trace.v2.StreamTracesMessage.spans', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STREAMTRACESMESSAGE_IDENTIFIER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=220,
  serialized_end=428,
)

_STREAMTRACESMESSAGE_IDENTIFIER.fields_by_name['node'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._NODE
_STREAMTRACESMESSAGE_IDENTIFIER.containing_type = _STREAMTRACESMESSAGE
_STREAMTRACESMESSAGE.fields_by_name['identifier'].message_type = _STREAMTRACESMESSAGE_IDENTIFIER
_STREAMTRACESMESSAGE.fields_by_name['spans'].message_type = opencensus_dot_proto_dot_trace_dot_v1_dot_trace__pb2._SPAN
DESCRIPTOR.message_types_by_name['StreamTracesResponse'] = _STREAMTRACESRESPONSE
DESCRIPTOR.message_types_by_name['StreamTracesMessage'] = _STREAMTRACESMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamTracesResponse = _reflection.GeneratedProtocolMessageType('StreamTracesResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMTRACESRESPONSE,
  '__module__' : 'envoy.service.trace.v2.trace_service_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.trace.v2.StreamTracesResponse)
  })
_sym_db.RegisterMessage(StreamTracesResponse)

StreamTracesMessage = _reflection.GeneratedProtocolMessageType('StreamTracesMessage', (_message.Message,), {

  'Identifier' : _reflection.GeneratedProtocolMessageType('Identifier', (_message.Message,), {
    'DESCRIPTOR' : _STREAMTRACESMESSAGE_IDENTIFIER,
    '__module__' : 'envoy.service.trace.v2.trace_service_pb2'
    # @@protoc_insertion_point(class_scope:envoy.service.trace.v2.StreamTracesMessage.Identifier)
    })
  ,
  'DESCRIPTOR' : _STREAMTRACESMESSAGE,
  '__module__' : 'envoy.service.trace.v2.trace_service_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.trace.v2.StreamTracesMessage)
  })
_sym_db.RegisterMessage(StreamTracesMessage)
_sym_db.RegisterMessage(StreamTracesMessage.Identifier)


DESCRIPTOR._options = None
_STREAMTRACESMESSAGE_IDENTIFIER.fields_by_name['node']._options = None

_TRACESERVICE = _descriptor.ServiceDescriptor(
  name='TraceService',
  full_name='envoy.service.trace.v2.TraceService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=430,
  serialized_end=555,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamTraces',
    full_name='envoy.service.trace.v2.TraceService.StreamTraces',
    index=0,
    containing_service=None,
    input_type=_STREAMTRACESMESSAGE,
    output_type=_STREAMTRACESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TRACESERVICE)

DESCRIPTOR.services_by_name['TraceService'] = _TRACESERVICE

# @@protoc_insertion_point(module_scope)
