# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/tap/v2alpha/tap.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.data.tap.v2alpha import wrapper_pb2 as envoy_dot_data_dot_tap_dot_v2alpha_dot_wrapper__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/tap/v2alpha/tap.proto',
  package='envoy.service.tap.v2alpha',
  syntax='proto3',
  serialized_options=b'\n\'io.envoyproxy.envoy.service.tap.v2alphaB\010TapProtoP\001\210\001\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#envoy/service/tap/v2alpha/tap.proto\x12\x19\x65nvoy.service.tap.v2alpha\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a$envoy/data/tap/v2alpha/wrapper.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xf6\x01\n\x11StreamTapsRequest\x12K\n\nidentifier\x18\x01 \x01(\x0b\x32\x37.envoy.service.tap.v2alpha.StreamTapsRequest.Identifier\x12\x10\n\x08trace_id\x18\x02 \x01(\x04\x12\x33\n\x05trace\x18\x03 \x01(\x0b\x32$.envoy.data.tap.v2alpha.TraceWrapper\x1aM\n\nIdentifier\x12/\n\x04node\x18\x01 \x01(\x0b\x32\x17.envoy.api.v2.core.NodeB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x0e\n\x06tap_id\x18\x02 \x01(\t\"\x14\n\x12StreamTapsResponse2\x7f\n\x0eTapSinkService\x12m\n\nStreamTaps\x12,.envoy.service.tap.v2alpha.StreamTapsRequest\x1a-.envoy.service.tap.v2alpha.StreamTapsResponse\"\x00(\x01\x42@\n\'io.envoyproxy.envoy.service.tap.v2alphaB\x08TapProtoP\x01\x88\x01\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_data_dot_tap_dot_v2alpha_dot_wrapper__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_STREAMTAPSREQUEST_IDENTIFIER = _descriptor.Descriptor(
  name='Identifier',
  full_name='envoy.service.tap.v2alpha.StreamTapsRequest.Identifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='envoy.service.tap.v2alpha.StreamTapsRequest.Identifier.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tap_id', full_name='envoy.service.tap.v2alpha.StreamTapsRequest.Identifier.tap_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=360,
  serialized_end=437,
)

_STREAMTAPSREQUEST = _descriptor.Descriptor(
  name='StreamTapsRequest',
  full_name='envoy.service.tap.v2alpha.StreamTapsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='envoy.service.tap.v2alpha.StreamTapsRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trace_id', full_name='envoy.service.tap.v2alpha.StreamTapsRequest.trace_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trace', full_name='envoy.service.tap.v2alpha.StreamTapsRequest.trace', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STREAMTAPSREQUEST_IDENTIFIER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=191,
  serialized_end=437,
)


_STREAMTAPSRESPONSE = _descriptor.Descriptor(
  name='StreamTapsResponse',
  full_name='envoy.service.tap.v2alpha.StreamTapsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=439,
  serialized_end=459,
)

_STREAMTAPSREQUEST_IDENTIFIER.fields_by_name['node'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._NODE
_STREAMTAPSREQUEST_IDENTIFIER.containing_type = _STREAMTAPSREQUEST
_STREAMTAPSREQUEST.fields_by_name['identifier'].message_type = _STREAMTAPSREQUEST_IDENTIFIER
_STREAMTAPSREQUEST.fields_by_name['trace'].message_type = envoy_dot_data_dot_tap_dot_v2alpha_dot_wrapper__pb2._TRACEWRAPPER
DESCRIPTOR.message_types_by_name['StreamTapsRequest'] = _STREAMTAPSREQUEST
DESCRIPTOR.message_types_by_name['StreamTapsResponse'] = _STREAMTAPSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamTapsRequest = _reflection.GeneratedProtocolMessageType('StreamTapsRequest', (_message.Message,), {

  'Identifier' : _reflection.GeneratedProtocolMessageType('Identifier', (_message.Message,), {
    'DESCRIPTOR' : _STREAMTAPSREQUEST_IDENTIFIER,
    '__module__' : 'envoy.service.tap.v2alpha.tap_pb2'
    # @@protoc_insertion_point(class_scope:envoy.service.tap.v2alpha.StreamTapsRequest.Identifier)
    })
  ,
  'DESCRIPTOR' : _STREAMTAPSREQUEST,
  '__module__' : 'envoy.service.tap.v2alpha.tap_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.tap.v2alpha.StreamTapsRequest)
  })
_sym_db.RegisterMessage(StreamTapsRequest)
_sym_db.RegisterMessage(StreamTapsRequest.Identifier)

StreamTapsResponse = _reflection.GeneratedProtocolMessageType('StreamTapsResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMTAPSRESPONSE,
  '__module__' : 'envoy.service.tap.v2alpha.tap_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.tap.v2alpha.StreamTapsResponse)
  })
_sym_db.RegisterMessage(StreamTapsResponse)


DESCRIPTOR._options = None
_STREAMTAPSREQUEST_IDENTIFIER.fields_by_name['node']._options = None

_TAPSINKSERVICE = _descriptor.ServiceDescriptor(
  name='TapSinkService',
  full_name='envoy.service.tap.v2alpha.TapSinkService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=461,
  serialized_end=588,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamTaps',
    full_name='envoy.service.tap.v2alpha.TapSinkService.StreamTaps',
    index=0,
    containing_service=None,
    input_type=_STREAMTAPSREQUEST,
    output_type=_STREAMTAPSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TAPSINKSERVICE)

DESCRIPTOR.services_by_name['TapSinkService'] = _TAPSINKSERVICE

# @@protoc_insertion_point(module_scope)
