# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/tap/v3/wrapper.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.data.tap.v3 import http_pb2 as envoy_dot_data_dot_tap_dot_v3_dot_http__pb2
from envoy.data.tap.v3 import transport_pb2 as envoy_dot_data_dot_tap_dot_v3_dot_transport__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/data/tap/v3/wrapper.proto',
  package='envoy.data.tap.v3',
  syntax='proto3',
  serialized_options=b'\n\037io.envoyproxy.envoy.data.tap.v3B\014WrapperProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1f\x65nvoy/data/tap/v3/wrapper.proto\x12\x11\x65nvoy.data.tap.v3\x1a\x1c\x65nvoy/data/tap/v3/http.proto\x1a!envoy/data/tap/v3/transport.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x82\x03\n\x0cTraceWrapper\x12\x43\n\x13http_buffered_trace\x18\x01 \x01(\x0b\x32$.envoy.data.tap.v3.HttpBufferedTraceH\x00\x12R\n\x1bhttp_streamed_trace_segment\x18\x02 \x01(\x0b\x32+.envoy.data.tap.v3.HttpStreamedTraceSegmentH\x00\x12G\n\x15socket_buffered_trace\x18\x03 \x01(\x0b\x32&.envoy.data.tap.v3.SocketBufferedTraceH\x00\x12V\n\x1dsocket_streamed_trace_segment\x18\x04 \x01(\x0b\x32-.envoy.data.tap.v3.SocketStreamedTraceSegmentH\x00:*\x9a\xc5\x88\x1e%\n#envoy.data.tap.v2alpha.TraceWrapperB\x0c\n\x05trace\x12\x03\xf8\x42\x01\x42\x39\n\x1fio.envoyproxy.envoy.data.tap.v3B\x0cWrapperProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_data_dot_tap_dot_v3_dot_http__pb2.DESCRIPTOR,envoy_dot_data_dot_tap_dot_v3_dot_transport__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_TRACEWRAPPER = _descriptor.Descriptor(
  name='TraceWrapper',
  full_name='envoy.data.tap.v3.TraceWrapper',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_buffered_trace', full_name='envoy.data.tap.v3.TraceWrapper.http_buffered_trace', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_streamed_trace_segment', full_name='envoy.data.tap.v3.TraceWrapper.http_streamed_trace_segment', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='socket_buffered_trace', full_name='envoy.data.tap.v3.TraceWrapper.socket_buffered_trace', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='socket_streamed_trace_segment', full_name='envoy.data.tap.v3.TraceWrapper.socket_streamed_trace_segment', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036%\n#envoy.data.tap.v2alpha.TraceWrapper',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='trace', full_name='envoy.data.tap.v3.TraceWrapper.trace',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=211,
  serialized_end=597,
)

_TRACEWRAPPER.fields_by_name['http_buffered_trace'].message_type = envoy_dot_data_dot_tap_dot_v3_dot_http__pb2._HTTPBUFFEREDTRACE
_TRACEWRAPPER.fields_by_name['http_streamed_trace_segment'].message_type = envoy_dot_data_dot_tap_dot_v3_dot_http__pb2._HTTPSTREAMEDTRACESEGMENT
_TRACEWRAPPER.fields_by_name['socket_buffered_trace'].message_type = envoy_dot_data_dot_tap_dot_v3_dot_transport__pb2._SOCKETBUFFEREDTRACE
_TRACEWRAPPER.fields_by_name['socket_streamed_trace_segment'].message_type = envoy_dot_data_dot_tap_dot_v3_dot_transport__pb2._SOCKETSTREAMEDTRACESEGMENT
_TRACEWRAPPER.oneofs_by_name['trace'].fields.append(
  _TRACEWRAPPER.fields_by_name['http_buffered_trace'])
_TRACEWRAPPER.fields_by_name['http_buffered_trace'].containing_oneof = _TRACEWRAPPER.oneofs_by_name['trace']
_TRACEWRAPPER.oneofs_by_name['trace'].fields.append(
  _TRACEWRAPPER.fields_by_name['http_streamed_trace_segment'])
_TRACEWRAPPER.fields_by_name['http_streamed_trace_segment'].containing_oneof = _TRACEWRAPPER.oneofs_by_name['trace']
_TRACEWRAPPER.oneofs_by_name['trace'].fields.append(
  _TRACEWRAPPER.fields_by_name['socket_buffered_trace'])
_TRACEWRAPPER.fields_by_name['socket_buffered_trace'].containing_oneof = _TRACEWRAPPER.oneofs_by_name['trace']
_TRACEWRAPPER.oneofs_by_name['trace'].fields.append(
  _TRACEWRAPPER.fields_by_name['socket_streamed_trace_segment'])
_TRACEWRAPPER.fields_by_name['socket_streamed_trace_segment'].containing_oneof = _TRACEWRAPPER.oneofs_by_name['trace']
DESCRIPTOR.message_types_by_name['TraceWrapper'] = _TRACEWRAPPER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TraceWrapper = _reflection.GeneratedProtocolMessageType('TraceWrapper', (_message.Message,), {
  'DESCRIPTOR' : _TRACEWRAPPER,
  '__module__' : 'envoy.data.tap.v3.wrapper_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.tap.v3.TraceWrapper)
  })
_sym_db.RegisterMessage(TraceWrapper)


DESCRIPTOR._options = None
_TRACEWRAPPER.oneofs_by_name['trace']._options = None
_TRACEWRAPPER._options = None
# @@protoc_insertion_point(module_scope)
