# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v3/config_source.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from xds.core.v3 import authority_pb2 as xds_dot_core_dot_v3_dot_authority__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/core/v3/config_source.proto',
  package='envoy.config.core.v3',
  syntax='proto3',
  serialized_options=b'\n\"io.envoyproxy.envoy.config.core.v3B\021ConfigSourceProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(envoy/config/core/v3/config_source.proto\x12\x14\x65nvoy.config.core.v3\x1a\'envoy/config/core/v3/grpc_service.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bxds/core/v3/authority.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x95\x05\n\x0f\x41piConfigSource\x12I\n\x08\x61pi_type\x18\x01 \x01(\x0e\x32-.envoy.config.core.v3.ApiConfigSource.ApiTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12I\n\x15transport_api_version\x18\x08 \x01(\x0e\x32 .envoy.config.core.v3.ApiVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x15\n\rcluster_names\x18\x02 \x03(\t\x12\x38\n\rgrpc_services\x18\x04 \x03(\x0b\x32!.envoy.config.core.v3.GrpcService\x12\x30\n\rrefresh_delay\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12<\n\x0frequest_timeout\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x44\n\x13rate_limit_settings\x18\x06 \x01(\x0b\x32\'.envoy.config.core.v3.RateLimitSettings\x12&\n\x1eset_node_on_first_message_only\x18\x07 \x01(\x08\"\x92\x01\n\x07\x41piType\x12\x33\n%DEPRECATED_AND_UNAVAILABLE_DO_NOT_USE\x10\x00\x1a\x08\x08\x01\xa8\xf7\xb4\x8b\x02\x01\x12\x08\n\x04REST\x10\x01\x12\x08\n\x04GRPC\x10\x02\x12\x0e\n\nDELTA_GRPC\x10\x03\x12\x13\n\x0f\x41GGREGATED_GRPC\x10\x05\x12\x19\n\x15\x41GGREGATED_DELTA_GRPC\x10\x06:(\x9a\xc5\x88\x1e#\n!envoy.api.v2.core.ApiConfigSource\"I\n\x16\x41ggregatedConfigSource:/\x9a\xc5\x88\x1e*\n(envoy.api.v2.core.AggregatedConfigSource\"\x88\x01\n\x10SelfConfigSource\x12I\n\x15transport_api_version\x18\x01 \x01(\x0e\x32 .envoy.config.core.v3.ApiVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01:)\x9a\xc5\x88\x1e$\n\"envoy.api.v2.core.SelfConfigSource\"\xb2\x01\n\x11RateLimitSettings\x12\x30\n\nmax_tokens\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12?\n\tfill_rate\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0e\xfa\x42\x0b\x12\t!\x00\x00\x00\x00\x00\x00\x00\x00:*\x9a\xc5\x88\x1e%\n#envoy.api.v2.core.RateLimitSettings\"\xcf\x03\n\x0c\x43onfigSource\x12+\n\x0b\x61uthorities\x18\x07 \x03(\x0b\x32\x16.xds.core.v3.Authority\x12\x0e\n\x04path\x18\x01 \x01(\tH\x00\x12\x42\n\x11\x61pi_config_source\x18\x02 \x01(\x0b\x32%.envoy.config.core.v3.ApiConfigSourceH\x00\x12;\n\x03\x61\x64s\x18\x03 \x01(\x0b\x32,.envoy.config.core.v3.AggregatedConfigSourceH\x00\x12\x36\n\x04self\x18\x05 \x01(\x0b\x32&.envoy.config.core.v3.SelfConfigSourceH\x00\x12\x38\n\x15initial_fetch_timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12H\n\x14resource_api_version\x18\x06 \x01(\x0e\x32 .envoy.config.core.v3.ApiVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01:%\x9a\xc5\x88\x1e \n\x1e\x65nvoy.api.v2.core.ConfigSourceB\x1e\n\x17\x63onfig_source_specifier\x12\x03\xf8\x42\x01*.\n\nApiVersion\x12\x0c\n\x04\x41UTO\x10\x00\x1a\x02\x08\x01\x12\n\n\x02V2\x10\x01\x1a\x02\x08\x01\x12\x06\n\x02V3\x10\x02\x42\x41\n\"io.envoyproxy.envoy.config.core.v3B\x11\x43onfigSourceProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,xds_dot_core_dot_v3_dot_authority__pb2.DESCRIPTOR,envoy_dot_annotations_dot_deprecation__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])

_APIVERSION = _descriptor.EnumDescriptor(
  name='ApiVersion',
  full_name='envoy.config.core.v3.ApiVersion',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTO', index=0, number=0,
      serialized_options=b'\010\001',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='V2', index=1, number=1,
      serialized_options=b'\010\001',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='V3', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1853,
  serialized_end=1899,
)
_sym_db.RegisterEnumDescriptor(_APIVERSION)

ApiVersion = enum_type_wrapper.EnumTypeWrapper(_APIVERSION)
AUTO = 0
V2 = 1
V3 = 2


_APICONFIGSOURCE_APITYPE = _descriptor.EnumDescriptor(
  name='ApiType',
  full_name='envoy.config.core.v3.ApiConfigSource.ApiType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEPRECATED_AND_UNAVAILABLE_DO_NOT_USE', index=0, number=0,
      serialized_options=b'\010\001\250\367\264\213\002\001',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REST', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRPC', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELTA_GRPC', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AGGREGATED_GRPC', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AGGREGATED_DELTA_GRPC', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=802,
  serialized_end=948,
)
_sym_db.RegisterEnumDescriptor(_APICONFIGSOURCE_APITYPE)


_APICONFIGSOURCE = _descriptor.Descriptor(
  name='ApiConfigSource',
  full_name='envoy.config.core.v3.ApiConfigSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='api_type', full_name='envoy.config.core.v3.ApiConfigSource.api_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transport_api_version', full_name='envoy.config.core.v3.ApiConfigSource.transport_api_version', index=1,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_names', full_name='envoy.config.core.v3.ApiConfigSource.cluster_names', index=2,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc_services', full_name='envoy.config.core.v3.ApiConfigSource.grpc_services', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='refresh_delay', full_name='envoy.config.core.v3.ApiConfigSource.refresh_delay', index=4,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_timeout', full_name='envoy.config.core.v3.ApiConfigSource.request_timeout', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate_limit_settings', full_name='envoy.config.core.v3.ApiConfigSource.rate_limit_settings', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_node_on_first_message_only', full_name='envoy.config.core.v3.ApiConfigSource.set_node_on_first_message_only', index=7,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _APICONFIGSOURCE_APITYPE,
  ],
  serialized_options=b'\232\305\210\036#\n!envoy.api.v2.core.ApiConfigSource',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=329,
  serialized_end=990,
)


_AGGREGATEDCONFIGSOURCE = _descriptor.Descriptor(
  name='AggregatedConfigSource',
  full_name='envoy.config.core.v3.AggregatedConfigSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036*\n(envoy.api.v2.core.AggregatedConfigSource',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=992,
  serialized_end=1065,
)


_SELFCONFIGSOURCE = _descriptor.Descriptor(
  name='SelfConfigSource',
  full_name='envoy.config.core.v3.SelfConfigSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transport_api_version', full_name='envoy.config.core.v3.SelfConfigSource.transport_api_version', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036$\n\"envoy.api.v2.core.SelfConfigSource',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1068,
  serialized_end=1204,
)


_RATELIMITSETTINGS = _descriptor.Descriptor(
  name='RateLimitSettings',
  full_name='envoy.config.core.v3.RateLimitSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_tokens', full_name='envoy.config.core.v3.RateLimitSettings.max_tokens', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fill_rate', full_name='envoy.config.core.v3.RateLimitSettings.fill_rate', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\013\022\t!\000\000\000\000\000\000\000\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036%\n#envoy.api.v2.core.RateLimitSettings',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1207,
  serialized_end=1385,
)


_CONFIGSOURCE = _descriptor.Descriptor(
  name='ConfigSource',
  full_name='envoy.config.core.v3.ConfigSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='authorities', full_name='envoy.config.core.v3.ConfigSource.authorities', index=0,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='envoy.config.core.v3.ConfigSource.path', index=1,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='api_config_source', full_name='envoy.config.core.v3.ConfigSource.api_config_source', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ads', full_name='envoy.config.core.v3.ConfigSource.ads', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='self', full_name='envoy.config.core.v3.ConfigSource.self', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_fetch_timeout', full_name='envoy.config.core.v3.ConfigSource.initial_fetch_timeout', index=5,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_api_version', full_name='envoy.config.core.v3.ConfigSource.resource_api_version', index=6,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036 \n\036envoy.api.v2.core.ConfigSource',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_source_specifier', full_name='envoy.config.core.v3.ConfigSource.config_source_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1388,
  serialized_end=1851,
)

_APICONFIGSOURCE.fields_by_name['api_type'].enum_type = _APICONFIGSOURCE_APITYPE
_APICONFIGSOURCE.fields_by_name['transport_api_version'].enum_type = _APIVERSION
_APICONFIGSOURCE.fields_by_name['grpc_services'].message_type = envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2._GRPCSERVICE
_APICONFIGSOURCE.fields_by_name['refresh_delay'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_APICONFIGSOURCE.fields_by_name['request_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_APICONFIGSOURCE.fields_by_name['rate_limit_settings'].message_type = _RATELIMITSETTINGS
_APICONFIGSOURCE_APITYPE.containing_type = _APICONFIGSOURCE
_SELFCONFIGSOURCE.fields_by_name['transport_api_version'].enum_type = _APIVERSION
_RATELIMITSETTINGS.fields_by_name['max_tokens'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_RATELIMITSETTINGS.fields_by_name['fill_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_CONFIGSOURCE.fields_by_name['authorities'].message_type = xds_dot_core_dot_v3_dot_authority__pb2._AUTHORITY
_CONFIGSOURCE.fields_by_name['api_config_source'].message_type = _APICONFIGSOURCE
_CONFIGSOURCE.fields_by_name['ads'].message_type = _AGGREGATEDCONFIGSOURCE
_CONFIGSOURCE.fields_by_name['self'].message_type = _SELFCONFIGSOURCE
_CONFIGSOURCE.fields_by_name['initial_fetch_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CONFIGSOURCE.fields_by_name['resource_api_version'].enum_type = _APIVERSION
_CONFIGSOURCE.oneofs_by_name['config_source_specifier'].fields.append(
  _CONFIGSOURCE.fields_by_name['path'])
_CONFIGSOURCE.fields_by_name['path'].containing_oneof = _CONFIGSOURCE.oneofs_by_name['config_source_specifier']
_CONFIGSOURCE.oneofs_by_name['config_source_specifier'].fields.append(
  _CONFIGSOURCE.fields_by_name['api_config_source'])
_CONFIGSOURCE.fields_by_name['api_config_source'].containing_oneof = _CONFIGSOURCE.oneofs_by_name['config_source_specifier']
_CONFIGSOURCE.oneofs_by_name['config_source_specifier'].fields.append(
  _CONFIGSOURCE.fields_by_name['ads'])
_CONFIGSOURCE.fields_by_name['ads'].containing_oneof = _CONFIGSOURCE.oneofs_by_name['config_source_specifier']
_CONFIGSOURCE.oneofs_by_name['config_source_specifier'].fields.append(
  _CONFIGSOURCE.fields_by_name['self'])
_CONFIGSOURCE.fields_by_name['self'].containing_oneof = _CONFIGSOURCE.oneofs_by_name['config_source_specifier']
DESCRIPTOR.message_types_by_name['ApiConfigSource'] = _APICONFIGSOURCE
DESCRIPTOR.message_types_by_name['AggregatedConfigSource'] = _AGGREGATEDCONFIGSOURCE
DESCRIPTOR.message_types_by_name['SelfConfigSource'] = _SELFCONFIGSOURCE
DESCRIPTOR.message_types_by_name['RateLimitSettings'] = _RATELIMITSETTINGS
DESCRIPTOR.message_types_by_name['ConfigSource'] = _CONFIGSOURCE
DESCRIPTOR.enum_types_by_name['ApiVersion'] = _APIVERSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ApiConfigSource = _reflection.GeneratedProtocolMessageType('ApiConfigSource', (_message.Message,), {
  'DESCRIPTOR' : _APICONFIGSOURCE,
  '__module__' : 'envoy.config.core.v3.config_source_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.ApiConfigSource)
  })
_sym_db.RegisterMessage(ApiConfigSource)

AggregatedConfigSource = _reflection.GeneratedProtocolMessageType('AggregatedConfigSource', (_message.Message,), {
  'DESCRIPTOR' : _AGGREGATEDCONFIGSOURCE,
  '__module__' : 'envoy.config.core.v3.config_source_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.AggregatedConfigSource)
  })
_sym_db.RegisterMessage(AggregatedConfigSource)

SelfConfigSource = _reflection.GeneratedProtocolMessageType('SelfConfigSource', (_message.Message,), {
  'DESCRIPTOR' : _SELFCONFIGSOURCE,
  '__module__' : 'envoy.config.core.v3.config_source_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.SelfConfigSource)
  })
_sym_db.RegisterMessage(SelfConfigSource)

RateLimitSettings = _reflection.GeneratedProtocolMessageType('RateLimitSettings', (_message.Message,), {
  'DESCRIPTOR' : _RATELIMITSETTINGS,
  '__module__' : 'envoy.config.core.v3.config_source_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.RateLimitSettings)
  })
_sym_db.RegisterMessage(RateLimitSettings)

ConfigSource = _reflection.GeneratedProtocolMessageType('ConfigSource', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGSOURCE,
  '__module__' : 'envoy.config.core.v3.config_source_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.ConfigSource)
  })
_sym_db.RegisterMessage(ConfigSource)


DESCRIPTOR._options = None
_APIVERSION.values_by_name["AUTO"]._options = None
_APIVERSION.values_by_name["V2"]._options = None
_APICONFIGSOURCE_APITYPE.values_by_name["DEPRECATED_AND_UNAVAILABLE_DO_NOT_USE"]._options = None
_APICONFIGSOURCE.fields_by_name['api_type']._options = None
_APICONFIGSOURCE.fields_by_name['transport_api_version']._options = None
_APICONFIGSOURCE.fields_by_name['request_timeout']._options = None
_APICONFIGSOURCE._options = None
_AGGREGATEDCONFIGSOURCE._options = None
_SELFCONFIGSOURCE.fields_by_name['transport_api_version']._options = None
_SELFCONFIGSOURCE._options = None
_RATELIMITSETTINGS.fields_by_name['fill_rate']._options = None
_RATELIMITSETTINGS._options = None
_CONFIGSOURCE.oneofs_by_name['config_source_specifier']._options = None
_CONFIGSOURCE.fields_by_name['resource_api_version']._options = None
_CONFIGSOURCE._options = None
# @@protoc_insertion_point(module_scope)
