# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/accesslog/v4alpha/accesslog.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import base_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2
from envoy.config.route.v4alpha import route_components_pb2 as envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2
from envoy.type.matcher.v4alpha import metadata_pb2 as envoy_dot_type_dot_matcher_dot_v4alpha_dot_metadata__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/accesslog/v4alpha/accesslog.proto',
  package='envoy.config.accesslog.v4alpha',
  syntax='proto3',
  serialized_options=b'\n,io.envoyproxy.envoy.config.accesslog.v4alphaB\016AccesslogProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.envoy/config/accesslog/v4alpha/accesslog.proto\x12\x1e\x65nvoy.config.accesslog.v4alpha\x1a$envoy/config/core/v4alpha/base.proto\x1a\x31\x65nvoy/config/route/v4alpha/route_components.proto\x1a)envoy/type/matcher/v4alpha/metadata.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xd1\x01\n\tAccessLog\x12\x0c\n\x04name\x18\x01 \x01(\t\x12?\n\x06\x66ilter\x18\x02 \x01(\x0b\x32/.envoy.config.accesslog.v4alpha.AccessLogFilter\x12,\n\x0ctyped_config\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00:*\x9a\xc5\x88\x1e%\n#envoy.config.accesslog.v3.AccessLogB\r\n\x0b\x63onfig_typeJ\x04\x08\x03\x10\x04R\x06\x63onfig\"\xe9\x07\n\x0f\x41\x63\x63\x65ssLogFilter\x12N\n\x12status_code_filter\x18\x01 \x01(\x0b\x32\x30.envoy.config.accesslog.v4alpha.StatusCodeFilterH\x00\x12I\n\x0f\x64uration_filter\x18\x02 \x01(\x0b\x32..envoy.config.accesslog.v4alpha.DurationFilterH\x00\x12W\n\x17not_health_check_filter\x18\x03 \x01(\x0b\x32\x34.envoy.config.accesslog.v4alpha.NotHealthCheckFilterH\x00\x12K\n\x10traceable_filter\x18\x04 \x01(\x0b\x32/.envoy.config.accesslog.v4alpha.TraceableFilterH\x00\x12G\n\x0eruntime_filter\x18\x05 \x01(\x0b\x32-.envoy.config.accesslog.v4alpha.RuntimeFilterH\x00\x12?\n\nand_filter\x18\x06 \x01(\x0b\x32).envoy.config.accesslog.v4alpha.AndFilterH\x00\x12=\n\tor_filter\x18\x07 \x01(\x0b\x32(.envoy.config.accesslog.v4alpha.OrFilterH\x00\x12\x45\n\rheader_filter\x18\x08 \x01(\x0b\x32,.envoy.config.accesslog.v4alpha.HeaderFilterH\x00\x12R\n\x14response_flag_filter\x18\t \x01(\x0b\x32\x32.envoy.config.accesslog.v4alpha.ResponseFlagFilterH\x00\x12N\n\x12grpc_status_filter\x18\n \x01(\x0b\x32\x30.envoy.config.accesslog.v4alpha.GrpcStatusFilterH\x00\x12K\n\x10\x65xtension_filter\x18\x0b \x01(\x0b\x32/.envoy.config.accesslog.v4alpha.ExtensionFilterH\x00\x12I\n\x0fmetadata_filter\x18\x0c \x01(\x0b\x32..envoy.config.accesslog.v4alpha.MetadataFilterH\x00:0\x9a\xc5\x88\x1e+\n)envoy.config.accesslog.v3.AccessLogFilterB\x17\n\x10\x66ilter_specifier\x12\x03\xf8\x42\x01\"\xe7\x01\n\x10\x43omparisonFilter\x12I\n\x02op\x18\x01 \x01(\x0e\x32\x33.envoy.config.accesslog.v4alpha.ComparisonFilter.OpB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x37\n\x05value\x18\x02 \x01(\x0b\x32(.envoy.config.core.v4alpha.RuntimeUInt32\"\x1c\n\x02Op\x12\x06\n\x02\x45Q\x10\x00\x12\x06\n\x02GE\x10\x01\x12\x06\n\x02LE\x10\x02:1\x9a\xc5\x88\x1e,\n*envoy.config.accesslog.v3.ComparisonFilter\"\x95\x01\n\x10StatusCodeFilter\x12N\n\ncomparison\x18\x01 \x01(\x0b\x32\x30.envoy.config.accesslog.v4alpha.ComparisonFilterB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:1\x9a\xc5\x88\x1e,\n*envoy.config.accesslog.v3.StatusCodeFilter\"\x91\x01\n\x0e\x44urationFilter\x12N\n\ncomparison\x18\x01 \x01(\x0b\x32\x30.envoy.config.accesslog.v4alpha.ComparisonFilterB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:/\x9a\xc5\x88\x1e*\n(envoy.config.accesslog.v3.DurationFilter\"M\n\x14NotHealthCheckFilter:5\x9a\xc5\x88\x1e\x30\n.envoy.config.accesslog.v3.NotHealthCheckFilter\"C\n\x0fTraceableFilter:0\x9a\xc5\x88\x1e+\n)envoy.config.accesslog.v3.TraceableFilter\"\xbc\x01\n\rRuntimeFilter\x12\x1c\n\x0bruntime_key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x39\n\x0fpercent_sampled\x18\x02 \x01(\x0b\x32 .envoy.type.v3.FractionalPercent\x12\"\n\x1ause_independent_randomness\x18\x03 \x01(\x08:.\x9a\xc5\x88\x1e)\n\'envoy.config.accesslog.v3.RuntimeFilter\"\x83\x01\n\tAndFilter\x12J\n\x07\x66ilters\x18\x01 \x03(\x0b\x32/.envoy.config.accesslog.v4alpha.AccessLogFilterB\x08\xfa\x42\x05\x92\x01\x02\x08\x02:*\x9a\xc5\x88\x1e%\n#envoy.config.accesslog.v3.AndFilter\"\x81\x01\n\x08OrFilter\x12J\n\x07\x66ilters\x18\x02 \x03(\x0b\x32/.envoy.config.accesslog.v4alpha.AccessLogFilterB\x08\xfa\x42\x05\x92\x01\x02\x08\x02:)\x9a\xc5\x88\x1e$\n\"envoy.config.accesslog.v3.OrFilter\"\x82\x01\n\x0cHeaderFilter\x12\x43\n\x06header\x18\x01 \x01(\x0b\x32).envoy.config.route.v4alpha.HeaderMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:-\x9a\xc5\x88\x1e(\n&envoy.config.accesslog.v3.HeaderFilter\"\xce\x01\n\x12ResponseFlagFilter\x12\x82\x01\n\x05\x66lags\x18\x01 \x03(\tBs\xfa\x42p\x92\x01m\"kriR\x02LHR\x02UHR\x02UTR\x02LRR\x02URR\x02UFR\x02UCR\x02UOR\x02NRR\x02\x44IR\x02\x46IR\x02RLR\x04UAEXR\x04RLSER\x02\x44\x43R\x03URXR\x02SIR\x02IHR\x03\x44PER\x05UMSDRR\x04RFCFR\x04NFCFR\x02\x44T:3\x9a\xc5\x88\x1e.\n,envoy.config.accesslog.v3.ResponseFlagFilter\"\xeb\x03\n\x10GrpcStatusFilter\x12X\n\x08statuses\x18\x01 \x03(\x0e\x32\x37.envoy.config.accesslog.v4alpha.GrpcStatusFilter.StatusB\r\xfa\x42\n\x92\x01\x07\"\x05\x82\x01\x02\x10\x01\x12\x0f\n\x07\x65xclude\x18\x02 \x01(\x08\"\xb8\x02\n\x06Status\x12\x06\n\x02OK\x10\x00\x12\x0c\n\x08\x43\x41NCELED\x10\x01\x12\x0b\n\x07UNKNOWN\x10\x02\x12\x14\n\x10INVALID_ARGUMENT\x10\x03\x12\x15\n\x11\x44\x45\x41\x44LINE_EXCEEDED\x10\x04\x12\r\n\tNOT_FOUND\x10\x05\x12\x12\n\x0e\x41LREADY_EXISTS\x10\x06\x12\x15\n\x11PERMISSION_DENIED\x10\x07\x12\x16\n\x12RESOURCE_EXHAUSTED\x10\x08\x12\x17\n\x13\x46\x41ILED_PRECONDITION\x10\t\x12\x0b\n\x07\x41\x42ORTED\x10\n\x12\x10\n\x0cOUT_OF_RANGE\x10\x0b\x12\x11\n\rUNIMPLEMENTED\x10\x0c\x12\x0c\n\x08INTERNAL\x10\r\x12\x0f\n\x0bUNAVAILABLE\x10\x0e\x12\r\n\tDATA_LOSS\x10\x0f\x12\x13\n\x0fUNAUTHENTICATED\x10\x10:1\x9a\xc5\x88\x1e,\n*envoy.config.accesslog.v3.GrpcStatusFilter\"\xbb\x01\n\x0eMetadataFilter\x12<\n\x07matcher\x18\x01 \x01(\x0b\x32+.envoy.type.matcher.v4alpha.MetadataMatcher\x12:\n\x16match_if_key_not_found\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue:/\x9a\xc5\x88\x1e*\n(envoy.config.accesslog.v3.MetadataFilter\"\x9c\x01\n\x0f\x45xtensionFilter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00:0\x9a\xc5\x88\x1e+\n)envoy.config.accesslog.v3.ExtensionFilterB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfigBH\n,io.envoyproxy.envoy.config.accesslog.v4alphaB\x0e\x41\x63\x63\x65sslogProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2.DESCRIPTOR,envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_v4alpha_dot_metadata__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_percent__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_COMPARISONFILTER_OP = _descriptor.EnumDescriptor(
  name='Op',
  full_name='envoy.config.accesslog.v4alpha.ComparisonFilter.Op',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EQ', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1762,
  serialized_end=1790,
)
_sym_db.RegisterEnumDescriptor(_COMPARISONFILTER_OP)

_GRPCSTATUSFILTER_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='envoy.config.accesslog.v4alpha.GrpcStatusFilter.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CANCELED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ARGUMENT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEADLINE_EXCEEDED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_FOUND', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALREADY_EXISTS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERMISSION_DENIED', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESOURCE_EXHAUSTED', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED_PRECONDITION', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ABORTED', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUT_OF_RANGE', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIMPLEMENTED', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNAVAILABLE', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_LOSS', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNAUTHENTICATED', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3219,
  serialized_end=3531,
)
_sym_db.RegisterEnumDescriptor(_GRPCSTATUSFILTER_STATUS)


_ACCESSLOG = _descriptor.Descriptor(
  name='AccessLog',
  full_name='envoy.config.accesslog.v4alpha.AccessLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.accesslog.v4alpha.AccessLog.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='envoy.config.accesslog.v4alpha.AccessLog.filter', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.config.accesslog.v4alpha.AccessLog.typed_config', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036%\n#envoy.config.accesslog.v3.AccessLog',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.config.accesslog.v4alpha.AccessLog.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=394,
  serialized_end=603,
)


_ACCESSLOGFILTER = _descriptor.Descriptor(
  name='AccessLogFilter',
  full_name='envoy.config.accesslog.v4alpha.AccessLogFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_code_filter', full_name='envoy.config.accesslog.v4alpha.AccessLogFilter.status_code_filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration_filter', full_name='envoy.config.accesslog.v4alpha.AccessLogFilter.duration_filter', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='not_health_check_filter', full_name='envoy.config.accesslog.v4alpha.AccessLogFilter.not_health_check_filter', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traceable_filter', full_name='envoy.config.accesslog.v4alpha.AccessLogFilter.traceable_filter', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime_filter', full_name='envoy.config.accesslog.v4alpha.AccessLogFilter.runtime_filter', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='and_filter', full_name='envoy.config.accesslog.v4alpha.AccessLogFilter.and_filter', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='or_filter', full_name='envoy.config.accesslog.v4alpha.AccessLogFilter.or_filter', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header_filter', full_name='envoy.config.accesslog.v4alpha.AccessLogFilter.header_filter', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_flag_filter', full_name='envoy.config.accesslog.v4alpha.AccessLogFilter.response_flag_filter', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc_status_filter', full_name='envoy.config.accesslog.v4alpha.AccessLogFilter.grpc_status_filter', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extension_filter', full_name='envoy.config.accesslog.v4alpha.AccessLogFilter.extension_filter', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_filter', full_name='envoy.config.accesslog.v4alpha.AccessLogFilter.metadata_filter', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036+\n)envoy.config.accesslog.v3.AccessLogFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='filter_specifier', full_name='envoy.config.accesslog.v4alpha.AccessLogFilter.filter_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=606,
  serialized_end=1607,
)


_COMPARISONFILTER = _descriptor.Descriptor(
  name='ComparisonFilter',
  full_name='envoy.config.accesslog.v4alpha.ComparisonFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='op', full_name='envoy.config.accesslog.v4alpha.ComparisonFilter.op', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.config.accesslog.v4alpha.ComparisonFilter.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COMPARISONFILTER_OP,
  ],
  serialized_options=b'\232\305\210\036,\n*envoy.config.accesslog.v3.ComparisonFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1610,
  serialized_end=1841,
)


_STATUSCODEFILTER = _descriptor.Descriptor(
  name='StatusCodeFilter',
  full_name='envoy.config.accesslog.v4alpha.StatusCodeFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='comparison', full_name='envoy.config.accesslog.v4alpha.StatusCodeFilter.comparison', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036,\n*envoy.config.accesslog.v3.StatusCodeFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1844,
  serialized_end=1993,
)


_DURATIONFILTER = _descriptor.Descriptor(
  name='DurationFilter',
  full_name='envoy.config.accesslog.v4alpha.DurationFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='comparison', full_name='envoy.config.accesslog.v4alpha.DurationFilter.comparison', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036*\n(envoy.config.accesslog.v3.DurationFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1996,
  serialized_end=2141,
)


_NOTHEALTHCHECKFILTER = _descriptor.Descriptor(
  name='NotHealthCheckFilter',
  full_name='envoy.config.accesslog.v4alpha.NotHealthCheckFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0360\n.envoy.config.accesslog.v3.NotHealthCheckFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2143,
  serialized_end=2220,
)


_TRACEABLEFILTER = _descriptor.Descriptor(
  name='TraceableFilter',
  full_name='envoy.config.accesslog.v4alpha.TraceableFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036+\n)envoy.config.accesslog.v3.TraceableFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2222,
  serialized_end=2289,
)


_RUNTIMEFILTER = _descriptor.Descriptor(
  name='RuntimeFilter',
  full_name='envoy.config.accesslog.v4alpha.RuntimeFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='runtime_key', full_name='envoy.config.accesslog.v4alpha.RuntimeFilter.runtime_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percent_sampled', full_name='envoy.config.accesslog.v4alpha.RuntimeFilter.percent_sampled', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_independent_randomness', full_name='envoy.config.accesslog.v4alpha.RuntimeFilter.use_independent_randomness', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036)\n\'envoy.config.accesslog.v3.RuntimeFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2292,
  serialized_end=2480,
)


_ANDFILTER = _descriptor.Descriptor(
  name='AndFilter',
  full_name='envoy.config.accesslog.v4alpha.AndFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filters', full_name='envoy.config.accesslog.v4alpha.AndFilter.filters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036%\n#envoy.config.accesslog.v3.AndFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2483,
  serialized_end=2614,
)


_ORFILTER = _descriptor.Descriptor(
  name='OrFilter',
  full_name='envoy.config.accesslog.v4alpha.OrFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filters', full_name='envoy.config.accesslog.v4alpha.OrFilter.filters', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036$\n\"envoy.config.accesslog.v3.OrFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2617,
  serialized_end=2746,
)


_HEADERFILTER = _descriptor.Descriptor(
  name='HeaderFilter',
  full_name='envoy.config.accesslog.v4alpha.HeaderFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='envoy.config.accesslog.v4alpha.HeaderFilter.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036(\n&envoy.config.accesslog.v3.HeaderFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2749,
  serialized_end=2879,
)


_RESPONSEFLAGFILTER = _descriptor.Descriptor(
  name='ResponseFlagFilter',
  full_name='envoy.config.accesslog.v4alpha.ResponseFlagFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flags', full_name='envoy.config.accesslog.v4alpha.ResponseFlagFilter.flags', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372Bp\222\001m\"kriR\002LHR\002UHR\002UTR\002LRR\002URR\002UFR\002UCR\002UOR\002NRR\002DIR\002FIR\002RLR\004UAEXR\004RLSER\002DCR\003URXR\002SIR\002IHR\003DPER\005UMSDRR\004RFCFR\004NFCFR\002DT', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036.\n,envoy.config.accesslog.v3.ResponseFlagFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2882,
  serialized_end=3088,
)


_GRPCSTATUSFILTER = _descriptor.Descriptor(
  name='GrpcStatusFilter',
  full_name='envoy.config.accesslog.v4alpha.GrpcStatusFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='statuses', full_name='envoy.config.accesslog.v4alpha.GrpcStatusFilter.statuses', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\n\222\001\007\"\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exclude', full_name='envoy.config.accesslog.v4alpha.GrpcStatusFilter.exclude', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GRPCSTATUSFILTER_STATUS,
  ],
  serialized_options=b'\232\305\210\036,\n*envoy.config.accesslog.v3.GrpcStatusFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3091,
  serialized_end=3582,
)


_METADATAFILTER = _descriptor.Descriptor(
  name='MetadataFilter',
  full_name='envoy.config.accesslog.v4alpha.MetadataFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='matcher', full_name='envoy.config.accesslog.v4alpha.MetadataFilter.matcher', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='match_if_key_not_found', full_name='envoy.config.accesslog.v4alpha.MetadataFilter.match_if_key_not_found', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036*\n(envoy.config.accesslog.v3.MetadataFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3585,
  serialized_end=3772,
)


_EXTENSIONFILTER = _descriptor.Descriptor(
  name='ExtensionFilter',
  full_name='envoy.config.accesslog.v4alpha.ExtensionFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.accesslog.v4alpha.ExtensionFilter.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.config.accesslog.v4alpha.ExtensionFilter.typed_config', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036+\n)envoy.config.accesslog.v3.ExtensionFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.config.accesslog.v4alpha.ExtensionFilter.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3775,
  serialized_end=3931,
)

_ACCESSLOG.fields_by_name['filter'].message_type = _ACCESSLOGFILTER
_ACCESSLOG.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_ACCESSLOG.oneofs_by_name['config_type'].fields.append(
  _ACCESSLOG.fields_by_name['typed_config'])
_ACCESSLOG.fields_by_name['typed_config'].containing_oneof = _ACCESSLOG.oneofs_by_name['config_type']
_ACCESSLOGFILTER.fields_by_name['status_code_filter'].message_type = _STATUSCODEFILTER
_ACCESSLOGFILTER.fields_by_name['duration_filter'].message_type = _DURATIONFILTER
_ACCESSLOGFILTER.fields_by_name['not_health_check_filter'].message_type = _NOTHEALTHCHECKFILTER
_ACCESSLOGFILTER.fields_by_name['traceable_filter'].message_type = _TRACEABLEFILTER
_ACCESSLOGFILTER.fields_by_name['runtime_filter'].message_type = _RUNTIMEFILTER
_ACCESSLOGFILTER.fields_by_name['and_filter'].message_type = _ANDFILTER
_ACCESSLOGFILTER.fields_by_name['or_filter'].message_type = _ORFILTER
_ACCESSLOGFILTER.fields_by_name['header_filter'].message_type = _HEADERFILTER
_ACCESSLOGFILTER.fields_by_name['response_flag_filter'].message_type = _RESPONSEFLAGFILTER
_ACCESSLOGFILTER.fields_by_name['grpc_status_filter'].message_type = _GRPCSTATUSFILTER
_ACCESSLOGFILTER.fields_by_name['extension_filter'].message_type = _EXTENSIONFILTER
_ACCESSLOGFILTER.fields_by_name['metadata_filter'].message_type = _METADATAFILTER
_ACCESSLOGFILTER.oneofs_by_name['filter_specifier'].fields.append(
  _ACCESSLOGFILTER.fields_by_name['status_code_filter'])
_ACCESSLOGFILTER.fields_by_name['status_code_filter'].containing_oneof = _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']
_ACCESSLOGFILTER.oneofs_by_name['filter_specifier'].fields.append(
  _ACCESSLOGFILTER.fields_by_name['duration_filter'])
_ACCESSLOGFILTER.fields_by_name['duration_filter'].containing_oneof = _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']
_ACCESSLOGFILTER.oneofs_by_name['filter_specifier'].fields.append(
  _ACCESSLOGFILTER.fields_by_name['not_health_check_filter'])
_ACCESSLOGFILTER.fields_by_name['not_health_check_filter'].containing_oneof = _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']
_ACCESSLOGFILTER.oneofs_by_name['filter_specifier'].fields.append(
  _ACCESSLOGFILTER.fields_by_name['traceable_filter'])
_ACCESSLOGFILTER.fields_by_name['traceable_filter'].containing_oneof = _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']
_ACCESSLOGFILTER.oneofs_by_name['filter_specifier'].fields.append(
  _ACCESSLOGFILTER.fields_by_name['runtime_filter'])
_ACCESSLOGFILTER.fields_by_name['runtime_filter'].containing_oneof = _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']
_ACCESSLOGFILTER.oneofs_by_name['filter_specifier'].fields.append(
  _ACCESSLOGFILTER.fields_by_name['and_filter'])
_ACCESSLOGFILTER.fields_by_name['and_filter'].containing_oneof = _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']
_ACCESSLOGFILTER.oneofs_by_name['filter_specifier'].fields.append(
  _ACCESSLOGFILTER.fields_by_name['or_filter'])
_ACCESSLOGFILTER.fields_by_name['or_filter'].containing_oneof = _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']
_ACCESSLOGFILTER.oneofs_by_name['filter_specifier'].fields.append(
  _ACCESSLOGFILTER.fields_by_name['header_filter'])
_ACCESSLOGFILTER.fields_by_name['header_filter'].containing_oneof = _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']
_ACCESSLOGFILTER.oneofs_by_name['filter_specifier'].fields.append(
  _ACCESSLOGFILTER.fields_by_name['response_flag_filter'])
_ACCESSLOGFILTER.fields_by_name['response_flag_filter'].containing_oneof = _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']
_ACCESSLOGFILTER.oneofs_by_name['filter_specifier'].fields.append(
  _ACCESSLOGFILTER.fields_by_name['grpc_status_filter'])
_ACCESSLOGFILTER.fields_by_name['grpc_status_filter'].containing_oneof = _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']
_ACCESSLOGFILTER.oneofs_by_name['filter_specifier'].fields.append(
  _ACCESSLOGFILTER.fields_by_name['extension_filter'])
_ACCESSLOGFILTER.fields_by_name['extension_filter'].containing_oneof = _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']
_ACCESSLOGFILTER.oneofs_by_name['filter_specifier'].fields.append(
  _ACCESSLOGFILTER.fields_by_name['metadata_filter'])
_ACCESSLOGFILTER.fields_by_name['metadata_filter'].containing_oneof = _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']
_COMPARISONFILTER.fields_by_name['op'].enum_type = _COMPARISONFILTER_OP
_COMPARISONFILTER.fields_by_name['value'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._RUNTIMEUINT32
_COMPARISONFILTER_OP.containing_type = _COMPARISONFILTER
_STATUSCODEFILTER.fields_by_name['comparison'].message_type = _COMPARISONFILTER
_DURATIONFILTER.fields_by_name['comparison'].message_type = _COMPARISONFILTER
_RUNTIMEFILTER.fields_by_name['percent_sampled'].message_type = envoy_dot_type_dot_v3_dot_percent__pb2._FRACTIONALPERCENT
_ANDFILTER.fields_by_name['filters'].message_type = _ACCESSLOGFILTER
_ORFILTER.fields_by_name['filters'].message_type = _ACCESSLOGFILTER
_HEADERFILTER.fields_by_name['header'].message_type = envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2._HEADERMATCHER
_GRPCSTATUSFILTER.fields_by_name['statuses'].enum_type = _GRPCSTATUSFILTER_STATUS
_GRPCSTATUSFILTER_STATUS.containing_type = _GRPCSTATUSFILTER
_METADATAFILTER.fields_by_name['matcher'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_metadata__pb2._METADATAMATCHER
_METADATAFILTER.fields_by_name['match_if_key_not_found'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_EXTENSIONFILTER.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_EXTENSIONFILTER.oneofs_by_name['config_type'].fields.append(
  _EXTENSIONFILTER.fields_by_name['typed_config'])
_EXTENSIONFILTER.fields_by_name['typed_config'].containing_oneof = _EXTENSIONFILTER.oneofs_by_name['config_type']
DESCRIPTOR.message_types_by_name['AccessLog'] = _ACCESSLOG
DESCRIPTOR.message_types_by_name['AccessLogFilter'] = _ACCESSLOGFILTER
DESCRIPTOR.message_types_by_name['ComparisonFilter'] = _COMPARISONFILTER
DESCRIPTOR.message_types_by_name['StatusCodeFilter'] = _STATUSCODEFILTER
DESCRIPTOR.message_types_by_name['DurationFilter'] = _DURATIONFILTER
DESCRIPTOR.message_types_by_name['NotHealthCheckFilter'] = _NOTHEALTHCHECKFILTER
DESCRIPTOR.message_types_by_name['TraceableFilter'] = _TRACEABLEFILTER
DESCRIPTOR.message_types_by_name['RuntimeFilter'] = _RUNTIMEFILTER
DESCRIPTOR.message_types_by_name['AndFilter'] = _ANDFILTER
DESCRIPTOR.message_types_by_name['OrFilter'] = _ORFILTER
DESCRIPTOR.message_types_by_name['HeaderFilter'] = _HEADERFILTER
DESCRIPTOR.message_types_by_name['ResponseFlagFilter'] = _RESPONSEFLAGFILTER
DESCRIPTOR.message_types_by_name['GrpcStatusFilter'] = _GRPCSTATUSFILTER
DESCRIPTOR.message_types_by_name['MetadataFilter'] = _METADATAFILTER
DESCRIPTOR.message_types_by_name['ExtensionFilter'] = _EXTENSIONFILTER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AccessLog = _reflection.GeneratedProtocolMessageType('AccessLog', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSLOG,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.AccessLog)
  })
_sym_db.RegisterMessage(AccessLog)

AccessLogFilter = _reflection.GeneratedProtocolMessageType('AccessLogFilter', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSLOGFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.AccessLogFilter)
  })
_sym_db.RegisterMessage(AccessLogFilter)

ComparisonFilter = _reflection.GeneratedProtocolMessageType('ComparisonFilter', (_message.Message,), {
  'DESCRIPTOR' : _COMPARISONFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.ComparisonFilter)
  })
_sym_db.RegisterMessage(ComparisonFilter)

StatusCodeFilter = _reflection.GeneratedProtocolMessageType('StatusCodeFilter', (_message.Message,), {
  'DESCRIPTOR' : _STATUSCODEFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.StatusCodeFilter)
  })
_sym_db.RegisterMessage(StatusCodeFilter)

DurationFilter = _reflection.GeneratedProtocolMessageType('DurationFilter', (_message.Message,), {
  'DESCRIPTOR' : _DURATIONFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.DurationFilter)
  })
_sym_db.RegisterMessage(DurationFilter)

NotHealthCheckFilter = _reflection.GeneratedProtocolMessageType('NotHealthCheckFilter', (_message.Message,), {
  'DESCRIPTOR' : _NOTHEALTHCHECKFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.NotHealthCheckFilter)
  })
_sym_db.RegisterMessage(NotHealthCheckFilter)

TraceableFilter = _reflection.GeneratedProtocolMessageType('TraceableFilter', (_message.Message,), {
  'DESCRIPTOR' : _TRACEABLEFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.TraceableFilter)
  })
_sym_db.RegisterMessage(TraceableFilter)

RuntimeFilter = _reflection.GeneratedProtocolMessageType('RuntimeFilter', (_message.Message,), {
  'DESCRIPTOR' : _RUNTIMEFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.RuntimeFilter)
  })
_sym_db.RegisterMessage(RuntimeFilter)

AndFilter = _reflection.GeneratedProtocolMessageType('AndFilter', (_message.Message,), {
  'DESCRIPTOR' : _ANDFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.AndFilter)
  })
_sym_db.RegisterMessage(AndFilter)

OrFilter = _reflection.GeneratedProtocolMessageType('OrFilter', (_message.Message,), {
  'DESCRIPTOR' : _ORFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.OrFilter)
  })
_sym_db.RegisterMessage(OrFilter)

HeaderFilter = _reflection.GeneratedProtocolMessageType('HeaderFilter', (_message.Message,), {
  'DESCRIPTOR' : _HEADERFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.HeaderFilter)
  })
_sym_db.RegisterMessage(HeaderFilter)

ResponseFlagFilter = _reflection.GeneratedProtocolMessageType('ResponseFlagFilter', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEFLAGFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.ResponseFlagFilter)
  })
_sym_db.RegisterMessage(ResponseFlagFilter)

GrpcStatusFilter = _reflection.GeneratedProtocolMessageType('GrpcStatusFilter', (_message.Message,), {
  'DESCRIPTOR' : _GRPCSTATUSFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.GrpcStatusFilter)
  })
_sym_db.RegisterMessage(GrpcStatusFilter)

MetadataFilter = _reflection.GeneratedProtocolMessageType('MetadataFilter', (_message.Message,), {
  'DESCRIPTOR' : _METADATAFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.MetadataFilter)
  })
_sym_db.RegisterMessage(MetadataFilter)

ExtensionFilter = _reflection.GeneratedProtocolMessageType('ExtensionFilter', (_message.Message,), {
  'DESCRIPTOR' : _EXTENSIONFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.ExtensionFilter)
  })
_sym_db.RegisterMessage(ExtensionFilter)


DESCRIPTOR._options = None
_ACCESSLOG._options = None
_ACCESSLOGFILTER.oneofs_by_name['filter_specifier']._options = None
_ACCESSLOGFILTER._options = None
_COMPARISONFILTER.fields_by_name['op']._options = None
_COMPARISONFILTER._options = None
_STATUSCODEFILTER.fields_by_name['comparison']._options = None
_STATUSCODEFILTER._options = None
_DURATIONFILTER.fields_by_name['comparison']._options = None
_DURATIONFILTER._options = None
_NOTHEALTHCHECKFILTER._options = None
_TRACEABLEFILTER._options = None
_RUNTIMEFILTER.fields_by_name['runtime_key']._options = None
_RUNTIMEFILTER._options = None
_ANDFILTER.fields_by_name['filters']._options = None
_ANDFILTER._options = None
_ORFILTER.fields_by_name['filters']._options = None
_ORFILTER._options = None
_HEADERFILTER.fields_by_name['header']._options = None
_HEADERFILTER._options = None
_RESPONSEFLAGFILTER.fields_by_name['flags']._options = None
_RESPONSEFLAGFILTER._options = None
_GRPCSTATUSFILTER.fields_by_name['statuses']._options = None
_GRPCSTATUSFILTER._options = None
_METADATAFILTER._options = None
_EXTENSIONFILTER._options = None
# @@protoc_insertion_point(module_scope)
