# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/accesslog/v2/als.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import grpc_service_pb2 as envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/accesslog/v2/als.proto',
  package='envoy.config.accesslog.v2',
  syntax='proto3',
  serialized_options=b'\n\'io.envoyproxy.envoy.config.accesslog.v2B\010AlsProtoP\001\362\230\376\217\005)\022\'envoy.extensions.access_loggers.grpc.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#envoy/config/accesslog/v2/als.proto\x12\x19\x65nvoy.config.accesslog.v2\x1a$envoy/api/v2/core/grpc_service.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xf4\x01\n\x17HttpGrpcAccessLogConfig\x12U\n\rcommon_config\x18\x01 \x01(\x0b\x32\x34.envoy.config.accesslog.v2.CommonGrpcAccessLogConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12)\n!additional_request_headers_to_log\x18\x02 \x03(\t\x12*\n\"additional_response_headers_to_log\x18\x03 \x03(\t\x12+\n#additional_response_trailers_to_log\x18\x04 \x03(\t\"o\n\x16TcpGrpcAccessLogConfig\x12U\n\rcommon_config\x18\x01 \x01(\x0b\x32\x34.envoy.config.accesslog.v2.CommonGrpcAccessLogConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x98\x02\n\x19\x43ommonGrpcAccessLogConfig\x12\x19\n\x08log_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12>\n\x0cgrpc_service\x18\x02 \x01(\x0b\x32\x1e.envoy.api.v2.core.GrpcServiceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x42\n\x15\x62uffer_flush_interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x37\n\x11\x62uffer_size_bytes\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12#\n\x1b\x66ilter_state_objects_to_log\x18\x05 \x03(\tBl\n\'io.envoyproxy.envoy.config.accesslog.v2B\x08\x41lsProtoP\x01\xf2\x98\xfe\x8f\x05)\x12\'envoy.extensions.access_loggers.grpc.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_HTTPGRPCACCESSLOGCONFIG = _descriptor.Descriptor(
  name='HttpGrpcAccessLogConfig',
  full_name='envoy.config.accesslog.v2.HttpGrpcAccessLogConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='common_config', full_name='envoy.config.accesslog.v2.HttpGrpcAccessLogConfig.common_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='additional_request_headers_to_log', full_name='envoy.config.accesslog.v2.HttpGrpcAccessLogConfig.additional_request_headers_to_log', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='additional_response_headers_to_log', full_name='envoy.config.accesslog.v2.HttpGrpcAccessLogConfig.additional_response_headers_to_log', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='additional_response_trailers_to_log', full_name='envoy.config.accesslog.v2.HttpGrpcAccessLogConfig.additional_response_trailers_to_log', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=257,
  serialized_end=501,
)


_TCPGRPCACCESSLOGCONFIG = _descriptor.Descriptor(
  name='TcpGrpcAccessLogConfig',
  full_name='envoy.config.accesslog.v2.TcpGrpcAccessLogConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='common_config', full_name='envoy.config.accesslog.v2.TcpGrpcAccessLogConfig.common_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=503,
  serialized_end=614,
)


_COMMONGRPCACCESSLOGCONFIG = _descriptor.Descriptor(
  name='CommonGrpcAccessLogConfig',
  full_name='envoy.config.accesslog.v2.CommonGrpcAccessLogConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_name', full_name='envoy.config.accesslog.v2.CommonGrpcAccessLogConfig.log_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc_service', full_name='envoy.config.accesslog.v2.CommonGrpcAccessLogConfig.grpc_service', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buffer_flush_interval', full_name='envoy.config.accesslog.v2.CommonGrpcAccessLogConfig.buffer_flush_interval', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buffer_size_bytes', full_name='envoy.config.accesslog.v2.CommonGrpcAccessLogConfig.buffer_size_bytes', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_state_objects_to_log', full_name='envoy.config.accesslog.v2.CommonGrpcAccessLogConfig.filter_state_objects_to_log', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=617,
  serialized_end=897,
)

_HTTPGRPCACCESSLOGCONFIG.fields_by_name['common_config'].message_type = _COMMONGRPCACCESSLOGCONFIG
_TCPGRPCACCESSLOGCONFIG.fields_by_name['common_config'].message_type = _COMMONGRPCACCESSLOGCONFIG
_COMMONGRPCACCESSLOGCONFIG.fields_by_name['grpc_service'].message_type = envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2._GRPCSERVICE
_COMMONGRPCACCESSLOGCONFIG.fields_by_name['buffer_flush_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_COMMONGRPCACCESSLOGCONFIG.fields_by_name['buffer_size_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
DESCRIPTOR.message_types_by_name['HttpGrpcAccessLogConfig'] = _HTTPGRPCACCESSLOGCONFIG
DESCRIPTOR.message_types_by_name['TcpGrpcAccessLogConfig'] = _TCPGRPCACCESSLOGCONFIG
DESCRIPTOR.message_types_by_name['CommonGrpcAccessLogConfig'] = _COMMONGRPCACCESSLOGCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HttpGrpcAccessLogConfig = _reflection.GeneratedProtocolMessageType('HttpGrpcAccessLogConfig', (_message.Message,), {
  'DESCRIPTOR' : _HTTPGRPCACCESSLOGCONFIG,
  '__module__' : 'envoy.config.accesslog.v2.als_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v2.HttpGrpcAccessLogConfig)
  })
_sym_db.RegisterMessage(HttpGrpcAccessLogConfig)

TcpGrpcAccessLogConfig = _reflection.GeneratedProtocolMessageType('TcpGrpcAccessLogConfig', (_message.Message,), {
  'DESCRIPTOR' : _TCPGRPCACCESSLOGCONFIG,
  '__module__' : 'envoy.config.accesslog.v2.als_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v2.TcpGrpcAccessLogConfig)
  })
_sym_db.RegisterMessage(TcpGrpcAccessLogConfig)

CommonGrpcAccessLogConfig = _reflection.GeneratedProtocolMessageType('CommonGrpcAccessLogConfig', (_message.Message,), {
  'DESCRIPTOR' : _COMMONGRPCACCESSLOGCONFIG,
  '__module__' : 'envoy.config.accesslog.v2.als_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v2.CommonGrpcAccessLogConfig)
  })
_sym_db.RegisterMessage(CommonGrpcAccessLogConfig)


DESCRIPTOR._options = None
_HTTPGRPCACCESSLOGCONFIG.fields_by_name['common_config']._options = None
_TCPGRPCACCESSLOGCONFIG.fields_by_name['common_config']._options = None
_COMMONGRPCACCESSLOGCONFIG.fields_by_name['log_name']._options = None
_COMMONGRPCACCESSLOGCONFIG.fields_by_name['grpc_service']._options = None
_COMMONGRPCACCESSLOGCONFIG.fields_by_name['buffer_flush_interval']._options = None
# @@protoc_insertion_point(module_scope)
