# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/matcher/v4alpha/http_inputs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/type/matcher/v4alpha/http_inputs.proto',
  package='envoy.type.matcher.v4alpha',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.type.matcher.v4alphaB\017HttpInputsProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,envoy/type/matcher/v4alpha/http_inputs.proto\x12\x1a\x65nvoy.type.matcher.v4alpha\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"l\n\x1bHttpRequestHeaderMatchInput\x12\x13\n\x0bheader_name\x18\x01 \x01(\t:8\x9a\xc5\x88\x1e\x33\n1envoy.type.matcher.v3.HttpRequestHeaderMatchInput\"n\n\x1cHttpResponseHeaderMatchInput\x12\x13\n\x0bheader_name\x18\x01 \x01(\t:9\x9a\xc5\x88\x1e\x34\n2envoy.type.matcher.v3.HttpResponseHeaderMatchInputBE\n(io.envoyproxy.envoy.type.matcher.v4alphaB\x0fHttpInputsProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_HTTPREQUESTHEADERMATCHINPUT = _descriptor.Descriptor(
  name='HttpRequestHeaderMatchInput',
  full_name='envoy.type.matcher.v4alpha.HttpRequestHeaderMatchInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header_name', full_name='envoy.type.matcher.v4alpha.HttpRequestHeaderMatchInput.header_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0363\n1envoy.type.matcher.v3.HttpRequestHeaderMatchInput',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=142,
  serialized_end=250,
)


_HTTPRESPONSEHEADERMATCHINPUT = _descriptor.Descriptor(
  name='HttpResponseHeaderMatchInput',
  full_name='envoy.type.matcher.v4alpha.HttpResponseHeaderMatchInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header_name', full_name='envoy.type.matcher.v4alpha.HttpResponseHeaderMatchInput.header_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0364\n2envoy.type.matcher.v3.HttpResponseHeaderMatchInput',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=362,
)

DESCRIPTOR.message_types_by_name['HttpRequestHeaderMatchInput'] = _HTTPREQUESTHEADERMATCHINPUT
DESCRIPTOR.message_types_by_name['HttpResponseHeaderMatchInput'] = _HTTPRESPONSEHEADERMATCHINPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HttpRequestHeaderMatchInput = _reflection.GeneratedProtocolMessageType('HttpRequestHeaderMatchInput', (_message.Message,), {
  'DESCRIPTOR' : _HTTPREQUESTHEADERMATCHINPUT,
  '__module__' : 'envoy.type.matcher.v4alpha.http_inputs_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.matcher.v4alpha.HttpRequestHeaderMatchInput)
  })
_sym_db.RegisterMessage(HttpRequestHeaderMatchInput)

HttpResponseHeaderMatchInput = _reflection.GeneratedProtocolMessageType('HttpResponseHeaderMatchInput', (_message.Message,), {
  'DESCRIPTOR' : _HTTPRESPONSEHEADERMATCHINPUT,
  '__module__' : 'envoy.type.matcher.v4alpha.http_inputs_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.matcher.v4alpha.HttpResponseHeaderMatchInput)
  })
_sym_db.RegisterMessage(HttpResponseHeaderMatchInput)


DESCRIPTOR._options = None
_HTTPREQUESTHEADERMATCHINPUT._options = None
_HTTPRESPONSEHEADERMATCHINPUT._options = None
# @@protoc_insertion_point(module_scope)
