# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v4alpha/event_service_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_grpc__service__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/core/v4alpha/event_service_config.proto',
  package='envoy.config.core.v4alpha',
  syntax='proto3',
  serialized_options=b'\n\'io.envoyproxy.envoy.config.core.v4alphaB\027EventServiceConfigProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4envoy/config/core/v4alpha/event_service_config.proto\x12\x19\x65nvoy.config.core.v4alpha\x1a,envoy/config/core/v4alpha/grpc_service.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xa4\x01\n\x12\x45ventServiceConfig\x12>\n\x0cgrpc_service\x18\x01 \x01(\x0b\x32&.envoy.config.core.v4alpha.GrpcServiceH\x00:.\x9a\xc5\x88\x1e)\n\'envoy.config.core.v3.EventServiceConfigB\x1e\n\x17\x63onfig_source_specifier\x12\x03\xf8\x42\x01\x42L\n\'io.envoyproxy.envoy.config.core.v4alphaB\x17\x45ventServiceConfigProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_grpc__service__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_EVENTSERVICECONFIG = _descriptor.Descriptor(
  name='EventServiceConfig',
  full_name='envoy.config.core.v4alpha.EventServiceConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='grpc_service', full_name='envoy.config.core.v4alpha.EventServiceConfig.grpc_service', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036)\n\'envoy.config.core.v3.EventServiceConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_source_specifier', full_name='envoy.config.core.v4alpha.EventServiceConfig.config_source_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=221,
  serialized_end=385,
)

_EVENTSERVICECONFIG.fields_by_name['grpc_service'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_grpc__service__pb2._GRPCSERVICE
_EVENTSERVICECONFIG.oneofs_by_name['config_source_specifier'].fields.append(
  _EVENTSERVICECONFIG.fields_by_name['grpc_service'])
_EVENTSERVICECONFIG.fields_by_name['grpc_service'].containing_oneof = _EVENTSERVICECONFIG.oneofs_by_name['config_source_specifier']
DESCRIPTOR.message_types_by_name['EventServiceConfig'] = _EVENTSERVICECONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EventServiceConfig = _reflection.GeneratedProtocolMessageType('EventServiceConfig', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSERVICECONFIG,
  '__module__' : 'envoy.config.core.v4alpha.event_service_config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v4alpha.EventServiceConfig)
  })
_sym_db.RegisterMessage(EventServiceConfig)


DESCRIPTOR._options = None
_EVENTSERVICECONFIG.oneofs_by_name['config_source_specifier']._options = None
_EVENTSERVICECONFIG._options = None
# @@protoc_insertion_point(module_scope)
