# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/tap/v3/transport.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.data.tap.v3 import common_pb2 as envoy_dot_data_dot_tap_dot_v3_dot_common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/data/tap/v3/transport.proto',
  package='envoy.data.tap.v3',
  syntax='proto3',
  serialized_options=b'\n\037io.envoyproxy.envoy.data.tap.v3B\016TransportProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!envoy/data/tap/v3/transport.proto\x12\x11\x65nvoy.data.tap.v3\x1a\"envoy/config/core/v3/address.proto\x1a\x1e\x65nvoy/data/tap/v3/common.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\xa3\x01\n\nConnection\x12\x34\n\rlocal_address\x18\x02 \x01(\x0b\x32\x1d.envoy.config.core.v3.Address\x12\x35\n\x0eremote_address\x18\x03 \x01(\x0b\x32\x1d.envoy.config.core.v3.Address:(\x9a\xc5\x88\x1e#\n!envoy.data.tap.v2alpha.Connection\"\xae\x04\n\x0bSocketEvent\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x04read\x18\x02 \x01(\x0b\x32#.envoy.data.tap.v3.SocketEvent.ReadH\x00\x12\x35\n\x05write\x18\x03 \x01(\x0b\x32$.envoy.data.tap.v3.SocketEvent.WriteH\x00\x12\x37\n\x06\x63losed\x18\x04 \x01(\x0b\x32%.envoy.data.tap.v3.SocketEvent.ClosedH\x00\x1a]\n\x04Read\x12%\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x17.envoy.data.tap.v3.Body:.\x9a\xc5\x88\x1e)\n\'envoy.data.tap.v2alpha.SocketEvent.Read\x1as\n\x05Write\x12%\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x17.envoy.data.tap.v3.Body\x12\x12\n\nend_stream\x18\x02 \x01(\x08:/\x9a\xc5\x88\x1e*\n(envoy.data.tap.v2alpha.SocketEvent.Write\x1a:\n\x06\x43losed:0\x9a\xc5\x88\x1e+\n)envoy.data.tap.v2alpha.SocketEvent.Closed:)\x9a\xc5\x88\x1e$\n\"envoy.data.tap.v2alpha.SocketEventB\x10\n\x0e\x65vent_selector\"\xee\x01\n\x13SocketBufferedTrace\x12\x10\n\x08trace_id\x18\x01 \x01(\x04\x12\x31\n\nconnection\x18\x02 \x01(\x0b\x32\x1d.envoy.data.tap.v3.Connection\x12.\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x1e.envoy.data.tap.v3.SocketEvent\x12\x16\n\x0eread_truncated\x18\x04 \x01(\x08\x12\x17\n\x0fwrite_truncated\x18\x05 \x01(\x08:1\x9a\xc5\x88\x1e,\n*envoy.data.tap.v2alpha.SocketBufferedTrace\"\xdf\x01\n\x1aSocketStreamedTraceSegment\x12\x10\n\x08trace_id\x18\x01 \x01(\x04\x12\x33\n\nconnection\x18\x02 \x01(\x0b\x32\x1d.envoy.data.tap.v3.ConnectionH\x00\x12/\n\x05\x65vent\x18\x03 \x01(\x0b\x32\x1e.envoy.data.tap.v3.SocketEventH\x00:8\x9a\xc5\x88\x1e\x33\n1envoy.data.tap.v2alpha.SocketStreamedTraceSegmentB\x0f\n\rmessage_pieceB;\n\x1fio.envoyproxy.envoy.data.tap.v3B\x0eTransportProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_address__pb2.DESCRIPTOR,envoy_dot_data_dot_tap_dot_v3_dot_common__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_CONNECTION = _descriptor.Descriptor(
  name='Connection',
  full_name='envoy.data.tap.v3.Connection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='local_address', full_name='envoy.data.tap.v3.Connection.local_address', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote_address', full_name='envoy.data.tap.v3.Connection.remote_address', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036#\n!envoy.data.tap.v2alpha.Connection',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=224,
  serialized_end=387,
)


_SOCKETEVENT_READ = _descriptor.Descriptor(
  name='Read',
  full_name='envoy.data.tap.v3.SocketEvent.Read',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='envoy.data.tap.v3.SocketEvent.Read.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036)\n\'envoy.data.tap.v2alpha.SocketEvent.Read',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=617,
  serialized_end=710,
)

_SOCKETEVENT_WRITE = _descriptor.Descriptor(
  name='Write',
  full_name='envoy.data.tap.v3.SocketEvent.Write',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='envoy.data.tap.v3.SocketEvent.Write.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_stream', full_name='envoy.data.tap.v3.SocketEvent.Write.end_stream', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036*\n(envoy.data.tap.v2alpha.SocketEvent.Write',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=712,
  serialized_end=827,
)

_SOCKETEVENT_CLOSED = _descriptor.Descriptor(
  name='Closed',
  full_name='envoy.data.tap.v3.SocketEvent.Closed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036+\n)envoy.data.tap.v2alpha.SocketEvent.Closed',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=829,
  serialized_end=887,
)

_SOCKETEVENT = _descriptor.Descriptor(
  name='SocketEvent',
  full_name='envoy.data.tap.v3.SocketEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='envoy.data.tap.v3.SocketEvent.timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='read', full_name='envoy.data.tap.v3.SocketEvent.read', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='write', full_name='envoy.data.tap.v3.SocketEvent.write', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='closed', full_name='envoy.data.tap.v3.SocketEvent.closed', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SOCKETEVENT_READ, _SOCKETEVENT_WRITE, _SOCKETEVENT_CLOSED, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036$\n\"envoy.data.tap.v2alpha.SocketEvent',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='event_selector', full_name='envoy.data.tap.v3.SocketEvent.event_selector',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=390,
  serialized_end=948,
)


_SOCKETBUFFEREDTRACE = _descriptor.Descriptor(
  name='SocketBufferedTrace',
  full_name='envoy.data.tap.v3.SocketBufferedTrace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trace_id', full_name='envoy.data.tap.v3.SocketBufferedTrace.trace_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='envoy.data.tap.v3.SocketBufferedTrace.connection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='events', full_name='envoy.data.tap.v3.SocketBufferedTrace.events', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='read_truncated', full_name='envoy.data.tap.v3.SocketBufferedTrace.read_truncated', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='write_truncated', full_name='envoy.data.tap.v3.SocketBufferedTrace.write_truncated', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036,\n*envoy.data.tap.v2alpha.SocketBufferedTrace',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=951,
  serialized_end=1189,
)


_SOCKETSTREAMEDTRACESEGMENT = _descriptor.Descriptor(
  name='SocketStreamedTraceSegment',
  full_name='envoy.data.tap.v3.SocketStreamedTraceSegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trace_id', full_name='envoy.data.tap.v3.SocketStreamedTraceSegment.trace_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='envoy.data.tap.v3.SocketStreamedTraceSegment.connection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event', full_name='envoy.data.tap.v3.SocketStreamedTraceSegment.event', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0363\n1envoy.data.tap.v2alpha.SocketStreamedTraceSegment',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message_piece', full_name='envoy.data.tap.v3.SocketStreamedTraceSegment.message_piece',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1192,
  serialized_end=1415,
)

_CONNECTION.fields_by_name['local_address'].message_type = envoy_dot_config_dot_core_dot_v3_dot_address__pb2._ADDRESS
_CONNECTION.fields_by_name['remote_address'].message_type = envoy_dot_config_dot_core_dot_v3_dot_address__pb2._ADDRESS
_SOCKETEVENT_READ.fields_by_name['data'].message_type = envoy_dot_data_dot_tap_dot_v3_dot_common__pb2._BODY
_SOCKETEVENT_READ.containing_type = _SOCKETEVENT
_SOCKETEVENT_WRITE.fields_by_name['data'].message_type = envoy_dot_data_dot_tap_dot_v3_dot_common__pb2._BODY
_SOCKETEVENT_WRITE.containing_type = _SOCKETEVENT
_SOCKETEVENT_CLOSED.containing_type = _SOCKETEVENT
_SOCKETEVENT.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SOCKETEVENT.fields_by_name['read'].message_type = _SOCKETEVENT_READ
_SOCKETEVENT.fields_by_name['write'].message_type = _SOCKETEVENT_WRITE
_SOCKETEVENT.fields_by_name['closed'].message_type = _SOCKETEVENT_CLOSED
_SOCKETEVENT.oneofs_by_name['event_selector'].fields.append(
  _SOCKETEVENT.fields_by_name['read'])
_SOCKETEVENT.fields_by_name['read'].containing_oneof = _SOCKETEVENT.oneofs_by_name['event_selector']
_SOCKETEVENT.oneofs_by_name['event_selector'].fields.append(
  _SOCKETEVENT.fields_by_name['write'])
_SOCKETEVENT.fields_by_name['write'].containing_oneof = _SOCKETEVENT.oneofs_by_name['event_selector']
_SOCKETEVENT.oneofs_by_name['event_selector'].fields.append(
  _SOCKETEVENT.fields_by_name['closed'])
_SOCKETEVENT.fields_by_name['closed'].containing_oneof = _SOCKETEVENT.oneofs_by_name['event_selector']
_SOCKETBUFFEREDTRACE.fields_by_name['connection'].message_type = _CONNECTION
_SOCKETBUFFEREDTRACE.fields_by_name['events'].message_type = _SOCKETEVENT
_SOCKETSTREAMEDTRACESEGMENT.fields_by_name['connection'].message_type = _CONNECTION
_SOCKETSTREAMEDTRACESEGMENT.fields_by_name['event'].message_type = _SOCKETEVENT
_SOCKETSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece'].fields.append(
  _SOCKETSTREAMEDTRACESEGMENT.fields_by_name['connection'])
_SOCKETSTREAMEDTRACESEGMENT.fields_by_name['connection'].containing_oneof = _SOCKETSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece']
_SOCKETSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece'].fields.append(
  _SOCKETSTREAMEDTRACESEGMENT.fields_by_name['event'])
_SOCKETSTREAMEDTRACESEGMENT.fields_by_name['event'].containing_oneof = _SOCKETSTREAMEDTRACESEGMENT.oneofs_by_name['message_piece']
DESCRIPTOR.message_types_by_name['Connection'] = _CONNECTION
DESCRIPTOR.message_types_by_name['SocketEvent'] = _SOCKETEVENT
DESCRIPTOR.message_types_by_name['SocketBufferedTrace'] = _SOCKETBUFFEREDTRACE
DESCRIPTOR.message_types_by_name['SocketStreamedTraceSegment'] = _SOCKETSTREAMEDTRACESEGMENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Connection = _reflection.GeneratedProtocolMessageType('Connection', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTION,
  '__module__' : 'envoy.data.tap.v3.transport_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.tap.v3.Connection)
  })
_sym_db.RegisterMessage(Connection)

SocketEvent = _reflection.GeneratedProtocolMessageType('SocketEvent', (_message.Message,), {

  'Read' : _reflection.GeneratedProtocolMessageType('Read', (_message.Message,), {
    'DESCRIPTOR' : _SOCKETEVENT_READ,
    '__module__' : 'envoy.data.tap.v3.transport_pb2'
    # @@protoc_insertion_point(class_scope:envoy.data.tap.v3.SocketEvent.Read)
    })
  ,

  'Write' : _reflection.GeneratedProtocolMessageType('Write', (_message.Message,), {
    'DESCRIPTOR' : _SOCKETEVENT_WRITE,
    '__module__' : 'envoy.data.tap.v3.transport_pb2'
    # @@protoc_insertion_point(class_scope:envoy.data.tap.v3.SocketEvent.Write)
    })
  ,

  'Closed' : _reflection.GeneratedProtocolMessageType('Closed', (_message.Message,), {
    'DESCRIPTOR' : _SOCKETEVENT_CLOSED,
    '__module__' : 'envoy.data.tap.v3.transport_pb2'
    # @@protoc_insertion_point(class_scope:envoy.data.tap.v3.SocketEvent.Closed)
    })
  ,
  'DESCRIPTOR' : _SOCKETEVENT,
  '__module__' : 'envoy.data.tap.v3.transport_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.tap.v3.SocketEvent)
  })
_sym_db.RegisterMessage(SocketEvent)
_sym_db.RegisterMessage(SocketEvent.Read)
_sym_db.RegisterMessage(SocketEvent.Write)
_sym_db.RegisterMessage(SocketEvent.Closed)

SocketBufferedTrace = _reflection.GeneratedProtocolMessageType('SocketBufferedTrace', (_message.Message,), {
  'DESCRIPTOR' : _SOCKETBUFFEREDTRACE,
  '__module__' : 'envoy.data.tap.v3.transport_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.tap.v3.SocketBufferedTrace)
  })
_sym_db.RegisterMessage(SocketBufferedTrace)

SocketStreamedTraceSegment = _reflection.GeneratedProtocolMessageType('SocketStreamedTraceSegment', (_message.Message,), {
  'DESCRIPTOR' : _SOCKETSTREAMEDTRACESEGMENT,
  '__module__' : 'envoy.data.tap.v3.transport_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.tap.v3.SocketStreamedTraceSegment)
  })
_sym_db.RegisterMessage(SocketStreamedTraceSegment)


DESCRIPTOR._options = None
_CONNECTION._options = None
_SOCKETEVENT_READ._options = None
_SOCKETEVENT_WRITE._options = None
_SOCKETEVENT_CLOSED._options = None
_SOCKETEVENT._options = None
_SOCKETBUFFEREDTRACE._options = None
_SOCKETSTREAMEDTRACESEGMENT._options = None
# @@protoc_insertion_point(module_scope)
