# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/dubbo_proxy/router/v3/router.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/network/dubbo_proxy/router/v3/router.proto',
  package='envoy.extensions.filters.network.dubbo_proxy.router.v3',
  syntax='proto3',
  serialized_options=b'\nDio.envoyproxy.envoy.extensions.filters.network.dubbo_proxy.router.v3B\013RouterProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nCenvoy/extensions/filters/network/dubbo_proxy/router/v3/router.proto\x12\x36\x65nvoy.extensions.filters.network.dubbo_proxy.router.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"A\n\x06Router:7\x9a\xc5\x88\x1e\x32\n0envoy.config.filter.dubbo.router.v2alpha1.RouterB]\nDio.envoyproxy.envoy.extensions.filters.network.dubbo_proxy.router.v3B\x0bRouterProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_ROUTER = _descriptor.Descriptor(
  name='Router',
  full_name='envoy.extensions.filters.network.dubbo_proxy.router.v3.Router',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0362\n0envoy.config.filter.dubbo.router.v2alpha1.Router',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=193,
  serialized_end=258,
)

DESCRIPTOR.message_types_by_name['Router'] = _ROUTER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Router = _reflection.GeneratedProtocolMessageType('Router', (_message.Message,), {
  'DESCRIPTOR' : _ROUTER,
  '__module__' : 'envoy.extensions.filters.network.dubbo_proxy.router.v3.router_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.dubbo_proxy.router.v3.Router)
  })
_sym_db.RegisterMessage(Router)


DESCRIPTOR._options = None
_ROUTER._options = None
# @@protoc_insertion_point(module_scope)
