# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/discovery/v3/discovery.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/discovery/v3/discovery.proto',
  package='envoy.service.discovery.v3',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.service.discovery.v3B\016DiscoveryProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*envoy/service/discovery/v3/discovery.proto\x12\x1a\x65nvoy.service.discovery.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x17google/rpc/status.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\xe4\x01\n\x10\x44iscoveryRequest\x12\x14\n\x0cversion_info\x18\x01 \x01(\t\x12(\n\x04node\x18\x02 \x01(\x0b\x32\x1a.envoy.config.core.v3.Node\x12\x16\n\x0eresource_names\x18\x03 \x03(\t\x12\x10\n\x08type_url\x18\x04 \x01(\t\x12\x16\n\x0eresponse_nonce\x18\x05 \x01(\t\x12(\n\x0c\x65rror_detail\x18\x06 \x01(\x0b\x32\x12.google.rpc.Status:$\x9a\xc5\x88\x1e\x1f\n\x1d\x65nvoy.api.v2.DiscoveryRequest\"\xe5\x01\n\x11\x44iscoveryResponse\x12\x14\n\x0cversion_info\x18\x01 \x01(\t\x12\'\n\tresources\x18\x02 \x03(\x0b\x32\x14.google.protobuf.Any\x12\x0e\n\x06\x63\x61nary\x18\x03 \x01(\x08\x12\x10\n\x08type_url\x18\x04 \x01(\t\x12\r\n\x05nonce\x18\x05 \x01(\t\x12\x39\n\rcontrol_plane\x18\x06 \x01(\x0b\x32\".envoy.config.core.v3.ControlPlane:%\x9a\xc5\x88\x1e \n\x1e\x65nvoy.api.v2.DiscoveryResponse\"\xb9\x03\n\x15\x44\x65ltaDiscoveryRequest\x12(\n\x04node\x18\x01 \x01(\x0b\x32\x1a.envoy.config.core.v3.Node\x12\x10\n\x08type_url\x18\x02 \x01(\t\x12 \n\x18resource_names_subscribe\x18\x03 \x03(\t\x12\"\n\x1aresource_names_unsubscribe\x18\x04 \x03(\t\x12q\n\x19initial_resource_versions\x18\x05 \x03(\x0b\x32N.envoy.service.discovery.v3.DeltaDiscoveryRequest.InitialResourceVersionsEntry\x12\x16\n\x0eresponse_nonce\x18\x06 \x01(\t\x12(\n\x0c\x65rror_detail\x18\x07 \x01(\x0b\x32\x12.google.rpc.Status\x1a>\n\x1cInitialResourceVersionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:)\x9a\xc5\x88\x1e$\n\"envoy.api.v2.DeltaDiscoveryRequest\"\x91\x02\n\x16\x44\x65ltaDiscoveryResponse\x12\x1b\n\x13system_version_info\x18\x01 \x01(\t\x12\x37\n\tresources\x18\x02 \x03(\x0b\x32$.envoy.service.discovery.v3.Resource\x12\x10\n\x08type_url\x18\x04 \x01(\t\x12\x19\n\x11removed_resources\x18\x06 \x03(\t\x12\r\n\x05nonce\x18\x05 \x01(\t\x12\x39\n\rcontrol_plane\x18\x07 \x01(\x0b\x32\".envoy.config.core.v3.ControlPlane:*\x9a\xc5\x88\x1e%\n#envoy.api.v2.DeltaDiscoveryResponse\"\x98\x02\n\x08Resource\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07\x61liases\x18\x04 \x03(\t\x12\x0f\n\x07version\x18\x01 \x01(\t\x12&\n\x08resource\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12&\n\x03ttl\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12H\n\rcache_control\x18\x07 \x01(\x0b\x32\x31.envoy.service.discovery.v3.Resource.CacheControl\x1a$\n\x0c\x43\x61\x63heControl\x12\x14\n\x0c\x64o_not_cache\x18\x01 \x01(\x08:\x1c\x9a\xc5\x88\x1e\x17\n\x15\x65nvoy.api.v2.ResourceBD\n(io.envoyproxy.envoy.service.discovery.v3B\x0e\x44iscoveryProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_DISCOVERYREQUEST = _descriptor.Descriptor(
  name='DiscoveryRequest',
  full_name='envoy.service.discovery.v3.DiscoveryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version_info', full_name='envoy.service.discovery.v3.DiscoveryRequest.version_info', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node', full_name='envoy.service.discovery.v3.DiscoveryRequest.node', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_names', full_name='envoy.service.discovery.v3.DiscoveryRequest.resource_names', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_url', full_name='envoy.service.discovery.v3.DiscoveryRequest.type_url', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_nonce', full_name='envoy.service.discovery.v3.DiscoveryRequest.response_nonce', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_detail', full_name='envoy.service.discovery.v3.DiscoveryRequest.error_detail', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\037\n\035envoy.api.v2.DiscoveryRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=258,
  serialized_end=486,
)


_DISCOVERYRESPONSE = _descriptor.Descriptor(
  name='DiscoveryResponse',
  full_name='envoy.service.discovery.v3.DiscoveryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version_info', full_name='envoy.service.discovery.v3.DiscoveryResponse.version_info', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='envoy.service.discovery.v3.DiscoveryResponse.resources', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='canary', full_name='envoy.service.discovery.v3.DiscoveryResponse.canary', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_url', full_name='envoy.service.discovery.v3.DiscoveryResponse.type_url', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='envoy.service.discovery.v3.DiscoveryResponse.nonce', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='control_plane', full_name='envoy.service.discovery.v3.DiscoveryResponse.control_plane', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036 \n\036envoy.api.v2.DiscoveryResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=489,
  serialized_end=718,
)


_DELTADISCOVERYREQUEST_INITIALRESOURCEVERSIONSENTRY = _descriptor.Descriptor(
  name='InitialResourceVersionsEntry',
  full_name='envoy.service.discovery.v3.DeltaDiscoveryRequest.InitialResourceVersionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.service.discovery.v3.DeltaDiscoveryRequest.InitialResourceVersionsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.service.discovery.v3.DeltaDiscoveryRequest.InitialResourceVersionsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1057,
  serialized_end=1119,
)

_DELTADISCOVERYREQUEST = _descriptor.Descriptor(
  name='DeltaDiscoveryRequest',
  full_name='envoy.service.discovery.v3.DeltaDiscoveryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='envoy.service.discovery.v3.DeltaDiscoveryRequest.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_url', full_name='envoy.service.discovery.v3.DeltaDiscoveryRequest.type_url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_names_subscribe', full_name='envoy.service.discovery.v3.DeltaDiscoveryRequest.resource_names_subscribe', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_names_unsubscribe', full_name='envoy.service.discovery.v3.DeltaDiscoveryRequest.resource_names_unsubscribe', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_resource_versions', full_name='envoy.service.discovery.v3.DeltaDiscoveryRequest.initial_resource_versions', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_nonce', full_name='envoy.service.discovery.v3.DeltaDiscoveryRequest.response_nonce', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_detail', full_name='envoy.service.discovery.v3.DeltaDiscoveryRequest.error_detail', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DELTADISCOVERYREQUEST_INITIALRESOURCEVERSIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036$\n\"envoy.api.v2.DeltaDiscoveryRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=721,
  serialized_end=1162,
)


_DELTADISCOVERYRESPONSE = _descriptor.Descriptor(
  name='DeltaDiscoveryResponse',
  full_name='envoy.service.discovery.v3.DeltaDiscoveryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='system_version_info', full_name='envoy.service.discovery.v3.DeltaDiscoveryResponse.system_version_info', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='envoy.service.discovery.v3.DeltaDiscoveryResponse.resources', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_url', full_name='envoy.service.discovery.v3.DeltaDiscoveryResponse.type_url', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='removed_resources', full_name='envoy.service.discovery.v3.DeltaDiscoveryResponse.removed_resources', index=3,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='envoy.service.discovery.v3.DeltaDiscoveryResponse.nonce', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='control_plane', full_name='envoy.service.discovery.v3.DeltaDiscoveryResponse.control_plane', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036%\n#envoy.api.v2.DeltaDiscoveryResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1165,
  serialized_end=1438,
)


_RESOURCE_CACHECONTROL = _descriptor.Descriptor(
  name='CacheControl',
  full_name='envoy.service.discovery.v3.Resource.CacheControl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='do_not_cache', full_name='envoy.service.discovery.v3.Resource.CacheControl.do_not_cache', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1655,
  serialized_end=1691,
)

_RESOURCE = _descriptor.Descriptor(
  name='Resource',
  full_name='envoy.service.discovery.v3.Resource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.service.discovery.v3.Resource.name', index=0,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aliases', full_name='envoy.service.discovery.v3.Resource.aliases', index=1,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='envoy.service.discovery.v3.Resource.version', index=2,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource', full_name='envoy.service.discovery.v3.Resource.resource', index=3,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ttl', full_name='envoy.service.discovery.v3.Resource.ttl', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cache_control', full_name='envoy.service.discovery.v3.Resource.cache_control', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RESOURCE_CACHECONTROL, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\027\n\025envoy.api.v2.Resource',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1441,
  serialized_end=1721,
)

_DISCOVERYREQUEST.fields_by_name['node'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._NODE
_DISCOVERYREQUEST.fields_by_name['error_detail'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_DISCOVERYRESPONSE.fields_by_name['resources'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_DISCOVERYRESPONSE.fields_by_name['control_plane'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._CONTROLPLANE
_DELTADISCOVERYREQUEST_INITIALRESOURCEVERSIONSENTRY.containing_type = _DELTADISCOVERYREQUEST
_DELTADISCOVERYREQUEST.fields_by_name['node'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._NODE
_DELTADISCOVERYREQUEST.fields_by_name['initial_resource_versions'].message_type = _DELTADISCOVERYREQUEST_INITIALRESOURCEVERSIONSENTRY
_DELTADISCOVERYREQUEST.fields_by_name['error_detail'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_DELTADISCOVERYRESPONSE.fields_by_name['resources'].message_type = _RESOURCE
_DELTADISCOVERYRESPONSE.fields_by_name['control_plane'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._CONTROLPLANE
_RESOURCE_CACHECONTROL.containing_type = _RESOURCE
_RESOURCE.fields_by_name['resource'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_RESOURCE.fields_by_name['ttl'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_RESOURCE.fields_by_name['cache_control'].message_type = _RESOURCE_CACHECONTROL
DESCRIPTOR.message_types_by_name['DiscoveryRequest'] = _DISCOVERYREQUEST
DESCRIPTOR.message_types_by_name['DiscoveryResponse'] = _DISCOVERYRESPONSE
DESCRIPTOR.message_types_by_name['DeltaDiscoveryRequest'] = _DELTADISCOVERYREQUEST
DESCRIPTOR.message_types_by_name['DeltaDiscoveryResponse'] = _DELTADISCOVERYRESPONSE
DESCRIPTOR.message_types_by_name['Resource'] = _RESOURCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DiscoveryRequest = _reflection.GeneratedProtocolMessageType('DiscoveryRequest', (_message.Message,), {
  'DESCRIPTOR' : _DISCOVERYREQUEST,
  '__module__' : 'envoy.service.discovery.v3.discovery_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v3.DiscoveryRequest)
  })
_sym_db.RegisterMessage(DiscoveryRequest)

DiscoveryResponse = _reflection.GeneratedProtocolMessageType('DiscoveryResponse', (_message.Message,), {
  'DESCRIPTOR' : _DISCOVERYRESPONSE,
  '__module__' : 'envoy.service.discovery.v3.discovery_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v3.DiscoveryResponse)
  })
_sym_db.RegisterMessage(DiscoveryResponse)

DeltaDiscoveryRequest = _reflection.GeneratedProtocolMessageType('DeltaDiscoveryRequest', (_message.Message,), {

  'InitialResourceVersionsEntry' : _reflection.GeneratedProtocolMessageType('InitialResourceVersionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DELTADISCOVERYREQUEST_INITIALRESOURCEVERSIONSENTRY,
    '__module__' : 'envoy.service.discovery.v3.discovery_pb2'
    # @@protoc_insertion_point(class_scope:envoy.service.discovery.v3.DeltaDiscoveryRequest.InitialResourceVersionsEntry)
    })
  ,
  'DESCRIPTOR' : _DELTADISCOVERYREQUEST,
  '__module__' : 'envoy.service.discovery.v3.discovery_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v3.DeltaDiscoveryRequest)
  })
_sym_db.RegisterMessage(DeltaDiscoveryRequest)
_sym_db.RegisterMessage(DeltaDiscoveryRequest.InitialResourceVersionsEntry)

DeltaDiscoveryResponse = _reflection.GeneratedProtocolMessageType('DeltaDiscoveryResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELTADISCOVERYRESPONSE,
  '__module__' : 'envoy.service.discovery.v3.discovery_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v3.DeltaDiscoveryResponse)
  })
_sym_db.RegisterMessage(DeltaDiscoveryResponse)

Resource = _reflection.GeneratedProtocolMessageType('Resource', (_message.Message,), {

  'CacheControl' : _reflection.GeneratedProtocolMessageType('CacheControl', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCE_CACHECONTROL,
    '__module__' : 'envoy.service.discovery.v3.discovery_pb2'
    # @@protoc_insertion_point(class_scope:envoy.service.discovery.v3.Resource.CacheControl)
    })
  ,
  'DESCRIPTOR' : _RESOURCE,
  '__module__' : 'envoy.service.discovery.v3.discovery_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v3.Resource)
  })
_sym_db.RegisterMessage(Resource)
_sym_db.RegisterMessage(Resource.CacheControl)


DESCRIPTOR._options = None
_DISCOVERYREQUEST._options = None
_DISCOVERYRESPONSE._options = None
_DELTADISCOVERYREQUEST_INITIALRESOURCEVERSIONSENTRY._options = None
_DELTADISCOVERYREQUEST._options = None
_DELTADISCOVERYRESPONSE._options = None
_RESOURCE._options = None
# @@protoc_insertion_point(module_scope)
