# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/watchdog/v3alpha/abort_action.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/watchdog/v3alpha/abort_action.proto',
  package='envoy.watchdog.v3alpha',
  syntax='proto3',
  serialized_options=b'\n$io.envoyproxy.envoy.watchdog.v3alphaB\020AbortActionProtoP\001\272\200\310\321\006\002\010\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)envoy/watchdog/v3alpha/abort_action.proto\x12\x16\x65nvoy.watchdog.v3alpha\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\"E\n\x11\x41\x62ortActionConfig\x12\x30\n\rwait_duration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationBJ\n$io.envoyproxy.envoy.watchdog.v3alphaB\x10\x41\x62ortActionProtoP\x01\xba\x80\xc8\xd1\x06\x02\x08\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_ABORTACTIONCONFIG = _descriptor.Descriptor(
  name='AbortActionConfig',
  full_name='envoy.watchdog.v3alpha.AbortActionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wait_duration', full_name='envoy.watchdog.v3alpha.AbortActionConfig.wait_duration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=201,
)

_ABORTACTIONCONFIG.fields_by_name['wait_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['AbortActionConfig'] = _ABORTACTIONCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AbortActionConfig = _reflection.GeneratedProtocolMessageType('AbortActionConfig', (_message.Message,), {
  'DESCRIPTOR' : _ABORTACTIONCONFIG,
  '__module__' : 'envoy.watchdog.v3alpha.abort_action_pb2'
  # @@protoc_insertion_point(class_scope:envoy.watchdog.v3alpha.AbortActionConfig)
  })
_sym_db.RegisterMessage(AbortActionConfig)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
