# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/common/dependency/v3/dependency.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/common/dependency/v3/dependency.proto',
  package='envoy.extensions.filters.common.dependency.v3',
  syntax='proto3',
  serialized_options=b'\n;io.envoyproxy.envoy.extensions.filters.common.dependency.v3B\017DependencyProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n>envoy/extensions/filters/common/dependency/v3/dependency.proto\x12-envoy.extensions.filters.common.dependency.v3\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xc5\x01\n\nDependency\x12V\n\x04type\x18\x01 \x01(\x0e\x32H.envoy.extensions.filters.common.dependency.v3.Dependency.DependencyType\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"H\n\x0e\x44\x65pendencyType\x12\n\n\x06HEADER\x10\x00\x12\x14\n\x10\x46ILTER_STATE_KEY\x10\x01\x12\x14\n\x10\x44YNAMIC_METADATA\x10\x02\"\xe4\x02\n\x12\x46ilterDependencies\x12R\n\x0f\x64\x65\x63ode_required\x18\x01 \x03(\x0b\x32\x39.envoy.extensions.filters.common.dependency.v3.Dependency\x12R\n\x0f\x64\x65\x63ode_provided\x18\x02 \x03(\x0b\x32\x39.envoy.extensions.filters.common.dependency.v3.Dependency\x12R\n\x0f\x65ncode_required\x18\x03 \x03(\x0b\x32\x39.envoy.extensions.filters.common.dependency.v3.Dependency\x12R\n\x0f\x65ncode_provided\x18\x04 \x03(\x0b\x32\x39.envoy.extensions.filters.common.dependency.v3.DependencyBX\n;io.envoyproxy.envoy.extensions.filters.common.dependency.v3B\x0f\x44\x65pendencyProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_DEPENDENCY_DEPENDENCYTYPE = _descriptor.EnumDescriptor(
  name='DependencyType',
  full_name='envoy.extensions.filters.common.dependency.v3.Dependency.DependencyType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HEADER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FILTER_STATE_KEY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DYNAMIC_METADATA', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=295,
  serialized_end=367,
)
_sym_db.RegisterEnumDescriptor(_DEPENDENCY_DEPENDENCYTYPE)


_DEPENDENCY = _descriptor.Descriptor(
  name='Dependency',
  full_name='envoy.extensions.filters.common.dependency.v3.Dependency',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='envoy.extensions.filters.common.dependency.v3.Dependency.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.extensions.filters.common.dependency.v3.Dependency.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DEPENDENCY_DEPENDENCYTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=170,
  serialized_end=367,
)


_FILTERDEPENDENCIES = _descriptor.Descriptor(
  name='FilterDependencies',
  full_name='envoy.extensions.filters.common.dependency.v3.FilterDependencies',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='decode_required', full_name='envoy.extensions.filters.common.dependency.v3.FilterDependencies.decode_required', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decode_provided', full_name='envoy.extensions.filters.common.dependency.v3.FilterDependencies.decode_provided', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encode_required', full_name='envoy.extensions.filters.common.dependency.v3.FilterDependencies.encode_required', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encode_provided', full_name='envoy.extensions.filters.common.dependency.v3.FilterDependencies.encode_provided', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=370,
  serialized_end=726,
)

_DEPENDENCY.fields_by_name['type'].enum_type = _DEPENDENCY_DEPENDENCYTYPE
_DEPENDENCY_DEPENDENCYTYPE.containing_type = _DEPENDENCY
_FILTERDEPENDENCIES.fields_by_name['decode_required'].message_type = _DEPENDENCY
_FILTERDEPENDENCIES.fields_by_name['decode_provided'].message_type = _DEPENDENCY
_FILTERDEPENDENCIES.fields_by_name['encode_required'].message_type = _DEPENDENCY
_FILTERDEPENDENCIES.fields_by_name['encode_provided'].message_type = _DEPENDENCY
DESCRIPTOR.message_types_by_name['Dependency'] = _DEPENDENCY
DESCRIPTOR.message_types_by_name['FilterDependencies'] = _FILTERDEPENDENCIES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Dependency = _reflection.GeneratedProtocolMessageType('Dependency', (_message.Message,), {
  'DESCRIPTOR' : _DEPENDENCY,
  '__module__' : 'envoy.extensions.filters.common.dependency.v3.dependency_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.common.dependency.v3.Dependency)
  })
_sym_db.RegisterMessage(Dependency)

FilterDependencies = _reflection.GeneratedProtocolMessageType('FilterDependencies', (_message.Message,), {
  'DESCRIPTOR' : _FILTERDEPENDENCIES,
  '__module__' : 'envoy.extensions.filters.common.dependency.v3.dependency_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.common.dependency.v3.FilterDependencies)
  })
_sym_db.RegisterMessage(FilterDependencies)


DESCRIPTOR._options = None
_DEPENDENCY.fields_by_name['name']._options = None
# @@protoc_insertion_point(module_scope)
