# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v3/init_dump.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/admin/v3/init_dump.proto',
  package='envoy.admin.v3',
  syntax='proto3',
  serialized_options=b'\n\034io.envoyproxy.envoy.admin.v3B\rInitDumpProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65nvoy/admin/v3/init_dump.proto\x12\x0e\x65nvoy.admin.v3\x1a\x1dudpa/annotations/status.proto\"\xa6\x01\n\x13UnreadyTargetsDumps\x12U\n\x15unready_targets_dumps\x18\x01 \x03(\x0b\x32\x36.envoy.admin.v3.UnreadyTargetsDumps.UnreadyTargetsDump\x1a\x38\n\x12UnreadyTargetsDump\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0ctarget_names\x18\x02 \x03(\tB7\n\x1cio.envoyproxy.envoy.admin.v3B\rInitDumpProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_UNREADYTARGETSDUMPS_UNREADYTARGETSDUMP = _descriptor.Descriptor(
  name='UnreadyTargetsDump',
  full_name='envoy.admin.v3.UnreadyTargetsDumps.UnreadyTargetsDump',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.admin.v3.UnreadyTargetsDumps.UnreadyTargetsDump.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_names', full_name='envoy.admin.v3.UnreadyTargetsDumps.UnreadyTargetsDump.target_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=192,
  serialized_end=248,
)

_UNREADYTARGETSDUMPS = _descriptor.Descriptor(
  name='UnreadyTargetsDumps',
  full_name='envoy.admin.v3.UnreadyTargetsDumps',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unready_targets_dumps', full_name='envoy.admin.v3.UnreadyTargetsDumps.unready_targets_dumps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UNREADYTARGETSDUMPS_UNREADYTARGETSDUMP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=82,
  serialized_end=248,
)

_UNREADYTARGETSDUMPS_UNREADYTARGETSDUMP.containing_type = _UNREADYTARGETSDUMPS
_UNREADYTARGETSDUMPS.fields_by_name['unready_targets_dumps'].message_type = _UNREADYTARGETSDUMPS_UNREADYTARGETSDUMP
DESCRIPTOR.message_types_by_name['UnreadyTargetsDumps'] = _UNREADYTARGETSDUMPS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UnreadyTargetsDumps = _reflection.GeneratedProtocolMessageType('UnreadyTargetsDumps', (_message.Message,), {

  'UnreadyTargetsDump' : _reflection.GeneratedProtocolMessageType('UnreadyTargetsDump', (_message.Message,), {
    'DESCRIPTOR' : _UNREADYTARGETSDUMPS_UNREADYTARGETSDUMP,
    '__module__' : 'envoy.admin.v3.init_dump_pb2'
    # @@protoc_insertion_point(class_scope:envoy.admin.v3.UnreadyTargetsDumps.UnreadyTargetsDump)
    })
  ,
  'DESCRIPTOR' : _UNREADYTARGETSDUMPS,
  '__module__' : 'envoy.admin.v3.init_dump_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v3.UnreadyTargetsDumps)
  })
_sym_db.RegisterMessage(UnreadyTargetsDumps)
_sym_db.RegisterMessage(UnreadyTargetsDumps.UnreadyTargetsDump)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
