# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/access_loggers/file/v3/file.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import substitution_format_string_pb2 as envoy_dot_config_dot_core_dot_v3_dot_substitution__format__string__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/access_loggers/file/v3/file.proto',
  package='envoy.extensions.access_loggers.file.v3',
  syntax='proto3',
  serialized_options=b'\n5io.envoyproxy.envoy.extensions.access_loggers.file.v3B\tFileProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2envoy/extensions/access_loggers/file/v3/file.proto\x12\'envoy.extensions.access_loggers.file.v3\x1a\x35\x65nvoy/config/core/v3/substitution_format_string.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xbf\x02\n\rFileAccessLog\x12\x15\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x14\n\x06\x66ormat\x18\x02 \x01(\tB\x02\x18\x01H\x00\x12\x32\n\x0bjson_format\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12\x38\n\x11typed_json_format\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12N\n\nlog_format\x18\x05 \x01(\x0b\x32..envoy.config.core.v3.SubstitutionFormatStringB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00:.\x9a\xc5\x88\x1e)\n\'envoy.config.accesslog.v2.FileAccessLogB\x13\n\x11\x61\x63\x63\x65ss_log_formatBL\n5io.envoyproxy.envoy.extensions.access_loggers.file.v3B\tFileProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_substitution__format__string__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_FILEACCESSLOG = _descriptor.Descriptor(
  name='FileAccessLog',
  full_name='envoy.extensions.access_loggers.file.v3.FileAccessLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='envoy.extensions.access_loggers.file.v3.FileAccessLog.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format', full_name='envoy.extensions.access_loggers.file.v3.FileAccessLog.format', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='json_format', full_name='envoy.extensions.access_loggers.file.v3.FileAccessLog.json_format', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_json_format', full_name='envoy.extensions.access_loggers.file.v3.FileAccessLog.typed_json_format', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_format', full_name='envoy.extensions.access_loggers.file.v3.FileAccessLog.log_format', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036)\n\'envoy.config.accesslog.v2.FileAccessLog',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='access_log_format', full_name='envoy.extensions.access_loggers.file.v3.FileAccessLog.access_log_format',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=272,
  serialized_end=591,
)

_FILEACCESSLOG.fields_by_name['json_format'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_FILEACCESSLOG.fields_by_name['typed_json_format'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_FILEACCESSLOG.fields_by_name['log_format'].message_type = envoy_dot_config_dot_core_dot_v3_dot_substitution__format__string__pb2._SUBSTITUTIONFORMATSTRING
_FILEACCESSLOG.oneofs_by_name['access_log_format'].fields.append(
  _FILEACCESSLOG.fields_by_name['format'])
_FILEACCESSLOG.fields_by_name['format'].containing_oneof = _FILEACCESSLOG.oneofs_by_name['access_log_format']
_FILEACCESSLOG.oneofs_by_name['access_log_format'].fields.append(
  _FILEACCESSLOG.fields_by_name['json_format'])
_FILEACCESSLOG.fields_by_name['json_format'].containing_oneof = _FILEACCESSLOG.oneofs_by_name['access_log_format']
_FILEACCESSLOG.oneofs_by_name['access_log_format'].fields.append(
  _FILEACCESSLOG.fields_by_name['typed_json_format'])
_FILEACCESSLOG.fields_by_name['typed_json_format'].containing_oneof = _FILEACCESSLOG.oneofs_by_name['access_log_format']
_FILEACCESSLOG.oneofs_by_name['access_log_format'].fields.append(
  _FILEACCESSLOG.fields_by_name['log_format'])
_FILEACCESSLOG.fields_by_name['log_format'].containing_oneof = _FILEACCESSLOG.oneofs_by_name['access_log_format']
DESCRIPTOR.message_types_by_name['FileAccessLog'] = _FILEACCESSLOG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FileAccessLog = _reflection.GeneratedProtocolMessageType('FileAccessLog', (_message.Message,), {
  'DESCRIPTOR' : _FILEACCESSLOG,
  '__module__' : 'envoy.extensions.access_loggers.file.v3.file_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.access_loggers.file.v3.FileAccessLog)
  })
_sym_db.RegisterMessage(FileAccessLog)


DESCRIPTOR._options = None
_FILEACCESSLOG.fields_by_name['path']._options = None
_FILEACCESSLOG.fields_by_name['format']._options = None
_FILEACCESSLOG.fields_by_name['json_format']._options = None
_FILEACCESSLOG.fields_by_name['typed_json_format']._options = None
_FILEACCESSLOG.fields_by_name['log_format']._options = None
_FILEACCESSLOG._options = None
# @@protoc_insertion_point(module_scope)
