# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/auth/secret.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.auth import common_pb2 as envoy_dot_api_dot_v2_dot_auth_dot_common__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import config_source_pb2 as envoy_dot_api_dot_v2_dot_core_dot_config__source__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/auth/secret.proto',
  package='envoy.api.v2.auth',
  syntax='proto3',
  serialized_options=b'\n\037io.envoyproxy.envoy.api.v2.authB\013SecretProtoP\001\362\230\376\217\005+\022)envoy.extensions.transport_sockets.tls.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65nvoy/api/v2/auth/secret.proto\x12\x11\x65nvoy.api.v2.auth\x1a\x1e\x65nvoy/api/v2/auth/common.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a%envoy/api/v2/core/config_source.proto\x1a\x1eudpa/annotations/migrate.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\"F\n\rGenericSecret\x12\x35\n\x06secret\x18\x01 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\"T\n\x0fSdsSecretConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x33\n\nsds_config\x18\x02 \x01(\x0b\x32\x1f.envoy.api.v2.core.ConfigSource\"\xaf\x02\n\x06Secret\x12\x0c\n\x04name\x18\x01 \x01(\t\x12<\n\x0ftls_certificate\x18\x02 \x01(\x0b\x32!.envoy.api.v2.auth.TlsCertificateH\x00\x12\x46\n\x13session_ticket_keys\x18\x03 \x01(\x0b\x32\'.envoy.api.v2.auth.TlsSessionTicketKeysH\x00\x12M\n\x12validation_context\x18\x04 \x01(\x0b\x32/.envoy.api.v2.auth.CertificateValidationContextH\x00\x12:\n\x0egeneric_secret\x18\x05 \x01(\x0b\x32 .envoy.api.v2.auth.GenericSecretH\x00\x42\x06\n\x04typeBi\n\x1fio.envoyproxy.envoy.api.v2.authB\x0bSecretProtoP\x01\xf2\x98\xfe\x8f\x05+\x12)envoy.extensions.transport_sockets.tls.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_auth_dot_common__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_config__source__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_sensitive__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_GENERICSECRET = _descriptor.Descriptor(
  name='GenericSecret',
  full_name='envoy.api.v2.auth.GenericSecret',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='secret', full_name='envoy.api.v2.auth.GenericSecret.secret', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=321,
)


_SDSSECRETCONFIG = _descriptor.Descriptor(
  name='SdsSecretConfig',
  full_name='envoy.api.v2.auth.SdsSecretConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.api.v2.auth.SdsSecretConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sds_config', full_name='envoy.api.v2.auth.SdsSecretConfig.sds_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=323,
  serialized_end=407,
)


_SECRET = _descriptor.Descriptor(
  name='Secret',
  full_name='envoy.api.v2.auth.Secret',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.api.v2.auth.Secret.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls_certificate', full_name='envoy.api.v2.auth.Secret.tls_certificate', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_ticket_keys', full_name='envoy.api.v2.auth.Secret.session_ticket_keys', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validation_context', full_name='envoy.api.v2.auth.Secret.validation_context', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='generic_secret', full_name='envoy.api.v2.auth.Secret.generic_secret', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='envoy.api.v2.auth.Secret.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=410,
  serialized_end=713,
)

_GENERICSECRET.fields_by_name['secret'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_SDSSECRETCONFIG.fields_by_name['sds_config'].message_type = envoy_dot_api_dot_v2_dot_core_dot_config__source__pb2._CONFIGSOURCE
_SECRET.fields_by_name['tls_certificate'].message_type = envoy_dot_api_dot_v2_dot_auth_dot_common__pb2._TLSCERTIFICATE
_SECRET.fields_by_name['session_ticket_keys'].message_type = envoy_dot_api_dot_v2_dot_auth_dot_common__pb2._TLSSESSIONTICKETKEYS
_SECRET.fields_by_name['validation_context'].message_type = envoy_dot_api_dot_v2_dot_auth_dot_common__pb2._CERTIFICATEVALIDATIONCONTEXT
_SECRET.fields_by_name['generic_secret'].message_type = _GENERICSECRET
_SECRET.oneofs_by_name['type'].fields.append(
  _SECRET.fields_by_name['tls_certificate'])
_SECRET.fields_by_name['tls_certificate'].containing_oneof = _SECRET.oneofs_by_name['type']
_SECRET.oneofs_by_name['type'].fields.append(
  _SECRET.fields_by_name['session_ticket_keys'])
_SECRET.fields_by_name['session_ticket_keys'].containing_oneof = _SECRET.oneofs_by_name['type']
_SECRET.oneofs_by_name['type'].fields.append(
  _SECRET.fields_by_name['validation_context'])
_SECRET.fields_by_name['validation_context'].containing_oneof = _SECRET.oneofs_by_name['type']
_SECRET.oneofs_by_name['type'].fields.append(
  _SECRET.fields_by_name['generic_secret'])
_SECRET.fields_by_name['generic_secret'].containing_oneof = _SECRET.oneofs_by_name['type']
DESCRIPTOR.message_types_by_name['GenericSecret'] = _GENERICSECRET
DESCRIPTOR.message_types_by_name['SdsSecretConfig'] = _SDSSECRETCONFIG
DESCRIPTOR.message_types_by_name['Secret'] = _SECRET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GenericSecret = _reflection.GeneratedProtocolMessageType('GenericSecret', (_message.Message,), {
  'DESCRIPTOR' : _GENERICSECRET,
  '__module__' : 'envoy.api.v2.auth.secret_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.auth.GenericSecret)
  })
_sym_db.RegisterMessage(GenericSecret)

SdsSecretConfig = _reflection.GeneratedProtocolMessageType('SdsSecretConfig', (_message.Message,), {
  'DESCRIPTOR' : _SDSSECRETCONFIG,
  '__module__' : 'envoy.api.v2.auth.secret_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.auth.SdsSecretConfig)
  })
_sym_db.RegisterMessage(SdsSecretConfig)

Secret = _reflection.GeneratedProtocolMessageType('Secret', (_message.Message,), {
  'DESCRIPTOR' : _SECRET,
  '__module__' : 'envoy.api.v2.auth.secret_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.auth.Secret)
  })
_sym_db.RegisterMessage(Secret)


DESCRIPTOR._options = None
_GENERICSECRET.fields_by_name['secret']._options = None
# @@protoc_insertion_point(module_scope)
