# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/transport_sockets/tls/v3/cert.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.transport_sockets.tls.v3 import common_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_common__pb2
from envoy.extensions.transport_sockets.tls.v3 import secret_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_secret__pb2
from envoy.extensions.transport_sockets.tls.v3 import tls_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_tls__pb2

from envoy.extensions.transport_sockets.tls.v3.common_pb2 import *
from envoy.extensions.transport_sockets.tls.v3.secret_pb2 import *
from envoy.extensions.transport_sockets.tls.v3.tls_pb2 import *

DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/transport_sockets/tls/v3/cert.proto',
  package='envoy.extensions.transport_sockets.tls.v3',
  syntax='proto3',
  serialized_options=b'\n7io.envoyproxy.envoy.extensions.transport_sockets.tls.v3B\tCertProtoP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4envoy/extensions/transport_sockets/tls/v3/cert.proto\x12)envoy.extensions.transport_sockets.tls.v3\x1a\x36\x65nvoy/extensions/transport_sockets/tls/v3/common.proto\x1a\x36\x65nvoy/extensions/transport_sockets/tls/v3/secret.proto\x1a\x33\x65nvoy/extensions/transport_sockets/tls/v3/tls.protoBF\n7io.envoyproxy.envoy.extensions.transport_sockets.tls.v3B\tCertProtoP\x01P\x00P\x01P\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_common__pb2.DESCRIPTOR,envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_secret__pb2.DESCRIPTOR,envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_tls__pb2.DESCRIPTOR,],
  public_dependencies=[envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_common__pb2.DESCRIPTOR,envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_secret__pb2.DESCRIPTOR,envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_tls__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
