# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/listener.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import socket_option_pb2 as envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
from envoy.api.v2.listener import listener_components_pb2 as envoy_dot_api_dot_v2_dot_listener_dot_listener__components__pb2
from envoy.api.v2.listener import udp_listener_config_pb2 as envoy_dot_api_dot_v2_dot_listener_dot_udp__listener__config__pb2
from envoy.config.filter.accesslog.v2 import accesslog_pb2 as envoy_dot_config_dot_filter_dot_accesslog_dot_v2_dot_accesslog__pb2
from envoy.config.listener.v2 import api_listener_pb2 as envoy_dot_config_dot_listener_dot_v2_dot_api__listener__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/listener.proto',
  package='envoy.api.v2',
  syntax='proto3',
  serialized_options=b'\n\032io.envoyproxy.envoy.api.v2B\rListenerProtoP\001\362\230\376\217\005\032\022\030envoy.config.listener.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1b\x65nvoy/api/v2/listener.proto\x12\x0c\x65nvoy.api.v2\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a%envoy/api/v2/core/socket_option.proto\x1a/envoy/api/v2/listener/listener_components.proto\x1a/envoy/api/v2/listener/udp_listener_config.proto\x1a\x30\x65nvoy/config/filter/accesslog/v2/accesslog.proto\x1a+envoy/config/listener/v2/api_listener.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xaa\x0b\n\x08Listener\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x35\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32\x1a.envoy.api.v2.core.AddressB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x39\n\rfilter_chains\x18\x03 \x03(\x0b\x32\".envoy.api.v2.listener.FilterChain\x12\x38\n\x10use_original_dst\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x02\x18\x01\x12G\n!per_connection_buffer_limit_bytes\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12-\n\x08metadata\x18\x06 \x01(\x0b\x32\x1b.envoy.api.v2.core.Metadata\x12:\n\rdeprecated_v1\x18\x07 \x01(\x0b\x32#.envoy.api.v2.Listener.DeprecatedV1\x12\x34\n\ndrain_type\x18\x08 \x01(\x0e\x32 .envoy.api.v2.Listener.DrainType\x12?\n\x10listener_filters\x18\t \x03(\x0b\x32%.envoy.api.v2.listener.ListenerFilter\x12;\n\x18listener_filters_timeout\x18\x0f \x01(\x0b\x32\x19.google.protobuf.Duration\x12,\n$continue_on_listener_filters_timeout\x18\x11 \x01(\x08\x12/\n\x0btransparent\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12,\n\x08\x66reebind\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x0esocket_options\x18\r \x03(\x0b\x32\x1f.envoy.api.v2.core.SocketOption\x12@\n\x1atcp_fast_open_queue_length\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12>\n\x11traffic_direction\x18\x10 \x01(\x0e\x32#.envoy.api.v2.core.TrafficDirection\x12\x45\n\x13udp_listener_config\x18\x12 \x01(\x0b\x32(.envoy.api.v2.listener.UdpListenerConfig\x12;\n\x0c\x61pi_listener\x18\x13 \x01(\x0b\x32%.envoy.config.listener.v2.ApiListener\x12Q\n\x19\x63onnection_balance_config\x18\x14 \x01(\x0b\x32..envoy.api.v2.Listener.ConnectionBalanceConfig\x12\x12\n\nreuse_port\x18\x15 \x01(\x08\x12?\n\naccess_log\x18\x16 \x03(\x0b\x32+.envoy.config.filter.accesslog.v2.AccessLog\x1a@\n\x0c\x44\x65precatedV1\x12\x30\n\x0c\x62ind_to_port\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1a\x94\x01\n\x17\x43onnectionBalanceConfig\x12T\n\rexact_balance\x18\x01 \x01(\x0b\x32;.envoy.api.v2.Listener.ConnectionBalanceConfig.ExactBalanceH\x00\x1a\x0e\n\x0c\x45xactBalanceB\x13\n\x0c\x62\x61lance_type\x12\x03\xf8\x42\x01\")\n\tDrainType\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0f\n\x0bMODIFY_ONLY\x10\x01J\x04\x08\x0e\x10\x0f\x42U\n\x1aio.envoyproxy.envoy.api.v2B\rListenerProtoP\x01\xf2\x98\xfe\x8f\x05\x1a\x12\x18\x65nvoy.config.listener.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_address__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_listener_dot_listener__components__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_listener_dot_udp__listener__config__pb2.DESCRIPTOR,envoy_dot_config_dot_filter_dot_accesslog_dot_v2_dot_accesslog__pb2.DESCRIPTOR,envoy_dot_config_dot_listener_dot_v2_dot_api__listener__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_LISTENER_DRAINTYPE = _descriptor.EnumDescriptor(
  name='DrainType',
  full_name='envoy.api.v2.Listener.DrainType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MODIFY_ONLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1896,
  serialized_end=1937,
)
_sym_db.RegisterEnumDescriptor(_LISTENER_DRAINTYPE)


_LISTENER_DEPRECATEDV1 = _descriptor.Descriptor(
  name='DeprecatedV1',
  full_name='envoy.api.v2.Listener.DeprecatedV1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bind_to_port', full_name='envoy.api.v2.Listener.DeprecatedV1.bind_to_port', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1679,
  serialized_end=1743,
)

_LISTENER_CONNECTIONBALANCECONFIG_EXACTBALANCE = _descriptor.Descriptor(
  name='ExactBalance',
  full_name='envoy.api.v2.Listener.ConnectionBalanceConfig.ExactBalance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1859,
  serialized_end=1873,
)

_LISTENER_CONNECTIONBALANCECONFIG = _descriptor.Descriptor(
  name='ConnectionBalanceConfig',
  full_name='envoy.api.v2.Listener.ConnectionBalanceConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exact_balance', full_name='envoy.api.v2.Listener.ConnectionBalanceConfig.exact_balance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTENER_CONNECTIONBALANCECONFIG_EXACTBALANCE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='balance_type', full_name='envoy.api.v2.Listener.ConnectionBalanceConfig.balance_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1746,
  serialized_end=1894,
)

_LISTENER = _descriptor.Descriptor(
  name='Listener',
  full_name='envoy.api.v2.Listener',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.api.v2.Listener.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='envoy.api.v2.Listener.address', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_chains', full_name='envoy.api.v2.Listener.filter_chains', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_original_dst', full_name='envoy.api.v2.Listener.use_original_dst', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='per_connection_buffer_limit_bytes', full_name='envoy.api.v2.Listener.per_connection_buffer_limit_bytes', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='envoy.api.v2.Listener.metadata', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_v1', full_name='envoy.api.v2.Listener.deprecated_v1', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drain_type', full_name='envoy.api.v2.Listener.drain_type', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listener_filters', full_name='envoy.api.v2.Listener.listener_filters', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listener_filters_timeout', full_name='envoy.api.v2.Listener.listener_filters_timeout', index=9,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='continue_on_listener_filters_timeout', full_name='envoy.api.v2.Listener.continue_on_listener_filters_timeout', index=10,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transparent', full_name='envoy.api.v2.Listener.transparent', index=11,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='freebind', full_name='envoy.api.v2.Listener.freebind', index=12,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='socket_options', full_name='envoy.api.v2.Listener.socket_options', index=13,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tcp_fast_open_queue_length', full_name='envoy.api.v2.Listener.tcp_fast_open_queue_length', index=14,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_direction', full_name='envoy.api.v2.Listener.traffic_direction', index=15,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='udp_listener_config', full_name='envoy.api.v2.Listener.udp_listener_config', index=16,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='api_listener', full_name='envoy.api.v2.Listener.api_listener', index=17,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_balance_config', full_name='envoy.api.v2.Listener.connection_balance_config', index=18,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reuse_port', full_name='envoy.api.v2.Listener.reuse_port', index=19,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_log', full_name='envoy.api.v2.Listener.access_log', index=20,
      number=22, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTENER_DEPRECATEDV1, _LISTENER_CONNECTIONBALANCECONFIG, ],
  enum_types=[
    _LISTENER_DRAINTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=493,
  serialized_end=1943,
)

_LISTENER_DEPRECATEDV1.fields_by_name['bind_to_port'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_LISTENER_DEPRECATEDV1.containing_type = _LISTENER
_LISTENER_CONNECTIONBALANCECONFIG_EXACTBALANCE.containing_type = _LISTENER_CONNECTIONBALANCECONFIG
_LISTENER_CONNECTIONBALANCECONFIG.fields_by_name['exact_balance'].message_type = _LISTENER_CONNECTIONBALANCECONFIG_EXACTBALANCE
_LISTENER_CONNECTIONBALANCECONFIG.containing_type = _LISTENER
_LISTENER_CONNECTIONBALANCECONFIG.oneofs_by_name['balance_type'].fields.append(
  _LISTENER_CONNECTIONBALANCECONFIG.fields_by_name['exact_balance'])
_LISTENER_CONNECTIONBALANCECONFIG.fields_by_name['exact_balance'].containing_oneof = _LISTENER_CONNECTIONBALANCECONFIG.oneofs_by_name['balance_type']
_LISTENER.fields_by_name['address'].message_type = envoy_dot_api_dot_v2_dot_core_dot_address__pb2._ADDRESS
_LISTENER.fields_by_name['filter_chains'].message_type = envoy_dot_api_dot_v2_dot_listener_dot_listener__components__pb2._FILTERCHAIN
_LISTENER.fields_by_name['use_original_dst'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_LISTENER.fields_by_name['per_connection_buffer_limit_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_LISTENER.fields_by_name['metadata'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._METADATA
_LISTENER.fields_by_name['deprecated_v1'].message_type = _LISTENER_DEPRECATEDV1
_LISTENER.fields_by_name['drain_type'].enum_type = _LISTENER_DRAINTYPE
_LISTENER.fields_by_name['listener_filters'].message_type = envoy_dot_api_dot_v2_dot_listener_dot_listener__components__pb2._LISTENERFILTER
_LISTENER.fields_by_name['listener_filters_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_LISTENER.fields_by_name['transparent'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_LISTENER.fields_by_name['freebind'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_LISTENER.fields_by_name['socket_options'].message_type = envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2._SOCKETOPTION
_LISTENER.fields_by_name['tcp_fast_open_queue_length'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_LISTENER.fields_by_name['traffic_direction'].enum_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._TRAFFICDIRECTION
_LISTENER.fields_by_name['udp_listener_config'].message_type = envoy_dot_api_dot_v2_dot_listener_dot_udp__listener__config__pb2._UDPLISTENERCONFIG
_LISTENER.fields_by_name['api_listener'].message_type = envoy_dot_config_dot_listener_dot_v2_dot_api__listener__pb2._APILISTENER
_LISTENER.fields_by_name['connection_balance_config'].message_type = _LISTENER_CONNECTIONBALANCECONFIG
_LISTENER.fields_by_name['access_log'].message_type = envoy_dot_config_dot_filter_dot_accesslog_dot_v2_dot_accesslog__pb2._ACCESSLOG
_LISTENER_DRAINTYPE.containing_type = _LISTENER
DESCRIPTOR.message_types_by_name['Listener'] = _LISTENER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Listener = _reflection.GeneratedProtocolMessageType('Listener', (_message.Message,), {

  'DeprecatedV1' : _reflection.GeneratedProtocolMessageType('DeprecatedV1', (_message.Message,), {
    'DESCRIPTOR' : _LISTENER_DEPRECATEDV1,
    '__module__' : 'envoy.api.v2.listener_pb2'
    # @@protoc_insertion_point(class_scope:envoy.api.v2.Listener.DeprecatedV1)
    })
  ,

  'ConnectionBalanceConfig' : _reflection.GeneratedProtocolMessageType('ConnectionBalanceConfig', (_message.Message,), {

    'ExactBalance' : _reflection.GeneratedProtocolMessageType('ExactBalance', (_message.Message,), {
      'DESCRIPTOR' : _LISTENER_CONNECTIONBALANCECONFIG_EXACTBALANCE,
      '__module__' : 'envoy.api.v2.listener_pb2'
      # @@protoc_insertion_point(class_scope:envoy.api.v2.Listener.ConnectionBalanceConfig.ExactBalance)
      })
    ,
    'DESCRIPTOR' : _LISTENER_CONNECTIONBALANCECONFIG,
    '__module__' : 'envoy.api.v2.listener_pb2'
    # @@protoc_insertion_point(class_scope:envoy.api.v2.Listener.ConnectionBalanceConfig)
    })
  ,
  'DESCRIPTOR' : _LISTENER,
  '__module__' : 'envoy.api.v2.listener_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.Listener)
  })
_sym_db.RegisterMessage(Listener)
_sym_db.RegisterMessage(Listener.DeprecatedV1)
_sym_db.RegisterMessage(Listener.ConnectionBalanceConfig)
_sym_db.RegisterMessage(Listener.ConnectionBalanceConfig.ExactBalance)


DESCRIPTOR._options = None
_LISTENER_CONNECTIONBALANCECONFIG.oneofs_by_name['balance_type']._options = None
_LISTENER.fields_by_name['address']._options = None
_LISTENER.fields_by_name['use_original_dst']._options = None
# @@protoc_insertion_point(module_scope)
