# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v2alpha/tap.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.service.tap.v2alpha import common_pb2 as envoy_dot_service_dot_tap_dot_v2alpha_dot_common__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/admin/v2alpha/tap.proto',
  package='envoy.admin.v2alpha',
  syntax='proto3',
  serialized_options=b'\n!io.envoyproxy.envoy.admin.v2alphaB\010TapProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1d\x65nvoy/admin/v2alpha/tap.proto\x12\x13\x65nvoy.admin.v2alpha\x1a&envoy/service/tap/v2alpha/common.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"l\n\nTapRequest\x12\x1a\n\tconfig_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x42\n\ntap_config\x18\x02 \x01(\x0b\x32$.envoy.service.tap.v2alpha.TapConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x42\x37\n!io.envoyproxy.envoy.admin.v2alphaB\x08TapProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_service_dot_tap_dot_v2alpha_dot_common__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_TAPREQUEST = _descriptor.Descriptor(
  name='TapRequest',
  full_name='envoy.admin.v2alpha.TapRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_id', full_name='envoy.admin.v2alpha.TapRequest.config_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tap_config', full_name='envoy.admin.v2alpha.TapRequest.tap_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=150,
  serialized_end=258,
)

_TAPREQUEST.fields_by_name['tap_config'].message_type = envoy_dot_service_dot_tap_dot_v2alpha_dot_common__pb2._TAPCONFIG
DESCRIPTOR.message_types_by_name['TapRequest'] = _TAPREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TapRequest = _reflection.GeneratedProtocolMessageType('TapRequest', (_message.Message,), {
  'DESCRIPTOR' : _TAPREQUEST,
  '__module__' : 'envoy.admin.v2alpha.tap_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.TapRequest)
  })
_sym_db.RegisterMessage(TapRequest)


DESCRIPTOR._options = None
_TAPREQUEST.fields_by_name['config_id']._options = None
_TAPREQUEST.fields_by_name['tap_config']._options = None
# @@protoc_insertion_point(module_scope)
