# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/tap/v2alpha/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/data/tap/v2alpha/common.proto',
  package='envoy.data.tap.v2alpha',
  syntax='proto3',
  serialized_options=b'\n$io.envoyproxy.envoy.data.tap.v2alphaB\013CommonProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#envoy/data/tap/v2alpha/common.proto\x12\x16\x65nvoy.data.tap.v2alpha\x1a\x1dudpa/annotations/status.proto\"O\n\x04\x42ody\x12\x12\n\x08\x61s_bytes\x18\x01 \x01(\x0cH\x00\x12\x13\n\tas_string\x18\x02 \x01(\tH\x00\x12\x11\n\ttruncated\x18\x03 \x01(\x08\x42\x0b\n\tbody_typeB=\n$io.envoyproxy.envoy.data.tap.v2alphaB\x0b\x43ommonProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_BODY = _descriptor.Descriptor(
  name='Body',
  full_name='envoy.data.tap.v2alpha.Body',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='as_bytes', full_name='envoy.data.tap.v2alpha.Body.as_bytes', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='as_string', full_name='envoy.data.tap.v2alpha.Body.as_string', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='truncated', full_name='envoy.data.tap.v2alpha.Body.truncated', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='body_type', full_name='envoy.data.tap.v2alpha.Body.body_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=94,
  serialized_end=173,
)

_BODY.oneofs_by_name['body_type'].fields.append(
  _BODY.fields_by_name['as_bytes'])
_BODY.fields_by_name['as_bytes'].containing_oneof = _BODY.oneofs_by_name['body_type']
_BODY.oneofs_by_name['body_type'].fields.append(
  _BODY.fields_by_name['as_string'])
_BODY.fields_by_name['as_string'].containing_oneof = _BODY.oneofs_by_name['body_type']
DESCRIPTOR.message_types_by_name['Body'] = _BODY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Body = _reflection.GeneratedProtocolMessageType('Body', (_message.Message,), {
  'DESCRIPTOR' : _BODY,
  '__module__' : 'envoy.data.tap.v2alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.tap.v2alpha.Body)
  })
_sym_db.RegisterMessage(Body)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
