# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v2alpha/config_dump.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.bootstrap.v2 import bootstrap_pb2 as envoy_dot_config_dot_bootstrap_dot_v2_dot_bootstrap__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/admin/v2alpha/config_dump.proto',
  package='envoy.admin.v2alpha',
  syntax='proto3',
  serialized_options=b'\n!io.envoyproxy.envoy.admin.v2alphaB\017ConfigDumpProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%envoy/admin/v2alpha/config_dump.proto\x12\x13\x65nvoy.admin.v2alpha\x1a)envoy/config/bootstrap/v2/bootstrap.proto\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dudpa/annotations/status.proto\"3\n\nConfigDump\x12%\n\x07\x63onfigs\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any\"\x92\x01\n\x12UpdateFailureState\x12\x32\n\x14\x66\x61iled_configuration\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x37\n\x13last_update_attempt\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x64\x65tails\x18\x03 \x01(\t\"\x80\x01\n\x13\x42ootstrapConfigDump\x12\x37\n\tbootstrap\x18\x01 \x01(\x0b\x32$.envoy.config.bootstrap.v2.Bootstrap\x12\x30\n\x0clast_updated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xaa\x06\n\x13ListenersConfigDump\x12\x14\n\x0cversion_info\x18\x01 \x01(\t\x12Q\n\x10static_listeners\x18\x02 \x03(\x0b\x32\x37.envoy.admin.v2alpha.ListenersConfigDump.StaticListener\x12S\n\x11\x64ynamic_listeners\x18\x03 \x03(\x0b\x32\x38.envoy.admin.v2alpha.ListenersConfigDump.DynamicListener\x1aj\n\x0eStaticListener\x12&\n\x08listener\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x0clast_updated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x86\x01\n\x14\x44ynamicListenerState\x12\x14\n\x0cversion_info\x18\x01 \x01(\t\x12&\n\x08listener\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x0clast_updated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\xdf\x02\n\x0f\x44ynamicListener\x12\x0c\n\x04name\x18\x01 \x01(\t\x12S\n\x0c\x61\x63tive_state\x18\x02 \x01(\x0b\x32=.envoy.admin.v2alpha.ListenersConfigDump.DynamicListenerState\x12T\n\rwarming_state\x18\x03 \x01(\x0b\x32=.envoy.admin.v2alpha.ListenersConfigDump.DynamicListenerState\x12U\n\x0e\x64raining_state\x18\x04 \x01(\x0b\x32=.envoy.admin.v2alpha.ListenersConfigDump.DynamicListenerState\x12<\n\x0b\x65rror_state\x18\x05 \x01(\x0b\x32\'.envoy.admin.v2alpha.UpdateFailureState\"\x98\x04\n\x12\x43lustersConfigDump\x12\x14\n\x0cversion_info\x18\x01 \x01(\t\x12N\n\x0fstatic_clusters\x18\x02 \x03(\x0b\x32\x35.envoy.admin.v2alpha.ClustersConfigDump.StaticCluster\x12W\n\x17\x64ynamic_active_clusters\x18\x03 \x03(\x0b\x32\x36.envoy.admin.v2alpha.ClustersConfigDump.DynamicCluster\x12X\n\x18\x64ynamic_warming_clusters\x18\x04 \x03(\x0b\x32\x36.envoy.admin.v2alpha.ClustersConfigDump.DynamicCluster\x1ah\n\rStaticCluster\x12%\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x0clast_updated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x7f\n\x0e\x44ynamicCluster\x12\x14\n\x0cversion_info\x18\x01 \x01(\t\x12%\n\x07\x63luster\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x0clast_updated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xc0\x03\n\x10RoutesConfigDump\x12U\n\x14static_route_configs\x18\x02 \x03(\x0b\x32\x37.envoy.admin.v2alpha.RoutesConfigDump.StaticRouteConfig\x12W\n\x15\x64ynamic_route_configs\x18\x03 \x03(\x0b\x32\x38.envoy.admin.v2alpha.RoutesConfigDump.DynamicRouteConfig\x1aq\n\x11StaticRouteConfig\x12*\n\x0croute_config\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x0clast_updated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x88\x01\n\x12\x44ynamicRouteConfig\x12\x14\n\x0cversion_info\x18\x01 \x01(\t\x12*\n\x0croute_config\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x0clast_updated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xa9\x04\n\x16ScopedRoutesConfigDump\x12i\n\x1binline_scoped_route_configs\x18\x01 \x03(\x0b\x32\x44.envoy.admin.v2alpha.ScopedRoutesConfigDump.InlineScopedRouteConfigs\x12k\n\x1c\x64ynamic_scoped_route_configs\x18\x02 \x03(\x0b\x32\x45.envoy.admin.v2alpha.ScopedRoutesConfigDump.DynamicScopedRouteConfigs\x1a\x8e\x01\n\x18InlineScopedRouteConfigs\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x32\n\x14scoped_route_configs\x18\x02 \x03(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x0clast_updated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\xa5\x01\n\x19\x44ynamicScopedRouteConfigs\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cversion_info\x18\x02 \x01(\t\x12\x32\n\x14scoped_route_configs\x18\x03 \x03(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x0clast_updated\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x91\x04\n\x11SecretsConfigDump\x12K\n\x0estatic_secrets\x18\x01 \x03(\x0b\x32\x33.envoy.admin.v2alpha.SecretsConfigDump.StaticSecret\x12T\n\x16\x64ynamic_active_secrets\x18\x02 \x03(\x0b\x32\x34.envoy.admin.v2alpha.SecretsConfigDump.DynamicSecret\x12U\n\x17\x64ynamic_warming_secrets\x18\x03 \x03(\x0b\x32\x34.envoy.admin.v2alpha.SecretsConfigDump.DynamicSecret\x1a\x8b\x01\n\rDynamicSecret\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cversion_info\x18\x02 \x01(\t\x12\x30\n\x0clast_updated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\x06secret\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\x1at\n\x0cStaticSecret\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x30\n\x0clast_updated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\x06secret\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB>\n!io.envoyproxy.envoy.admin.v2alphaB\x0f\x43onfigDumpProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_bootstrap_dot_v2_dot_bootstrap__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_CONFIGDUMP = _descriptor.Descriptor(
  name='ConfigDump',
  full_name='envoy.admin.v2alpha.ConfigDump',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='configs', full_name='envoy.admin.v2alpha.ConfigDump.configs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=196,
  serialized_end=247,
)


_UPDATEFAILURESTATE = _descriptor.Descriptor(
  name='UpdateFailureState',
  full_name='envoy.admin.v2alpha.UpdateFailureState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='failed_configuration', full_name='envoy.admin.v2alpha.UpdateFailureState.failed_configuration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_update_attempt', full_name='envoy.admin.v2alpha.UpdateFailureState.last_update_attempt', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details', full_name='envoy.admin.v2alpha.UpdateFailureState.details', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=396,
)


_BOOTSTRAPCONFIGDUMP = _descriptor.Descriptor(
  name='BootstrapConfigDump',
  full_name='envoy.admin.v2alpha.BootstrapConfigDump',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bootstrap', full_name='envoy.admin.v2alpha.BootstrapConfigDump.bootstrap', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='envoy.admin.v2alpha.BootstrapConfigDump.last_updated', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=399,
  serialized_end=527,
)


_LISTENERSCONFIGDUMP_STATICLISTENER = _descriptor.Descriptor(
  name='StaticListener',
  full_name='envoy.admin.v2alpha.ListenersConfigDump.StaticListener',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='listener', full_name='envoy.admin.v2alpha.ListenersConfigDump.StaticListener.listener', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='envoy.admin.v2alpha.ListenersConfigDump.StaticListener.last_updated', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=743,
  serialized_end=849,
)

_LISTENERSCONFIGDUMP_DYNAMICLISTENERSTATE = _descriptor.Descriptor(
  name='DynamicListenerState',
  full_name='envoy.admin.v2alpha.ListenersConfigDump.DynamicListenerState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version_info', full_name='envoy.admin.v2alpha.ListenersConfigDump.DynamicListenerState.version_info', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listener', full_name='envoy.admin.v2alpha.ListenersConfigDump.DynamicListenerState.listener', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='envoy.admin.v2alpha.ListenersConfigDump.DynamicListenerState.last_updated', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=852,
  serialized_end=986,
)

_LISTENERSCONFIGDUMP_DYNAMICLISTENER = _descriptor.Descriptor(
  name='DynamicListener',
  full_name='envoy.admin.v2alpha.ListenersConfigDump.DynamicListener',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.admin.v2alpha.ListenersConfigDump.DynamicListener.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active_state', full_name='envoy.admin.v2alpha.ListenersConfigDump.DynamicListener.active_state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='warming_state', full_name='envoy.admin.v2alpha.ListenersConfigDump.DynamicListener.warming_state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='draining_state', full_name='envoy.admin.v2alpha.ListenersConfigDump.DynamicListener.draining_state', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_state', full_name='envoy.admin.v2alpha.ListenersConfigDump.DynamicListener.error_state', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=989,
  serialized_end=1340,
)

_LISTENERSCONFIGDUMP = _descriptor.Descriptor(
  name='ListenersConfigDump',
  full_name='envoy.admin.v2alpha.ListenersConfigDump',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version_info', full_name='envoy.admin.v2alpha.ListenersConfigDump.version_info', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='static_listeners', full_name='envoy.admin.v2alpha.ListenersConfigDump.static_listeners', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_listeners', full_name='envoy.admin.v2alpha.ListenersConfigDump.dynamic_listeners', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTENERSCONFIGDUMP_STATICLISTENER, _LISTENERSCONFIGDUMP_DYNAMICLISTENERSTATE, _LISTENERSCONFIGDUMP_DYNAMICLISTENER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=530,
  serialized_end=1340,
)


_CLUSTERSCONFIGDUMP_STATICCLUSTER = _descriptor.Descriptor(
  name='StaticCluster',
  full_name='envoy.admin.v2alpha.ClustersConfigDump.StaticCluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster', full_name='envoy.admin.v2alpha.ClustersConfigDump.StaticCluster.cluster', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='envoy.admin.v2alpha.ClustersConfigDump.StaticCluster.last_updated', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1646,
  serialized_end=1750,
)

_CLUSTERSCONFIGDUMP_DYNAMICCLUSTER = _descriptor.Descriptor(
  name='DynamicCluster',
  full_name='envoy.admin.v2alpha.ClustersConfigDump.DynamicCluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version_info', full_name='envoy.admin.v2alpha.ClustersConfigDump.DynamicCluster.version_info', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='envoy.admin.v2alpha.ClustersConfigDump.DynamicCluster.cluster', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='envoy.admin.v2alpha.ClustersConfigDump.DynamicCluster.last_updated', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1752,
  serialized_end=1879,
)

_CLUSTERSCONFIGDUMP = _descriptor.Descriptor(
  name='ClustersConfigDump',
  full_name='envoy.admin.v2alpha.ClustersConfigDump',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version_info', full_name='envoy.admin.v2alpha.ClustersConfigDump.version_info', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='static_clusters', full_name='envoy.admin.v2alpha.ClustersConfigDump.static_clusters', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_active_clusters', full_name='envoy.admin.v2alpha.ClustersConfigDump.dynamic_active_clusters', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_warming_clusters', full_name='envoy.admin.v2alpha.ClustersConfigDump.dynamic_warming_clusters', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CLUSTERSCONFIGDUMP_STATICCLUSTER, _CLUSTERSCONFIGDUMP_DYNAMICCLUSTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1343,
  serialized_end=1879,
)


_ROUTESCONFIGDUMP_STATICROUTECONFIG = _descriptor.Descriptor(
  name='StaticRouteConfig',
  full_name='envoy.admin.v2alpha.RoutesConfigDump.StaticRouteConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='route_config', full_name='envoy.admin.v2alpha.RoutesConfigDump.StaticRouteConfig.route_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='envoy.admin.v2alpha.RoutesConfigDump.StaticRouteConfig.last_updated', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2078,
  serialized_end=2191,
)

_ROUTESCONFIGDUMP_DYNAMICROUTECONFIG = _descriptor.Descriptor(
  name='DynamicRouteConfig',
  full_name='envoy.admin.v2alpha.RoutesConfigDump.DynamicRouteConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version_info', full_name='envoy.admin.v2alpha.RoutesConfigDump.DynamicRouteConfig.version_info', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_config', full_name='envoy.admin.v2alpha.RoutesConfigDump.DynamicRouteConfig.route_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='envoy.admin.v2alpha.RoutesConfigDump.DynamicRouteConfig.last_updated', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2194,
  serialized_end=2330,
)

_ROUTESCONFIGDUMP = _descriptor.Descriptor(
  name='RoutesConfigDump',
  full_name='envoy.admin.v2alpha.RoutesConfigDump',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='static_route_configs', full_name='envoy.admin.v2alpha.RoutesConfigDump.static_route_configs', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_route_configs', full_name='envoy.admin.v2alpha.RoutesConfigDump.dynamic_route_configs', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ROUTESCONFIGDUMP_STATICROUTECONFIG, _ROUTESCONFIGDUMP_DYNAMICROUTECONFIG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1882,
  serialized_end=2330,
)


_SCOPEDROUTESCONFIGDUMP_INLINESCOPEDROUTECONFIGS = _descriptor.Descriptor(
  name='InlineScopedRouteConfigs',
  full_name='envoy.admin.v2alpha.ScopedRoutesConfigDump.InlineScopedRouteConfigs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.admin.v2alpha.ScopedRoutesConfigDump.InlineScopedRouteConfigs.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scoped_route_configs', full_name='envoy.admin.v2alpha.ScopedRoutesConfigDump.InlineScopedRouteConfigs.scoped_route_configs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='envoy.admin.v2alpha.ScopedRoutesConfigDump.InlineScopedRouteConfigs.last_updated', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2576,
  serialized_end=2718,
)

_SCOPEDROUTESCONFIGDUMP_DYNAMICSCOPEDROUTECONFIGS = _descriptor.Descriptor(
  name='DynamicScopedRouteConfigs',
  full_name='envoy.admin.v2alpha.ScopedRoutesConfigDump.DynamicScopedRouteConfigs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.admin.v2alpha.ScopedRoutesConfigDump.DynamicScopedRouteConfigs.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_info', full_name='envoy.admin.v2alpha.ScopedRoutesConfigDump.DynamicScopedRouteConfigs.version_info', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scoped_route_configs', full_name='envoy.admin.v2alpha.ScopedRoutesConfigDump.DynamicScopedRouteConfigs.scoped_route_configs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='envoy.admin.v2alpha.ScopedRoutesConfigDump.DynamicScopedRouteConfigs.last_updated', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2721,
  serialized_end=2886,
)

_SCOPEDROUTESCONFIGDUMP = _descriptor.Descriptor(
  name='ScopedRoutesConfigDump',
  full_name='envoy.admin.v2alpha.ScopedRoutesConfigDump',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='inline_scoped_route_configs', full_name='envoy.admin.v2alpha.ScopedRoutesConfigDump.inline_scoped_route_configs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_scoped_route_configs', full_name='envoy.admin.v2alpha.ScopedRoutesConfigDump.dynamic_scoped_route_configs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCOPEDROUTESCONFIGDUMP_INLINESCOPEDROUTECONFIGS, _SCOPEDROUTESCONFIGDUMP_DYNAMICSCOPEDROUTECONFIGS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2333,
  serialized_end=2886,
)


_SECRETSCONFIGDUMP_DYNAMICSECRET = _descriptor.Descriptor(
  name='DynamicSecret',
  full_name='envoy.admin.v2alpha.SecretsConfigDump.DynamicSecret',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.admin.v2alpha.SecretsConfigDump.DynamicSecret.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_info', full_name='envoy.admin.v2alpha.SecretsConfigDump.DynamicSecret.version_info', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='envoy.admin.v2alpha.SecretsConfigDump.DynamicSecret.last_updated', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='envoy.admin.v2alpha.SecretsConfigDump.DynamicSecret.secret', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3161,
  serialized_end=3300,
)

_SECRETSCONFIGDUMP_STATICSECRET = _descriptor.Descriptor(
  name='StaticSecret',
  full_name='envoy.admin.v2alpha.SecretsConfigDump.StaticSecret',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.admin.v2alpha.SecretsConfigDump.StaticSecret.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='envoy.admin.v2alpha.SecretsConfigDump.StaticSecret.last_updated', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='envoy.admin.v2alpha.SecretsConfigDump.StaticSecret.secret', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3302,
  serialized_end=3418,
)

_SECRETSCONFIGDUMP = _descriptor.Descriptor(
  name='SecretsConfigDump',
  full_name='envoy.admin.v2alpha.SecretsConfigDump',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='static_secrets', full_name='envoy.admin.v2alpha.SecretsConfigDump.static_secrets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_active_secrets', full_name='envoy.admin.v2alpha.SecretsConfigDump.dynamic_active_secrets', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_warming_secrets', full_name='envoy.admin.v2alpha.SecretsConfigDump.dynamic_warming_secrets', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SECRETSCONFIGDUMP_DYNAMICSECRET, _SECRETSCONFIGDUMP_STATICSECRET, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2889,
  serialized_end=3418,
)

_CONFIGDUMP.fields_by_name['configs'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_UPDATEFAILURESTATE.fields_by_name['failed_configuration'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_UPDATEFAILURESTATE.fields_by_name['last_update_attempt'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BOOTSTRAPCONFIGDUMP.fields_by_name['bootstrap'].message_type = envoy_dot_config_dot_bootstrap_dot_v2_dot_bootstrap__pb2._BOOTSTRAP
_BOOTSTRAPCONFIGDUMP.fields_by_name['last_updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTENERSCONFIGDUMP_STATICLISTENER.fields_by_name['listener'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_LISTENERSCONFIGDUMP_STATICLISTENER.fields_by_name['last_updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTENERSCONFIGDUMP_STATICLISTENER.containing_type = _LISTENERSCONFIGDUMP
_LISTENERSCONFIGDUMP_DYNAMICLISTENERSTATE.fields_by_name['listener'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_LISTENERSCONFIGDUMP_DYNAMICLISTENERSTATE.fields_by_name['last_updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTENERSCONFIGDUMP_DYNAMICLISTENERSTATE.containing_type = _LISTENERSCONFIGDUMP
_LISTENERSCONFIGDUMP_DYNAMICLISTENER.fields_by_name['active_state'].message_type = _LISTENERSCONFIGDUMP_DYNAMICLISTENERSTATE
_LISTENERSCONFIGDUMP_DYNAMICLISTENER.fields_by_name['warming_state'].message_type = _LISTENERSCONFIGDUMP_DYNAMICLISTENERSTATE
_LISTENERSCONFIGDUMP_DYNAMICLISTENER.fields_by_name['draining_state'].message_type = _LISTENERSCONFIGDUMP_DYNAMICLISTENERSTATE
_LISTENERSCONFIGDUMP_DYNAMICLISTENER.fields_by_name['error_state'].message_type = _UPDATEFAILURESTATE
_LISTENERSCONFIGDUMP_DYNAMICLISTENER.containing_type = _LISTENERSCONFIGDUMP
_LISTENERSCONFIGDUMP.fields_by_name['static_listeners'].message_type = _LISTENERSCONFIGDUMP_STATICLISTENER
_LISTENERSCONFIGDUMP.fields_by_name['dynamic_listeners'].message_type = _LISTENERSCONFIGDUMP_DYNAMICLISTENER
_CLUSTERSCONFIGDUMP_STATICCLUSTER.fields_by_name['cluster'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_CLUSTERSCONFIGDUMP_STATICCLUSTER.fields_by_name['last_updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CLUSTERSCONFIGDUMP_STATICCLUSTER.containing_type = _CLUSTERSCONFIGDUMP
_CLUSTERSCONFIGDUMP_DYNAMICCLUSTER.fields_by_name['cluster'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_CLUSTERSCONFIGDUMP_DYNAMICCLUSTER.fields_by_name['last_updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CLUSTERSCONFIGDUMP_DYNAMICCLUSTER.containing_type = _CLUSTERSCONFIGDUMP
_CLUSTERSCONFIGDUMP.fields_by_name['static_clusters'].message_type = _CLUSTERSCONFIGDUMP_STATICCLUSTER
_CLUSTERSCONFIGDUMP.fields_by_name['dynamic_active_clusters'].message_type = _CLUSTERSCONFIGDUMP_DYNAMICCLUSTER
_CLUSTERSCONFIGDUMP.fields_by_name['dynamic_warming_clusters'].message_type = _CLUSTERSCONFIGDUMP_DYNAMICCLUSTER
_ROUTESCONFIGDUMP_STATICROUTECONFIG.fields_by_name['route_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_ROUTESCONFIGDUMP_STATICROUTECONFIG.fields_by_name['last_updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ROUTESCONFIGDUMP_STATICROUTECONFIG.containing_type = _ROUTESCONFIGDUMP
_ROUTESCONFIGDUMP_DYNAMICROUTECONFIG.fields_by_name['route_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_ROUTESCONFIGDUMP_DYNAMICROUTECONFIG.fields_by_name['last_updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ROUTESCONFIGDUMP_DYNAMICROUTECONFIG.containing_type = _ROUTESCONFIGDUMP
_ROUTESCONFIGDUMP.fields_by_name['static_route_configs'].message_type = _ROUTESCONFIGDUMP_STATICROUTECONFIG
_ROUTESCONFIGDUMP.fields_by_name['dynamic_route_configs'].message_type = _ROUTESCONFIGDUMP_DYNAMICROUTECONFIG
_SCOPEDROUTESCONFIGDUMP_INLINESCOPEDROUTECONFIGS.fields_by_name['scoped_route_configs'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_SCOPEDROUTESCONFIGDUMP_INLINESCOPEDROUTECONFIGS.fields_by_name['last_updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SCOPEDROUTESCONFIGDUMP_INLINESCOPEDROUTECONFIGS.containing_type = _SCOPEDROUTESCONFIGDUMP
_SCOPEDROUTESCONFIGDUMP_DYNAMICSCOPEDROUTECONFIGS.fields_by_name['scoped_route_configs'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_SCOPEDROUTESCONFIGDUMP_DYNAMICSCOPEDROUTECONFIGS.fields_by_name['last_updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SCOPEDROUTESCONFIGDUMP_DYNAMICSCOPEDROUTECONFIGS.containing_type = _SCOPEDROUTESCONFIGDUMP
_SCOPEDROUTESCONFIGDUMP.fields_by_name['inline_scoped_route_configs'].message_type = _SCOPEDROUTESCONFIGDUMP_INLINESCOPEDROUTECONFIGS
_SCOPEDROUTESCONFIGDUMP.fields_by_name['dynamic_scoped_route_configs'].message_type = _SCOPEDROUTESCONFIGDUMP_DYNAMICSCOPEDROUTECONFIGS
_SECRETSCONFIGDUMP_DYNAMICSECRET.fields_by_name['last_updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SECRETSCONFIGDUMP_DYNAMICSECRET.fields_by_name['secret'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_SECRETSCONFIGDUMP_DYNAMICSECRET.containing_type = _SECRETSCONFIGDUMP
_SECRETSCONFIGDUMP_STATICSECRET.fields_by_name['last_updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SECRETSCONFIGDUMP_STATICSECRET.fields_by_name['secret'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_SECRETSCONFIGDUMP_STATICSECRET.containing_type = _SECRETSCONFIGDUMP
_SECRETSCONFIGDUMP.fields_by_name['static_secrets'].message_type = _SECRETSCONFIGDUMP_STATICSECRET
_SECRETSCONFIGDUMP.fields_by_name['dynamic_active_secrets'].message_type = _SECRETSCONFIGDUMP_DYNAMICSECRET
_SECRETSCONFIGDUMP.fields_by_name['dynamic_warming_secrets'].message_type = _SECRETSCONFIGDUMP_DYNAMICSECRET
DESCRIPTOR.message_types_by_name['ConfigDump'] = _CONFIGDUMP
DESCRIPTOR.message_types_by_name['UpdateFailureState'] = _UPDATEFAILURESTATE
DESCRIPTOR.message_types_by_name['BootstrapConfigDump'] = _BOOTSTRAPCONFIGDUMP
DESCRIPTOR.message_types_by_name['ListenersConfigDump'] = _LISTENERSCONFIGDUMP
DESCRIPTOR.message_types_by_name['ClustersConfigDump'] = _CLUSTERSCONFIGDUMP
DESCRIPTOR.message_types_by_name['RoutesConfigDump'] = _ROUTESCONFIGDUMP
DESCRIPTOR.message_types_by_name['ScopedRoutesConfigDump'] = _SCOPEDROUTESCONFIGDUMP
DESCRIPTOR.message_types_by_name['SecretsConfigDump'] = _SECRETSCONFIGDUMP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConfigDump = _reflection.GeneratedProtocolMessageType('ConfigDump', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGDUMP,
  '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.ConfigDump)
  })
_sym_db.RegisterMessage(ConfigDump)

UpdateFailureState = _reflection.GeneratedProtocolMessageType('UpdateFailureState', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFAILURESTATE,
  '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.UpdateFailureState)
  })
_sym_db.RegisterMessage(UpdateFailureState)

BootstrapConfigDump = _reflection.GeneratedProtocolMessageType('BootstrapConfigDump', (_message.Message,), {
  'DESCRIPTOR' : _BOOTSTRAPCONFIGDUMP,
  '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.BootstrapConfigDump)
  })
_sym_db.RegisterMessage(BootstrapConfigDump)

ListenersConfigDump = _reflection.GeneratedProtocolMessageType('ListenersConfigDump', (_message.Message,), {

  'StaticListener' : _reflection.GeneratedProtocolMessageType('StaticListener', (_message.Message,), {
    'DESCRIPTOR' : _LISTENERSCONFIGDUMP_STATICLISTENER,
    '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
    # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.ListenersConfigDump.StaticListener)
    })
  ,

  'DynamicListenerState' : _reflection.GeneratedProtocolMessageType('DynamicListenerState', (_message.Message,), {
    'DESCRIPTOR' : _LISTENERSCONFIGDUMP_DYNAMICLISTENERSTATE,
    '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
    # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.ListenersConfigDump.DynamicListenerState)
    })
  ,

  'DynamicListener' : _reflection.GeneratedProtocolMessageType('DynamicListener', (_message.Message,), {
    'DESCRIPTOR' : _LISTENERSCONFIGDUMP_DYNAMICLISTENER,
    '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
    # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.ListenersConfigDump.DynamicListener)
    })
  ,
  'DESCRIPTOR' : _LISTENERSCONFIGDUMP,
  '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.ListenersConfigDump)
  })
_sym_db.RegisterMessage(ListenersConfigDump)
_sym_db.RegisterMessage(ListenersConfigDump.StaticListener)
_sym_db.RegisterMessage(ListenersConfigDump.DynamicListenerState)
_sym_db.RegisterMessage(ListenersConfigDump.DynamicListener)

ClustersConfigDump = _reflection.GeneratedProtocolMessageType('ClustersConfigDump', (_message.Message,), {

  'StaticCluster' : _reflection.GeneratedProtocolMessageType('StaticCluster', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTERSCONFIGDUMP_STATICCLUSTER,
    '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
    # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.ClustersConfigDump.StaticCluster)
    })
  ,

  'DynamicCluster' : _reflection.GeneratedProtocolMessageType('DynamicCluster', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTERSCONFIGDUMP_DYNAMICCLUSTER,
    '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
    # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.ClustersConfigDump.DynamicCluster)
    })
  ,
  'DESCRIPTOR' : _CLUSTERSCONFIGDUMP,
  '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.ClustersConfigDump)
  })
_sym_db.RegisterMessage(ClustersConfigDump)
_sym_db.RegisterMessage(ClustersConfigDump.StaticCluster)
_sym_db.RegisterMessage(ClustersConfigDump.DynamicCluster)

RoutesConfigDump = _reflection.GeneratedProtocolMessageType('RoutesConfigDump', (_message.Message,), {

  'StaticRouteConfig' : _reflection.GeneratedProtocolMessageType('StaticRouteConfig', (_message.Message,), {
    'DESCRIPTOR' : _ROUTESCONFIGDUMP_STATICROUTECONFIG,
    '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
    # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.RoutesConfigDump.StaticRouteConfig)
    })
  ,

  'DynamicRouteConfig' : _reflection.GeneratedProtocolMessageType('DynamicRouteConfig', (_message.Message,), {
    'DESCRIPTOR' : _ROUTESCONFIGDUMP_DYNAMICROUTECONFIG,
    '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
    # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.RoutesConfigDump.DynamicRouteConfig)
    })
  ,
  'DESCRIPTOR' : _ROUTESCONFIGDUMP,
  '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.RoutesConfigDump)
  })
_sym_db.RegisterMessage(RoutesConfigDump)
_sym_db.RegisterMessage(RoutesConfigDump.StaticRouteConfig)
_sym_db.RegisterMessage(RoutesConfigDump.DynamicRouteConfig)

ScopedRoutesConfigDump = _reflection.GeneratedProtocolMessageType('ScopedRoutesConfigDump', (_message.Message,), {

  'InlineScopedRouteConfigs' : _reflection.GeneratedProtocolMessageType('InlineScopedRouteConfigs', (_message.Message,), {
    'DESCRIPTOR' : _SCOPEDROUTESCONFIGDUMP_INLINESCOPEDROUTECONFIGS,
    '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
    # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.ScopedRoutesConfigDump.InlineScopedRouteConfigs)
    })
  ,

  'DynamicScopedRouteConfigs' : _reflection.GeneratedProtocolMessageType('DynamicScopedRouteConfigs', (_message.Message,), {
    'DESCRIPTOR' : _SCOPEDROUTESCONFIGDUMP_DYNAMICSCOPEDROUTECONFIGS,
    '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
    # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.ScopedRoutesConfigDump.DynamicScopedRouteConfigs)
    })
  ,
  'DESCRIPTOR' : _SCOPEDROUTESCONFIGDUMP,
  '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.ScopedRoutesConfigDump)
  })
_sym_db.RegisterMessage(ScopedRoutesConfigDump)
_sym_db.RegisterMessage(ScopedRoutesConfigDump.InlineScopedRouteConfigs)
_sym_db.RegisterMessage(ScopedRoutesConfigDump.DynamicScopedRouteConfigs)

SecretsConfigDump = _reflection.GeneratedProtocolMessageType('SecretsConfigDump', (_message.Message,), {

  'DynamicSecret' : _reflection.GeneratedProtocolMessageType('DynamicSecret', (_message.Message,), {
    'DESCRIPTOR' : _SECRETSCONFIGDUMP_DYNAMICSECRET,
    '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
    # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.SecretsConfigDump.DynamicSecret)
    })
  ,

  'StaticSecret' : _reflection.GeneratedProtocolMessageType('StaticSecret', (_message.Message,), {
    'DESCRIPTOR' : _SECRETSCONFIGDUMP_STATICSECRET,
    '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
    # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.SecretsConfigDump.StaticSecret)
    })
  ,
  'DESCRIPTOR' : _SECRETSCONFIGDUMP,
  '__module__' : 'envoy.admin.v2alpha.config_dump_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.SecretsConfigDump)
  })
_sym_db.RegisterMessage(SecretsConfigDump)
_sym_db.RegisterMessage(SecretsConfigDump.DynamicSecret)
_sym_db.RegisterMessage(SecretsConfigDump.StaticSecret)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
