# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/rbac/v4alpha/rbac.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.rbac.v4alpha import rbac_pb2 as envoy_dot_config_dot_rbac_dot_v4alpha_dot_rbac__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/rbac/v4alpha/rbac.proto',
  package='envoy.extensions.filters.http.rbac.v4alpha',
  syntax='proto3',
  serialized_options=b'\n8io.envoyproxy.envoy.extensions.filters.http.rbac.v4alphaB\tRbacProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5envoy/extensions/filters/http/rbac/v4alpha/rbac.proto\x12*envoy.extensions.filters.http.rbac.v4alpha\x1a$envoy/config/rbac/v4alpha/rbac.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\xa0\x01\n\x04RBAC\x12.\n\x05rules\x18\x01 \x01(\x0b\x32\x1f.envoy.config.rbac.v4alpha.RBAC\x12\x35\n\x0cshadow_rules\x18\x02 \x01(\x0b\x32\x1f.envoy.config.rbac.v4alpha.RBAC:1\x9a\xc5\x88\x1e,\n*envoy.extensions.filters.http.rbac.v3.RBAC\"\x8f\x01\n\x0cRBACPerRoute\x12>\n\x04rbac\x18\x02 \x01(\x0b\x32\x30.envoy.extensions.filters.http.rbac.v4alpha.RBAC:9\x9a\xc5\x88\x1e\x34\n2envoy.extensions.filters.http.rbac.v3.RBACPerRouteJ\x04\x08\x01\x10\x02\x42O\n8io.envoyproxy.envoy.extensions.filters.http.rbac.v4alphaB\tRbacProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_rbac_dot_v4alpha_dot_rbac__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_RBAC = _descriptor.Descriptor(
  name='RBAC',
  full_name='envoy.extensions.filters.http.rbac.v4alpha.RBAC',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rules', full_name='envoy.extensions.filters.http.rbac.v4alpha.RBAC.rules', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shadow_rules', full_name='envoy.extensions.filters.http.rbac.v4alpha.RBAC.shadow_rules', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036,\n*envoy.extensions.filters.http.rbac.v3.RBAC',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=206,
  serialized_end=366,
)


_RBACPERROUTE = _descriptor.Descriptor(
  name='RBACPerRoute',
  full_name='envoy.extensions.filters.http.rbac.v4alpha.RBACPerRoute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rbac', full_name='envoy.extensions.filters.http.rbac.v4alpha.RBACPerRoute.rbac', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0364\n2envoy.extensions.filters.http.rbac.v3.RBACPerRoute',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=369,
  serialized_end=512,
)

_RBAC.fields_by_name['rules'].message_type = envoy_dot_config_dot_rbac_dot_v4alpha_dot_rbac__pb2._RBAC
_RBAC.fields_by_name['shadow_rules'].message_type = envoy_dot_config_dot_rbac_dot_v4alpha_dot_rbac__pb2._RBAC
_RBACPERROUTE.fields_by_name['rbac'].message_type = _RBAC
DESCRIPTOR.message_types_by_name['RBAC'] = _RBAC
DESCRIPTOR.message_types_by_name['RBACPerRoute'] = _RBACPERROUTE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RBAC = _reflection.GeneratedProtocolMessageType('RBAC', (_message.Message,), {
  'DESCRIPTOR' : _RBAC,
  '__module__' : 'envoy.extensions.filters.http.rbac.v4alpha.rbac_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.rbac.v4alpha.RBAC)
  })
_sym_db.RegisterMessage(RBAC)

RBACPerRoute = _reflection.GeneratedProtocolMessageType('RBACPerRoute', (_message.Message,), {
  'DESCRIPTOR' : _RBACPERROUTE,
  '__module__' : 'envoy.extensions.filters.http.rbac.v4alpha.rbac_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.rbac.v4alpha.RBACPerRoute)
  })
_sym_db.RegisterMessage(RBACPerRoute)


DESCRIPTOR._options = None
_RBAC._options = None
_RBACPERROUTE._options = None
# @@protoc_insertion_point(module_scope)
