# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/transport_sockets/quic/v3/quic_transport.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.transport_sockets.tls.v3 import tls_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_tls__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/transport_sockets/quic/v3/quic_transport.proto',
  package='envoy.extensions.transport_sockets.quic.v3',
  syntax='proto3',
  serialized_options=b'\n8io.envoyproxy.envoy.extensions.transport_sockets.quic.v3B\022QuicTransportProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n?envoy/extensions/transport_sockets/quic/v3/quic_transport.proto\x12*envoy.extensions.transport_sockets.quic.v3\x1a\x33\x65nvoy/extensions/transport_sockets/tls/v3/tls.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x84\x01\n\x17QuicDownstreamTransport\x12i\n\x16\x64ownstream_tls_context\x18\x01 \x01(\x0b\x32?.envoy.extensions.transport_sockets.tls.v3.DownstreamTlsContextB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"~\n\x15QuicUpstreamTransport\x12\x65\n\x14upstream_tls_context\x18\x01 \x01(\x0b\x32=.envoy.extensions.transport_sockets.tls.v3.UpstreamTlsContextB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x42X\n8io.envoyproxy.envoy.extensions.transport_sockets.quic.v3B\x12QuicTransportProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_tls__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_QUICDOWNSTREAMTRANSPORT = _descriptor.Descriptor(
  name='QuicDownstreamTransport',
  full_name='envoy.extensions.transport_sockets.quic.v3.QuicDownstreamTransport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='downstream_tls_context', full_name='envoy.extensions.transport_sockets.quic.v3.QuicDownstreamTransport.downstream_tls_context', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=353,
)


_QUICUPSTREAMTRANSPORT = _descriptor.Descriptor(
  name='QuicUpstreamTransport',
  full_name='envoy.extensions.transport_sockets.quic.v3.QuicUpstreamTransport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='upstream_tls_context', full_name='envoy.extensions.transport_sockets.quic.v3.QuicUpstreamTransport.upstream_tls_context', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=355,
  serialized_end=481,
)

_QUICDOWNSTREAMTRANSPORT.fields_by_name['downstream_tls_context'].message_type = envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_tls__pb2._DOWNSTREAMTLSCONTEXT
_QUICUPSTREAMTRANSPORT.fields_by_name['upstream_tls_context'].message_type = envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_tls__pb2._UPSTREAMTLSCONTEXT
DESCRIPTOR.message_types_by_name['QuicDownstreamTransport'] = _QUICDOWNSTREAMTRANSPORT
DESCRIPTOR.message_types_by_name['QuicUpstreamTransport'] = _QUICUPSTREAMTRANSPORT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QuicDownstreamTransport = _reflection.GeneratedProtocolMessageType('QuicDownstreamTransport', (_message.Message,), {
  'DESCRIPTOR' : _QUICDOWNSTREAMTRANSPORT,
  '__module__' : 'envoy.extensions.transport_sockets.quic.v3.quic_transport_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.transport_sockets.quic.v3.QuicDownstreamTransport)
  })
_sym_db.RegisterMessage(QuicDownstreamTransport)

QuicUpstreamTransport = _reflection.GeneratedProtocolMessageType('QuicUpstreamTransport', (_message.Message,), {
  'DESCRIPTOR' : _QUICUPSTREAMTRANSPORT,
  '__module__' : 'envoy.extensions.transport_sockets.quic.v3.quic_transport_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.transport_sockets.quic.v3.QuicUpstreamTransport)
  })
_sym_db.RegisterMessage(QuicUpstreamTransport)


DESCRIPTOR._options = None
_QUICDOWNSTREAMTRANSPORT.fields_by_name['downstream_tls_context']._options = None
_QUICUPSTREAMTRANSPORT.fields_by_name['upstream_tls_context']._options = None
# @@protoc_insertion_point(module_scope)
