# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/lds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2 import discovery_pb2 as envoy_dot_api_dot_v2_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from envoy.api.v2 import listener_pb2 as envoy_dot_api_dot_v2_dot_listener__pb2

from envoy.api.v2.listener_pb2 import *

DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/lds.proto',
  package='envoy.api.v2',
  syntax='proto3',
  serialized_options=b'\n\032io.envoyproxy.envoy.api.v2B\010LdsProtoP\001\210\001\001\362\230\376\217\005\033\022\031envoy.service.listener.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16\x65nvoy/api/v2/lds.proto\x12\x0c\x65nvoy.api.v2\x1a\x1c\x65nvoy/api/v2/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a envoy/annotations/resource.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x1b\x65nvoy/api/v2/listener.proto\"\n\n\x08LdsDummy2\xf3\x02\n\x18ListenerDiscoveryService\x12\x61\n\x0e\x44\x65ltaListeners\x12#.envoy.api.v2.DeltaDiscoveryRequest\x1a$.envoy.api.v2.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12X\n\x0fStreamListeners\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"\x00(\x01\x30\x01\x12{\n\x0e\x46\x65tchListeners\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"(\x82\xd3\xe4\x93\x02\x19\"\x17/v2/discovery:listeners\x82\xd3\xe4\x93\x02\x03:\x01*\x1a\x1d\x8a\xa4\x96\xf3\x07\x17\n\x15\x65nvoy.api.v2.ListenerBT\n\x1aio.envoyproxy.envoy.api.v2B\x08LdsProtoP\x01\x88\x01\x01\xf2\x98\xfe\x8f\x05\x1b\x12\x19\x65nvoy.service.listener.v3\xba\x80\xc8\xd1\x06\x02\x10\x01P\x05\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_discovery__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,envoy_dot_annotations_dot_resource__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_listener__pb2.DESCRIPTOR,],
  public_dependencies=[envoy_dot_api_dot_v2_dot_listener__pb2.DESCRIPTOR,])




_LDSDUMMY = _descriptor.Descriptor(
  name='LdsDummy',
  full_name='envoy.api.v2.LdsDummy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=226,
  serialized_end=236,
)

DESCRIPTOR.message_types_by_name['LdsDummy'] = _LDSDUMMY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LdsDummy = _reflection.GeneratedProtocolMessageType('LdsDummy', (_message.Message,), {
  'DESCRIPTOR' : _LDSDUMMY,
  '__module__' : 'envoy.api.v2.lds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.LdsDummy)
  })
_sym_db.RegisterMessage(LdsDummy)


DESCRIPTOR._options = None

_LISTENERDISCOVERYSERVICE = _descriptor.ServiceDescriptor(
  name='ListenerDiscoveryService',
  full_name='envoy.api.v2.ListenerDiscoveryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\212\244\226\363\007\027\n\025envoy.api.v2.Listener',
  create_key=_descriptor._internal_create_key,
  serialized_start=239,
  serialized_end=610,
  methods=[
  _descriptor.MethodDescriptor(
    name='DeltaListeners',
    full_name='envoy.api.v2.ListenerDiscoveryService.DeltaListeners',
    index=0,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DELTADISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DELTADISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamListeners',
    full_name='envoy.api.v2.ListenerDiscoveryService.StreamListeners',
    index=1,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchListeners',
    full_name='envoy.api.v2.ListenerDiscoveryService.FetchListeners',
    index=2,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=b'\202\323\344\223\002\031\"\027/v2/discovery:listeners\202\323\344\223\002\003:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LISTENERDISCOVERYSERVICE)

DESCRIPTOR.services_by_name['ListenerDiscoveryService'] = _LISTENERDISCOVERYSERVICE

# @@protoc_insertion_point(module_scope)
