# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/trace/v2/lightstep.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/trace/v2/lightstep.proto',
  package='envoy.config.trace.v2',
  syntax='proto3',
  serialized_options=b'\n#io.envoyproxy.envoy.config.trace.v2B\016LightstepProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%envoy/config/trace/v2/lightstep.proto\x12\x15\x65nvoy.config.trace.v2\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x83\x02\n\x0fLightstepConfig\x12\"\n\x11\x63ollector_cluster\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\"\n\x11\x61\x63\x63\x65ss_token_file\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12`\n\x11propagation_modes\x18\x03 \x03(\x0e\x32\x36.envoy.config.trace.v2.LightstepConfig.PropagationModeB\r\xfa\x42\n\x92\x01\x07\"\x05\x82\x01\x02\x10\x01\"F\n\x0fPropagationMode\x12\t\n\x05\x45NVOY\x10\x00\x12\r\n\tLIGHTSTEP\x10\x01\x12\x06\n\x02\x42\x33\x10\x02\x12\x11\n\rTRACE_CONTEXT\x10\x03\x42?\n#io.envoyproxy.envoy.config.trace.v2B\x0eLightstepProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_LIGHTSTEPCONFIG_PROPAGATIONMODE = _descriptor.EnumDescriptor(
  name='PropagationMode',
  full_name='envoy.config.trace.v2.LightstepConfig.PropagationMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ENVOY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LIGHTSTEP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='B3', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRACE_CONTEXT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=310,
  serialized_end=380,
)
_sym_db.RegisterEnumDescriptor(_LIGHTSTEPCONFIG_PROPAGATIONMODE)


_LIGHTSTEPCONFIG = _descriptor.Descriptor(
  name='LightstepConfig',
  full_name='envoy.config.trace.v2.LightstepConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='collector_cluster', full_name='envoy.config.trace.v2.LightstepConfig.collector_cluster', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_token_file', full_name='envoy.config.trace.v2.LightstepConfig.access_token_file', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='propagation_modes', full_name='envoy.config.trace.v2.LightstepConfig.propagation_modes', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\n\222\001\007\"\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LIGHTSTEPCONFIG_PROPAGATIONMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=380,
)

_LIGHTSTEPCONFIG.fields_by_name['propagation_modes'].enum_type = _LIGHTSTEPCONFIG_PROPAGATIONMODE
_LIGHTSTEPCONFIG_PROPAGATIONMODE.containing_type = _LIGHTSTEPCONFIG
DESCRIPTOR.message_types_by_name['LightstepConfig'] = _LIGHTSTEPCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LightstepConfig = _reflection.GeneratedProtocolMessageType('LightstepConfig', (_message.Message,), {
  'DESCRIPTOR' : _LIGHTSTEPCONFIG,
  '__module__' : 'envoy.config.trace.v2.lightstep_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.trace.v2.LightstepConfig)
  })
_sym_db.RegisterMessage(LightstepConfig)


DESCRIPTOR._options = None
_LIGHTSTEPCONFIG.fields_by_name['collector_cluster']._options = None
_LIGHTSTEPCONFIG.fields_by_name['access_token_file']._options = None
_LIGHTSTEPCONFIG.fields_by_name['propagation_modes']._options = None
# @@protoc_insertion_point(module_scope)
