# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencensus/proto/agent/trace/v1/trace_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencensus.proto.agent.common.v1 import common_pb2 as opencensus_dot_proto_dot_agent_dot_common_dot_v1_dot_common__pb2
from opencensus.proto.resource.v1 import resource_pb2 as opencensus_dot_proto_dot_resource_dot_v1_dot_resource__pb2
from opencensus.proto.trace.v1 import trace_pb2 as opencensus_dot_proto_dot_trace_dot_v1_dot_trace__pb2
from opencensus.proto.trace.v1 import trace_config_pb2 as opencensus_dot_proto_dot_trace_dot_v1_dot_trace__config__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencensus/proto/agent/trace/v1/trace_service.proto',
  package='opencensus.proto.agent.trace.v1',
  syntax='proto3',
  serialized_options=b'\n\"io.opencensus.proto.agent.trace.v1B\021TraceServiceProtoP\001ZHgithub.com/census-instrumentation/opencensus-proto/gen-go/agent/trace/v1\352\002\037OpenCensus.Proto.Agent.Trace.V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3opencensus/proto/agent/trace/v1/trace_service.proto\x12\x1fopencensus.proto.agent.trace.v1\x1a-opencensus/proto/agent/common/v1/common.proto\x1a+opencensus/proto/resource/v1/resource.proto\x1a%opencensus/proto/trace/v1/trace.proto\x1a,opencensus/proto/trace/v1/trace_config.proto\"\x84\x01\n\x14\x43urrentLibraryConfig\x12\x34\n\x04node\x18\x01 \x01(\x0b\x32&.opencensus.proto.agent.common.v1.Node\x12\x36\n\x06\x63onfig\x18\x02 \x01(\x0b\x32&.opencensus.proto.trace.v1.TraceConfig\"\x84\x01\n\x14UpdatedLibraryConfig\x12\x34\n\x04node\x18\x01 \x01(\x0b\x32&.opencensus.proto.agent.common.v1.Node\x12\x36\n\x06\x63onfig\x18\x02 \x01(\x0b\x32&.opencensus.proto.trace.v1.TraceConfig\"\xbb\x01\n\x19\x45xportTraceServiceRequest\x12\x34\n\x04node\x18\x01 \x01(\x0b\x32&.opencensus.proto.agent.common.v1.Node\x12.\n\x05spans\x18\x02 \x03(\x0b\x32\x1f.opencensus.proto.trace.v1.Span\x12\x38\n\x08resource\x18\x03 \x01(\x0b\x32&.opencensus.proto.resource.v1.Resource\"\x1c\n\x1a\x45xportTraceServiceResponse2\x96\x02\n\x0cTraceService\x12|\n\x06\x43onfig\x12\x35.opencensus.proto.agent.trace.v1.CurrentLibraryConfig\x1a\x35.opencensus.proto.agent.trace.v1.UpdatedLibraryConfig\"\x00(\x01\x30\x01\x12\x87\x01\n\x06\x45xport\x12:.opencensus.proto.agent.trace.v1.ExportTraceServiceRequest\x1a;.opencensus.proto.agent.trace.v1.ExportTraceServiceResponse\"\x00(\x01\x30\x01\x42\xa5\x01\n\"io.opencensus.proto.agent.trace.v1B\x11TraceServiceProtoP\x01ZHgithub.com/census-instrumentation/opencensus-proto/gen-go/agent/trace/v1\xea\x02\x1fOpenCensus.Proto.Agent.Trace.V1b\x06proto3'
  ,
  dependencies=[opencensus_dot_proto_dot_agent_dot_common_dot_v1_dot_common__pb2.DESCRIPTOR,opencensus_dot_proto_dot_resource_dot_v1_dot_resource__pb2.DESCRIPTOR,opencensus_dot_proto_dot_trace_dot_v1_dot_trace__pb2.DESCRIPTOR,opencensus_dot_proto_dot_trace_dot_v1_dot_trace__config__pb2.DESCRIPTOR,])




_CURRENTLIBRARYCONFIG = _descriptor.Descriptor(
  name='CurrentLibraryConfig',
  full_name='opencensus.proto.agent.trace.v1.CurrentLibraryConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='opencensus.proto.agent.trace.v1.CurrentLibraryConfig.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='opencensus.proto.agent.trace.v1.CurrentLibraryConfig.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=266,
  serialized_end=398,
)


_UPDATEDLIBRARYCONFIG = _descriptor.Descriptor(
  name='UpdatedLibraryConfig',
  full_name='opencensus.proto.agent.trace.v1.UpdatedLibraryConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='opencensus.proto.agent.trace.v1.UpdatedLibraryConfig.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='opencensus.proto.agent.trace.v1.UpdatedLibraryConfig.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=401,
  serialized_end=533,
)


_EXPORTTRACESERVICEREQUEST = _descriptor.Descriptor(
  name='ExportTraceServiceRequest',
  full_name='opencensus.proto.agent.trace.v1.ExportTraceServiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='opencensus.proto.agent.trace.v1.ExportTraceServiceRequest.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spans', full_name='opencensus.proto.agent.trace.v1.ExportTraceServiceRequest.spans', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource', full_name='opencensus.proto.agent.trace.v1.ExportTraceServiceRequest.resource', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=536,
  serialized_end=723,
)


_EXPORTTRACESERVICERESPONSE = _descriptor.Descriptor(
  name='ExportTraceServiceResponse',
  full_name='opencensus.proto.agent.trace.v1.ExportTraceServiceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=725,
  serialized_end=753,
)

_CURRENTLIBRARYCONFIG.fields_by_name['node'].message_type = opencensus_dot_proto_dot_agent_dot_common_dot_v1_dot_common__pb2._NODE
_CURRENTLIBRARYCONFIG.fields_by_name['config'].message_type = opencensus_dot_proto_dot_trace_dot_v1_dot_trace__config__pb2._TRACECONFIG
_UPDATEDLIBRARYCONFIG.fields_by_name['node'].message_type = opencensus_dot_proto_dot_agent_dot_common_dot_v1_dot_common__pb2._NODE
_UPDATEDLIBRARYCONFIG.fields_by_name['config'].message_type = opencensus_dot_proto_dot_trace_dot_v1_dot_trace__config__pb2._TRACECONFIG
_EXPORTTRACESERVICEREQUEST.fields_by_name['node'].message_type = opencensus_dot_proto_dot_agent_dot_common_dot_v1_dot_common__pb2._NODE
_EXPORTTRACESERVICEREQUEST.fields_by_name['spans'].message_type = opencensus_dot_proto_dot_trace_dot_v1_dot_trace__pb2._SPAN
_EXPORTTRACESERVICEREQUEST.fields_by_name['resource'].message_type = opencensus_dot_proto_dot_resource_dot_v1_dot_resource__pb2._RESOURCE
DESCRIPTOR.message_types_by_name['CurrentLibraryConfig'] = _CURRENTLIBRARYCONFIG
DESCRIPTOR.message_types_by_name['UpdatedLibraryConfig'] = _UPDATEDLIBRARYCONFIG
DESCRIPTOR.message_types_by_name['ExportTraceServiceRequest'] = _EXPORTTRACESERVICEREQUEST
DESCRIPTOR.message_types_by_name['ExportTraceServiceResponse'] = _EXPORTTRACESERVICERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CurrentLibraryConfig = _reflection.GeneratedProtocolMessageType('CurrentLibraryConfig', (_message.Message,), {
  'DESCRIPTOR' : _CURRENTLIBRARYCONFIG,
  '__module__' : 'opencensus.proto.agent.trace.v1.trace_service_pb2'
  # @@protoc_insertion_point(class_scope:opencensus.proto.agent.trace.v1.CurrentLibraryConfig)
  })
_sym_db.RegisterMessage(CurrentLibraryConfig)

UpdatedLibraryConfig = _reflection.GeneratedProtocolMessageType('UpdatedLibraryConfig', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDLIBRARYCONFIG,
  '__module__' : 'opencensus.proto.agent.trace.v1.trace_service_pb2'
  # @@protoc_insertion_point(class_scope:opencensus.proto.agent.trace.v1.UpdatedLibraryConfig)
  })
_sym_db.RegisterMessage(UpdatedLibraryConfig)

ExportTraceServiceRequest = _reflection.GeneratedProtocolMessageType('ExportTraceServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTTRACESERVICEREQUEST,
  '__module__' : 'opencensus.proto.agent.trace.v1.trace_service_pb2'
  # @@protoc_insertion_point(class_scope:opencensus.proto.agent.trace.v1.ExportTraceServiceRequest)
  })
_sym_db.RegisterMessage(ExportTraceServiceRequest)

ExportTraceServiceResponse = _reflection.GeneratedProtocolMessageType('ExportTraceServiceResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTTRACESERVICERESPONSE,
  '__module__' : 'opencensus.proto.agent.trace.v1.trace_service_pb2'
  # @@protoc_insertion_point(class_scope:opencensus.proto.agent.trace.v1.ExportTraceServiceResponse)
  })
_sym_db.RegisterMessage(ExportTraceServiceResponse)


DESCRIPTOR._options = None

_TRACESERVICE = _descriptor.ServiceDescriptor(
  name='TraceService',
  full_name='opencensus.proto.agent.trace.v1.TraceService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=756,
  serialized_end=1034,
  methods=[
  _descriptor.MethodDescriptor(
    name='Config',
    full_name='opencensus.proto.agent.trace.v1.TraceService.Config',
    index=0,
    containing_service=None,
    input_type=_CURRENTLIBRARYCONFIG,
    output_type=_UPDATEDLIBRARYCONFIG,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Export',
    full_name='opencensus.proto.agent.trace.v1.TraceService.Export',
    index=1,
    containing_service=None,
    input_type=_EXPORTTRACESERVICEREQUEST,
    output_type=_EXPORTTRACESERVICERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TRACESERVICE)

DESCRIPTOR.services_by_name['TraceService'] = _TRACESERVICE

# @@protoc_insertion_point(module_scope)
