# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/load_stats/v2/lrs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.endpoint import load_report_pb2 as envoy_dot_api_dot_v2_dot_endpoint_dot_load__report__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/load_stats/v2/lrs.proto',
  package='envoy.service.load_stats.v2',
  syntax='proto3',
  serialized_options=b'\n)io.envoyproxy.envoy.service.load_stats.v2B\010LrsProtoP\001\210\001\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%envoy/service/load_stats/v2/lrs.proto\x12\x1b\x65nvoy.service.load_stats.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\'envoy/api/v2/endpoint/load_report.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\"u\n\x10LoadStatsRequest\x12%\n\x04node\x18\x01 \x01(\x0b\x32\x17.envoy.api.v2.core.Node\x12:\n\rcluster_stats\x18\x02 \x03(\x0b\x32#.envoy.api.v2.endpoint.ClusterStats\"\xa1\x01\n\x11LoadStatsResponse\x12\x10\n\x08\x63lusters\x18\x01 \x03(\t\x12\x19\n\x11send_all_clusters\x18\x04 \x01(\x08\x12:\n\x17load_reporting_interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12#\n\x1breport_endpoint_granularity\x18\x03 \x01(\x08\x32\x8e\x01\n\x14LoadReportingService\x12v\n\x0fStreamLoadStats\x12-.envoy.service.load_stats.v2.LoadStatsRequest\x1a..envoy.service.load_stats.v2.LoadStatsResponse\"\x00(\x01\x30\x01\x42\x42\n)io.envoyproxy.envoy.service.load_stats.v2B\x08LrsProtoP\x01\x88\x01\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_endpoint_dot_load__report__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_LOADSTATSREQUEST = _descriptor.Descriptor(
  name='LoadStatsRequest',
  full_name='envoy.service.load_stats.v2.LoadStatsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='envoy.service.load_stats.v2.LoadStatsRequest.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_stats', full_name='envoy.service.load_stats.v2.LoadStatsRequest.cluster_stats', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=204,
  serialized_end=321,
)


_LOADSTATSRESPONSE = _descriptor.Descriptor(
  name='LoadStatsResponse',
  full_name='envoy.service.load_stats.v2.LoadStatsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clusters', full_name='envoy.service.load_stats.v2.LoadStatsResponse.clusters', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_all_clusters', full_name='envoy.service.load_stats.v2.LoadStatsResponse.send_all_clusters', index=1,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_reporting_interval', full_name='envoy.service.load_stats.v2.LoadStatsResponse.load_reporting_interval', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='report_endpoint_granularity', full_name='envoy.service.load_stats.v2.LoadStatsResponse.report_endpoint_granularity', index=3,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=324,
  serialized_end=485,
)

_LOADSTATSREQUEST.fields_by_name['node'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._NODE
_LOADSTATSREQUEST.fields_by_name['cluster_stats'].message_type = envoy_dot_api_dot_v2_dot_endpoint_dot_load__report__pb2._CLUSTERSTATS
_LOADSTATSRESPONSE.fields_by_name['load_reporting_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['LoadStatsRequest'] = _LOADSTATSREQUEST
DESCRIPTOR.message_types_by_name['LoadStatsResponse'] = _LOADSTATSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LoadStatsRequest = _reflection.GeneratedProtocolMessageType('LoadStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOADSTATSREQUEST,
  '__module__' : 'envoy.service.load_stats.v2.lrs_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.load_stats.v2.LoadStatsRequest)
  })
_sym_db.RegisterMessage(LoadStatsRequest)

LoadStatsResponse = _reflection.GeneratedProtocolMessageType('LoadStatsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOADSTATSRESPONSE,
  '__module__' : 'envoy.service.load_stats.v2.lrs_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.load_stats.v2.LoadStatsResponse)
  })
_sym_db.RegisterMessage(LoadStatsResponse)


DESCRIPTOR._options = None

_LOADREPORTINGSERVICE = _descriptor.ServiceDescriptor(
  name='LoadReportingService',
  full_name='envoy.service.load_stats.v2.LoadReportingService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=488,
  serialized_end=630,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamLoadStats',
    full_name='envoy.service.load_stats.v2.LoadReportingService.StreamLoadStats',
    index=0,
    containing_service=None,
    input_type=_LOADSTATSREQUEST,
    output_type=_LOADSTATSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LOADREPORTINGSERVICE)

DESCRIPTOR.services_by_name['LoadReportingService'] = _LOADREPORTINGSERVICE

# @@protoc_insertion_point(module_scope)
